import{g as kp,R as F,a as dl,r as i,b as Dl,c as Pr,d as xS}from"./react-vendor-DApNTkmZ.js";var Vp={exports:{}};/*!
	Copyright (c) 2018 Jed Watson.
	Licensed under the MIT License (MIT), see
	http://jedwatson.github.io/classnames
*/(function(e){(function(){var t={}.hasOwnProperty;function n(){for(var a="",l=0;l<arguments.length;l++){var s=arguments[l];s&&(a=o(a,r(s)))}return a}function r(a){if(typeof a=="string"||typeof a=="number")return a;if(typeof a!="object")return"";if(Array.isArray(a))return n.apply(null,a);if(a.toString!==Object.prototype.toString&&!a.toString.toString().includes("[native code]"))return a.toString();var l="";for(var s in a)t.call(a,s)&&a[s]&&(l=o(l,s));return l}function o(a,l){return l?a?a+" "+l:a+l:a}e.exports?(n.default=n,e.exports=n):window.classNames=n})()})(Vp);var wS=Vp.exports;const A=kp(wS);function ue(){return ue=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},ue.apply(null,arguments)}function Qe(e){"@babel/helpers - typeof";return Qe=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},Qe(e)}var ES=Symbol.for("react.element"),OS=Symbol.for("react.transitional.element"),IS=Symbol.for("react.fragment");function Wp(e){return e&&Qe(e)==="object"&&(e.$$typeof===ES||e.$$typeof===OS)&&e.type===IS}function xn(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=[];return F.Children.forEach(e,function(r){r==null&&!t.keepEmpty||(Array.isArray(r)?n=n.concat(xn(r)):Wp(r)&&r.props?n=n.concat(xn(r.props.children,t)):n.push(r))}),n}var Uc={},RS=function(t){};function PS(e,t){}function NS(e,t){}function MS(){Uc={}}function Kp(e,t,n){!t&&!Uc[n]&&(e(!1,n),Uc[n]=!0)}function Kt(e,t){Kp(PS,e,t)}function TS(e,t){Kp(NS,e,t)}Kt.preMessage=RS;Kt.resetWarned=MS;Kt.noteOnce=TS;function jS(e,t){if(Qe(e)!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(Qe(r)!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function Gp(e){var t=jS(e,"string");return Qe(t)=="symbol"?t:t+""}function D(e,t,n){return(t=Gp(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Wf(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(o){return Object.getOwnPropertyDescriptor(e,o).enumerable})),n.push.apply(n,r)}return n}function k(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?Wf(Object(n),!0).forEach(function(r){D(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):Wf(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function Wa(e){return e instanceof HTMLElement||e instanceof SVGElement}function _l(e){return e&&Qe(e)==="object"&&Wa(e.nativeElement)?e.nativeElement:Wa(e)?e:null}function qi(e){var t=_l(e);if(t)return t;if(e instanceof F.Component){var n;return(n=dl.findDOMNode)===null||n===void 0?void 0:n.call(dl,e)}return null}var qp={exports:{}},Ut={};/**
 * @license React
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var vd=Symbol.for("react.element"),gd=Symbol.for("react.portal"),Bl=Symbol.for("react.fragment"),Ll=Symbol.for("react.strict_mode"),Hl=Symbol.for("react.profiler"),Al=Symbol.for("react.provider"),Fl=Symbol.for("react.context"),zS=Symbol.for("react.server_context"),kl=Symbol.for("react.forward_ref"),Vl=Symbol.for("react.suspense"),Wl=Symbol.for("react.suspense_list"),Kl=Symbol.for("react.memo"),Gl=Symbol.for("react.lazy"),DS=Symbol.for("react.offscreen"),Up;Up=Symbol.for("react.module.reference");function cr(e){if(typeof e=="object"&&e!==null){var t=e.$$typeof;switch(t){case vd:switch(e=e.type,e){case Bl:case Hl:case Ll:case Vl:case Wl:return e;default:switch(e=e&&e.$$typeof,e){case zS:case Fl:case kl:case Gl:case Kl:case Al:return e;default:return t}}case gd:return t}}}Ut.ContextConsumer=Fl;Ut.ContextProvider=Al;Ut.Element=vd;Ut.ForwardRef=kl;Ut.Fragment=Bl;Ut.Lazy=Gl;Ut.Memo=Kl;Ut.Portal=gd;Ut.Profiler=Hl;Ut.StrictMode=Ll;Ut.Suspense=Vl;Ut.SuspenseList=Wl;Ut.isAsyncMode=function(){return!1};Ut.isConcurrentMode=function(){return!1};Ut.isContextConsumer=function(e){return cr(e)===Fl};Ut.isContextProvider=function(e){return cr(e)===Al};Ut.isElement=function(e){return typeof e=="object"&&e!==null&&e.$$typeof===vd};Ut.isForwardRef=function(e){return cr(e)===kl};Ut.isFragment=function(e){return cr(e)===Bl};Ut.isLazy=function(e){return cr(e)===Gl};Ut.isMemo=function(e){return cr(e)===Kl};Ut.isPortal=function(e){return cr(e)===gd};Ut.isProfiler=function(e){return cr(e)===Hl};Ut.isStrictMode=function(e){return cr(e)===Ll};Ut.isSuspense=function(e){return cr(e)===Vl};Ut.isSuspenseList=function(e){return cr(e)===Wl};Ut.isValidElementType=function(e){return typeof e=="string"||typeof e=="function"||e===Bl||e===Hl||e===Ll||e===Vl||e===Wl||e===DS||typeof e=="object"&&e!==null&&(e.$$typeof===Gl||e.$$typeof===Kl||e.$$typeof===Al||e.$$typeof===Fl||e.$$typeof===kl||e.$$typeof===Up||e.getModuleId!==void 0)};Ut.typeOf=cr;qp.exports=Ut;var Ks=qp.exports;function So(e,t,n){var r=i.useRef({});return(!("value"in r.current)||n(r.current.condition,t))&&(r.current.value=e(),r.current.condition=t),r.current.value}var _S=Number(i.version.split(".")[0]),Ka=function(t,n){typeof t=="function"?t(n):Qe(t)==="object"&&t&&"current"in t&&(t.current=n)},un=function(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];var o=n.filter(Boolean);return o.length<=1?o[0]:function(a){n.forEach(function(l){Ka(l,a)})}},zr=function(){for(var t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return So(function(){return un.apply(void 0,n)},n,function(o,a){return o.length!==a.length||o.every(function(l,s){return l!==a[s]})})},Nr=function(t){var n,r;if(!t)return!1;if(pd(t)&&_S>=19)return!0;var o=Ks.isMemo(t)?t.type.type:t.type;return!(typeof o=="function"&&!((n=o.prototype)!==null&&n!==void 0&&n.render)&&o.$$typeof!==Ks.ForwardRef||typeof t=="function"&&!((r=t.prototype)!==null&&r!==void 0&&r.render)&&t.$$typeof!==Ks.ForwardRef)};function pd(e){return i.isValidElement(e)&&!Wp(e)}var BS=function(t){return pd(t)&&Nr(t)},$o=function(t){if(t&&pd(t)){var n=t;return n.props.propertyIsEnumerable("ref")?n.props.ref:n.ref}return null},Xc=i.createContext(null);function LS(e){var t=e.children,n=e.onBatchResize,r=i.useRef(0),o=i.useRef([]),a=i.useContext(Xc),l=i.useCallback(function(s,c,u){r.current+=1;var d=r.current;o.current.push({size:s,element:c,data:u}),Promise.resolve().then(function(){d===r.current&&(n==null||n(o.current),o.current=[])}),a==null||a(s,c,u)},[n,a]);return i.createElement(Xc.Provider,{value:l},t)}var Xp=function(){if(typeof Map<"u")return Map;function e(t,n){var r=-1;return t.some(function(o,a){return o[0]===n?(r=a,!0):!1}),r}return function(){function t(){this.__entries__=[]}return Object.defineProperty(t.prototype,"size",{get:function(){return this.__entries__.length},enumerable:!0,configurable:!0}),t.prototype.get=function(n){var r=e(this.__entries__,n),o=this.__entries__[r];return o&&o[1]},t.prototype.set=function(n,r){var o=e(this.__entries__,n);~o?this.__entries__[o][1]=r:this.__entries__.push([n,r])},t.prototype.delete=function(n){var r=this.__entries__,o=e(r,n);~o&&r.splice(o,1)},t.prototype.has=function(n){return!!~e(this.__entries__,n)},t.prototype.clear=function(){this.__entries__.splice(0)},t.prototype.forEach=function(n,r){r===void 0&&(r=null);for(var o=0,a=this.__entries__;o<a.length;o++){var l=a[o];n.call(r,l[1],l[0])}},t}()}(),Yc=typeof window<"u"&&typeof document<"u"&&window.document===document,fl=function(){return typeof global<"u"&&global.Math===Math?global:typeof self<"u"&&self.Math===Math?self:typeof window<"u"&&window.Math===Math?window:Function("return this")()}(),HS=function(){return typeof requestAnimationFrame=="function"?requestAnimationFrame.bind(fl):function(e){return setTimeout(function(){return e(Date.now())},1e3/60)}}(),AS=2;function FS(e,t){var n=!1,r=!1,o=0;function a(){n&&(n=!1,e()),r&&s()}function l(){HS(a)}function s(){var c=Date.now();if(n){if(c-o<AS)return;r=!0}else n=!0,r=!1,setTimeout(l,t);o=c}return s}var kS=20,VS=["top","right","bottom","left","width","height","size","weight"],WS=typeof MutationObserver<"u",KS=function(){function e(){this.connected_=!1,this.mutationEventsAdded_=!1,this.mutationsObserver_=null,this.observers_=[],this.onTransitionEnd_=this.onTransitionEnd_.bind(this),this.refresh=FS(this.refresh.bind(this),kS)}return e.prototype.addObserver=function(t){~this.observers_.indexOf(t)||this.observers_.push(t),this.connected_||this.connect_()},e.prototype.removeObserver=function(t){var n=this.observers_,r=n.indexOf(t);~r&&n.splice(r,1),!n.length&&this.connected_&&this.disconnect_()},e.prototype.refresh=function(){var t=this.updateObservers_();t&&this.refresh()},e.prototype.updateObservers_=function(){var t=this.observers_.filter(function(n){return n.gatherActive(),n.hasActive()});return t.forEach(function(n){return n.broadcastActive()}),t.length>0},e.prototype.connect_=function(){!Yc||this.connected_||(document.addEventListener("transitionend",this.onTransitionEnd_),window.addEventListener("resize",this.refresh),WS?(this.mutationsObserver_=new MutationObserver(this.refresh),this.mutationsObserver_.observe(document,{attributes:!0,childList:!0,characterData:!0,subtree:!0})):(document.addEventListener("DOMSubtreeModified",this.refresh),this.mutationEventsAdded_=!0),this.connected_=!0)},e.prototype.disconnect_=function(){!Yc||!this.connected_||(document.removeEventListener("transitionend",this.onTransitionEnd_),window.removeEventListener("resize",this.refresh),this.mutationsObserver_&&this.mutationsObserver_.disconnect(),this.mutationEventsAdded_&&document.removeEventListener("DOMSubtreeModified",this.refresh),this.mutationsObserver_=null,this.mutationEventsAdded_=!1,this.connected_=!1)},e.prototype.onTransitionEnd_=function(t){var n=t.propertyName,r=n===void 0?"":n,o=VS.some(function(a){return!!~r.indexOf(a)});o&&this.refresh()},e.getInstance=function(){return this.instance_||(this.instance_=new e),this.instance_},e.instance_=null,e}(),Yp=function(e,t){for(var n=0,r=Object.keys(t);n<r.length;n++){var o=r[n];Object.defineProperty(e,o,{value:t[o],enumerable:!1,writable:!1,configurable:!0})}return e},Xo=function(e){var t=e&&e.ownerDocument&&e.ownerDocument.defaultView;return t||fl},Qp=ql(0,0,0,0);function ml(e){return parseFloat(e)||0}function Kf(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return t.reduce(function(r,o){var a=e["border-"+o+"-width"];return r+ml(a)},0)}function GS(e){for(var t=["top","right","bottom","left"],n={},r=0,o=t;r<o.length;r++){var a=o[r],l=e["padding-"+a];n[a]=ml(l)}return n}function qS(e){var t=e.getBBox();return ql(0,0,t.width,t.height)}function US(e){var t=e.clientWidth,n=e.clientHeight;if(!t&&!n)return Qp;var r=Xo(e).getComputedStyle(e),o=GS(r),a=o.left+o.right,l=o.top+o.bottom,s=ml(r.width),c=ml(r.height);if(r.boxSizing==="border-box"&&(Math.round(s+a)!==t&&(s-=Kf(r,"left","right")+a),Math.round(c+l)!==n&&(c-=Kf(r,"top","bottom")+l)),!YS(e)){var u=Math.round(s+a)-t,d=Math.round(c+l)-n;Math.abs(u)!==1&&(s-=u),Math.abs(d)!==1&&(c-=d)}return ql(o.left,o.top,s,c)}var XS=function(){return typeof SVGGraphicsElement<"u"?function(e){return e instanceof Xo(e).SVGGraphicsElement}:function(e){return e instanceof Xo(e).SVGElement&&typeof e.getBBox=="function"}}();function YS(e){return e===Xo(e).document.documentElement}function QS(e){return Yc?XS(e)?qS(e):US(e):Qp}function ZS(e){var t=e.x,n=e.y,r=e.width,o=e.height,a=typeof DOMRectReadOnly<"u"?DOMRectReadOnly:Object,l=Object.create(a.prototype);return Yp(l,{x:t,y:n,width:r,height:o,top:n,right:t+r,bottom:o+n,left:t}),l}function ql(e,t,n,r){return{x:e,y:t,width:n,height:r}}var JS=function(){function e(t){this.broadcastWidth=0,this.broadcastHeight=0,this.contentRect_=ql(0,0,0,0),this.target=t}return e.prototype.isActive=function(){var t=QS(this.target);return this.contentRect_=t,t.width!==this.broadcastWidth||t.height!==this.broadcastHeight},e.prototype.broadcastRect=function(){var t=this.contentRect_;return this.broadcastWidth=t.width,this.broadcastHeight=t.height,t},e}(),e1=function(){function e(t,n){var r=ZS(n);Yp(this,{target:t,contentRect:r})}return e}(),t1=function(){function e(t,n,r){if(this.activeObservations_=[],this.observations_=new Xp,typeof t!="function")throw new TypeError("The callback provided as parameter 1 is not a function.");this.callback_=t,this.controller_=n,this.callbackCtx_=r}return e.prototype.observe=function(t){if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");if(!(typeof Element>"u"||!(Element instanceof Object))){if(!(t instanceof Xo(t).Element))throw new TypeError('parameter 1 is not of type "Element".');var n=this.observations_;n.has(t)||(n.set(t,new JS(t)),this.controller_.addObserver(this),this.controller_.refresh())}},e.prototype.unobserve=function(t){if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");if(!(typeof Element>"u"||!(Element instanceof Object))){if(!(t instanceof Xo(t).Element))throw new TypeError('parameter 1 is not of type "Element".');var n=this.observations_;n.has(t)&&(n.delete(t),n.size||this.controller_.removeObserver(this))}},e.prototype.disconnect=function(){this.clearActive(),this.observations_.clear(),this.controller_.removeObserver(this)},e.prototype.gatherActive=function(){var t=this;this.clearActive(),this.observations_.forEach(function(n){n.isActive()&&t.activeObservations_.push(n)})},e.prototype.broadcastActive=function(){if(this.hasActive()){var t=this.callbackCtx_,n=this.activeObservations_.map(function(r){return new e1(r.target,r.broadcastRect())});this.callback_.call(t,n,t),this.clearActive()}},e.prototype.clearActive=function(){this.activeObservations_.splice(0)},e.prototype.hasActive=function(){return this.activeObservations_.length>0},e}(),Zp=typeof WeakMap<"u"?new WeakMap:new Xp,Jp=function(){function e(t){if(!(this instanceof e))throw new TypeError("Cannot call a class as a function.");if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");var n=KS.getInstance(),r=new t1(t,n,this);Zp.set(this,r)}return e}();["observe","unobserve","disconnect"].forEach(function(e){Jp.prototype[e]=function(){var t;return(t=Zp.get(this))[e].apply(t,arguments)}});var n1=function(){return typeof fl.ResizeObserver<"u"?fl.ResizeObserver:Jp}(),Ur=new Map;function r1(e){e.forEach(function(t){var n,r=t.target;(n=Ur.get(r))===null||n===void 0||n.forEach(function(o){return o(r)})})}var eh=new n1(r1);function o1(e,t){Ur.has(e)||(Ur.set(e,new Set),eh.observe(e)),Ur.get(e).add(t)}function a1(e,t){Ur.has(e)&&(Ur.get(e).delete(t),Ur.get(e).size||(eh.unobserve(e),Ur.delete(e)))}function Zt(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function Gf(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,Gp(r.key),r)}}function Jt(e,t,n){return t&&Gf(e.prototype,t),n&&Gf(e,n),Object.defineProperty(e,"prototype",{writable:!1}),e}function Ga(e,t){return Ga=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,r){return n.__proto__=r,n},Ga(e,t)}function tr(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&Ga(e,t)}function ho(e){return ho=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},ho(e)}function Ul(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(Ul=function(){return!!e})()}function Ve(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function th(e,t){if(t&&(Qe(t)=="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return Ve(e)}function ur(e){var t=Ul();return function(){var n,r=ho(e);if(t){var o=ho(this).constructor;n=Reflect.construct(r,arguments,o)}else n=r.apply(this,arguments);return th(this,n)}}var i1=function(e){tr(n,e);var t=ur(n);function n(){return Zt(this,n),t.apply(this,arguments)}return Jt(n,[{key:"render",value:function(){return this.props.children}}]),n}(i.Component);function l1(e,t){var n=e.children,r=e.disabled,o=i.useRef(null),a=i.useRef(null),l=i.useContext(Xc),s=typeof n=="function",c=s?n(o):n,u=i.useRef({width:-1,height:-1,offsetWidth:-1,offsetHeight:-1}),d=!s&&i.isValidElement(c)&&Nr(c),f=d?$o(c):null,m=zr(f,o),v=function(){var b;return qi(o.current)||(o.current&&Qe(o.current)==="object"?qi((b=o.current)===null||b===void 0?void 0:b.nativeElement):null)||qi(a.current)};i.useImperativeHandle(t,function(){return v()});var g=i.useRef(e);g.current=e;var h=i.useCallback(function(p){var b=g.current,y=b.onResize,C=b.data,$=p.getBoundingClientRect(),S=$.width,x=$.height,E=p.offsetWidth,O=p.offsetHeight,w=Math.floor(S),I=Math.floor(x);if(u.current.width!==w||u.current.height!==I||u.current.offsetWidth!==E||u.current.offsetHeight!==O){var P={width:w,height:I,offsetWidth:E,offsetHeight:O};u.current=P;var M=E===Math.round(S)?S:E,R=O===Math.round(x)?x:O,N=k(k({},P),{},{offsetWidth:M,offsetHeight:R});l==null||l(N,p,C),y&&Promise.resolve().then(function(){y(N,p)})}},[]);return i.useEffect(function(){var p=v();return p&&!r&&o1(p,h),function(){return a1(p,h)}},[o.current,r]),i.createElement(i1,{ref:a},d?i.cloneElement(c,{ref:m}):c)}var s1=i.forwardRef(l1),c1="rc-observer-key";function u1(e,t){var n=e.children,r=typeof n=="function"?[n]:xn(n);return r.map(function(o,a){var l=(o==null?void 0:o.key)||"".concat(c1,"-").concat(a);return i.createElement(s1,ue({},e,{key:l,ref:a===0?t:void 0}),o)})}var Bn=i.forwardRef(u1);Bn.Collection=LS;function Qc(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function d1(e){if(Array.isArray(e))return Qc(e)}function nh(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function hd(e,t){if(e){if(typeof e=="string")return Qc(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Qc(e,t):void 0}}function f1(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function pe(e){return d1(e)||nh(e)||hd(e)||f1()}var rh=function(t){return+setTimeout(t,16)},oh=function(t){return clearTimeout(t)};typeof window<"u"&&"requestAnimationFrame"in window&&(rh=function(t){return window.requestAnimationFrame(t)},oh=function(t){return window.cancelAnimationFrame(t)});var qf=0,bd=new Map;function ah(e){bd.delete(e)}var Et=function(t){var n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:1;qf+=1;var r=qf;function o(a){if(a===0)ah(r),t();else{var l=rh(function(){o(a-1)});bd.set(r,l)}}return o(n),r};Et.cancel=function(e){var t=bd.get(e);return ah(e),oh(t)};function ih(e){if(Array.isArray(e))return e}function m1(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r,o,a,l,s=[],c=!0,u=!1;try{if(a=(n=n.call(e)).next,t===0){if(Object(n)!==n)return;c=!1}else for(;!(c=(r=a.call(n)).done)&&(s.push(r.value),s.length!==t);c=!0);}catch(d){u=!0,o=d}finally{try{if(!c&&n.return!=null&&(l=n.return(),Object(l)!==l))return}finally{if(u)throw o}}return s}}function lh(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function J(e,t){return ih(e)||m1(e,t)||hd(e,t)||lh()}function qa(e){for(var t=0,n,r=0,o=e.length;o>=4;++r,o-=4)n=e.charCodeAt(r)&255|(e.charCodeAt(++r)&255)<<8|(e.charCodeAt(++r)&255)<<16|(e.charCodeAt(++r)&255)<<24,n=(n&65535)*1540483477+((n>>>16)*59797<<16),n^=n>>>24,t=(n&65535)*1540483477+((n>>>16)*59797<<16)^(t&65535)*1540483477+((t>>>16)*59797<<16);switch(o){case 3:t^=(e.charCodeAt(r+2)&255)<<16;case 2:t^=(e.charCodeAt(r+1)&255)<<8;case 1:t^=e.charCodeAt(r)&255,t=(t&65535)*1540483477+((t>>>16)*59797<<16)}return t^=t>>>13,t=(t&65535)*1540483477+((t>>>16)*59797<<16),((t^t>>>15)>>>0).toString(36)}function wn(){return!!(typeof window<"u"&&window.document&&window.document.createElement)}function Zc(e,t){if(!e)return!1;if(e.contains)return e.contains(t);for(var n=t;n;){if(n===e)return!0;n=n.parentNode}return!1}var Uf="data-rc-order",Xf="data-rc-priority",v1="rc-util-key",Jc=new Map;function sh(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},t=e.mark;return t?t.startsWith("data-")?t:"data-".concat(t):v1}function Xl(e){if(e.attachTo)return e.attachTo;var t=document.querySelector("head");return t||document.body}function g1(e){return e==="queue"?"prependQueue":e?"prepend":"append"}function yd(e){return Array.from((Jc.get(e)||e).children).filter(function(t){return t.tagName==="STYLE"})}function ch(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};if(!wn())return null;var n=t.csp,r=t.prepend,o=t.priority,a=o===void 0?0:o,l=g1(r),s=l==="prependQueue",c=document.createElement("style");c.setAttribute(Uf,l),s&&a&&c.setAttribute(Xf,"".concat(a)),n!=null&&n.nonce&&(c.nonce=n==null?void 0:n.nonce),c.innerHTML=e;var u=Xl(t),d=u.firstChild;if(r){if(s){var f=(t.styles||yd(u)).filter(function(m){if(!["prepend","prependQueue"].includes(m.getAttribute(Uf)))return!1;var v=Number(m.getAttribute(Xf)||0);return a>=v});if(f.length)return u.insertBefore(c,f[f.length-1].nextSibling),c}u.insertBefore(c,d)}else u.appendChild(c);return c}function uh(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=Xl(t);return(t.styles||yd(n)).find(function(r){return r.getAttribute(sh(t))===e})}function Ua(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=uh(e,t);if(n){var r=Xl(t);r.removeChild(n)}}function p1(e,t){var n=Jc.get(e);if(!n||!Zc(document,n)){var r=ch("",t),o=r.parentNode;Jc.set(e,o),e.removeChild(r)}}function Ar(e,t){var n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},r=Xl(n),o=yd(r),a=k(k({},n),{},{styles:o});p1(r,a);var l=uh(t,a);if(l){var s,c;if((s=a.csp)!==null&&s!==void 0&&s.nonce&&l.nonce!==((c=a.csp)===null||c===void 0?void 0:c.nonce)){var u;l.nonce=(u=a.csp)===null||u===void 0?void 0:u.nonce}return l.innerHTML!==e&&(l.innerHTML=e),l}var d=ch(e,a);return d.setAttribute(sh(a),t),d}function h1(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function ft(e,t){if(e==null)return{};var n,r,o=h1(e,t);if(Object.getOwnPropertySymbols){var a=Object.getOwnPropertySymbols(e);for(r=0;r<a.length;r++)n=a[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(o[n]=e[n])}return o}function hr(e,t){var n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1,r=new Set;function o(a,l){var s=arguments.length>2&&arguments[2]!==void 0?arguments[2]:1,c=r.has(a);if(Kt(!c,"Warning: There may be circular references"),c)return!1;if(a===l)return!0;if(n&&s>1)return!1;r.add(a);var u=s+1;if(Array.isArray(a)){if(!Array.isArray(l)||a.length!==l.length)return!1;for(var d=0;d<a.length;d++)if(!o(a[d],l[d],u))return!1;return!0}if(a&&l&&Qe(a)==="object"&&Qe(l)==="object"){var f=Object.keys(a);return f.length!==Object.keys(l).length?!1:f.every(function(m){return o(a[m],l[m],u)})}return!1}return o(e,t)}var b1="%";function eu(e){return e.join(b1)}var y1=function(){function e(t){Zt(this,e),D(this,"instanceId",void 0),D(this,"cache",new Map),D(this,"extracted",new Set),this.instanceId=t}return Jt(e,[{key:"get",value:function(n){return this.opGet(eu(n))}},{key:"opGet",value:function(n){return this.cache.get(n)||null}},{key:"update",value:function(n,r){return this.opUpdate(eu(n),r)}},{key:"opUpdate",value:function(n,r){var o=this.cache.get(n),a=r(o);a===null?this.cache.delete(n):this.cache.set(n,a)}}]),e}(),Yo="data-token-hash",gr="data-css-hash",Xr="__cssinjs_instance__";function C1(){var e=Math.random().toString(12).slice(2);if(typeof document<"u"&&document.head&&document.body){var t=document.body.querySelectorAll("style[".concat(gr,"]"))||[],n=document.head.firstChild;Array.from(t).forEach(function(o){o[Xr]=o[Xr]||e,o[Xr]===e&&document.head.insertBefore(o,n)});var r={};Array.from(document.querySelectorAll("style[".concat(gr,"]"))).forEach(function(o){var a=o.getAttribute(gr);if(r[a]){if(o[Xr]===e){var l;(l=o.parentNode)===null||l===void 0||l.removeChild(o)}}else r[a]=!0})}return new y1(e)}var ai=i.createContext({hashPriority:"low",cache:C1(),defaultCache:!0});function S1(e,t){if(e.length!==t.length)return!1;for(var n=0;n<e.length;n++)if(e[n]!==t[n])return!1;return!0}var Cd=function(){function e(){Zt(this,e),D(this,"cache",void 0),D(this,"keys",void 0),D(this,"cacheCallTimes",void 0),this.cache=new Map,this.keys=[],this.cacheCallTimes=0}return Jt(e,[{key:"size",value:function(){return this.keys.length}},{key:"internalGet",value:function(n){var r,o,a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,l={map:this.cache};return n.forEach(function(s){if(!l)l=void 0;else{var c;l=(c=l)===null||c===void 0||(c=c.map)===null||c===void 0?void 0:c.get(s)}}),(r=l)!==null&&r!==void 0&&r.value&&a&&(l.value[1]=this.cacheCallTimes++),(o=l)===null||o===void 0?void 0:o.value}},{key:"get",value:function(n){var r;return(r=this.internalGet(n,!0))===null||r===void 0?void 0:r[0]}},{key:"has",value:function(n){return!!this.internalGet(n)}},{key:"set",value:function(n,r){var o=this;if(!this.has(n)){if(this.size()+1>e.MAX_CACHE_SIZE+e.MAX_CACHE_OFFSET){var a=this.keys.reduce(function(u,d){var f=J(u,2),m=f[1];return o.internalGet(d)[1]<m?[d,o.internalGet(d)[1]]:u},[this.keys[0],this.cacheCallTimes]),l=J(a,1),s=l[0];this.delete(s)}this.keys.push(n)}var c=this.cache;n.forEach(function(u,d){if(d===n.length-1)c.set(u,{value:[r,o.cacheCallTimes++]});else{var f=c.get(u);f?f.map||(f.map=new Map):c.set(u,{map:new Map}),c=c.get(u).map}})}},{key:"deleteByPath",value:function(n,r){var o=n.get(r[0]);if(r.length===1){var a;return o.map?n.set(r[0],{map:o.map}):n.delete(r[0]),(a=o.value)===null||a===void 0?void 0:a[0]}var l=this.deleteByPath(o.map,r.slice(1));return(!o.map||o.map.size===0)&&!o.value&&n.delete(r[0]),l}},{key:"delete",value:function(n){if(this.has(n))return this.keys=this.keys.filter(function(r){return!S1(r,n)}),this.deleteByPath(this.cache,n)}}]),e}();D(Cd,"MAX_CACHE_SIZE",20);D(Cd,"MAX_CACHE_OFFSET",5);var Yf=0,dh=function(){function e(t){Zt(this,e),D(this,"derivatives",void 0),D(this,"id",void 0),this.derivatives=Array.isArray(t)?t:[t],this.id=Yf,t.length===0&&(t.length>0,void 0),Yf+=1}return Jt(e,[{key:"getDerivativeToken",value:function(n){return this.derivatives.reduce(function(r,o){return o(n,r)},void 0)}}]),e}(),Gs=new Cd;function tu(e){var t=Array.isArray(e)?e:[e];return Gs.has(t)||Gs.set(t,new dh(t)),Gs.get(t)}var $1=new WeakMap,qs={};function x1(e,t){for(var n=$1,r=0;r<t.length;r+=1){var o=t[r];n.has(o)||n.set(o,new WeakMap),n=n.get(o)}return n.has(qs)||n.set(qs,e()),n.get(qs)}var Qf=new WeakMap;function La(e){var t=Qf.get(e)||"";return t||(Object.keys(e).forEach(function(n){var r=e[n];t+=n,r instanceof dh?t+=r.id:r&&Qe(r)==="object"?t+=La(r):t+=r}),t=qa(t),Qf.set(e,t)),t}function Zf(e,t){return qa("".concat(t,"_").concat(La(e)))}var nu=wn();function L(e){return typeof e=="number"?"".concat(e,"px"):e}function vl(e,t,n){var r=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{},o=arguments.length>4&&arguments[4]!==void 0?arguments[4]:!1;if(o)return e;var a=k(k({},r),{},D(D({},Yo,t),gr,n)),l=Object.keys(a).map(function(s){var c=a[s];return c?"".concat(s,'="').concat(c,'"'):null}).filter(function(s){return s}).join(" ");return"<style ".concat(l,">").concat(e,"</style>")}var Ui=function(t){var n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"";return"--".concat(n?"".concat(n,"-"):"").concat(t).replace(/([a-z0-9])([A-Z])/g,"$1-$2").replace(/([A-Z]+)([A-Z][a-z0-9]+)/g,"$1-$2").replace(/([a-z])([A-Z0-9])/g,"$1-$2").toLowerCase()},w1=function(t,n,r){return Object.keys(t).length?".".concat(n).concat(r!=null&&r.scope?".".concat(r.scope):"","{").concat(Object.entries(t).map(function(o){var a=J(o,2),l=a[0],s=a[1];return"".concat(l,":").concat(s,";")}).join(""),"}"):""},fh=function(t,n,r){var o={},a={};return Object.entries(t).forEach(function(l){var s,c,u=J(l,2),d=u[0],f=u[1];if(r!=null&&(s=r.preserve)!==null&&s!==void 0&&s[d])a[d]=f;else if((typeof f=="string"||typeof f=="number")&&!(r!=null&&(c=r.ignore)!==null&&c!==void 0&&c[d])){var m,v=Ui(d,r==null?void 0:r.prefix);o[v]=typeof f=="number"&&!(r!=null&&(m=r.unitless)!==null&&m!==void 0&&m[d])?"".concat(f,"px"):String(f),a[d]="var(".concat(v,")")}}),[a,w1(o,n,{scope:r==null?void 0:r.scope})]},Jf=wn()?i.useLayoutEffect:i.useEffect,wt=function(t,n){var r=i.useRef(!0);Jf(function(){return t(r.current)},n),Jf(function(){return r.current=!1,function(){r.current=!0}},[])},Fo=function(t,n){wt(function(r){if(!r)return t()},n)},E1=k({},Dl),em=E1.useInsertionEffect,O1=function(t,n,r){i.useMemo(t,r),wt(function(){return n(!0)},r)},I1=em?function(e,t,n){return em(function(){return e(),t()},n)}:O1,R1=k({},Dl),P1=R1.useInsertionEffect,N1=function(t){var n=[],r=!1;function o(a){r||n.push(a)}return i.useEffect(function(){return r=!1,function(){r=!0,n.length&&n.forEach(function(a){return a()})}},t),o},M1=function(){return function(t){t()}},T1=typeof P1<"u"?N1:M1;function Sd(e,t,n,r,o){var a=i.useContext(ai),l=a.cache,s=[e].concat(pe(t)),c=eu(s),u=T1([c]),d=function(g){l.opUpdate(c,function(h){var p=h||[void 0,void 0],b=J(p,2),y=b[0],C=y===void 0?0:y,$=b[1],S=$,x=S||n(),E=[C,x];return g?g(E):E})};i.useMemo(function(){d()},[c]);var f=l.opGet(c),m=f[1];return I1(function(){o==null||o(m)},function(v){return d(function(g){var h=J(g,2),p=h[0],b=h[1];return v&&p===0&&(o==null||o(m)),[p+1,b]}),function(){l.opUpdate(c,function(g){var h=g||[],p=J(h,2),b=p[0],y=b===void 0?0:b,C=p[1],$=y-1;return $===0?(u(function(){(v||!l.opGet(c))&&(r==null||r(C,!1))}),null):[y-1,C]})}},[c]),m}var j1={},z1="css",lo=new Map;function D1(e){lo.set(e,(lo.get(e)||0)+1)}function _1(e,t){if(typeof document<"u"){var n=document.querySelectorAll("style[".concat(Yo,'="').concat(e,'"]'));n.forEach(function(r){if(r[Xr]===t){var o;(o=r.parentNode)===null||o===void 0||o.removeChild(r)}})}}var B1=0;function L1(e,t){lo.set(e,(lo.get(e)||0)-1);var n=new Set;lo.forEach(function(r,o){r<=0&&n.add(o)}),lo.size-n.size>B1&&n.forEach(function(r){_1(r,t),lo.delete(r)})}var H1=function(t,n,r,o){var a=r.getDerivativeToken(t),l=k(k({},a),n);return o&&(l=o(l)),l},mh="token";function A1(e,t){var n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},r=i.useContext(ai),o=r.cache.instanceId,a=r.container,l=n.salt,s=l===void 0?"":l,c=n.override,u=c===void 0?j1:c,d=n.formatToken,f=n.getComputedToken,m=n.cssVar,v=x1(function(){return Object.assign.apply(Object,[{}].concat(pe(t)))},t),g=La(v),h=La(u),p=m?La(m):"",b=Sd(mh,[s,e.id,g,h,p],function(){var y,C=f?f(v,u,e):H1(v,u,e,d),$=k({},C),S="";if(m){var x=fh(C,m.key,{prefix:m.prefix,ignore:m.ignore,unitless:m.unitless,preserve:m.preserve}),E=J(x,2);C=E[0],S=E[1]}var O=Zf(C,s);C._tokenKey=O,$._tokenKey=Zf($,s);var w=(y=m==null?void 0:m.key)!==null&&y!==void 0?y:O;C._themeKey=w,D1(w);var I="".concat(z1,"-").concat(qa(O));return C._hashId=I,[C,I,$,S,(m==null?void 0:m.key)||""]},function(y){L1(y[0]._themeKey,o)},function(y){var C=J(y,4),$=C[0],S=C[3];if(m&&S){var x=Ar(S,qa("css-variables-".concat($._themeKey)),{mark:gr,prepend:"queue",attachTo:a,priority:-999});x[Xr]=o,x.setAttribute(Yo,$._themeKey)}});return b}var F1=function(t,n,r){var o=J(t,5),a=o[2],l=o[3],s=o[4],c=r||{},u=c.plain;if(!l)return null;var d=a._tokenKey,f=-999,m={"data-rc-order":"prependQueue","data-rc-priority":"".concat(f)},v=vl(l,s,d,m,u);return[f,d,v]},k1={animationIterationCount:1,borderImageOutset:1,borderImageSlice:1,borderImageWidth:1,boxFlex:1,boxFlexGroup:1,boxOrdinalGroup:1,columnCount:1,columns:1,flex:1,flexGrow:1,flexPositive:1,flexShrink:1,flexNegative:1,flexOrder:1,gridRow:1,gridRowEnd:1,gridRowSpan:1,gridRowStart:1,gridColumn:1,gridColumnEnd:1,gridColumnSpan:1,gridColumnStart:1,msGridRow:1,msGridRowSpan:1,msGridColumn:1,msGridColumnSpan:1,fontWeight:1,lineHeight:1,opacity:1,order:1,orphans:1,tabSize:1,widows:1,zIndex:1,zoom:1,WebkitLineClamp:1,fillOpacity:1,floodOpacity:1,stopOpacity:1,strokeDasharray:1,strokeDashoffset:1,strokeMiterlimit:1,strokeOpacity:1,strokeWidth:1},vh="comm",gh="rule",ph="decl",V1="@import",W1="@namespace",K1="@keyframes",G1="@layer",hh=Math.abs,$d=String.fromCharCode;function bh(e){return e.trim()}function Xi(e,t,n){return e.replace(t,n)}function q1(e,t,n){return e.indexOf(t,n)}function ko(e,t){return e.charCodeAt(t)|0}function Qo(e,t,n){return e.slice(t,n)}function Ir(e){return e.length}function U1(e){return e.length}function Ni(e,t){return t.push(e),e}var Yl=1,Zo=1,yh=0,lr=0,mn=0,ca="";function xd(e,t,n,r,o,a,l,s){return{value:e,root:t,parent:n,type:r,props:o,children:a,line:Yl,column:Zo,length:l,return:"",siblings:s}}function X1(){return mn}function Y1(){return mn=lr>0?ko(ca,--lr):0,Zo--,mn===10&&(Zo=1,Yl--),mn}function pr(){return mn=lr<yh?ko(ca,lr++):0,Zo++,mn===10&&(Zo=1,Yl++),mn}function Yr(){return ko(ca,lr)}function Yi(){return lr}function Ql(e,t){return Qo(ca,e,t)}function Xa(e){switch(e){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function Q1(e){return Yl=Zo=1,yh=Ir(ca=e),lr=0,[]}function Z1(e){return ca="",e}function Us(e){return bh(Ql(lr-1,ru(e===91?e+2:e===40?e+1:e)))}function J1(e){for(;(mn=Yr())&&mn<33;)pr();return Xa(e)>2||Xa(mn)>3?"":" "}function e$(e,t){for(;--t&&pr()&&!(mn<48||mn>102||mn>57&&mn<65||mn>70&&mn<97););return Ql(e,Yi()+(t<6&&Yr()==32&&pr()==32))}function ru(e){for(;pr();)switch(mn){case e:return lr;case 34:case 39:e!==34&&e!==39&&ru(mn);break;case 40:e===41&&ru(e);break;case 92:pr();break}return lr}function t$(e,t){for(;pr()&&e+mn!==57;)if(e+mn===84&&Yr()===47)break;return"/*"+Ql(t,lr-1)+"*"+$d(e===47?e:pr())}function n$(e){for(;!Xa(Yr());)pr();return Ql(e,lr)}function r$(e){return Z1(Qi("",null,null,null,[""],e=Q1(e),0,[0],e))}function Qi(e,t,n,r,o,a,l,s,c){for(var u=0,d=0,f=l,m=0,v=0,g=0,h=1,p=1,b=1,y=0,C="",$=o,S=a,x=r,E=C;p;)switch(g=y,y=pr()){case 40:if(g!=108&&ko(E,f-1)==58){q1(E+=Xi(Us(y),"&","&\f"),"&\f",hh(u?s[u-1]:0))!=-1&&(b=-1);break}case 34:case 39:case 91:E+=Us(y);break;case 9:case 10:case 13:case 32:E+=J1(g);break;case 92:E+=e$(Yi()-1,7);continue;case 47:switch(Yr()){case 42:case 47:Ni(o$(t$(pr(),Yi()),t,n,c),c),(Xa(g||1)==5||Xa(Yr()||1)==5)&&Ir(E)&&Qo(E,-1,void 0)!==" "&&(E+=" ");break;default:E+="/"}break;case 123*h:s[u++]=Ir(E)*b;case 125*h:case 59:case 0:switch(y){case 0:case 125:p=0;case 59+d:b==-1&&(E=Xi(E,/\f/g,"")),v>0&&(Ir(E)-f||h===0&&g===47)&&Ni(v>32?nm(E+";",r,n,f-1,c):nm(Xi(E," ","")+";",r,n,f-2,c),c);break;case 59:E+=";";default:if(Ni(x=tm(E,t,n,u,d,o,s,C,$=[],S=[],f,a),a),y===123)if(d===0)Qi(E,t,x,x,$,a,f,s,S);else{switch(m){case 99:if(ko(E,3)===110)break;case 108:if(ko(E,2)===97)break;default:d=0;case 100:case 109:case 115:}d?Qi(e,x,x,r&&Ni(tm(e,x,x,0,0,o,s,C,o,$=[],f,S),S),o,S,f,s,r?$:S):Qi(E,x,x,x,[""],S,0,s,S)}}u=d=v=0,h=b=1,C=E="",f=l;break;case 58:f=1+Ir(E),v=g;default:if(h<1){if(y==123)--h;else if(y==125&&h++==0&&Y1()==125)continue}switch(E+=$d(y),y*h){case 38:b=d>0?1:(E+="\f",-1);break;case 44:s[u++]=(Ir(E)-1)*b,b=1;break;case 64:Yr()===45&&(E+=Us(pr())),m=Yr(),d=f=Ir(C=E+=n$(Yi())),y++;break;case 45:g===45&&Ir(E)==2&&(h=0)}}return a}function tm(e,t,n,r,o,a,l,s,c,u,d,f){for(var m=o-1,v=o===0?a:[""],g=U1(v),h=0,p=0,b=0;h<r;++h)for(var y=0,C=Qo(e,m+1,m=hh(p=l[h])),$=e;y<g;++y)($=bh(p>0?v[y]+" "+C:Xi(C,/&\f/g,v[y])))&&(c[b++]=$);return xd(e,t,n,o===0?gh:s,c,u,d,f)}function o$(e,t,n,r){return xd(e,t,n,vh,$d(X1()),Qo(e,2,-2),0,r)}function nm(e,t,n,r,o){return xd(e,t,n,ph,Qo(e,0,r),Qo(e,r+1,-1),r,o)}function ou(e,t){for(var n="",r=0;r<e.length;r++)n+=t(e[r],r,e,t)||"";return n}function a$(e,t,n,r){switch(e.type){case G1:if(e.children.length)break;case V1:case W1:case ph:return e.return=e.return||e.value;case vh:return"";case K1:return e.return=e.value+"{"+ou(e.children,r)+"}";case gh:if(!Ir(e.value=e.props.join(",")))return""}return Ir(n=ou(e.children,r))?e.return=e.value+"{"+n+"}":""}var rm="data-ant-cssinjs-cache-path",Ch="_FILE_STYLE__",vo,Sh=!0;function i$(){if(!vo&&(vo={},wn())){var e=document.createElement("div");e.className=rm,e.style.position="fixed",e.style.visibility="hidden",e.style.top="-9999px",document.body.appendChild(e);var t=getComputedStyle(e).content||"";t=t.replace(/^"/,"").replace(/"$/,""),t.split(";").forEach(function(o){var a=o.split(":"),l=J(a,2),s=l[0],c=l[1];vo[s]=c});var n=document.querySelector("style[".concat(rm,"]"));if(n){var r;Sh=!1,(r=n.parentNode)===null||r===void 0||r.removeChild(n)}document.body.removeChild(e)}}function l$(e){return i$(),!!vo[e]}function s$(e){var t=vo[e],n=null;if(t&&wn())if(Sh)n=Ch;else{var r=document.querySelector("style[".concat(gr,'="').concat(vo[e],'"]'));r?n=r.innerHTML:delete vo[e]}return[n,t]}var c$="_skip_check_",$h="_multi_value_";function Zi(e){var t=ou(r$(e),a$);return t.replace(/\{%%%\:[^;];}/g,";")}function u$(e){return Qe(e)==="object"&&e&&(c$ in e||$h in e)}function om(e,t,n){if(!t)return e;var r=".".concat(t),o=n==="low"?":where(".concat(r,")"):r,a=e.split(",").map(function(l){var s,c=l.trim().split(/\s+/),u=c[0]||"",d=((s=u.match(/^\w+/))===null||s===void 0?void 0:s[0])||"";return u="".concat(d).concat(o).concat(u.slice(d.length)),[u].concat(pe(c.slice(1))).join(" ")});return a.join(",")}var d$=function e(t){var n=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},r=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{root:!0,parentSelectors:[]},o=r.root,a=r.injectHash,l=r.parentSelectors,s=n.hashId,c=n.layer;n.path;var u=n.hashPriority,d=n.transformers,f=d===void 0?[]:d;n.linters;var m="",v={};function g(b){var y=b.getName(s);if(!v[y]){var C=e(b.style,n,{root:!1,parentSelectors:l}),$=J(C,1),S=$[0];v[y]="@keyframes ".concat(b.getName(s)).concat(S)}}function h(b){var y=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[];return b.forEach(function(C){Array.isArray(C)?h(C,y):C&&y.push(C)}),y}var p=h(Array.isArray(t)?t:[t]);return p.forEach(function(b){var y=typeof b=="string"&&!o?{}:b;if(typeof y=="string")m+="".concat(y,`
`);else if(y._keyframe)g(y);else{var C=f.reduce(function($,S){var x;return(S==null||(x=S.visit)===null||x===void 0?void 0:x.call(S,$))||$},y);Object.keys(C).forEach(function($){var S=C[$];if(Qe(S)==="object"&&S&&($!=="animationName"||!S._keyframe)&&!u$(S)){var x=!1,E=$.trim(),O=!1;(o||a)&&s?E.startsWith("@")?x=!0:E==="&"?E=om("",s,u):E=om($,s,u):o&&!s&&(E==="&"||E==="")&&(E="",O=!0);var w=e(S,n,{root:O,injectHash:x,parentSelectors:[].concat(pe(l),[E])}),I=J(w,2),P=I[0],M=I[1];v=k(k({},v),M),m+="".concat(E).concat(P)}else{let T=function(j,z){var _=j.replace(/[A-Z]/g,function(V){return"-".concat(V.toLowerCase())}),B=z;!k1[j]&&typeof B=="number"&&B!==0&&(B="".concat(B,"px")),j==="animationName"&&z!==null&&z!==void 0&&z._keyframe&&(g(z),B=z.getName(s)),m+="".concat(_,":").concat(B,";")};var R,N=(R=S==null?void 0:S.value)!==null&&R!==void 0?R:S;Qe(S)==="object"&&S!==null&&S!==void 0&&S[$h]&&Array.isArray(N)?N.forEach(function(j){T($,j)}):T($,N)}})}}),o?c&&(m&&(m="@layer ".concat(c.name," {").concat(m,"}")),c.dependencies&&(v["@layer ".concat(c.name)]=c.dependencies.map(function(b){return"@layer ".concat(b,", ").concat(c.name,";")}).join(`
`))):m="{".concat(m,"}"),[m,v]};function xh(e,t){return qa("".concat(e.join("%")).concat(t))}function f$(){return null}var wh="style";function au(e,t){var n=e.token,r=e.path,o=e.hashId,a=e.layer,l=e.nonce,s=e.clientOnly,c=e.order,u=c===void 0?0:c,d=i.useContext(ai),f=d.autoClear;d.mock;var m=d.defaultCache,v=d.hashPriority,g=d.container,h=d.ssrInline,p=d.transformers,b=d.linters,y=d.cache,C=d.layer,$=n._tokenKey,S=[$];C&&S.push("layer"),S.push.apply(S,pe(r));var x=nu,E=Sd(wh,S,function(){var M=S.join("|");if(l$(M)){var R=s$(M),N=J(R,2),T=N[0],j=N[1];if(T)return[T,$,j,{},s,u]}var z=t(),_=d$(z,{hashId:o,hashPriority:v,layer:C?a:void 0,path:r.join("-"),transformers:p,linters:b}),B=J(_,2),V=B[0],G=B[1],q=Zi(V),H=xh(S,q);return[q,$,H,G,s,u]},function(M,R){var N=J(M,3),T=N[2];(R||f)&&nu&&Ua(T,{mark:gr,attachTo:g})},function(M){var R=J(M,4),N=R[0];R[1];var T=R[2],j=R[3];if(x&&N!==Ch){var z={mark:gr,prepend:C?!1:"queue",attachTo:g,priority:u},_=typeof l=="function"?l():l;_&&(z.csp={nonce:_});var B=[],V=[];Object.keys(j).forEach(function(q){q.startsWith("@layer")?B.push(q):V.push(q)}),B.forEach(function(q){Ar(Zi(j[q]),"_layer-".concat(q),k(k({},z),{},{prepend:!0}))});var G=Ar(N,T,z);G[Xr]=y.instanceId,G.setAttribute(Yo,$),V.forEach(function(q){Ar(Zi(j[q]),"_effect-".concat(q),z)})}}),O=J(E,3),w=O[0],I=O[1],P=O[2];return function(M){var R;return!h||x||!m?R=i.createElement(f$,null):R=i.createElement("style",ue({},D(D({},Yo,I),gr,P),{dangerouslySetInnerHTML:{__html:w}})),i.createElement(i.Fragment,null,R,M)}}var m$=function(t,n,r){var o=J(t,6),a=o[0],l=o[1],s=o[2],c=o[3],u=o[4],d=o[5],f=r||{},m=f.plain;if(u)return null;var v=a,g={"data-rc-order":"prependQueue","data-rc-priority":"".concat(d)};return v=vl(a,l,s,g,m),c&&Object.keys(c).forEach(function(h){if(!n[h]){n[h]=!0;var p=Zi(c[h]),b=vl(p,l,"_effect-".concat(h),g,m);h.startsWith("@layer")?v=b+v:v+=b}}),[d,s,v]},Eh="cssVar",v$=function(t,n){var r=t.key,o=t.prefix,a=t.unitless,l=t.ignore,s=t.token,c=t.scope,u=c===void 0?"":c,d=i.useContext(ai),f=d.cache.instanceId,m=d.container,v=s._tokenKey,g=[].concat(pe(t.path),[r,u,v]),h=Sd(Eh,g,function(){var p=n(),b=fh(p,r,{prefix:o,unitless:a,ignore:l,scope:u}),y=J(b,2),C=y[0],$=y[1],S=xh(g,$);return[C,$,S,r]},function(p){var b=J(p,3),y=b[2];nu&&Ua(y,{mark:gr,attachTo:m})},function(p){var b=J(p,3),y=b[1],C=b[2];if(y){var $=Ar(y,C,{mark:gr,prepend:"queue",attachTo:m,priority:-999});$[Xr]=f,$.setAttribute(Yo,r)}});return h},g$=function(t,n,r){var o=J(t,4),a=o[1],l=o[2],s=o[3],c=r||{},u=c.plain;if(!a)return null;var d=-999,f={"data-rc-order":"prependQueue","data-rc-priority":"".concat(d)},m=vl(a,s,l,f,u);return[d,l,m]};D(D(D({},wh,m$),mh,F1),Eh,g$);var $t=function(){function e(t,n){Zt(this,e),D(this,"name",void 0),D(this,"style",void 0),D(this,"_keyframe",!0),this.name=t,this.style=n}return Jt(e,[{key:"getName",value:function(){var n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:"";return n?"".concat(n,"-").concat(this.name):this.name}}]),e}();function Io(e){return e.notSplit=!0,e}Io(["borderTop","borderBottom"]),Io(["borderTop"]),Io(["borderBottom"]),Io(["borderLeft","borderRight"]),Io(["borderLeft"]),Io(["borderRight"]);var wd=i.createContext({});function Oh(e){return ih(e)||nh(e)||hd(e)||lh()}function Qn(e,t){for(var n=e,r=0;r<t.length;r+=1){if(n==null)return;n=n[t[r]]}return n}function Ih(e,t,n,r){if(!t.length)return n;var o=Oh(t),a=o[0],l=o.slice(1),s;return!e&&typeof a=="number"?s=[]:Array.isArray(e)?s=pe(e):s=k({},e),r&&n===void 0&&l.length===1?delete s[a][l[0]]:s[a]=Ih(s[a],l,n,r),s}function fr(e,t,n){var r=arguments.length>3&&arguments[3]!==void 0?arguments[3]:!1;return t.length&&r&&n===void 0&&!Qn(e,t.slice(0,-1))?e:Ih(e,t,n,r)}function p$(e){return Qe(e)==="object"&&e!==null&&Object.getPrototypeOf(e)===Object.prototype}function am(e){return Array.isArray(e)?[]:{}}var h$=typeof Reflect>"u"?Object.keys:Reflect.ownKeys;function Lo(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];var r=am(t[0]);return t.forEach(function(o){function a(l,s){var c=new Set(s),u=Qn(o,l),d=Array.isArray(u);if(d||p$(u)){if(!c.has(u)){c.add(u);var f=Qn(r,l);d?r=fr(r,l,[]):(!f||Qe(f)!=="object")&&(r=fr(r,l,am(u))),h$(u).forEach(function(m){a([].concat(pe(l),[m]),c)})}}else r=fr(r,l,u)}a([])}),r}function b$(){}const y$=i.createContext({}),no=()=>{const e=()=>{};return e.deprecated=b$,e},C$=i.createContext(void 0);var Rh={items_per_page:"/ page",jump_to:"Go to",jump_to_confirm:"confirm",page:"Page",prev_page:"Previous Page",next_page:"Next Page",prev_5:"Previous 5 Pages",next_5:"Next 5 Pages",prev_3:"Previous 3 Pages",next_3:"Next 3 Pages",page_size:"Page Size"},S$={yearFormat:"YYYY",dayFormat:"D",cellMeridiemFormat:"A",monthBeforeYear:!0},$$=k(k({},S$),{},{locale:"en_US",today:"Today",now:"Now",backToToday:"Back to today",ok:"OK",clear:"Clear",week:"Week",month:"Month",year:"Year",timeSelect:"select time",dateSelect:"select date",weekSelect:"Choose a week",monthSelect:"Choose a month",yearSelect:"Choose a year",decadeSelect:"Choose a decade",dateFormat:"M/D/YYYY",dateTimeFormat:"M/D/YYYY HH:mm:ss",previousMonth:"Previous month (PageUp)",nextMonth:"Next month (PageDown)",previousYear:"Last year (Control + left)",nextYear:"Next year (Control + right)",previousDecade:"Last decade",nextDecade:"Next decade",previousCentury:"Last century",nextCentury:"Next century"});const Ph={placeholder:"Select time",rangePlaceholder:["Start time","End time"]},im={lang:Object.assign({placeholder:"Select date",yearPlaceholder:"Select year",quarterPlaceholder:"Select quarter",monthPlaceholder:"Select month",weekPlaceholder:"Select week",rangePlaceholder:["Start date","End date"],rangeYearPlaceholder:["Start year","End year"],rangeQuarterPlaceholder:["Start quarter","End quarter"],rangeMonthPlaceholder:["Start month","End month"],rangeWeekPlaceholder:["Start week","End week"]},$$),timePickerLocale:Object.assign({},Ph)},Un="${label} is not a valid ${type}",br={locale:"en",Pagination:Rh,DatePicker:im,TimePicker:Ph,Calendar:im,global:{placeholder:"Please select",close:"Close"},Table:{filterTitle:"Filter menu",filterConfirm:"OK",filterReset:"Reset",filterEmptyText:"No filters",filterCheckAll:"Select all items",filterSearchPlaceholder:"Search in filters",emptyText:"No data",selectAll:"Select current page",selectInvert:"Invert current page",selectNone:"Clear all data",selectionAll:"Select all data",sortTitle:"Sort",expand:"Expand row",collapse:"Collapse row",triggerDesc:"Click to sort descending",triggerAsc:"Click to sort ascending",cancelSort:"Click to cancel sorting"},Tour:{Next:"Next",Previous:"Previous",Finish:"Finish"},Modal:{okText:"OK",cancelText:"Cancel",justOkText:"OK"},Popconfirm:{okText:"OK",cancelText:"Cancel"},Transfer:{titles:["",""],searchPlaceholder:"Search here",itemUnit:"item",itemsUnit:"items",remove:"Remove",selectCurrent:"Select current page",removeCurrent:"Remove current page",selectAll:"Select all data",deselectAll:"Deselect all data",removeAll:"Remove all data",selectInvert:"Invert current page"},Upload:{uploading:"Uploading...",removeFile:"Remove file",uploadError:"Upload error",previewFile:"Preview file",downloadFile:"Download file"},Empty:{description:"No data"},Icon:{icon:"icon"},Text:{edit:"Edit",copy:"Copy",copied:"Copied",expand:"Expand",collapse:"Collapse"},Form:{optional:"(optional)",defaultValidateMessages:{default:"Field validation error for ${label}",required:"Please enter ${label}",enum:"${label} must be one of [${enum}]",whitespace:"${label} cannot be a blank character",date:{format:"${label} date format is invalid",parse:"${label} cannot be converted to a date",invalid:"${label} is an invalid date"},types:{string:Un,method:Un,array:Un,object:Un,number:Un,date:Un,boolean:Un,integer:Un,float:Un,regexp:Un,email:Un,url:Un,hex:Un},string:{len:"${label} must be ${len} characters",min:"${label} must be at least ${min} characters",max:"${label} must be up to ${max} characters",range:"${label} must be between ${min}-${max} characters"},number:{len:"${label} must be equal to ${len}",min:"${label} must be minimum ${min}",max:"${label} must be maximum ${max}",range:"${label} must be between ${min}-${max}"},array:{len:"Must be ${len} ${label}",min:"At least ${min} ${label}",max:"At most ${max} ${label}",range:"The amount of ${label} must be between ${min}-${max}"},pattern:{mismatch:"${label} does not match the pattern ${pattern}"}}},Image:{preview:"Preview"},QRCode:{expired:"QR code expired",refresh:"Refresh",scanned:"Scanned"},ColorPicker:{presetEmpty:"Empty",transparent:"Transparent",singleColor:"Single",gradientColor:"Gradient"}};let Ji=Object.assign({},br.Modal),el=[];const lm=()=>el.reduce((e,t)=>Object.assign(Object.assign({},e),t),br.Modal);function x$(e){if(e){const t=Object.assign({},e);return el.push(t),Ji=lm(),()=>{el=el.filter(n=>n!==t),Ji=lm()}}Ji=Object.assign({},br.Modal)}function Nh(){return Ji}const Ed=i.createContext(void 0),Kn=(e,t)=>{const n=i.useContext(Ed),r=i.useMemo(()=>{var a;const l=t||br[e],s=(a=n==null?void 0:n[e])!==null&&a!==void 0?a:{};return Object.assign(Object.assign({},typeof l=="function"?l():l),s||{})},[e,t,n]),o=i.useMemo(()=>{const a=n==null?void 0:n.locale;return n!=null&&n.exist&&!a?br.locale:a},[n]);return[r,o]},w$="internalMark",E$=e=>{const{locale:t={},children:n,_ANT_MARK__:r}=e;i.useEffect(()=>x$(t==null?void 0:t.Modal),[t]);const o=i.useMemo(()=>Object.assign(Object.assign({},t),{exist:!0}),[t]);return i.createElement(Ed.Provider,{value:o},n)},Od={blue:"#1677FF",purple:"#722ED1",cyan:"#13C2C2",green:"#52C41A",magenta:"#EB2F96",pink:"#EB2F96",red:"#F5222D",orange:"#FA8C16",yellow:"#FADB14",volcano:"#FA541C",geekblue:"#2F54EB",gold:"#FAAD14",lime:"#A0D911"},Ya=Object.assign(Object.assign({},Od),{colorPrimary:"#1677ff",colorSuccess:"#52c41a",colorWarning:"#faad14",colorError:"#ff4d4f",colorInfo:"#1677ff",colorLink:"",colorTextBase:"",colorBgBase:"",fontFamily:`-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial,
'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol',
'Noto Color Emoji'`,fontFamilyCode:"'SFMono-Regular', Consolas, 'Liberation Mono', Menlo, Courier, monospace",fontSize:14,lineWidth:1,lineType:"solid",motionUnit:.1,motionBase:0,motionEaseOutCirc:"cubic-bezier(0.08, 0.82, 0.17, 1)",motionEaseInOutCirc:"cubic-bezier(0.78, 0.14, 0.15, 0.86)",motionEaseOut:"cubic-bezier(0.215, 0.61, 0.355, 1)",motionEaseInOut:"cubic-bezier(0.645, 0.045, 0.355, 1)",motionEaseOutBack:"cubic-bezier(0.12, 0.4, 0.29, 1.46)",motionEaseInBack:"cubic-bezier(0.71, -0.46, 0.88, 0.6)",motionEaseInQuint:"cubic-bezier(0.755, 0.05, 0.855, 0.06)",motionEaseOutQuint:"cubic-bezier(0.23, 1, 0.32, 1)",borderRadius:6,sizeUnit:4,sizeStep:4,sizePopupArrow:16,controlHeight:32,zIndexBase:0,zIndexPopupBase:1e3,opacityImage:1,wireframe:!1,motion:!0}),$n=Math.round;function Xs(e,t){const n=e.replace(/^[^(]*\((.*)/,"$1").replace(/\).*/,"").match(/\d*\.?\d+%?/g)||[],r=n.map(o=>parseFloat(o));for(let o=0;o<3;o+=1)r[o]=t(r[o]||0,n[o]||"",o);return n[3]?r[3]=n[3].includes("%")?r[3]/100:r[3]:r[3]=1,r}const sm=(e,t,n)=>n===0?e:e/100;function Ea(e,t){const n=t||255;return e>n?n:e<0?0:e}class Mt{constructor(t){D(this,"isValid",!0),D(this,"r",0),D(this,"g",0),D(this,"b",0),D(this,"a",1),D(this,"_h",void 0),D(this,"_s",void 0),D(this,"_l",void 0),D(this,"_v",void 0),D(this,"_max",void 0),D(this,"_min",void 0),D(this,"_brightness",void 0);function n(r){return r[0]in t&&r[1]in t&&r[2]in t}if(t)if(typeof t=="string"){let o=function(a){return r.startsWith(a)};const r=t.trim();/^#?[A-F\d]{3,8}$/i.test(r)?this.fromHexString(r):o("rgb")?this.fromRgbString(r):o("hsl")?this.fromHslString(r):(o("hsv")||o("hsb"))&&this.fromHsvString(r)}else if(t instanceof Mt)this.r=t.r,this.g=t.g,this.b=t.b,this.a=t.a,this._h=t._h,this._s=t._s,this._l=t._l,this._v=t._v;else if(n("rgb"))this.r=Ea(t.r),this.g=Ea(t.g),this.b=Ea(t.b),this.a=typeof t.a=="number"?Ea(t.a,1):1;else if(n("hsl"))this.fromHsl(t);else if(n("hsv"))this.fromHsv(t);else throw new Error("@ant-design/fast-color: unsupported input "+JSON.stringify(t))}setR(t){return this._sc("r",t)}setG(t){return this._sc("g",t)}setB(t){return this._sc("b",t)}setA(t){return this._sc("a",t,1)}setHue(t){const n=this.toHsv();return n.h=t,this._c(n)}getLuminance(){function t(a){const l=a/255;return l<=.03928?l/12.92:Math.pow((l+.055)/1.055,2.4)}const n=t(this.r),r=t(this.g),o=t(this.b);return .2126*n+.7152*r+.0722*o}getHue(){if(typeof this._h>"u"){const t=this.getMax()-this.getMin();t===0?this._h=0:this._h=$n(60*(this.r===this.getMax()?(this.g-this.b)/t+(this.g<this.b?6:0):this.g===this.getMax()?(this.b-this.r)/t+2:(this.r-this.g)/t+4))}return this._h}getSaturation(){if(typeof this._s>"u"){const t=this.getMax()-this.getMin();t===0?this._s=0:this._s=t/this.getMax()}return this._s}getLightness(){return typeof this._l>"u"&&(this._l=(this.getMax()+this.getMin())/510),this._l}getValue(){return typeof this._v>"u"&&(this._v=this.getMax()/255),this._v}getBrightness(){return typeof this._brightness>"u"&&(this._brightness=(this.r*299+this.g*587+this.b*114)/1e3),this._brightness}darken(t=10){const n=this.getHue(),r=this.getSaturation();let o=this.getLightness()-t/100;return o<0&&(o=0),this._c({h:n,s:r,l:o,a:this.a})}lighten(t=10){const n=this.getHue(),r=this.getSaturation();let o=this.getLightness()+t/100;return o>1&&(o=1),this._c({h:n,s:r,l:o,a:this.a})}mix(t,n=50){const r=this._c(t),o=n/100,a=s=>(r[s]-this[s])*o+this[s],l={r:$n(a("r")),g:$n(a("g")),b:$n(a("b")),a:$n(a("a")*100)/100};return this._c(l)}tint(t=10){return this.mix({r:255,g:255,b:255,a:1},t)}shade(t=10){return this.mix({r:0,g:0,b:0,a:1},t)}onBackground(t){const n=this._c(t),r=this.a+n.a*(1-this.a),o=a=>$n((this[a]*this.a+n[a]*n.a*(1-this.a))/r);return this._c({r:o("r"),g:o("g"),b:o("b"),a:r})}isDark(){return this.getBrightness()<128}isLight(){return this.getBrightness()>=128}equals(t){return this.r===t.r&&this.g===t.g&&this.b===t.b&&this.a===t.a}clone(){return this._c(this)}toHexString(){let t="#";const n=(this.r||0).toString(16);t+=n.length===2?n:"0"+n;const r=(this.g||0).toString(16);t+=r.length===2?r:"0"+r;const o=(this.b||0).toString(16);if(t+=o.length===2?o:"0"+o,typeof this.a=="number"&&this.a>=0&&this.a<1){const a=$n(this.a*255).toString(16);t+=a.length===2?a:"0"+a}return t}toHsl(){return{h:this.getHue(),s:this.getSaturation(),l:this.getLightness(),a:this.a}}toHslString(){const t=this.getHue(),n=$n(this.getSaturation()*100),r=$n(this.getLightness()*100);return this.a!==1?`hsla(${t},${n}%,${r}%,${this.a})`:`hsl(${t},${n}%,${r}%)`}toHsv(){return{h:this.getHue(),s:this.getSaturation(),v:this.getValue(),a:this.a}}toRgb(){return{r:this.r,g:this.g,b:this.b,a:this.a}}toRgbString(){return this.a!==1?`rgba(${this.r},${this.g},${this.b},${this.a})`:`rgb(${this.r},${this.g},${this.b})`}toString(){return this.toRgbString()}_sc(t,n,r){const o=this.clone();return o[t]=Ea(n,r),o}_c(t){return new this.constructor(t)}getMax(){return typeof this._max>"u"&&(this._max=Math.max(this.r,this.g,this.b)),this._max}getMin(){return typeof this._min>"u"&&(this._min=Math.min(this.r,this.g,this.b)),this._min}fromHexString(t){const n=t.replace("#","");function r(o,a){return parseInt(n[o]+n[a||o],16)}n.length<6?(this.r=r(0),this.g=r(1),this.b=r(2),this.a=n[3]?r(3)/255:1):(this.r=r(0,1),this.g=r(2,3),this.b=r(4,5),this.a=n[6]?r(6,7)/255:1)}fromHsl({h:t,s:n,l:r,a:o}){if(this._h=t%360,this._s=n,this._l=r,this.a=typeof o=="number"?o:1,n<=0){const m=$n(r*255);this.r=m,this.g=m,this.b=m}let a=0,l=0,s=0;const c=t/60,u=(1-Math.abs(2*r-1))*n,d=u*(1-Math.abs(c%2-1));c>=0&&c<1?(a=u,l=d):c>=1&&c<2?(a=d,l=u):c>=2&&c<3?(l=u,s=d):c>=3&&c<4?(l=d,s=u):c>=4&&c<5?(a=d,s=u):c>=5&&c<6&&(a=u,s=d);const f=r-u/2;this.r=$n((a+f)*255),this.g=$n((l+f)*255),this.b=$n((s+f)*255)}fromHsv({h:t,s:n,v:r,a:o}){this._h=t%360,this._s=n,this._v=r,this.a=typeof o=="number"?o:1;const a=$n(r*255);if(this.r=a,this.g=a,this.b=a,n<=0)return;const l=t/60,s=Math.floor(l),c=l-s,u=$n(r*(1-n)*255),d=$n(r*(1-n*c)*255),f=$n(r*(1-n*(1-c))*255);switch(s){case 0:this.g=f,this.b=u;break;case 1:this.r=d,this.b=u;break;case 2:this.r=u,this.b=f;break;case 3:this.r=u,this.g=d;break;case 4:this.r=f,this.g=u;break;case 5:default:this.g=u,this.b=d;break}}fromHsvString(t){const n=Xs(t,sm);this.fromHsv({h:n[0],s:n[1],v:n[2],a:n[3]})}fromHslString(t){const n=Xs(t,sm);this.fromHsl({h:n[0],s:n[1],l:n[2],a:n[3]})}fromRgbString(t){const n=Xs(t,(r,o)=>o.includes("%")?$n(r/100*255):r);this.r=n[0],this.g=n[1],this.b=n[2],this.a=n[3]}}var Mi=2,cm=.16,O$=.05,I$=.05,R$=.15,Mh=5,Th=4,P$=[{index:7,amount:15},{index:6,amount:25},{index:5,amount:30},{index:5,amount:45},{index:5,amount:65},{index:5,amount:85},{index:4,amount:90},{index:3,amount:95},{index:2,amount:97},{index:1,amount:98}];function um(e,t,n){var r;return Math.round(e.h)>=60&&Math.round(e.h)<=240?r=n?Math.round(e.h)-Mi*t:Math.round(e.h)+Mi*t:r=n?Math.round(e.h)+Mi*t:Math.round(e.h)-Mi*t,r<0?r+=360:r>=360&&(r-=360),r}function dm(e,t,n){if(e.h===0&&e.s===0)return e.s;var r;return n?r=e.s-cm*t:t===Th?r=e.s+cm:r=e.s+O$*t,r>1&&(r=1),n&&t===Mh&&r>.1&&(r=.1),r<.06&&(r=.06),Math.round(r*100)/100}function fm(e,t,n){var r;return n?r=e.v+I$*t:r=e.v-R$*t,r=Math.max(0,Math.min(1,r)),Math.round(r*100)/100}function bo(e){for(var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=[],r=new Mt(e),o=r.toHsv(),a=Mh;a>0;a-=1){var l=new Mt({h:um(o,a,!0),s:dm(o,a,!0),v:fm(o,a,!0)});n.push(l)}n.push(r);for(var s=1;s<=Th;s+=1){var c=new Mt({h:um(o,s),s:dm(o,s),v:fm(o,s)});n.push(c)}return t.theme==="dark"?P$.map(function(u){var d=u.index,f=u.amount;return new Mt(t.backgroundColor||"#141414").mix(n[d],f).toHexString()}):n.map(function(u){return u.toHexString()})}var Vo={red:"#F5222D",volcano:"#FA541C",orange:"#FA8C16",gold:"#FAAD14",yellow:"#FADB14",lime:"#A0D911",green:"#52C41A",cyan:"#13C2C2",blue:"#1677FF",geekblue:"#2F54EB",purple:"#722ED1",magenta:"#EB2F96",grey:"#666666"},iu=["#fff1f0","#ffccc7","#ffa39e","#ff7875","#ff4d4f","#f5222d","#cf1322","#a8071a","#820014","#5c0011"];iu.primary=iu[5];var lu=["#fff2e8","#ffd8bf","#ffbb96","#ff9c6e","#ff7a45","#fa541c","#d4380d","#ad2102","#871400","#610b00"];lu.primary=lu[5];var su=["#fff7e6","#ffe7ba","#ffd591","#ffc069","#ffa940","#fa8c16","#d46b08","#ad4e00","#873800","#612500"];su.primary=su[5];var gl=["#fffbe6","#fff1b8","#ffe58f","#ffd666","#ffc53d","#faad14","#d48806","#ad6800","#874d00","#613400"];gl.primary=gl[5];var cu=["#feffe6","#ffffb8","#fffb8f","#fff566","#ffec3d","#fadb14","#d4b106","#ad8b00","#876800","#614700"];cu.primary=cu[5];var uu=["#fcffe6","#f4ffb8","#eaff8f","#d3f261","#bae637","#a0d911","#7cb305","#5b8c00","#3f6600","#254000"];uu.primary=uu[5];var du=["#f6ffed","#d9f7be","#b7eb8f","#95de64","#73d13d","#52c41a","#389e0d","#237804","#135200","#092b00"];du.primary=du[5];var fu=["#e6fffb","#b5f5ec","#87e8de","#5cdbd3","#36cfc9","#13c2c2","#08979c","#006d75","#00474f","#002329"];fu.primary=fu[5];var Jo=["#e6f4ff","#bae0ff","#91caff","#69b1ff","#4096ff","#1677ff","#0958d9","#003eb3","#002c8c","#001d66"];Jo.primary=Jo[5];var mu=["#f0f5ff","#d6e4ff","#adc6ff","#85a5ff","#597ef7","#2f54eb","#1d39c4","#10239e","#061178","#030852"];mu.primary=mu[5];var vu=["#f9f0ff","#efdbff","#d3adf7","#b37feb","#9254de","#722ed1","#531dab","#391085","#22075e","#120338"];vu.primary=vu[5];var gu=["#fff0f6","#ffd6e7","#ffadd2","#ff85c0","#f759ab","#eb2f96","#c41d7f","#9e1068","#780650","#520339"];gu.primary=gu[5];var pu=["#a6a6a6","#999999","#8c8c8c","#808080","#737373","#666666","#404040","#1a1a1a","#000000","#000000"];pu.primary=pu[5];var Ys={red:iu,volcano:lu,orange:su,gold:gl,yellow:cu,lime:uu,green:du,cyan:fu,blue:Jo,geekblue:mu,purple:vu,magenta:gu,grey:pu};function jh(e,{generateColorPalettes:t,generateNeutralColorPalettes:n}){const{colorSuccess:r,colorWarning:o,colorError:a,colorInfo:l,colorPrimary:s,colorBgBase:c,colorTextBase:u}=e,d=t(s),f=t(r),m=t(o),v=t(a),g=t(l),h=n(c,u),p=e.colorLink||e.colorInfo,b=t(p),y=new Mt(v[1]).mix(new Mt(v[3]),50).toHexString();return Object.assign(Object.assign({},h),{colorPrimaryBg:d[1],colorPrimaryBgHover:d[2],colorPrimaryBorder:d[3],colorPrimaryBorderHover:d[4],colorPrimaryHover:d[5],colorPrimary:d[6],colorPrimaryActive:d[7],colorPrimaryTextHover:d[8],colorPrimaryText:d[9],colorPrimaryTextActive:d[10],colorSuccessBg:f[1],colorSuccessBgHover:f[2],colorSuccessBorder:f[3],colorSuccessBorderHover:f[4],colorSuccessHover:f[4],colorSuccess:f[6],colorSuccessActive:f[7],colorSuccessTextHover:f[8],colorSuccessText:f[9],colorSuccessTextActive:f[10],colorErrorBg:v[1],colorErrorBgHover:v[2],colorErrorBgFilledHover:y,colorErrorBgActive:v[3],colorErrorBorder:v[3],colorErrorBorderHover:v[4],colorErrorHover:v[5],colorError:v[6],colorErrorActive:v[7],colorErrorTextHover:v[8],colorErrorText:v[9],colorErrorTextActive:v[10],colorWarningBg:m[1],colorWarningBgHover:m[2],colorWarningBorder:m[3],colorWarningBorderHover:m[4],colorWarningHover:m[4],colorWarning:m[6],colorWarningActive:m[7],colorWarningTextHover:m[8],colorWarningText:m[9],colorWarningTextActive:m[10],colorInfoBg:g[1],colorInfoBgHover:g[2],colorInfoBorder:g[3],colorInfoBorderHover:g[4],colorInfoHover:g[4],colorInfo:g[6],colorInfoActive:g[7],colorInfoTextHover:g[8],colorInfoText:g[9],colorInfoTextActive:g[10],colorLinkHover:b[4],colorLink:b[6],colorLinkActive:b[7],colorBgMask:new Mt("#000").setA(.45).toRgbString(),colorWhite:"#fff"})}const N$=e=>{let t=e,n=e,r=e,o=e;return e<6&&e>=5?t=e+1:e<16&&e>=6?t=e+2:e>=16&&(t=16),e<7&&e>=5?n=4:e<8&&e>=7?n=5:e<14&&e>=8?n=6:e<16&&e>=14?n=7:e>=16&&(n=8),e<6&&e>=2?r=1:e>=6&&(r=2),e>4&&e<8?o=4:e>=8&&(o=6),{borderRadius:e,borderRadiusXS:r,borderRadiusSM:n,borderRadiusLG:t,borderRadiusOuter:o}};function M$(e){const{motionUnit:t,motionBase:n,borderRadius:r,lineWidth:o}=e;return Object.assign({motionDurationFast:`${(n+t).toFixed(1)}s`,motionDurationMid:`${(n+t*2).toFixed(1)}s`,motionDurationSlow:`${(n+t*3).toFixed(1)}s`,lineWidthBold:o+1},N$(r))}const zh=e=>{const{controlHeight:t}=e;return{controlHeightSM:t*.75,controlHeightXS:t*.5,controlHeightLG:t*1.25}};function tl(e){return(e+8)/e}function T$(e){const t=Array.from({length:10}).map((n,r)=>{const o=r-1,a=e*Math.pow(Math.E,o/5),l=r>1?Math.floor(a):Math.ceil(a);return Math.floor(l/2)*2});return t[1]=e,t.map(n=>({size:n,lineHeight:tl(n)}))}const Dh=e=>{const t=T$(e),n=t.map(d=>d.size),r=t.map(d=>d.lineHeight),o=n[1],a=n[0],l=n[2],s=r[1],c=r[0],u=r[2];return{fontSizeSM:a,fontSize:o,fontSizeLG:l,fontSizeXL:n[3],fontSizeHeading1:n[6],fontSizeHeading2:n[5],fontSizeHeading3:n[4],fontSizeHeading4:n[3],fontSizeHeading5:n[2],lineHeight:s,lineHeightLG:u,lineHeightSM:c,fontHeight:Math.round(s*o),fontHeightLG:Math.round(u*l),fontHeightSM:Math.round(c*a),lineHeightHeading1:r[6],lineHeightHeading2:r[5],lineHeightHeading3:r[4],lineHeightHeading4:r[3],lineHeightHeading5:r[2]}};function j$(e){const{sizeUnit:t,sizeStep:n}=e;return{sizeXXL:t*(n+8),sizeXL:t*(n+4),sizeLG:t*(n+2),sizeMD:t*(n+1),sizeMS:t*n,size:t*n,sizeSM:t*(n-1),sizeXS:t*(n-2),sizeXXS:t*(n-3)}}const nr=(e,t)=>new Mt(e).setA(t).toRgbString(),Oa=(e,t)=>new Mt(e).darken(t).toHexString(),z$=e=>{const t=bo(e);return{1:t[0],2:t[1],3:t[2],4:t[3],5:t[4],6:t[5],7:t[6],8:t[4],9:t[5],10:t[6]}},D$=(e,t)=>{const n=e||"#fff",r=t||"#000";return{colorBgBase:n,colorTextBase:r,colorText:nr(r,.88),colorTextSecondary:nr(r,.65),colorTextTertiary:nr(r,.45),colorTextQuaternary:nr(r,.25),colorFill:nr(r,.15),colorFillSecondary:nr(r,.06),colorFillTertiary:nr(r,.04),colorFillQuaternary:nr(r,.02),colorBgSolid:nr(r,1),colorBgSolidHover:nr(r,.75),colorBgSolidActive:nr(r,.95),colorBgLayout:Oa(n,4),colorBgContainer:Oa(n,0),colorBgElevated:Oa(n,0),colorBgSpotlight:nr(r,.85),colorBgBlur:"transparent",colorBorder:Oa(n,15),colorBorderSecondary:Oa(n,6)}};function Zl(e){Vo.pink=Vo.magenta,Ys.pink=Ys.magenta;const t=Object.keys(Od).map(n=>{const r=e[n]===Vo[n]?Ys[n]:bo(e[n]);return Array.from({length:10},()=>1).reduce((o,a,l)=>(o[`${n}-${l+1}`]=r[l],o[`${n}${l+1}`]=r[l],o),{})}).reduce((n,r)=>(n=Object.assign(Object.assign({},n),r),n),{});return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},e),t),jh(e,{generateColorPalettes:z$,generateNeutralColorPalettes:D$})),Dh(e.fontSize)),j$(e)),zh(e)),M$(e))}const _h=tu(Zl),pl={token:Ya,override:{override:Ya},hashed:!0},Bh=F.createContext(pl),Qa="ant",Jl="anticon",_$=["outlined","borderless","filled","underlined"],B$=(e,t)=>t||(e?`${Qa}-${e}`:Qa),ot=i.createContext({getPrefixCls:B$,iconPrefixCls:Jl}),{Consumer:uA}=ot,mm={};function tn(e){const t=i.useContext(ot),{getPrefixCls:n,direction:r,getPopupContainer:o}=t,a=t[e];return Object.assign(Object.assign({classNames:mm,styles:mm},a),{getPrefixCls:n,direction:r,getPopupContainer:o})}const L$=`-ant-${Date.now()}-${Math.random()}`;function H$(e,t){const n={},r=(l,s)=>{let c=l.clone();return c=(s==null?void 0:s(c))||c,c.toRgbString()},o=(l,s)=>{const c=new Mt(l),u=bo(c.toRgbString());n[`${s}-color`]=r(c),n[`${s}-color-disabled`]=u[1],n[`${s}-color-hover`]=u[4],n[`${s}-color-active`]=u[6],n[`${s}-color-outline`]=c.clone().setA(.2).toRgbString(),n[`${s}-color-deprecated-bg`]=u[0],n[`${s}-color-deprecated-border`]=u[2]};if(t.primaryColor){o(t.primaryColor,"primary");const l=new Mt(t.primaryColor),s=bo(l.toRgbString());s.forEach((u,d)=>{n[`primary-${d+1}`]=u}),n["primary-color-deprecated-l-35"]=r(l,u=>u.lighten(35)),n["primary-color-deprecated-l-20"]=r(l,u=>u.lighten(20)),n["primary-color-deprecated-t-20"]=r(l,u=>u.tint(20)),n["primary-color-deprecated-t-50"]=r(l,u=>u.tint(50)),n["primary-color-deprecated-f-12"]=r(l,u=>u.setA(u.a*.12));const c=new Mt(s[0]);n["primary-color-active-deprecated-f-30"]=r(c,u=>u.setA(u.a*.3)),n["primary-color-active-deprecated-d-02"]=r(c,u=>u.darken(2))}return t.successColor&&o(t.successColor,"success"),t.warningColor&&o(t.warningColor,"warning"),t.errorColor&&o(t.errorColor,"error"),t.infoColor&&o(t.infoColor,"info"),`
  :root {
    ${Object.keys(n).map(l=>`--${e}-${l}: ${n[l]};`).join(`
`)}
  }
  `.trim()}function A$(e,t){const n=H$(e,t);wn()&&Ar(n,`${L$}-dynamic-theme`)}const Ln=i.createContext(!1),Lh=({children:e,disabled:t})=>{const n=i.useContext(Ln);return i.createElement(Ln.Provider,{value:t??n},e)},ea=i.createContext(void 0),F$=({children:e,size:t})=>{const n=i.useContext(ea);return i.createElement(ea.Provider,{value:t||n},e)};function k$(){const e=i.useContext(Ln),t=i.useContext(ea);return{componentDisabled:e,componentSize:t}}var Hh=Jt(function e(){Zt(this,e)}),Ah="CALC_UNIT",V$=new RegExp(Ah,"g");function Qs(e){return typeof e=="number"?"".concat(e).concat(Ah):e}var W$=function(e){tr(n,e);var t=ur(n);function n(r,o){var a;Zt(this,n),a=t.call(this),D(Ve(a),"result",""),D(Ve(a),"unitlessCssVar",void 0),D(Ve(a),"lowPriority",void 0);var l=Qe(r);return a.unitlessCssVar=o,r instanceof n?a.result="(".concat(r.result,")"):l==="number"?a.result=Qs(r):l==="string"&&(a.result=r),a}return Jt(n,[{key:"add",value:function(o){return o instanceof n?this.result="".concat(this.result," + ").concat(o.getResult()):(typeof o=="number"||typeof o=="string")&&(this.result="".concat(this.result," + ").concat(Qs(o))),this.lowPriority=!0,this}},{key:"sub",value:function(o){return o instanceof n?this.result="".concat(this.result," - ").concat(o.getResult()):(typeof o=="number"||typeof o=="string")&&(this.result="".concat(this.result," - ").concat(Qs(o))),this.lowPriority=!0,this}},{key:"mul",value:function(o){return this.lowPriority&&(this.result="(".concat(this.result,")")),o instanceof n?this.result="".concat(this.result," * ").concat(o.getResult(!0)):(typeof o=="number"||typeof o=="string")&&(this.result="".concat(this.result," * ").concat(o)),this.lowPriority=!1,this}},{key:"div",value:function(o){return this.lowPriority&&(this.result="(".concat(this.result,")")),o instanceof n?this.result="".concat(this.result," / ").concat(o.getResult(!0)):(typeof o=="number"||typeof o=="string")&&(this.result="".concat(this.result," / ").concat(o)),this.lowPriority=!1,this}},{key:"getResult",value:function(o){return this.lowPriority||o?"(".concat(this.result,")"):this.result}},{key:"equal",value:function(o){var a=this,l=o||{},s=l.unit,c=!0;return typeof s=="boolean"?c=s:Array.from(this.unitlessCssVar).some(function(u){return a.result.includes(u)})&&(c=!1),this.result=this.result.replace(V$,c?"px":""),typeof this.lowPriority<"u"?"calc(".concat(this.result,")"):this.result}}]),n}(Hh),K$=function(e){tr(n,e);var t=ur(n);function n(r){var o;return Zt(this,n),o=t.call(this),D(Ve(o),"result",0),r instanceof n?o.result=r.result:typeof r=="number"&&(o.result=r),o}return Jt(n,[{key:"add",value:function(o){return o instanceof n?this.result+=o.result:typeof o=="number"&&(this.result+=o),this}},{key:"sub",value:function(o){return o instanceof n?this.result-=o.result:typeof o=="number"&&(this.result-=o),this}},{key:"mul",value:function(o){return o instanceof n?this.result*=o.result:typeof o=="number"&&(this.result*=o),this}},{key:"div",value:function(o){return o instanceof n?this.result/=o.result:typeof o=="number"&&(this.result/=o),this}},{key:"equal",value:function(){return this.result}}]),n}(Hh),G$=function(t,n){var r=t==="css"?W$:K$;return function(o){return new r(o,n)}},vm=function(t,n){return"".concat([n,t.replace(/([A-Z]+)([A-Z][a-z]+)/g,"$1-$2").replace(/([a-z])([A-Z])/g,"$1-$2")].filter(Boolean).join("-"))};function Nt(e){var t=i.useRef();t.current=e;var n=i.useCallback(function(){for(var r,o=arguments.length,a=new Array(o),l=0;l<o;l++)a[l]=arguments[l];return(r=t.current)===null||r===void 0?void 0:r.call.apply(r,[t].concat(a))},[]);return n}function ta(e){var t=i.useRef(!1),n=i.useState(e),r=J(n,2),o=r[0],a=r[1];i.useEffect(function(){return t.current=!1,function(){t.current=!0}},[]);function l(s,c){c&&t.current||a(s)}return[o,l]}function Zs(e){return e!==void 0}function Lt(e,t){var n=t||{},r=n.defaultValue,o=n.value,a=n.onChange,l=n.postState,s=ta(function(){return Zs(o)?o:Zs(r)?typeof r=="function"?r():r:typeof e=="function"?e():e}),c=J(s,2),u=c[0],d=c[1],f=o!==void 0?o:u,m=l?l(f):f,v=Nt(a),g=ta([f]),h=J(g,2),p=h[0],b=h[1];Fo(function(){var C=p[0];u!==C&&v(u,C)},[p]),Fo(function(){Zs(o)||d(o)},[o]);var y=Nt(function(C,$){d(C,$),b([f],$)});return[m,y]}function gm(e,t,n,r){var o=k({},t[e]);if(r!=null&&r.deprecatedTokens){var a=r.deprecatedTokens;a.forEach(function(s){var c=J(s,2),u=c[0],d=c[1];if(o!=null&&o[u]||o!=null&&o[d]){var f;(f=o[d])!==null&&f!==void 0||(o[d]=o==null?void 0:o[u])}})}var l=k(k({},n),o);return Object.keys(l).forEach(function(s){l[s]===t[s]&&delete l[s]}),l}var Fh=typeof CSSINJS_STATISTIC<"u",hu=!0;function yt(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];if(!Fh)return Object.assign.apply(Object,[{}].concat(t));hu=!1;var r={};return t.forEach(function(o){if(Qe(o)==="object"){var a=Object.keys(o);a.forEach(function(l){Object.defineProperty(r,l,{configurable:!0,enumerable:!0,get:function(){return o[l]}})})}}),hu=!0,r}var pm={};function q$(){}var U$=function(t){var n,r=t,o=q$;return Fh&&typeof Proxy<"u"&&(n=new Set,r=new Proxy(t,{get:function(l,s){if(hu){var c;(c=n)===null||c===void 0||c.add(s)}return l[s]}}),o=function(l,s){var c;pm[l]={global:Array.from(n),component:k(k({},(c=pm[l])===null||c===void 0?void 0:c.component),s)}}),{token:r,keys:n,flush:o}};function hm(e,t,n){if(typeof n=="function"){var r;return n(yt(t,(r=t[e])!==null&&r!==void 0?r:{}))}return n??{}}function X$(e){return e==="js"?{max:Math.max,min:Math.min}:{max:function(){for(var n=arguments.length,r=new Array(n),o=0;o<n;o++)r[o]=arguments[o];return"max(".concat(r.map(function(a){return L(a)}).join(","),")")},min:function(){for(var n=arguments.length,r=new Array(n),o=0;o<n;o++)r[o]=arguments[o];return"min(".concat(r.map(function(a){return L(a)}).join(","),")")}}}var Y$=1e3*60*10,Q$=function(){function e(){Zt(this,e),D(this,"map",new Map),D(this,"objectIDMap",new WeakMap),D(this,"nextID",0),D(this,"lastAccessBeat",new Map),D(this,"accessBeat",0)}return Jt(e,[{key:"set",value:function(n,r){this.clear();var o=this.getCompositeKey(n);this.map.set(o,r),this.lastAccessBeat.set(o,Date.now())}},{key:"get",value:function(n){var r=this.getCompositeKey(n),o=this.map.get(r);return this.lastAccessBeat.set(r,Date.now()),this.accessBeat+=1,o}},{key:"getCompositeKey",value:function(n){var r=this,o=n.map(function(a){return a&&Qe(a)==="object"?"obj_".concat(r.getObjectID(a)):"".concat(Qe(a),"_").concat(a)});return o.join("|")}},{key:"getObjectID",value:function(n){if(this.objectIDMap.has(n))return this.objectIDMap.get(n);var r=this.nextID;return this.objectIDMap.set(n,r),this.nextID+=1,r}},{key:"clear",value:function(){var n=this;if(this.accessBeat>1e4){var r=Date.now();this.lastAccessBeat.forEach(function(o,a){r-o>Y$&&(n.map.delete(a),n.lastAccessBeat.delete(a))}),this.accessBeat=0}}}]),e}(),bm=new Q$;function Z$(e,t){return F.useMemo(function(){var n=bm.get(t);if(n)return n;var r=e();return bm.set(t,r),r},t)}var J$=function(){return{}};function ex(e){var t=e.useCSP,n=t===void 0?J$:t,r=e.useToken,o=e.usePrefix,a=e.getResetStyles,l=e.getCommonStyle,s=e.getCompUnitless;function c(m,v,g,h){var p=Array.isArray(m)?m[0]:m;function b(O){return"".concat(String(p)).concat(O.slice(0,1).toUpperCase()).concat(O.slice(1))}var y=(h==null?void 0:h.unitless)||{},C=typeof s=="function"?s(m):{},$=k(k({},C),{},D({},b("zIndexPopup"),!0));Object.keys(y).forEach(function(O){$[b(O)]=y[O]});var S=k(k({},h),{},{unitless:$,prefixToken:b}),x=d(m,v,g,S),E=u(p,g,S);return function(O){var w=arguments.length>1&&arguments[1]!==void 0?arguments[1]:O,I=x(O,w),P=J(I,2),M=P[1],R=E(w),N=J(R,2),T=N[0],j=N[1];return[T,M,j]}}function u(m,v,g){var h=g.unitless,p=g.injectStyle,b=p===void 0?!0:p,y=g.prefixToken,C=g.ignore,$=function(E){var O=E.rootCls,w=E.cssVar,I=w===void 0?{}:w,P=r(),M=P.realToken;return v$({path:[m],prefix:I.prefix,key:I.key,unitless:h,ignore:C,token:M,scope:O},function(){var R=hm(m,M,v),N=gm(m,M,R,{deprecatedTokens:g==null?void 0:g.deprecatedTokens});return Object.keys(R).forEach(function(T){N[y(T)]=N[T],delete N[T]}),N}),null},S=function(E){var O=r(),w=O.cssVar;return[function(I){return b&&w?F.createElement(F.Fragment,null,F.createElement($,{rootCls:E,cssVar:w,component:m}),I):I},w==null?void 0:w.key]};return S}function d(m,v,g){var h=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{},p=Array.isArray(m)?m:[m,m],b=J(p,1),y=b[0],C=p.join("-"),$=e.layer||{name:"antd"};return function(S){var x=arguments.length>1&&arguments[1]!==void 0?arguments[1]:S,E=r(),O=E.theme,w=E.realToken,I=E.hashId,P=E.token,M=E.cssVar,R=o(),N=R.rootPrefixCls,T=R.iconPrefixCls,j=n(),z=M?"css":"js",_=Z$(function(){var W=new Set;return M&&Object.keys(h.unitless||{}).forEach(function(K){W.add(Ui(K,M.prefix)),W.add(Ui(K,vm(y,M.prefix)))}),G$(z,W)},[z,y,M==null?void 0:M.prefix]),B=X$(z),V=B.max,G=B.min,q={theme:O,token:P,hashId:I,nonce:function(){return j.nonce},clientOnly:h.clientOnly,layer:$,order:h.order||-999};typeof a=="function"&&au(k(k({},q),{},{clientOnly:!1,path:["Shared",N]}),function(){return a(P,{prefix:{rootPrefixCls:N,iconPrefixCls:T},csp:j})});var H=au(k(k({},q),{},{path:[C,S,T]}),function(){if(h.injectStyle===!1)return[];var W=U$(P),K=W.token,U=W.flush,te=hm(y,w,g),X=".".concat(S),ae=gm(y,w,te,{deprecatedTokens:h.deprecatedTokens});M&&te&&Qe(te)==="object"&&Object.keys(te).forEach(function(re){te[re]="var(".concat(Ui(re,vm(y,M.prefix)),")")});var le=yt(K,{componentCls:X,prefixCls:S,iconCls:".".concat(T),antCls:".".concat(N),calc:_,max:V,min:G},M?te:ae),ee=v(le,{hashId:I,prefixCls:S,rootPrefixCls:N,iconPrefixCls:T});U(y,ae);var Y=typeof l=="function"?l(le,S,x,h.resetFont):null;return[h.resetStyle===!1?null:Y,ee]});return[H,I]}}function f(m,v,g){var h=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{},p=d(m,v,g,k({resetStyle:!1,order:-998},h)),b=function(C){var $=C.prefixCls,S=C.rootCls,x=S===void 0?$:S;return p($,x),null};return b}return{genStyleHooks:c,genSubStyleComponent:f,genComponentStyleHook:d}}const Zr=["blue","purple","cyan","green","magenta","pink","red","orange","yellow","volcano","geekblue","lime","gold"],tx="5.27.1";function Js(e){return e>=0&&e<=255}function Ta(e,t){const{r:n,g:r,b:o,a}=new Mt(e).toRgb();if(a<1)return e;const{r:l,g:s,b:c}=new Mt(t).toRgb();for(let u=.01;u<=1;u+=.01){const d=Math.round((n-l*(1-u))/u),f=Math.round((r-s*(1-u))/u),m=Math.round((o-c*(1-u))/u);if(Js(d)&&Js(f)&&Js(m))return new Mt({r:d,g:f,b:m,a:Math.round(u*100)/100}).toRgbString()}return new Mt({r:n,g:r,b:o,a:1}).toRgbString()}var nx=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function kh(e){const{override:t}=e,n=nx(e,["override"]),r=Object.assign({},t);Object.keys(Ya).forEach(m=>{delete r[m]});const o=Object.assign(Object.assign({},n),r),a=480,l=576,s=768,c=992,u=1200,d=1600;if(o.motion===!1){const m="0s";o.motionDurationFast=m,o.motionDurationMid=m,o.motionDurationSlow=m}return Object.assign(Object.assign(Object.assign({},o),{colorFillContent:o.colorFillSecondary,colorFillContentHover:o.colorFill,colorFillAlter:o.colorFillQuaternary,colorBgContainerDisabled:o.colorFillTertiary,colorBorderBg:o.colorBgContainer,colorSplit:Ta(o.colorBorderSecondary,o.colorBgContainer),colorTextPlaceholder:o.colorTextQuaternary,colorTextDisabled:o.colorTextQuaternary,colorTextHeading:o.colorText,colorTextLabel:o.colorTextSecondary,colorTextDescription:o.colorTextTertiary,colorTextLightSolid:o.colorWhite,colorHighlight:o.colorError,colorBgTextHover:o.colorFillSecondary,colorBgTextActive:o.colorFill,colorIcon:o.colorTextTertiary,colorIconHover:o.colorText,colorErrorOutline:Ta(o.colorErrorBg,o.colorBgContainer),colorWarningOutline:Ta(o.colorWarningBg,o.colorBgContainer),fontSizeIcon:o.fontSizeSM,lineWidthFocus:o.lineWidth*3,lineWidth:o.lineWidth,controlOutlineWidth:o.lineWidth*2,controlInteractiveSize:o.controlHeight/2,controlItemBgHover:o.colorFillTertiary,controlItemBgActive:o.colorPrimaryBg,controlItemBgActiveHover:o.colorPrimaryBgHover,controlItemBgActiveDisabled:o.colorFill,controlTmpOutline:o.colorFillQuaternary,controlOutline:Ta(o.colorPrimaryBg,o.colorBgContainer),lineType:o.lineType,borderRadius:o.borderRadius,borderRadiusXS:o.borderRadiusXS,borderRadiusSM:o.borderRadiusSM,borderRadiusLG:o.borderRadiusLG,fontWeightStrong:600,opacityLoading:.65,linkDecoration:"none",linkHoverDecoration:"none",linkFocusDecoration:"none",controlPaddingHorizontal:12,controlPaddingHorizontalSM:8,paddingXXS:o.sizeXXS,paddingXS:o.sizeXS,paddingSM:o.sizeSM,padding:o.size,paddingMD:o.sizeMD,paddingLG:o.sizeLG,paddingXL:o.sizeXL,paddingContentHorizontalLG:o.sizeLG,paddingContentVerticalLG:o.sizeMS,paddingContentHorizontal:o.sizeMS,paddingContentVertical:o.sizeSM,paddingContentHorizontalSM:o.size,paddingContentVerticalSM:o.sizeXS,marginXXS:o.sizeXXS,marginXS:o.sizeXS,marginSM:o.sizeSM,margin:o.size,marginMD:o.sizeMD,marginLG:o.sizeLG,marginXL:o.sizeXL,marginXXL:o.sizeXXL,boxShadow:`
      0 6px 16px 0 rgba(0, 0, 0, 0.08),
      0 3px 6px -4px rgba(0, 0, 0, 0.12),
      0 9px 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowSecondary:`
      0 6px 16px 0 rgba(0, 0, 0, 0.08),
      0 3px 6px -4px rgba(0, 0, 0, 0.12),
      0 9px 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowTertiary:`
      0 1px 2px 0 rgba(0, 0, 0, 0.03),
      0 1px 6px -1px rgba(0, 0, 0, 0.02),
      0 2px 4px 0 rgba(0, 0, 0, 0.02)
    `,screenXS:a,screenXSMin:a,screenXSMax:l-1,screenSM:l,screenSMMin:l,screenSMMax:s-1,screenMD:s,screenMDMin:s,screenMDMax:c-1,screenLG:c,screenLGMin:c,screenLGMax:u-1,screenXL:u,screenXLMin:u,screenXLMax:d-1,screenXXL:d,screenXXLMin:d,boxShadowPopoverArrow:"2px 2px 5px rgba(0, 0, 0, 0.05)",boxShadowCard:`
      0 1px 2px -2px ${new Mt("rgba(0, 0, 0, 0.16)").toRgbString()},
      0 3px 6px 0 ${new Mt("rgba(0, 0, 0, 0.12)").toRgbString()},
      0 5px 12px 4px ${new Mt("rgba(0, 0, 0, 0.09)").toRgbString()}
    `,boxShadowDrawerRight:`
      -6px 0 16px 0 rgba(0, 0, 0, 0.08),
      -3px 0 6px -4px rgba(0, 0, 0, 0.12),
      -9px 0 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowDrawerLeft:`
      6px 0 16px 0 rgba(0, 0, 0, 0.08),
      3px 0 6px -4px rgba(0, 0, 0, 0.12),
      9px 0 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowDrawerUp:`
      0 6px 16px 0 rgba(0, 0, 0, 0.08),
      0 3px 6px -4px rgba(0, 0, 0, 0.12),
      0 9px 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowDrawerDown:`
      0 -6px 16px 0 rgba(0, 0, 0, 0.08),
      0 -3px 6px -4px rgba(0, 0, 0, 0.12),
      0 -9px 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowTabsOverflowLeft:"inset 10px 0 8px -8px rgba(0, 0, 0, 0.08)",boxShadowTabsOverflowRight:"inset -10px 0 8px -8px rgba(0, 0, 0, 0.08)",boxShadowTabsOverflowTop:"inset 0 10px 8px -8px rgba(0, 0, 0, 0.08)",boxShadowTabsOverflowBottom:"inset 0 -10px 8px -8px rgba(0, 0, 0, 0.08)"}),r)}var ym=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Vh={lineHeight:!0,lineHeightSM:!0,lineHeightLG:!0,lineHeightHeading1:!0,lineHeightHeading2:!0,lineHeightHeading3:!0,lineHeightHeading4:!0,lineHeightHeading5:!0,opacityLoading:!0,fontWeightStrong:!0,zIndexPopupBase:!0,zIndexBase:!0,opacityImage:!0},rx={motionBase:!0,motionUnit:!0},ox={screenXS:!0,screenXSMin:!0,screenXSMax:!0,screenSM:!0,screenSMMin:!0,screenSMMax:!0,screenMD:!0,screenMDMin:!0,screenMDMax:!0,screenLG:!0,screenLGMin:!0,screenLGMax:!0,screenXL:!0,screenXLMin:!0,screenXLMax:!0,screenXXL:!0,screenXXLMin:!0},Wh=(e,t,n)=>{const r=n.getDerivativeToken(e),{override:o}=t,a=ym(t,["override"]);let l=Object.assign(Object.assign({},r),{override:o});return l=kh(l),a&&Object.entries(a).forEach(([s,c])=>{const{theme:u}=c,d=ym(c,["theme"]);let f=d;u&&(f=Wh(Object.assign(Object.assign({},l),d),{override:d},u)),l[s]=f}),l};function yn(){const{token:e,hashed:t,theme:n,override:r,cssVar:o}=F.useContext(Bh),a=`${tx}-${t||""}`,l=n||_h,[s,c,u]=A1(l,[Ya,e],{salt:a,override:r,getComputedToken:Wh,formatToken:kh,cssVar:o&&{prefix:o.prefix,key:o.key,unitless:Vh,ignore:rx,preserve:ox}});return[l,u,t?c:"",s,o]}const sr={overflow:"hidden",whiteSpace:"nowrap",textOverflow:"ellipsis"},Tt=(e,t=!1)=>({boxSizing:"border-box",margin:0,padding:0,color:e.colorText,fontSize:e.fontSize,lineHeight:e.lineHeight,listStyle:"none",fontFamily:t?"inherit":e.fontFamily}),xo=()=>({display:"inline-flex",alignItems:"center",color:"inherit",fontStyle:"normal",lineHeight:0,textAlign:"center",textTransform:"none",verticalAlign:"-0.125em",textRendering:"optimizeLegibility","-webkit-font-smoothing":"antialiased","-moz-osx-font-smoothing":"grayscale","> *":{lineHeight:1},svg:{display:"inline-block"}}),yr=()=>({"&::before":{display:"table",content:'""'},"&::after":{display:"table",clear:"both",content:'""'}}),ax=e=>({a:{color:e.colorLink,textDecoration:e.linkDecoration,backgroundColor:"transparent",outline:"none",cursor:"pointer",transition:`color ${e.motionDurationSlow}`,"-webkit-text-decoration-skip":"objects","&:hover":{color:e.colorLinkHover},"&:active":{color:e.colorLinkActive},"&:active, &:hover":{textDecoration:e.linkHoverDecoration,outline:0},"&:focus":{textDecoration:e.linkFocusDecoration,outline:0},"&[disabled]":{color:e.colorTextDisabled,cursor:"not-allowed"}}}),ix=(e,t,n,r)=>{const o=`[class^="${t}"], [class*=" ${t}"]`,a=n?`.${n}`:o,l={boxSizing:"border-box","&::before, &::after":{boxSizing:"border-box"}};let s={};return r!==!1&&(s={fontFamily:e.fontFamily,fontSize:e.fontSize}),{[a]:Object.assign(Object.assign(Object.assign({},s),l),{[o]:l})}},Cr=(e,t)=>({outline:`${L(e.lineWidthFocus)} solid ${e.colorPrimaryBorder}`,outlineOffset:t??1,transition:"outline-offset 0s, outline 0s"}),Vn=(e,t)=>({"&:focus-visible":Cr(e,t)}),Kh=e=>({[`.${e}`]:Object.assign(Object.assign({},xo()),{[`.${e} .${e}-icon`]:{display:"block"}})}),Id=e=>Object.assign(Object.assign({color:e.colorLink,textDecoration:e.linkDecoration,outline:"none",cursor:"pointer",transition:`all ${e.motionDurationSlow}`,border:0,padding:0,background:"none",userSelect:"none"},Vn(e)),{"&:focus, &:hover":{color:e.colorLinkHover},"&:active":{color:e.colorLinkActive}}),{genStyleHooks:It,genComponentStyleHook:lx,genSubStyleComponent:ua}=ex({usePrefix:()=>{const{getPrefixCls:e,iconPrefixCls:t}=i.useContext(ot);return{rootPrefixCls:e(),iconPrefixCls:t}},useToken:()=>{const[e,t,n,r,o]=yn();return{theme:e,realToken:t,hashId:n,token:r,cssVar:o}},useCSP:()=>{const{csp:e}=i.useContext(ot);return e??{}},getResetStyles:(e,t)=>{var n;const r=ax(e);return[r,{"&":r},Kh((n=t==null?void 0:t.prefix.iconPrefixCls)!==null&&n!==void 0?n:Jl)]},getCommonStyle:ix,getCompUnitless:()=>Vh});function es(e,t){return Zr.reduce((n,r)=>{const o=e[`${r}1`],a=e[`${r}3`],l=e[`${r}6`],s=e[`${r}7`];return Object.assign(Object.assign({},n),t(r,{lightColor:o,lightBorderColor:a,darkColor:l,textColor:s}))},{})}const sx=(e,t)=>{const[n,r]=yn();return au({token:r,hashId:"",path:["ant-design-icons",e],nonce:()=>t==null?void 0:t.nonce,layer:{name:"antd"}},()=>Kh(e))},cx=Object.assign({},Dl),{useId:Cm}=cx,ux=()=>"",dx=typeof Cm>"u"?ux:Cm;function fx(e,t,n){var r;no();const o=e||{},a=o.inherit===!1||!t?Object.assign(Object.assign({},pl),{hashed:(r=t==null?void 0:t.hashed)!==null&&r!==void 0?r:pl.hashed,cssVar:t==null?void 0:t.cssVar}):t,l=dx();return So(()=>{var s,c;if(!e)return t;const u=Object.assign({},a.components);Object.keys(e.components||{}).forEach(m=>{u[m]=Object.assign(Object.assign({},u[m]),e.components[m])});const d=`css-var-${l.replace(/:/g,"")}`,f=((s=o.cssVar)!==null&&s!==void 0?s:a.cssVar)&&Object.assign(Object.assign(Object.assign({prefix:n==null?void 0:n.prefixCls},typeof a.cssVar=="object"?a.cssVar:{}),typeof o.cssVar=="object"?o.cssVar:{}),{key:typeof o.cssVar=="object"&&((c=o.cssVar)===null||c===void 0?void 0:c.key)||d});return Object.assign(Object.assign(Object.assign({},a),o),{token:Object.assign(Object.assign({},a.token),o.token),components:u,cssVar:f})},[o,a],(s,c)=>s.some((u,d)=>{const f=c[d];return!hr(u,f,!0)}))}var mx=["children"],Gh=i.createContext({});function vx(e){var t=e.children,n=ft(e,mx);return i.createElement(Gh.Provider,{value:n},t)}var gx=function(e){tr(n,e);var t=ur(n);function n(){return Zt(this,n),t.apply(this,arguments)}return Jt(n,[{key:"render",value:function(){return this.props.children}}]),n}(i.Component);function px(e){var t=i.useReducer(function(s){return s+1},0),n=J(t,2),r=n[1],o=i.useRef(e),a=Nt(function(){return o.current}),l=Nt(function(s){o.current=typeof s=="function"?s(o.current):s,r()});return[a,l]}var Kr="none",Ti="appear",ji="enter",zi="leave",Sm="none",mr="prepare",Ho="start",Ao="active",Rd="end",qh="prepared";function $m(e,t){var n={};return n[e.toLowerCase()]=t.toLowerCase(),n["Webkit".concat(e)]="webkit".concat(t),n["Moz".concat(e)]="moz".concat(t),n["ms".concat(e)]="MS".concat(t),n["O".concat(e)]="o".concat(t.toLowerCase()),n}function hx(e,t){var n={animationend:$m("Animation","AnimationEnd"),transitionend:$m("Transition","TransitionEnd")};return e&&("AnimationEvent"in t||delete n.animationend.animation,"TransitionEvent"in t||delete n.transitionend.transition),n}var bx=hx(wn(),typeof window<"u"?window:{}),Uh={};if(wn()){var yx=document.createElement("div");Uh=yx.style}var Di={};function Xh(e){if(Di[e])return Di[e];var t=bx[e];if(t)for(var n=Object.keys(t),r=n.length,o=0;o<r;o+=1){var a=n[o];if(Object.prototype.hasOwnProperty.call(t,a)&&a in Uh)return Di[e]=t[a],Di[e]}return""}var Yh=Xh("animationend"),Qh=Xh("transitionend"),Zh=!!(Yh&&Qh),xm=Yh||"animationend",wm=Qh||"transitionend";function Em(e,t){if(!e)return null;if(Qe(e)==="object"){var n=t.replace(/-\w/g,function(r){return r[1].toUpperCase()});return e[n]}return"".concat(e,"-").concat(t)}const Cx=function(e){var t=i.useRef();function n(o){o&&(o.removeEventListener(wm,e),o.removeEventListener(xm,e))}function r(o){t.current&&t.current!==o&&n(t.current),o&&o!==t.current&&(o.addEventListener(wm,e),o.addEventListener(xm,e),t.current=o)}return i.useEffect(function(){return function(){n(t.current)}},[]),[r,n]};var Jh=wn()?i.useLayoutEffect:i.useEffect;const Sx=function(){var e=i.useRef(null);function t(){Et.cancel(e.current)}function n(r){var o=arguments.length>1&&arguments[1]!==void 0?arguments[1]:2;t();var a=Et(function(){o<=1?r({isCanceled:function(){return a!==e.current}}):n(r,o-1)});e.current=a}return i.useEffect(function(){return function(){t()}},[]),[n,t]};var $x=[mr,Ho,Ao,Rd],xx=[mr,qh],e0=!1,wx=!0;function t0(e){return e===Ao||e===Rd}const Ex=function(e,t,n){var r=ta(Sm),o=J(r,2),a=o[0],l=o[1],s=Sx(),c=J(s,2),u=c[0],d=c[1];function f(){l(mr,!0)}var m=t?xx:$x;return Jh(function(){if(a!==Sm&&a!==Rd){var v=m.indexOf(a),g=m[v+1],h=n(a);h===e0?l(g,!0):g&&u(function(p){function b(){p.isCanceled()||l(g,!0)}h===!0?b():Promise.resolve(h).then(b)})}},[e,a]),i.useEffect(function(){return function(){d()}},[]),[f,a]};function Ox(e,t,n,r){var o=r.motionEnter,a=o===void 0?!0:o,l=r.motionAppear,s=l===void 0?!0:l,c=r.motionLeave,u=c===void 0?!0:c,d=r.motionDeadline,f=r.motionLeaveImmediately,m=r.onAppearPrepare,v=r.onEnterPrepare,g=r.onLeavePrepare,h=r.onAppearStart,p=r.onEnterStart,b=r.onLeaveStart,y=r.onAppearActive,C=r.onEnterActive,$=r.onLeaveActive,S=r.onAppearEnd,x=r.onEnterEnd,E=r.onLeaveEnd,O=r.onVisibleChanged,w=ta(),I=J(w,2),P=I[0],M=I[1],R=px(Kr),N=J(R,2),T=N[0],j=N[1],z=ta(null),_=J(z,2),B=_[0],V=_[1],G=T(),q=i.useRef(!1),H=i.useRef(null);function W(){return n()}var K=i.useRef(!1);function U(){j(Kr),V(null,!0)}var te=Nt(function(oe){var ce=T();if(ce!==Kr){var ge=W();if(!(oe&&!oe.deadline&&oe.target!==ge)){var se=K.current,be;ce===Ti&&se?be=S==null?void 0:S(ge,oe):ce===ji&&se?be=x==null?void 0:x(ge,oe):ce===zi&&se&&(be=E==null?void 0:E(ge,oe)),se&&be!==!1&&U()}}}),X=Cx(te),ae=J(X,1),le=ae[0],ee=function(ce){switch(ce){case Ti:return D(D(D({},mr,m),Ho,h),Ao,y);case ji:return D(D(D({},mr,v),Ho,p),Ao,C);case zi:return D(D(D({},mr,g),Ho,b),Ao,$);default:return{}}},Y=i.useMemo(function(){return ee(G)},[G]),re=Ex(G,!e,function(oe){if(oe===mr){var ce=Y[mr];return ce?ce(W()):e0}if(Q in Y){var ge;V(((ge=Y[Q])===null||ge===void 0?void 0:ge.call(Y,W(),null))||null)}return Q===Ao&&G!==Kr&&(le(W()),d>0&&(clearTimeout(H.current),H.current=setTimeout(function(){te({deadline:!0})},d))),Q===qh&&U(),wx}),ne=J(re,2),Z=ne[0],Q=ne[1],ie=t0(Q);K.current=ie;var de=i.useRef(null);Jh(function(){if(!(q.current&&de.current===t)){M(t);var oe=q.current;q.current=!0;var ce;!oe&&t&&s&&(ce=Ti),oe&&t&&a&&(ce=ji),(oe&&!t&&u||!oe&&f&&!t&&u)&&(ce=zi);var ge=ee(ce);ce&&(e||ge[mr])?(j(ce),Z()):j(Kr),de.current=t}},[t]),i.useEffect(function(){(G===Ti&&!s||G===ji&&!a||G===zi&&!u)&&j(Kr)},[s,a,u]),i.useEffect(function(){return function(){q.current=!1,clearTimeout(H.current)}},[]);var he=i.useRef(!1);i.useEffect(function(){P&&(he.current=!0),P!==void 0&&G===Kr&&((he.current||P)&&(O==null||O(P)),he.current=!0)},[P,G]);var ye=B;return Y[mr]&&Q===Ho&&(ye=k({transition:"none"},ye)),[G,Q,ye,P??t]}function Ix(e){var t=e;Qe(e)==="object"&&(t=e.transitionSupport);function n(o,a){return!!(o.motionName&&t&&a!==!1)}var r=i.forwardRef(function(o,a){var l=o.visible,s=l===void 0?!0:l,c=o.removeOnLeave,u=c===void 0?!0:c,d=o.forceRender,f=o.children,m=o.motionName,v=o.leavedClassName,g=o.eventProps,h=i.useContext(Gh),p=h.motion,b=n(o,p),y=i.useRef(),C=i.useRef();function $(){try{return y.current instanceof HTMLElement?y.current:qi(C.current)}catch{return null}}var S=Ox(b,s,$,o),x=J(S,4),E=x[0],O=x[1],w=x[2],I=x[3],P=i.useRef(I);I&&(P.current=!0);var M=i.useCallback(function(_){y.current=_,Ka(a,_)},[a]),R,N=k(k({},g),{},{visible:s});if(!f)R=null;else if(E===Kr)I?R=f(k({},N),M):!u&&P.current&&v?R=f(k(k({},N),{},{className:v}),M):d||!u&&!v?R=f(k(k({},N),{},{style:{display:"none"}}),M):R=null;else{var T;O===mr?T="prepare":t0(O)?T="active":O===Ho&&(T="start");var j=Em(m,"".concat(E,"-").concat(T));R=f(k(k({},N),{},{className:A(Em(m,E),D(D({},j,j&&T),m,typeof m=="string")),style:w}),M)}if(i.isValidElement(R)&&Nr(R)){var z=$o(R);z||(R=i.cloneElement(R,{ref:M}))}return i.createElement(gx,{ref:C},R)});return r.displayName="CSSMotion",r}const En=Ix(Zh);var bu="add",yu="keep",Cu="remove",ec="removed";function Rx(e){var t;return e&&Qe(e)==="object"&&"key"in e?t=e:t={key:e},k(k({},t),{},{key:String(t.key)})}function Su(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[];return e.map(Rx)}function Px(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],n=[],r=0,o=t.length,a=Su(e),l=Su(t);a.forEach(function(u){for(var d=!1,f=r;f<o;f+=1){var m=l[f];if(m.key===u.key){r<f&&(n=n.concat(l.slice(r,f).map(function(v){return k(k({},v),{},{status:bu})})),r=f),n.push(k(k({},m),{},{status:yu})),r+=1,d=!0;break}}d||n.push(k(k({},u),{},{status:Cu}))}),r<o&&(n=n.concat(l.slice(r).map(function(u){return k(k({},u),{},{status:bu})})));var s={};n.forEach(function(u){var d=u.key;s[d]=(s[d]||0)+1});var c=Object.keys(s).filter(function(u){return s[u]>1});return c.forEach(function(u){n=n.filter(function(d){var f=d.key,m=d.status;return f!==u||m!==Cu}),n.forEach(function(d){d.key===u&&(d.status=yu)})}),n}var Nx=["component","children","onVisibleChanged","onAllRemoved"],Mx=["status"],Tx=["eventProps","visible","children","motionName","motionAppear","motionEnter","motionLeave","motionLeaveImmediately","motionDeadline","removeOnLeave","leavedClassName","onAppearPrepare","onAppearStart","onAppearActive","onAppearEnd","onEnterStart","onEnterActive","onEnterEnd","onLeaveStart","onLeaveActive","onLeaveEnd"];function jx(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:En,n=function(r){tr(a,r);var o=ur(a);function a(){var l;Zt(this,a);for(var s=arguments.length,c=new Array(s),u=0;u<s;u++)c[u]=arguments[u];return l=o.call.apply(o,[this].concat(c)),D(Ve(l),"state",{keyEntities:[]}),D(Ve(l),"removeKey",function(d){l.setState(function(f){var m=f.keyEntities.map(function(v){return v.key!==d?v:k(k({},v),{},{status:ec})});return{keyEntities:m}},function(){var f=l.state.keyEntities,m=f.filter(function(v){var g=v.status;return g!==ec}).length;m===0&&l.props.onAllRemoved&&l.props.onAllRemoved()})}),l}return Jt(a,[{key:"render",value:function(){var s=this,c=this.state.keyEntities,u=this.props,d=u.component,f=u.children,m=u.onVisibleChanged;u.onAllRemoved;var v=ft(u,Nx),g=d||i.Fragment,h={};return Tx.forEach(function(p){h[p]=v[p],delete v[p]}),delete v.keys,i.createElement(g,v,c.map(function(p,b){var y=p.status,C=ft(p,Mx),$=y===bu||y===yu;return i.createElement(t,ue({},h,{key:C.key,visible:$,eventProps:C,onVisibleChanged:function(x){m==null||m(x,{key:C.key}),x||s.removeKey(C.key)}}),function(S,x){return f(k(k({},S),{},{index:b}),x)})}))}}],[{key:"getDerivedStateFromProps",value:function(s,c){var u=s.keys,d=c.keyEntities,f=Su(u),m=Px(d,f);return{keyEntities:m.filter(function(v){var g=d.find(function(h){var p=h.key;return v.key===p});return!(g&&g.status===ec&&v.status===Cu)})}}}]),a}(i.Component);return D(n,"defaultProps",{component:"div"}),n}const n0=jx(Zh),Om=i.createContext(!0);function zx(e){const t=i.useContext(Om),{children:n}=e,[,r]=yn(),{motion:o}=r,a=i.useRef(!1);return a.current||(a.current=t!==o),a.current?i.createElement(Om.Provider,{value:o},i.createElement(vx,{motion:o},n)):n}const Dx=()=>null;var _x=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Bx=["getTargetContainer","getPopupContainer","renderEmpty","input","pagination","form","select","button"];let hl,r0,o0,a0;function nl(){return hl||Qa}function Lx(){return r0||Jl}function Hx(e){return Object.keys(e).some(t=>t.endsWith("Color"))}const Ax=e=>{const{prefixCls:t,iconPrefixCls:n,theme:r,holderRender:o}=e;t!==void 0&&(hl=t),n!==void 0&&(r0=n),"holderRender"in e&&(a0=o),r&&(Hx(r)?A$(nl(),r):o0=r)},Pd=()=>({getPrefixCls:(e,t)=>t||(e?`${nl()}-${e}`:nl()),getIconPrefixCls:Lx,getRootPrefixCls:()=>hl||nl(),getTheme:()=>o0,holderRender:a0}),Fx=e=>{const{children:t,csp:n,autoInsertSpaceInButton:r,alert:o,anchor:a,form:l,locale:s,componentSize:c,direction:u,space:d,splitter:f,virtual:m,dropdownMatchSelectWidth:v,popupMatchSelectWidth:g,popupOverflow:h,legacyLocale:p,parentContext:b,iconPrefixCls:y,theme:C,componentDisabled:$,segmented:S,statistic:x,spin:E,calendar:O,carousel:w,cascader:I,collapse:P,typography:M,checkbox:R,descriptions:N,divider:T,drawer:j,skeleton:z,steps:_,image:B,layout:V,list:G,mentions:q,modal:H,progress:W,result:K,slider:U,breadcrumb:te,menu:X,pagination:ae,input:le,textArea:ee,empty:Y,badge:re,radio:ne,rate:Z,switch:Q,transfer:ie,avatar:de,message:he,tag:ye,table:oe,card:ce,tabs:ge,timeline:se,timePicker:be,upload:we,notification:Me,tree:Te,colorPicker:Se,datePicker:Fe,rangePicker:Ce,flex:me,wave:$e,dropdown:Ee,warning:Ie,tour:fe,tooltip:ve,popover:xe,popconfirm:Re,floatButton:it,floatButtonGroup:dt,variant:Oe,inputNumber:Le,treeSelect:Ue}=e,ke=i.useCallback((ct,Ke)=>{const{prefixCls:Ye}=e;if(Ke)return Ke;const at=Ye||b.getPrefixCls("");return ct?`${at}-${ct}`:at},[b.getPrefixCls,e.prefixCls]),Je=y||b.iconPrefixCls||Jl,Xe=n||b.csp;sx(Je,Xe);const He=fx(C,b.theme,{prefixCls:ke("")}),je={csp:Xe,autoInsertSpaceInButton:r,alert:o,anchor:a,locale:s||p,direction:u,space:d,splitter:f,virtual:m,popupMatchSelectWidth:g??v,popupOverflow:h,getPrefixCls:ke,iconPrefixCls:Je,theme:He,segmented:S,statistic:x,spin:E,calendar:O,carousel:w,cascader:I,collapse:P,typography:M,checkbox:R,descriptions:N,divider:T,drawer:j,skeleton:z,steps:_,image:B,input:le,textArea:ee,layout:V,list:G,mentions:q,modal:H,progress:W,result:K,slider:U,breadcrumb:te,menu:X,pagination:ae,empty:Y,badge:re,radio:ne,rate:Z,switch:Q,transfer:ie,avatar:de,message:he,tag:ye,table:oe,card:ce,tabs:ge,timeline:se,timePicker:be,upload:we,notification:Me,tree:Te,colorPicker:Se,datePicker:Fe,rangePicker:Ce,flex:me,wave:$e,dropdown:Ee,warning:Ie,tour:fe,tooltip:ve,popover:xe,popconfirm:Re,floatButton:it,floatButtonGroup:dt,variant:Oe,inputNumber:Le,treeSelect:Ue},rt=Object.assign({},b);Object.keys(je).forEach(ct=>{je[ct]!==void 0&&(rt[ct]=je[ct])}),Bx.forEach(ct=>{const Ke=e[ct];Ke&&(rt[ct]=Ke)}),typeof r<"u"&&(rt.button=Object.assign({autoInsertSpace:r},rt.button));const et=So(()=>rt,rt,(ct,Ke)=>{const Ye=Object.keys(ct),at=Object.keys(Ke);return Ye.length!==at.length||Ye.some(gt=>ct[gt]!==Ke[gt])}),{layer:Pe}=i.useContext(ai),qe=i.useMemo(()=>({prefixCls:Je,csp:Xe,layer:Pe?"antd":void 0}),[Je,Xe,Pe]);let We=i.createElement(i.Fragment,null,i.createElement(Dx,{dropdownMatchSelectWidth:v}),t);const tt=i.useMemo(()=>{var ct,Ke,Ye,at;return Lo(((ct=br.Form)===null||ct===void 0?void 0:ct.defaultValidateMessages)||{},((Ye=(Ke=et.locale)===null||Ke===void 0?void 0:Ke.Form)===null||Ye===void 0?void 0:Ye.defaultValidateMessages)||{},((at=et.form)===null||at===void 0?void 0:at.validateMessages)||{},(l==null?void 0:l.validateMessages)||{})},[et,l==null?void 0:l.validateMessages]);Object.keys(tt).length>0&&(We=i.createElement(C$.Provider,{value:tt},We)),s&&(We=i.createElement(E$,{locale:s,_ANT_MARK__:w$},We)),We=i.createElement(wd.Provider,{value:qe},We),c&&(We=i.createElement(F$,{size:c},We)),We=i.createElement(zx,null,We);const mt=i.useMemo(()=>{const ct=He||{},{algorithm:Ke,token:Ye,components:at,cssVar:gt}=ct,Ot=_x(ct,["algorithm","token","components","cssVar"]),Pt=Ke&&(!Array.isArray(Ke)||Ke.length>0)?tu(Ke):_h,Rt={};Object.entries(at||{}).forEach(([zt,Dt])=>{const De=Object.assign({},Dt);"algorithm"in De&&(De.algorithm===!0?De.theme=Pt:(Array.isArray(De.algorithm)||typeof De.algorithm=="function")&&(De.theme=tu(De.algorithm)),delete De.algorithm),Rt[zt]=De});const jt=Object.assign(Object.assign({},Ya),Ye);return Object.assign(Object.assign({},Ot),{theme:Pt,token:jt,components:Rt,override:Object.assign({override:jt},Rt),cssVar:gt})},[He]);return C&&(We=i.createElement(Bh.Provider,{value:mt},We)),et.warning&&(We=i.createElement(y$.Provider,{value:et.warning},We)),$!==void 0&&(We=i.createElement(Lh,{disabled:$},We)),i.createElement(ot.Provider,{value:et},We)},wr=e=>{const t=i.useContext(ot),n=i.useContext(Ed);return i.createElement(Fx,Object.assign({parentContext:t,legacyLocale:n},e))};wr.ConfigContext=ot;wr.SizeContext=ea;wr.config=Ax;wr.useConfig=k$;Object.defineProperty(wr,"SizeContext",{get:()=>ea});var kx={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm193.5 301.7l-210.6 292a31.8 31.8 0 01-51.7 0L318.5 484.9c-3.8-5.3 0-12.7 6.5-12.7h46.9c10.2 0 19.9 4.9 25.9 13.3l71.2 98.8 157.2-218c6-8.3 15.6-13.3 25.9-13.3H699c6.5 0 10.3 7.4 6.5 12.7z"}}]},name:"check-circle",theme:"filled"};function i0(e){var t;return e==null||(t=e.getRootNode)===null||t===void 0?void 0:t.call(e)}function Vx(e){return i0(e)instanceof ShadowRoot}function bl(e){return Vx(e)?i0(e):null}function Wx(e){return e.replace(/-(.)/g,function(t,n){return n.toUpperCase()})}function Kx(e,t){Kt(e,"[@ant-design/icons] ".concat(t))}function Im(e){return Qe(e)==="object"&&typeof e.name=="string"&&typeof e.theme=="string"&&(Qe(e.icon)==="object"||typeof e.icon=="function")}function Rm(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};return Object.keys(e).reduce(function(t,n){var r=e[n];switch(n){case"class":t.className=r,delete t.class;break;default:delete t[n],t[Wx(n)]=r}return t},{})}function $u(e,t,n){return n?F.createElement(e.tag,k(k({key:t},Rm(e.attrs)),n),(e.children||[]).map(function(r,o){return $u(r,"".concat(t,"-").concat(e.tag,"-").concat(o))})):F.createElement(e.tag,k({key:t},Rm(e.attrs)),(e.children||[]).map(function(r,o){return $u(r,"".concat(t,"-").concat(e.tag,"-").concat(o))}))}function l0(e){return bo(e)[0]}function s0(e){return e?Array.isArray(e)?e:[e]:[]}var Gx=`
.anticon {
  display: inline-flex;
  align-items: center;
  color: inherit;
  font-style: normal;
  line-height: 0;
  text-align: center;
  text-transform: none;
  vertical-align: -0.125em;
  text-rendering: optimizeLegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.anticon > * {
  line-height: 1;
}

.anticon svg {
  display: inline-block;
}

.anticon::before {
  display: none;
}

.anticon .anticon-icon {
  display: block;
}

.anticon[tabindex] {
  cursor: pointer;
}

.anticon-spin::before,
.anticon-spin {
  display: inline-block;
  -webkit-animation: loadingCircle 1s infinite linear;
  animation: loadingCircle 1s infinite linear;
}

@-webkit-keyframes loadingCircle {
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes loadingCircle {
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
`,qx=function(t){var n=i.useContext(wd),r=n.csp,o=n.prefixCls,a=n.layer,l=Gx;o&&(l=l.replace(/anticon/g,o)),a&&(l="@layer ".concat(a,` {
`).concat(l,`
}`)),i.useEffect(function(){var s=t.current,c=bl(s);Ar(l,"@ant-design-icons",{prepend:!a,csp:r,attachTo:c})},[])},Ux=["icon","className","onClick","style","primaryColor","secondaryColor"],Ha={primaryColor:"#333",secondaryColor:"#E6E6E6",calculated:!1};function Xx(e){var t=e.primaryColor,n=e.secondaryColor;Ha.primaryColor=t,Ha.secondaryColor=n||l0(t),Ha.calculated=!!n}function Yx(){return k({},Ha)}var da=function(t){var n=t.icon,r=t.className,o=t.onClick,a=t.style,l=t.primaryColor,s=t.secondaryColor,c=ft(t,Ux),u=i.useRef(),d=Ha;if(l&&(d={primaryColor:l,secondaryColor:s||l0(l)}),qx(u),Kx(Im(n),"icon should be icon definiton, but got ".concat(n)),!Im(n))return null;var f=n;return f&&typeof f.icon=="function"&&(f=k(k({},f),{},{icon:f.icon(d.primaryColor,d.secondaryColor)})),$u(f.icon,"svg-".concat(f.name),k(k({className:r,onClick:o,style:a,"data-icon":f.name,width:"1em",height:"1em",fill:"currentColor","aria-hidden":"true"},c),{},{ref:u}))};da.displayName="IconReact";da.getTwoToneColors=Yx;da.setTwoToneColors=Xx;function c0(e){var t=s0(e),n=J(t,2),r=n[0],o=n[1];return da.setTwoToneColors({primaryColor:r,secondaryColor:o})}function Qx(){var e=da.getTwoToneColors();return e.calculated?[e.primaryColor,e.secondaryColor]:e.primaryColor}var Zx=["className","icon","spin","rotate","tabIndex","onClick","twoToneColor"];c0(Jo.primary);var vt=i.forwardRef(function(e,t){var n=e.className,r=e.icon,o=e.spin,a=e.rotate,l=e.tabIndex,s=e.onClick,c=e.twoToneColor,u=ft(e,Zx),d=i.useContext(wd),f=d.prefixCls,m=f===void 0?"anticon":f,v=d.rootClassName,g=A(v,m,D(D({},"".concat(m,"-").concat(r.name),!!r.name),"".concat(m,"-spin"),!!o||r.name==="loading"),n),h=l;h===void 0&&s&&(h=-1);var p=a?{msTransform:"rotate(".concat(a,"deg)"),transform:"rotate(".concat(a,"deg)")}:void 0,b=s0(c),y=J(b,2),C=y[0],$=y[1];return i.createElement("span",ue({role:"img","aria-label":r.name},u,{ref:t,tabIndex:h,onClick:s,className:g}),i.createElement(da,{icon:r,primaryColor:C,secondaryColor:$,style:p}))});vt.displayName="AntdIcon";vt.getTwoToneColor=Qx;vt.setTwoToneColor=c0;var Jx=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:kx}))},ii=i.forwardRef(Jx),ew={icon:{tag:"svg",attrs:{"fill-rule":"evenodd",viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64c247.4 0 448 200.6 448 448S759.4 960 512 960 64 759.4 64 512 264.6 64 512 64zm127.98 274.82h-.04l-.08.06L512 466.75 384.14 338.88c-.04-.05-.06-.06-.08-.06a.12.12 0 00-.07 0c-.03 0-.05.01-.09.05l-45.02 45.02a.2.2 0 00-.05.09.12.12 0 000 .07v.02a.27.27 0 00.06.06L466.75 512 338.88 639.86c-.05.04-.06.06-.06.08a.12.12 0 000 .07c0 .03.01.05.05.09l45.02 45.02a.2.2 0 00.09.05.12.12 0 00.07 0c.02 0 .04-.01.08-.05L512 557.25l127.86 127.87c.04.04.06.05.08.05a.12.12 0 00.07 0c.03 0 .05-.01.09-.05l45.02-45.02a.2.2 0 00.05-.09.12.12 0 000-.07v-.02a.27.27 0 00-.05-.06L557.25 512l127.87-127.86c.04-.04.05-.06.05-.08a.12.12 0 000-.07c0-.03-.01-.05-.05-.09l-45.02-45.02a.2.2 0 00-.09-.05.12.12 0 00-.07 0z"}}]},name:"close-circle",theme:"filled"},tw=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:ew}))},wo=i.forwardRef(tw),nw={icon:{tag:"svg",attrs:{"fill-rule":"evenodd",viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M799.86 166.31c.02 0 .04.02.08.06l57.69 57.7c.04.03.05.05.06.08a.12.12 0 010 .06c0 .03-.02.05-.06.09L569.93 512l287.7 287.7c.04.04.05.06.06.09a.12.12 0 010 .07c0 .02-.02.04-.06.08l-57.7 57.69c-.03.04-.05.05-.07.06a.12.12 0 01-.07 0c-.03 0-.05-.02-.09-.06L512 569.93l-287.7 287.7c-.04.04-.06.05-.09.06a.12.12 0 01-.07 0c-.02 0-.04-.02-.08-.06l-57.69-57.7c-.04-.03-.05-.05-.06-.07a.12.12 0 010-.07c0-.03.02-.05.06-.09L454.07 512l-287.7-287.7c-.04-.04-.05-.06-.06-.09a.12.12 0 010-.07c0-.02.02-.04.06-.08l57.7-57.69c.03-.04.05-.05.07-.06a.12.12 0 01.07 0c.03 0 .05.02.09.06L512 454.07l287.7-287.7c.04-.04.06-.05.09-.06a.12.12 0 01.07 0z"}}]},name:"close",theme:"outlined"},rw=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:nw}))},Fr=i.forwardRef(rw),ow={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm-32 232c0-4.4 3.6-8 8-8h48c4.4 0 8 3.6 8 8v272c0 4.4-3.6 8-8 8h-48c-4.4 0-8-3.6-8-8V296zm32 440a48.01 48.01 0 010-96 48.01 48.01 0 010 96z"}}]},name:"exclamation-circle",theme:"filled"},aw=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:ow}))},fa=i.forwardRef(aw),iw={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm32 664c0 4.4-3.6 8-8 8h-48c-4.4 0-8-3.6-8-8V456c0-4.4 3.6-8 8-8h48c4.4 0 8 3.6 8 8v272zm-32-344a48.01 48.01 0 010-96 48.01 48.01 0 010 96z"}}]},name:"info-circle",theme:"filled"},lw=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:iw}))},ts=i.forwardRef(lw),sw=`accept acceptCharset accessKey action allowFullScreen allowTransparency
    alt async autoComplete autoFocus autoPlay capture cellPadding cellSpacing challenge
    charSet checked classID className colSpan cols content contentEditable contextMenu
    controls coords crossOrigin data dateTime default defer dir disabled download draggable
    encType form formAction formEncType formMethod formNoValidate formTarget frameBorder
    headers height hidden high href hrefLang htmlFor httpEquiv icon id inputMode integrity
    is keyParams keyType kind label lang list loop low manifest marginHeight marginWidth max maxLength media
    mediaGroup method min minLength multiple muted name noValidate nonce open
    optimum pattern placeholder poster preload radioGroup readOnly rel required
    reversed role rowSpan rows sandbox scope scoped scrolling seamless selected
    shape size sizes span spellCheck src srcDoc srcLang srcSet start step style
    summary tabIndex target title type useMap value width wmode wrap`,cw=`onCopy onCut onPaste onCompositionEnd onCompositionStart onCompositionUpdate onKeyDown
    onKeyPress onKeyUp onFocus onBlur onChange onInput onSubmit onClick onContextMenu onDoubleClick
    onDrag onDragEnd onDragEnter onDragExit onDragLeave onDragOver onDragStart onDrop onMouseDown
    onMouseEnter onMouseLeave onMouseMove onMouseOut onMouseOver onMouseUp onSelect onTouchCancel
    onTouchEnd onTouchMove onTouchStart onScroll onWheel onAbort onCanPlay onCanPlayThrough
    onDurationChange onEmptied onEncrypted onEnded onError onLoadedData onLoadedMetadata
    onLoadStart onPause onPlay onPlaying onProgress onRateChange onSeeked onSeeking onStalled onSuspend onTimeUpdate onVolumeChange onWaiting onLoad onError`,uw="".concat(sw," ").concat(cw).split(/[\s\n]+/),dw="aria-",fw="data-";function Pm(e,t){return e.indexOf(t)===0}function rn(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,n;t===!1?n={aria:!0,data:!0,attr:!0}:t===!0?n={aria:!0}:n=k({},t);var r={};return Object.keys(e).forEach(function(o){(n.aria&&(o==="role"||Pm(o,dw))||n.data&&Pm(o,fw)||n.attr&&uw.includes(o))&&(r[o]=e[o])}),r}function u0(e){return e&&F.isValidElement(e)&&e.type===F.Fragment}const Nd=(e,t,n)=>F.isValidElement(e)?F.cloneElement(e,typeof n=="function"?n(e.props||{}):n):t;function cn(e,t){return Nd(e,e,t)}const _i=(e,t,n,r,o)=>({background:e,border:`${L(r.lineWidth)} ${r.lineType} ${t}`,[`${o}-icon`]:{color:n}}),mw=e=>{const{componentCls:t,motionDurationSlow:n,marginXS:r,marginSM:o,fontSize:a,fontSizeLG:l,lineHeight:s,borderRadiusLG:c,motionEaseInOutCirc:u,withDescriptionIconSize:d,colorText:f,colorTextHeading:m,withDescriptionPadding:v,defaultPadding:g}=e;return{[t]:Object.assign(Object.assign({},Tt(e)),{position:"relative",display:"flex",alignItems:"center",padding:g,wordWrap:"break-word",borderRadius:c,[`&${t}-rtl`]:{direction:"rtl"},[`${t}-content`]:{flex:1,minWidth:0},[`${t}-icon`]:{marginInlineEnd:r,lineHeight:0},"&-description":{display:"none",fontSize:a,lineHeight:s},"&-message":{color:m},[`&${t}-motion-leave`]:{overflow:"hidden",opacity:1,transition:`max-height ${n} ${u}, opacity ${n} ${u},
        padding-top ${n} ${u}, padding-bottom ${n} ${u},
        margin-bottom ${n} ${u}`},[`&${t}-motion-leave-active`]:{maxHeight:0,marginBottom:"0 !important",paddingTop:0,paddingBottom:0,opacity:0}}),[`${t}-with-description`]:{alignItems:"flex-start",padding:v,[`${t}-icon`]:{marginInlineEnd:o,fontSize:d,lineHeight:0},[`${t}-message`]:{display:"block",marginBottom:r,color:m,fontSize:l},[`${t}-description`]:{display:"block",color:f}},[`${t}-banner`]:{marginBottom:0,border:"0 !important",borderRadius:0}}},vw=e=>{const{componentCls:t,colorSuccess:n,colorSuccessBorder:r,colorSuccessBg:o,colorWarning:a,colorWarningBorder:l,colorWarningBg:s,colorError:c,colorErrorBorder:u,colorErrorBg:d,colorInfo:f,colorInfoBorder:m,colorInfoBg:v}=e;return{[t]:{"&-success":_i(o,r,n,e,t),"&-info":_i(v,m,f,e,t),"&-warning":_i(s,l,a,e,t),"&-error":Object.assign(Object.assign({},_i(d,u,c,e,t)),{[`${t}-description > pre`]:{margin:0,padding:0}})}}},gw=e=>{const{componentCls:t,iconCls:n,motionDurationMid:r,marginXS:o,fontSizeIcon:a,colorIcon:l,colorIconHover:s}=e;return{[t]:{"&-action":{marginInlineStart:o},[`${t}-close-icon`]:{marginInlineStart:o,padding:0,overflow:"hidden",fontSize:a,lineHeight:L(a),backgroundColor:"transparent",border:"none",outline:"none",cursor:"pointer",[`${n}-close`]:{color:l,transition:`color ${r}`,"&:hover":{color:s}}},"&-close-text":{color:l,transition:`color ${r}`,"&:hover":{color:s}}}}},pw=e=>({withDescriptionIconSize:e.fontSizeHeading3,defaultPadding:`${e.paddingContentVerticalSM}px 12px`,withDescriptionPadding:`${e.paddingMD}px ${e.paddingContentHorizontalLG}px`}),hw=It("Alert",e=>[mw(e),vw(e),gw(e)],pw);var Nm=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const bw={success:ii,info:ts,error:wo,warning:fa},yw=e=>{const{icon:t,prefixCls:n,type:r}=e,o=bw[r]||null;return t?Nd(t,i.createElement("span",{className:`${n}-icon`},t),()=>({className:A(`${n}-icon`,t.props.className)})):i.createElement(o,{className:`${n}-icon`})},Cw=e=>{const{isClosable:t,prefixCls:n,closeIcon:r,handleClose:o,ariaProps:a}=e,l=r===!0||r===void 0?i.createElement(Fr,null):r;return t?i.createElement("button",Object.assign({type:"button",onClick:o,className:`${n}-close-icon`,tabIndex:0},a),l):null},d0=i.forwardRef((e,t)=>{const{description:n,prefixCls:r,message:o,banner:a,className:l,rootClassName:s,style:c,onMouseEnter:u,onMouseLeave:d,onClick:f,afterClose:m,showIcon:v,closable:g,closeText:h,closeIcon:p,action:b,id:y}=e,C=Nm(e,["description","prefixCls","message","banner","className","rootClassName","style","onMouseEnter","onMouseLeave","onClick","afterClose","showIcon","closable","closeText","closeIcon","action","id"]),[$,S]=i.useState(!1),x=i.useRef(null);i.useImperativeHandle(t,()=>({nativeElement:x.current}));const{getPrefixCls:E,direction:O,closable:w,closeIcon:I,className:P,style:M}=tn("alert"),R=E("alert",r),[N,T,j]=hw(R),z=K=>{var U;S(!0),(U=e.onClose)===null||U===void 0||U.call(e,K)},_=i.useMemo(()=>e.type!==void 0?e.type:a?"warning":"info",[e.type,a]),B=i.useMemo(()=>typeof g=="object"&&g.closeIcon||h?!0:typeof g=="boolean"?g:p!==!1&&p!==null&&p!==void 0?!0:!!w,[h,p,g,w]),V=a&&v===void 0?!0:v,G=A(R,`${R}-${_}`,{[`${R}-with-description`]:!!n,[`${R}-no-icon`]:!V,[`${R}-banner`]:!!a,[`${R}-rtl`]:O==="rtl"},P,l,s,j,T),q=rn(C,{aria:!0,data:!0}),H=i.useMemo(()=>typeof g=="object"&&g.closeIcon?g.closeIcon:h||(p!==void 0?p:typeof w=="object"&&w.closeIcon?w.closeIcon:I),[p,g,h,I]),W=i.useMemo(()=>{const K=g??w;if(typeof K=="object"){const{closeIcon:U}=K;return Nm(K,["closeIcon"])}return{}},[g,w]);return N(i.createElement(En,{visible:!$,motionName:`${R}-motion`,motionAppear:!1,motionEnter:!1,onLeaveStart:K=>({maxHeight:K.offsetHeight}),onLeaveEnd:m},({className:K,style:U},te)=>i.createElement("div",Object.assign({id:y,ref:un(x,te),"data-show":!$,className:A(G,K),style:Object.assign(Object.assign(Object.assign({},M),c),U),onMouseEnter:u,onMouseLeave:d,onClick:f,role:"alert"},q),V?i.createElement(yw,{description:n,icon:e.icon,prefixCls:R,type:_}):null,i.createElement("div",{className:`${R}-content`},o?i.createElement("div",{className:`${R}-message`},o):null,n?i.createElement("div",{className:`${R}-description`},n):null),b?i.createElement("div",{className:`${R}-action`},b):null,i.createElement(Cw,{isClosable:B,prefixCls:R,closeIcon:H,handleClose:z,ariaProps:W}))))});function Sw(e,t,n){return t=ho(t),th(e,Ul()?Reflect.construct(t,n||[],ho(e).constructor):t.apply(e,n))}let $w=function(e){function t(){var n;return Zt(this,t),n=Sw(this,t,arguments),n.state={error:void 0,info:{componentStack:""}},n}return tr(t,e),Jt(t,[{key:"componentDidCatch",value:function(r,o){this.setState({error:r,info:o})}},{key:"render",value:function(){const{message:r,description:o,id:a,children:l}=this.props,{error:s,info:c}=this.state,u=(c==null?void 0:c.componentStack)||null,d=typeof r>"u"?(s||"").toString():r,f=typeof o>"u"?u:o;return s?i.createElement(d0,{id:a,type:"error",message:d,description:i.createElement("pre",{style:{fontSize:"0.9em",overflowX:"auto"}},f)}):l}}])}(i.Component);const xw=d0;xw.ErrorBoundary=$w;function xu(e){return e!=null&&e===e.window}const ww=e=>{var t,n;if(typeof window>"u")return 0;let r=0;return xu(e)?r=e.pageYOffset:e instanceof Document?r=e.documentElement.scrollTop:(e instanceof HTMLElement||e)&&(r=e.scrollTop),e&&!xu(e)&&typeof r!="number"&&(r=(n=((t=e.ownerDocument)!==null&&t!==void 0?t:e).documentElement)===null||n===void 0?void 0:n.scrollTop),r};function Ew(e,t,n,r){const o=n-t;return e/=r/2,e<1?o/2*e*e*e+t:o/2*((e-=2)*e*e+2)+t}function Ow(e,t={}){const{getContainer:n=()=>window,callback:r,duration:o=450}=t,a=n(),l=ww(a),s=Date.now(),c=()=>{const d=Date.now()-s,f=Ew(d>o?o:d,l,e,o);xu(a)?a.scrollTo(window.pageXOffset,f):a instanceof Document||a.constructor.name==="HTMLDocument"?a.documentElement.scrollTop=f:a.scrollTop=f,d<o?Et(c):typeof r=="function"&&r()};Et(c)}const Cn=e=>{const[,,,,t]=yn();return t?`${e}-css-var`:""};var Ne={BACKSPACE:8,TAB:9,ENTER:13,SHIFT:16,CTRL:17,ALT:18,CAPS_LOCK:20,ESC:27,SPACE:32,PAGE_UP:33,PAGE_DOWN:34,END:35,HOME:36,LEFT:37,UP:38,RIGHT:39,DOWN:40,DELETE:46,N:78,P:80,META:91,WIN_KEY_RIGHT:92,CONTEXT_MENU:93,F1:112,F2:113,F3:114,F4:115,F5:116,F6:117,F7:118,F8:119,F9:120,F10:121,F11:122,F12:123,SEMICOLON:186,EQUALS:187,WIN_KEY:224},Md=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.style,o=e.className,a=e.duration,l=a===void 0?4.5:a,s=e.showProgress,c=e.pauseOnHover,u=c===void 0?!0:c,d=e.eventKey,f=e.content,m=e.closable,v=e.closeIcon,g=v===void 0?"x":v,h=e.props,p=e.onClick,b=e.onNoticeClose,y=e.times,C=e.hovering,$=i.useState(!1),S=J($,2),x=S[0],E=S[1],O=i.useState(0),w=J(O,2),I=w[0],P=w[1],M=i.useState(0),R=J(M,2),N=R[0],T=R[1],j=C||x,z=l>0&&s,_=function(){b(d)},B=function(K){(K.key==="Enter"||K.code==="Enter"||K.keyCode===Ne.ENTER)&&_()};i.useEffect(function(){if(!j&&l>0){var W=Date.now()-N,K=setTimeout(function(){_()},l*1e3-N);return function(){u&&clearTimeout(K),T(Date.now()-W)}}},[l,j,y]),i.useEffect(function(){if(!j&&z&&(u||N===0)){var W=performance.now(),K,U=function te(){cancelAnimationFrame(K),K=requestAnimationFrame(function(X){var ae=X+N-W,le=Math.min(ae/(l*1e3),1);P(le*100),le<1&&te()})};return U(),function(){u&&cancelAnimationFrame(K)}}},[l,N,j,z,y]);var V=i.useMemo(function(){return Qe(m)==="object"&&m!==null?m:m?{closeIcon:g}:{}},[m,g]),G=rn(V,!0),q=100-(!I||I<0?0:I>100?100:I),H="".concat(n,"-notice");return i.createElement("div",ue({},h,{ref:t,className:A(H,o,D({},"".concat(H,"-closable"),m)),style:r,onMouseEnter:function(K){var U;E(!0),h==null||(U=h.onMouseEnter)===null||U===void 0||U.call(h,K)},onMouseLeave:function(K){var U;E(!1),h==null||(U=h.onMouseLeave)===null||U===void 0||U.call(h,K)},onClick:p}),i.createElement("div",{className:"".concat(H,"-content")},f),m&&i.createElement("a",ue({tabIndex:0,className:"".concat(H,"-close"),onKeyDown:B,"aria-label":"Close"},G,{onClick:function(K){K.preventDefault(),K.stopPropagation(),_()}}),V.closeIcon),z&&i.createElement("progress",{className:"".concat(H,"-progress"),max:"100",value:q},q+"%"))}),f0=F.createContext({}),m0=function(t){var n=t.children,r=t.classNames;return F.createElement(f0.Provider,{value:{classNames:r}},n)},Mm=8,Tm=3,jm=16,Iw=function(t){var n={offset:Mm,threshold:Tm,gap:jm};if(t&&Qe(t)==="object"){var r,o,a;n.offset=(r=t.offset)!==null&&r!==void 0?r:Mm,n.threshold=(o=t.threshold)!==null&&o!==void 0?o:Tm,n.gap=(a=t.gap)!==null&&a!==void 0?a:jm}return[!!t,n]},Rw=["className","style","classNames","styles"],Pw=function(t){var n=t.configList,r=t.placement,o=t.prefixCls,a=t.className,l=t.style,s=t.motion,c=t.onAllNoticeRemoved,u=t.onNoticeClose,d=t.stack,f=i.useContext(f0),m=f.classNames,v=i.useRef({}),g=i.useState(null),h=J(g,2),p=h[0],b=h[1],y=i.useState([]),C=J(y,2),$=C[0],S=C[1],x=n.map(function(j){return{config:j,key:String(j.key)}}),E=Iw(d),O=J(E,2),w=O[0],I=O[1],P=I.offset,M=I.threshold,R=I.gap,N=w&&($.length>0||x.length<=M),T=typeof s=="function"?s(r):s;return i.useEffect(function(){w&&$.length>1&&S(function(j){return j.filter(function(z){return x.some(function(_){var B=_.key;return z===B})})})},[$,x,w]),i.useEffect(function(){var j;if(w&&v.current[(j=x[x.length-1])===null||j===void 0?void 0:j.key]){var z;b(v.current[(z=x[x.length-1])===null||z===void 0?void 0:z.key])}},[x,w]),F.createElement(n0,ue({key:r,className:A(o,"".concat(o,"-").concat(r),m==null?void 0:m.list,a,D(D({},"".concat(o,"-stack"),!!w),"".concat(o,"-stack-expanded"),N)),style:l,keys:x,motionAppear:!0},T,{onAllRemoved:function(){c(r)}}),function(j,z){var _=j.config,B=j.className,V=j.style,G=j.index,q=_,H=q.key,W=q.times,K=String(H),U=_,te=U.className,X=U.style,ae=U.classNames,le=U.styles,ee=ft(U,Rw),Y=x.findIndex(function(se){return se.key===K}),re={};if(w){var ne=x.length-1-(Y>-1?Y:G-1),Z=r==="top"||r==="bottom"?"-50%":"0";if(ne>0){var Q,ie,de;re.height=N?(Q=v.current[K])===null||Q===void 0?void 0:Q.offsetHeight:p==null?void 0:p.offsetHeight;for(var he=0,ye=0;ye<ne;ye++){var oe;he+=((oe=v.current[x[x.length-1-ye].key])===null||oe===void 0?void 0:oe.offsetHeight)+R}var ce=(N?he:ne*P)*(r.startsWith("top")?1:-1),ge=!N&&p!==null&&p!==void 0&&p.offsetWidth&&(ie=v.current[K])!==null&&ie!==void 0&&ie.offsetWidth?((p==null?void 0:p.offsetWidth)-P*2*(ne<3?ne:3))/((de=v.current[K])===null||de===void 0?void 0:de.offsetWidth):1;re.transform="translate3d(".concat(Z,", ").concat(ce,"px, 0) scaleX(").concat(ge,")")}else re.transform="translate3d(".concat(Z,", 0, 0)")}return F.createElement("div",{ref:z,className:A("".concat(o,"-notice-wrapper"),B,ae==null?void 0:ae.wrapper),style:k(k(k({},V),re),le==null?void 0:le.wrapper),onMouseEnter:function(){return S(function(be){return be.includes(K)?be:[].concat(pe(be),[K])})},onMouseLeave:function(){return S(function(be){return be.filter(function(we){return we!==K})})}},F.createElement(Md,ue({},ee,{ref:function(be){Y>-1?v.current[K]=be:delete v.current[K]},prefixCls:o,classNames:ae,styles:le,className:A(te,m==null?void 0:m.notice),style:X,times:W,key:H,eventKey:H,onNoticeClose:u,hovering:w&&$.length>0})))})},Nw=i.forwardRef(function(e,t){var n=e.prefixCls,r=n===void 0?"rc-notification":n,o=e.container,a=e.motion,l=e.maxCount,s=e.className,c=e.style,u=e.onAllRemoved,d=e.stack,f=e.renderNotifications,m=i.useState([]),v=J(m,2),g=v[0],h=v[1],p=function(w){var I,P=g.find(function(M){return M.key===w});P==null||(I=P.onClose)===null||I===void 0||I.call(P),h(function(M){return M.filter(function(R){return R.key!==w})})};i.useImperativeHandle(t,function(){return{open:function(w){h(function(I){var P=pe(I),M=P.findIndex(function(T){return T.key===w.key}),R=k({},w);if(M>=0){var N;R.times=(((N=I[M])===null||N===void 0?void 0:N.times)||0)+1,P[M]=R}else R.times=0,P.push(R);return l>0&&P.length>l&&(P=P.slice(-l)),P})},close:function(w){p(w)},destroy:function(){h([])}}});var b=i.useState({}),y=J(b,2),C=y[0],$=y[1];i.useEffect(function(){var O={};g.forEach(function(w){var I=w.placement,P=I===void 0?"topRight":I;P&&(O[P]=O[P]||[],O[P].push(w))}),Object.keys(C).forEach(function(w){O[w]=O[w]||[]}),$(O)},[g]);var S=function(w){$(function(I){var P=k({},I),M=P[w]||[];return M.length||delete P[w],P})},x=i.useRef(!1);if(i.useEffect(function(){Object.keys(C).length>0?x.current=!0:x.current&&(u==null||u(),x.current=!1)},[C]),!o)return null;var E=Object.keys(C);return Pr.createPortal(i.createElement(i.Fragment,null,E.map(function(O){var w=C[O],I=i.createElement(Pw,{key:O,configList:w,placement:O,prefixCls:r,className:s==null?void 0:s(O),style:c==null?void 0:c(O),motion:a,onNoticeClose:p,onAllNoticeRemoved:S,stack:d});return f?f(I,{prefixCls:r,key:O}):I})),o)}),Mw=["getContainer","motion","prefixCls","maxCount","className","style","onAllRemoved","stack","renderNotifications"],Tw=function(){return document.body},zm=0;function jw(){for(var e={},t=arguments.length,n=new Array(t),r=0;r<t;r++)n[r]=arguments[r];return n.forEach(function(o){o&&Object.keys(o).forEach(function(a){var l=o[a];l!==void 0&&(e[a]=l)})}),e}function v0(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},t=e.getContainer,n=t===void 0?Tw:t,r=e.motion,o=e.prefixCls,a=e.maxCount,l=e.className,s=e.style,c=e.onAllRemoved,u=e.stack,d=e.renderNotifications,f=ft(e,Mw),m=i.useState(),v=J(m,2),g=v[0],h=v[1],p=i.useRef(),b=i.createElement(Nw,{container:g,ref:p,prefixCls:o,motion:r,maxCount:a,className:l,style:s,onAllRemoved:c,stack:u,renderNotifications:d}),y=i.useState([]),C=J(y,2),$=C[0],S=C[1],x=Nt(function(O){var w=jw(f,O);(w.key===null||w.key===void 0)&&(w.key="rc-notification-".concat(zm),zm+=1),S(function(I){return[].concat(pe(I),[{type:"open",config:w}])})}),E=i.useMemo(function(){return{open:x,close:function(w){S(function(I){return[].concat(pe(I),[{type:"close",key:w}])})},destroy:function(){S(function(w){return[].concat(pe(w),[{type:"destroy"}])})}}},[]);return i.useEffect(function(){h(n())}),i.useEffect(function(){if(p.current&&$.length){$.forEach(function(I){switch(I.type){case"open":p.current.open(I.config);break;case"close":p.current.close(I.key);break;case"destroy":p.current.destroy();break}});var O,w;S(function(I){return(O!==I||!w)&&(O=I,w=I.filter(function(P){return!$.includes(P)})),w})}},[$]),[E,b]}var zw={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M988 548c-19.9 0-36-16.1-36-36 0-59.4-11.6-117-34.6-171.3a440.45 440.45 0 00-94.3-139.9 437.71 437.71 0 00-139.9-94.3C629 83.6 571.4 72 512 72c-19.9 0-36-16.1-36-36s16.1-36 36-36c69.1 0 136.2 13.5 199.3 40.3C772.3 66 827 103 874 150c47 47 83.9 101.8 109.7 162.7 26.7 63.1 40.2 130.2 40.2 199.3.1 19.9-16 36-35.9 36z"}}]},name:"loading",theme:"outlined"},Dw=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:zw}))},Jr=i.forwardRef(Dw);const li=F.createContext(void 0),Gr=100,_w=10,Td=Gr*_w,g0={Modal:Gr,Drawer:Gr,Popover:Gr,Popconfirm:Gr,Tooltip:Gr,Tour:Gr,FloatButton:Gr},Bw={SelectLike:50,Dropdown:50,DatePicker:50,Menu:50,ImagePreview:1};function Lw(e){return e in g0}const ma=(e,t)=>{const[,n]=yn(),r=F.useContext(li),o=Lw(e);let a;if(t!==void 0)a=[t,t];else{let l=r??0;o?l+=(r?0:n.zIndexPopupBase)+g0[e]:l+=Bw[e],a=[r===void 0?t:l,l]}return a},Hw=e=>{const{componentCls:t,iconCls:n,boxShadow:r,colorText:o,colorSuccess:a,colorError:l,colorWarning:s,colorInfo:c,fontSizeLG:u,motionEaseInOutCirc:d,motionDurationSlow:f,marginXS:m,paddingXS:v,borderRadiusLG:g,zIndexPopup:h,contentPadding:p,contentBg:b}=e,y=`${t}-notice`,C=new $t("MessageMoveIn",{"0%":{padding:0,transform:"translateY(-100%)",opacity:0},"100%":{padding:v,transform:"translateY(0)",opacity:1}}),$=new $t("MessageMoveOut",{"0%":{maxHeight:e.height,padding:v,opacity:1},"100%":{maxHeight:0,padding:0,opacity:0}}),S={padding:v,textAlign:"center",[`${t}-custom-content`]:{display:"flex",alignItems:"center"},[`${t}-custom-content > ${n}`]:{marginInlineEnd:m,fontSize:u},[`${y}-content`]:{display:"inline-block",padding:p,background:b,borderRadius:g,boxShadow:r,pointerEvents:"all"},[`${t}-success > ${n}`]:{color:a},[`${t}-error > ${n}`]:{color:l},[`${t}-warning > ${n}`]:{color:s},[`${t}-info > ${n},
      ${t}-loading > ${n}`]:{color:c}};return[{[t]:Object.assign(Object.assign({},Tt(e)),{color:o,position:"fixed",top:m,width:"100%",pointerEvents:"none",zIndex:h,[`${t}-move-up`]:{animationFillMode:"forwards"},[`
        ${t}-move-up-appear,
        ${t}-move-up-enter
      `]:{animationName:C,animationDuration:f,animationPlayState:"paused",animationTimingFunction:d},[`
        ${t}-move-up-appear${t}-move-up-appear-active,
        ${t}-move-up-enter${t}-move-up-enter-active
      `]:{animationPlayState:"running"},[`${t}-move-up-leave`]:{animationName:$,animationDuration:f,animationPlayState:"paused",animationTimingFunction:d},[`${t}-move-up-leave${t}-move-up-leave-active`]:{animationPlayState:"running"},"&-rtl":{direction:"rtl",span:{direction:"rtl"}}})},{[t]:{[`${y}-wrapper`]:Object.assign({},S)}},{[`${t}-notice-pure-panel`]:Object.assign(Object.assign({},S),{padding:0,textAlign:"start"})}]},Aw=e=>({zIndexPopup:e.zIndexPopupBase+Td+10,contentBg:e.colorBgElevated,contentPadding:`${(e.controlHeightLG-e.fontSize*e.lineHeight)/2}px ${e.paddingSM}px`}),p0=It("Message",e=>{const t=yt(e,{height:150});return Hw(t)},Aw);var Fw=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const kw={info:i.createElement(ts,null),success:i.createElement(ii,null),error:i.createElement(wo,null),warning:i.createElement(fa,null),loading:i.createElement(Jr,null)},h0=({prefixCls:e,type:t,icon:n,children:r})=>i.createElement("div",{className:A(`${e}-custom-content`,`${e}-${t}`)},n||kw[t],i.createElement("span",null,r)),Vw=e=>{const{prefixCls:t,className:n,type:r,icon:o,content:a}=e,l=Fw(e,["prefixCls","className","type","icon","content"]),{getPrefixCls:s}=i.useContext(ot),c=t||s("message"),u=Cn(c),[d,f,m]=p0(c,u);return d(i.createElement(Md,Object.assign({},l,{prefixCls:c,className:A(n,f,`${c}-notice-pure-panel`,m,u),eventKey:"pure",duration:null,content:i.createElement(h0,{prefixCls:c,type:r,icon:o},a)})))};function Ww(e,t){return{motionName:t??`${e}-move-up`}}function jd(e){let t;const n=new Promise(o=>{t=e(()=>{o(!0)})}),r=()=>{t==null||t()};return r.then=(o,a)=>n.then(o,a),r.promise=n,r}var Kw=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Gw=8,qw=3,Uw=({children:e,prefixCls:t})=>{const n=Cn(t),[r,o,a]=p0(t,n);return r(i.createElement(m0,{classNames:{list:A(o,a,n)}},e))},Xw=(e,{prefixCls:t,key:n})=>i.createElement(Uw,{prefixCls:t,key:n},e),Yw=i.forwardRef((e,t)=>{const{top:n,prefixCls:r,getContainer:o,maxCount:a,duration:l=qw,rtl:s,transitionName:c,onAllRemoved:u}=e,{getPrefixCls:d,getPopupContainer:f,message:m,direction:v}=i.useContext(ot),g=r||d("message"),h=()=>({left:"50%",transform:"translateX(-50%)",top:n??Gw}),p=()=>A({[`${g}-rtl`]:s??v==="rtl"}),b=()=>Ww(g,c),y=i.createElement("span",{className:`${g}-close-x`},i.createElement(Fr,{className:`${g}-close-icon`})),[C,$]=v0({prefixCls:g,style:h,className:p,motion:b,closable:!1,closeIcon:y,duration:l,getContainer:()=>(o==null?void 0:o())||(f==null?void 0:f())||document.body,maxCount:a,onAllRemoved:u,renderNotifications:Xw});return i.useImperativeHandle(t,()=>Object.assign(Object.assign({},C),{prefixCls:g,message:m})),$});let Dm=0;function b0(e){const t=i.useRef(null);return no(),[i.useMemo(()=>{const r=c=>{var u;(u=t.current)===null||u===void 0||u.close(c)},o=c=>{if(!t.current){const x=()=>{};return x.then=()=>{},x}const{open:u,prefixCls:d,message:f}=t.current,m=`${d}-notice`,{content:v,icon:g,type:h,key:p,className:b,style:y,onClose:C}=c,$=Kw(c,["content","icon","type","key","className","style","onClose"]);let S=p;return S==null&&(Dm+=1,S=`antd-message-${Dm}`),jd(x=>(u(Object.assign(Object.assign({},$),{key:S,content:i.createElement(h0,{prefixCls:d,type:h,icon:g},v),placement:"top",className:A(h&&`${m}-${h}`,b,f==null?void 0:f.className),style:Object.assign(Object.assign({},f==null?void 0:f.style),y),onClose:()=>{C==null||C(),x()}})),()=>{r(S)}))},l={open:o,destroy:c=>{var u;c!==void 0?r(c):(u=t.current)===null||u===void 0||u.destroy()}};return["info","success","warning","error","loading"].forEach(c=>{const u=(d,f,m)=>{let v;d&&typeof d=="object"&&"content"in d?v=d:v={content:d};let g,h;typeof f=="function"?h=f:(g=f,h=m);const p=Object.assign(Object.assign({onClose:h,duration:g},v),{type:c});return o(p)};l[c]=u}),l},[]),i.createElement(Yw,Object.assign({key:"message-holder"},e,{ref:t}))]}function Qw(e){return b0(e)}function Zw(){const[e,t]=i.useState([]),n=i.useCallback(r=>(t(o=>[].concat(pe(o),[r])),()=>{t(o=>o.filter(a=>a!==r))}),[]);return[e,n]}function y0(e,t){this.v=e,this.k=t}function zn(e,t,n,r){var o=Object.defineProperty;try{o({},"",{})}catch{o=0}zn=function(l,s,c,u){function d(f,m){zn(l,f,function(v){return this._invoke(f,m,v)})}s?o?o(l,s,{value:c,enumerable:!u,configurable:!u,writable:!u}):l[s]=c:(d("next",0),d("throw",1),d("return",2))},zn(e,t,n,r)}function zd(){/*! regenerator-runtime -- Copyright (c) 2014-present, Facebook, Inc. -- license (MIT): https://github.com/babel/babel/blob/main/packages/babel-helpers/LICENSE */var e,t,n=typeof Symbol=="function"?Symbol:{},r=n.iterator||"@@iterator",o=n.toStringTag||"@@toStringTag";function a(v,g,h,p){var b=g&&g.prototype instanceof s?g:s,y=Object.create(b.prototype);return zn(y,"_invoke",function(C,$,S){var x,E,O,w=0,I=S||[],P=!1,M={p:0,n:0,v:e,a:R,f:R.bind(e,4),d:function(T,j){return x=T,E=0,O=e,M.n=j,l}};function R(N,T){for(E=N,O=T,t=0;!P&&w&&!j&&t<I.length;t++){var j,z=I[t],_=M.p,B=z[2];N>3?(j=B===T)&&(O=z[(E=z[4])?5:(E=3,3)],z[4]=z[5]=e):z[0]<=_&&((j=N<2&&_<z[1])?(E=0,M.v=T,M.n=z[1]):_<B&&(j=N<3||z[0]>T||T>B)&&(z[4]=N,z[5]=T,M.n=B,E=0))}if(j||N>1)return l;throw P=!0,T}return function(N,T,j){if(w>1)throw TypeError("Generator is already running");for(P&&T===1&&R(T,j),E=T,O=j;(t=E<2?e:O)||!P;){x||(E?E<3?(E>1&&(M.n=-1),R(E,O)):M.n=O:M.v=O);try{if(w=2,x){if(E||(N="next"),t=x[N]){if(!(t=t.call(x,O)))throw TypeError("iterator result is not an object");if(!t.done)return t;O=t.value,E<2&&(E=0)}else E===1&&(t=x.return)&&t.call(x),E<2&&(O=TypeError("The iterator does not provide a '"+N+"' method"),E=1);x=e}else if((t=(P=M.n<0)?O:C.call($,M))!==l)break}catch(z){x=e,E=1,O=z}finally{w=1}}return{value:t,done:P}}}(v,h,p),!0),y}var l={};function s(){}function c(){}function u(){}t=Object.getPrototypeOf;var d=[][r]?t(t([][r]())):(zn(t={},r,function(){return this}),t),f=u.prototype=s.prototype=Object.create(d);function m(v){return Object.setPrototypeOf?Object.setPrototypeOf(v,u):(v.__proto__=u,zn(v,o,"GeneratorFunction")),v.prototype=Object.create(f),v}return c.prototype=u,zn(f,"constructor",u),zn(u,"constructor",c),c.displayName="GeneratorFunction",zn(u,o,"GeneratorFunction"),zn(f),zn(f,o,"Generator"),zn(f,r,function(){return this}),zn(f,"toString",function(){return"[object Generator]"}),(zd=function(){return{w:a,m}})()}function yl(e,t){function n(o,a,l,s){try{var c=e[o](a),u=c.value;return u instanceof y0?t.resolve(u.v).then(function(d){n("next",d,l,s)},function(d){n("throw",d,l,s)}):t.resolve(u).then(function(d){c.value=d,l(c)},function(d){return n("throw",d,l,s)})}catch(d){s(d)}}var r;this.next||(zn(yl.prototype),zn(yl.prototype,typeof Symbol=="function"&&Symbol.asyncIterator||"@asyncIterator",function(){return this})),zn(this,"_invoke",function(o,a,l){function s(){return new t(function(c,u){n(o,l,c,u)})}return r=r?r.then(s,s):s()},!0)}function C0(e,t,n,r,o){return new yl(zd().w(e,t,n,r),o||Promise)}function Jw(e,t,n,r,o){var a=C0(e,t,n,r,o);return a.next().then(function(l){return l.done?l.value:a.next()})}function eE(e){var t=Object(e),n=[];for(var r in t)n.unshift(r);return function o(){for(;n.length;)if((r=n.pop())in t)return o.value=r,o.done=!1,o;return o.done=!0,o}}function _m(e){if(e!=null){var t=e[typeof Symbol=="function"&&Symbol.iterator||"@@iterator"],n=0;if(t)return t.call(e);if(typeof e.next=="function")return e;if(!isNaN(e.length))return{next:function(){return e&&n>=e.length&&(e=void 0),{value:e&&e[n++],done:!e}}}}throw new TypeError(Qe(e)+" is not iterable")}function kt(){var e=zd(),t=e.m(kt),n=(Object.getPrototypeOf?Object.getPrototypeOf(t):t.__proto__).constructor;function r(l){var s=typeof l=="function"&&l.constructor;return!!s&&(s===n||(s.displayName||s.name)==="GeneratorFunction")}var o={throw:1,return:2,break:3,continue:3};function a(l){var s,c;return function(u){s||(s={stop:function(){return c(u.a,2)},catch:function(){return u.v},abrupt:function(f,m){return c(u.a,o[f],m)},delegateYield:function(f,m,v){return s.resultName=m,c(u.d,_m(f),v)},finish:function(f){return c(u.f,f)}},c=function(f,m,v){u.p=s.prev,u.n=s.next;try{return f(m,v)}finally{s.next=u.n}}),s.resultName&&(s[s.resultName]=u.v,s.resultName=void 0),s.sent=u.v,s.next=u.n;try{return l.call(this,s)}finally{u.p=s.prev,u.n=s.next}}}return(kt=function(){return{wrap:function(c,u,d,f){return e.w(a(c),u,d,f&&f.reverse())},isGeneratorFunction:r,mark:e.m,awrap:function(c,u){return new y0(c,u)},AsyncIterator:yl,async:function(c,u,d,f,m){return(r(u)?C0:Jw)(a(c),u,d,f,m)},keys:eE,values:_m}})()}function Bm(e,t,n,r,o,a,l){try{var s=e[a](l),c=s.value}catch(u){return void n(u)}s.done?t(c):Promise.resolve(c).then(r,o)}function _n(e){return function(){var t=this,n=arguments;return new Promise(function(r,o){var a=e.apply(t,n);function l(c){Bm(a,r,o,l,s,"next",c)}function s(c){Bm(a,r,o,l,s,"throw",c)}l(void 0)})}}var si=k({},xS),tE=si.version,tc=si.render,nE=si.unmountComponentAtNode,ns;try{var rE=Number((tE||"").split(".")[0]);rE>=18&&(ns=si.createRoot)}catch{}function Lm(e){var t=si.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;t&&Qe(t)==="object"&&(t.usingClientEntryPoint=e)}var Cl="__rc_react_root__";function oE(e,t){Lm(!0);var n=t[Cl]||ns(t);Lm(!1),n.render(e),t[Cl]=n}function aE(e,t){tc==null||tc(e,t)}function iE(e,t){if(ns){oE(e,t);return}aE(e,t)}function lE(e){return wu.apply(this,arguments)}function wu(){return wu=_n(kt().mark(function e(t){return kt().wrap(function(r){for(;;)switch(r.prev=r.next){case 0:return r.abrupt("return",Promise.resolve().then(function(){var o;(o=t[Cl])===null||o===void 0||o.unmount(),delete t[Cl]}));case 1:case"end":return r.stop()}},e)})),wu.apply(this,arguments)}function sE(e){nE(e)}function cE(e){return Eu.apply(this,arguments)}function Eu(){return Eu=_n(kt().mark(function e(t){return kt().wrap(function(r){for(;;)switch(r.prev=r.next){case 0:if(ns===void 0){r.next=2;break}return r.abrupt("return",lE(t));case 2:sE(t);case 3:case"end":return r.stop()}},e)})),Eu.apply(this,arguments)}const uE=(e,t)=>(iE(e,t),()=>cE(t));let dE=uE;function rs(e){return dE}const nc=()=>({height:0,opacity:0}),Hm=e=>{const{scrollHeight:t}=e;return{height:t,opacity:1}},fE=e=>({height:e?e.offsetHeight:0}),rc=(e,t)=>(t==null?void 0:t.deadline)===!0||t.propertyName==="height",os=(e=Qa)=>({motionName:`${e}-motion-collapse`,onAppearStart:nc,onEnterStart:nc,onAppearActive:Hm,onEnterActive:Hm,onLeaveStart:fE,onLeaveActive:nc,onAppearEnd:rc,onEnterEnd:rc,onLeaveEnd:rc,motionDeadline:500}),Mr=(e,t,n)=>n!==void 0?n:`${e}-${t}`;function Gt(e,t){var n=Object.assign({},e);return Array.isArray(t)&&t.forEach(function(r){delete n[r]}),n}const as=function(e){if(!e)return!1;if(e instanceof Element){if(e.offsetParent)return!0;if(e.getBBox){var t=e.getBBox(),n=t.width,r=t.height;if(n||r)return!0}if(e.getBoundingClientRect){var o=e.getBoundingClientRect(),a=o.width,l=o.height;if(a||l)return!0}}return!1},mE=e=>{const{componentCls:t,colorPrimary:n}=e;return{[t]:{position:"absolute",background:"transparent",pointerEvents:"none",boxSizing:"border-box",color:`var(--wave-color, ${n})`,boxShadow:"0 0 0 0 currentcolor",opacity:.2,"&.wave-motion-appear":{transition:[`box-shadow 0.4s ${e.motionEaseOutCirc}`,`opacity 2s ${e.motionEaseOutCirc}`].join(","),"&-active":{boxShadow:"0 0 0 6px currentcolor",opacity:0},"&.wave-quick":{transition:[`box-shadow ${e.motionDurationSlow} ${e.motionEaseInOut}`,`opacity ${e.motionDurationSlow} ${e.motionEaseInOut}`].join(",")}}}}},vE=lx("Wave",mE),is=`${Qa}-wave-target`;function gE(e){return e&&e!=="#fff"&&e!=="#ffffff"&&e!=="rgb(255, 255, 255)"&&e!=="rgba(255, 255, 255, 1)"&&!/rgba\((?:\d*, ){3}0\)/.test(e)&&e!=="transparent"&&e!=="canvastext"}function pE(e){var t;const{borderTopColor:n,borderColor:r,backgroundColor:o}=getComputedStyle(e);return(t=[n,r,o].find(gE))!==null&&t!==void 0?t:null}function oc(e){return Number.isNaN(e)?0:e}const hE=e=>{const{className:t,target:n,component:r,registerUnmount:o}=e,a=i.useRef(null),l=i.useRef(null);i.useEffect(()=>{l.current=o()},[]);const[s,c]=i.useState(null),[u,d]=i.useState([]),[f,m]=i.useState(0),[v,g]=i.useState(0),[h,p]=i.useState(0),[b,y]=i.useState(0),[C,$]=i.useState(!1),S={left:f,top:v,width:h,height:b,borderRadius:u.map(O=>`${O}px`).join(" ")};s&&(S["--wave-color"]=s);function x(){const O=getComputedStyle(n);c(pE(n));const w=O.position==="static",{borderLeftWidth:I,borderTopWidth:P}=O;m(w?n.offsetLeft:oc(-parseFloat(I))),g(w?n.offsetTop:oc(-parseFloat(P))),p(n.offsetWidth),y(n.offsetHeight);const{borderTopLeftRadius:M,borderTopRightRadius:R,borderBottomLeftRadius:N,borderBottomRightRadius:T}=O;d([M,R,T,N].map(j=>oc(parseFloat(j))))}if(i.useEffect(()=>{if(n){const O=Et(()=>{x(),$(!0)});let w;return typeof ResizeObserver<"u"&&(w=new ResizeObserver(x),w.observe(n)),()=>{Et.cancel(O),w==null||w.disconnect()}}},[]),!C)return null;const E=(r==="Checkbox"||r==="Radio")&&(n==null?void 0:n.classList.contains(is));return i.createElement(En,{visible:!0,motionAppear:!0,motionName:"wave-motion",motionDeadline:5e3,onAppearEnd:(O,w)=>{var I,P;if(w.deadline||w.propertyName==="opacity"){const M=(I=a.current)===null||I===void 0?void 0:I.parentElement;(P=l.current)===null||P===void 0||P.call(l).then(()=>{M==null||M.remove()})}return!1}},({className:O},w)=>i.createElement("div",{ref:un(a,w),className:A(t,O,{"wave-quick":E}),style:S}))},bE=(e,t)=>{var n;const{component:r}=t;if(r==="Checkbox"&&!(!((n=e.querySelector("input"))===null||n===void 0)&&n.checked))return;const o=document.createElement("div");o.style.position="absolute",o.style.left="0px",o.style.top="0px",e==null||e.insertBefore(o,e==null?void 0:e.firstChild);const a=rs();let l=null;function s(){return l}l=a(i.createElement(hE,Object.assign({},t,{target:e,registerUnmount:s})),o)},yE=(e,t,n)=>{const{wave:r}=i.useContext(ot),[,o,a]=yn(),l=Nt(u=>{const d=e.current;if(r!=null&&r.disabled||!d)return;const f=d.querySelector(`.${is}`)||d,{showEffect:m}=r||{};(m||bE)(f,{className:t,token:o,component:n,event:u,hashId:a})}),s=i.useRef(null);return u=>{Et.cancel(s.current),s.current=Et(()=>{l(u)})}},ci=e=>{const{children:t,disabled:n,component:r}=e,{getPrefixCls:o}=i.useContext(ot),a=i.useRef(null),l=o("wave"),[,s]=vE(l),c=yE(a,A(l,s),r);if(F.useEffect(()=>{const d=a.current;if(!d||d.nodeType!==1||n)return;const f=m=>{!as(m.target)||!d.getAttribute||d.getAttribute("disabled")||d.disabled||d.className.includes("disabled")||d.className.includes("-leave")||c(m)};return d.addEventListener("click",f,!0),()=>{d.removeEventListener("click",f,!0)}},[n]),!F.isValidElement(t))return t??null;const u=Nr(t)?un($o(t),a):a;return cn(t,{ref:u})},Sn=e=>{const t=F.useContext(ea);return F.useMemo(()=>e?typeof e=="string"?e??t:typeof e=="function"?e(t):t:t,[e,t])},CE=e=>{const{componentCls:t}=e;return{[t]:{"&-block":{display:"flex",width:"100%"},"&-vertical":{flexDirection:"column"}}}},SE=e=>{const{componentCls:t,antCls:n}=e;return{[t]:{display:"inline-flex","&-rtl":{direction:"rtl"},"&-vertical":{flexDirection:"column"},"&-align":{flexDirection:"column","&-center":{alignItems:"center"},"&-start":{alignItems:"flex-start"},"&-end":{alignItems:"flex-end"},"&-baseline":{alignItems:"baseline"}},[`${t}-item:empty`]:{display:"none"},[`${t}-item > ${n}-badge-not-a-wrapper:only-child`]:{display:"block"}}}},$E=e=>{const{componentCls:t}=e;return{[t]:{"&-gap-row-small":{rowGap:e.spaceGapSmallSize},"&-gap-row-middle":{rowGap:e.spaceGapMiddleSize},"&-gap-row-large":{rowGap:e.spaceGapLargeSize},"&-gap-col-small":{columnGap:e.spaceGapSmallSize},"&-gap-col-middle":{columnGap:e.spaceGapMiddleSize},"&-gap-col-large":{columnGap:e.spaceGapLargeSize}}}},S0=It("Space",e=>{const t=yt(e,{spaceGapSmallSize:e.paddingXS,spaceGapMiddleSize:e.padding,spaceGapLargeSize:e.paddingLG});return[SE(t),$E(t),CE(t)]},()=>({}),{resetStyle:!1});var $0=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const ls=i.createContext(null),ro=(e,t)=>{const n=i.useContext(ls),r=i.useMemo(()=>{if(!n)return"";const{compactDirection:o,isFirstItem:a,isLastItem:l}=n,s=o==="vertical"?"-vertical-":"-";return A(`${e}-compact${s}item`,{[`${e}-compact${s}first-item`]:a,[`${e}-compact${s}last-item`]:l,[`${e}-compact${s}item-rtl`]:t==="rtl"})},[e,t,n]);return{compactSize:n==null?void 0:n.compactSize,compactDirection:n==null?void 0:n.compactDirection,compactItemClassnames:r}},xE=e=>{const{children:t}=e;return i.createElement(ls.Provider,{value:null},t)},wE=e=>{const{children:t}=e,n=$0(e,["children"]);return i.createElement(ls.Provider,{value:i.useMemo(()=>n,[n])},t)},EE=e=>{const{getPrefixCls:t,direction:n}=i.useContext(ot),{size:r,direction:o,block:a,prefixCls:l,className:s,rootClassName:c,children:u}=e,d=$0(e,["size","direction","block","prefixCls","className","rootClassName","children"]),f=Sn(C=>r??C),m=t("space-compact",l),[v,g]=S0(m),h=A(m,g,{[`${m}-rtl`]:n==="rtl",[`${m}-block`]:a,[`${m}-vertical`]:o==="vertical"},s,c),p=i.useContext(ls),b=xn(u),y=i.useMemo(()=>b.map((C,$)=>{const S=(C==null?void 0:C.key)||`${m}-item-${$}`;return i.createElement(wE,{key:S,compactSize:f,compactDirection:o,isFirstItem:$===0&&(!p||(p==null?void 0:p.isFirstItem)),isLastItem:$===b.length-1&&(!p||(p==null?void 0:p.isLastItem))},C)}),[r,b,p]);return b.length===0?null:v(i.createElement("div",Object.assign({className:h},d),y))};var OE=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const x0=i.createContext(void 0),IE=e=>{const{getPrefixCls:t,direction:n}=i.useContext(ot),{prefixCls:r,size:o,className:a}=e,l=OE(e,["prefixCls","size","className"]),s=t("btn-group",r),[,,c]=yn(),u=i.useMemo(()=>{switch(o){case"large":return"lg";case"small":return"sm";default:return""}},[o]),d=A(s,{[`${s}-${u}`]:u,[`${s}-rtl`]:n==="rtl"},a,c);return i.createElement(x0.Provider,{value:o},i.createElement("div",Object.assign({},l,{className:d})))},Am=/^[\u4E00-\u9FA5]{2}$/,Ou=Am.test.bind(Am);function Dd(e){return e==="danger"?{danger:!0}:{type:e}}function Fm(e){return typeof e=="string"}function ac(e){return e==="text"||e==="link"}function RE(e,t){if(e==null)return;const n=t?" ":"";return typeof e!="string"&&typeof e!="number"&&Fm(e.type)&&Ou(e.props.children)?cn(e,{children:e.props.children.split("").join(n)}):Fm(e)?Ou(e)?F.createElement("span",null,e.split("").join(n)):F.createElement("span",null,e):u0(e)?F.createElement("span",null,e):e}function PE(e,t){let n=!1;const r=[];return F.Children.forEach(e,o=>{const a=typeof o,l=a==="string"||a==="number";if(n&&l){const s=r.length-1,c=r[s];r[s]=`${c}${o}`}else r.push(o);n=l}),F.Children.map(r,o=>RE(o,t))}["default","primary","danger"].concat(pe(Zr));const Iu=i.forwardRef((e,t)=>{const{className:n,style:r,children:o,prefixCls:a}=e,l=A(`${a}-icon`,n);return F.createElement("span",{ref:t,className:l,style:r},o)}),km=i.forwardRef((e,t)=>{const{prefixCls:n,className:r,style:o,iconClassName:a}=e,l=A(`${n}-loading-icon`,r);return F.createElement(Iu,{prefixCls:n,className:l,style:o,ref:t},F.createElement(Jr,{className:a}))}),ic=()=>({width:0,opacity:0,transform:"scale(0)"}),lc=e=>({width:e.scrollWidth,opacity:1,transform:"scale(1)"}),NE=e=>{const{prefixCls:t,loading:n,existIcon:r,className:o,style:a,mount:l}=e,s=!!n;return r?F.createElement(km,{prefixCls:t,className:o,style:a}):F.createElement(En,{visible:s,motionName:`${t}-loading-icon-motion`,motionAppear:!l,motionEnter:!l,motionLeave:!l,removeOnLeave:!0,onAppearStart:ic,onAppearActive:lc,onEnterStart:ic,onEnterActive:lc,onLeaveStart:lc,onLeaveActive:ic},({className:c,style:u},d)=>{const f=Object.assign(Object.assign({},a),u);return F.createElement(km,{prefixCls:t,className:A(o,c),style:f,ref:d})})},Vm=(e,t)=>({[`> span, > ${e}`]:{"&:not(:last-child)":{[`&, & > ${e}`]:{"&:not(:disabled)":{borderInlineEndColor:t}}},"&:not(:first-child)":{[`&, & > ${e}`]:{"&:not(:disabled)":{borderInlineStartColor:t}}}}}),ME=e=>{const{componentCls:t,fontSize:n,lineWidth:r,groupBorderColor:o,colorErrorHover:a}=e;return{[`${t}-group`]:[{position:"relative",display:"inline-flex",[`> span, > ${t}`]:{"&:not(:last-child)":{[`&, & > ${t}`]:{borderStartEndRadius:0,borderEndEndRadius:0}},"&:not(:first-child)":{marginInlineStart:e.calc(r).mul(-1).equal(),[`&, & > ${t}`]:{borderStartStartRadius:0,borderEndStartRadius:0}}},[t]:{position:"relative",zIndex:1,"&:hover, &:focus, &:active":{zIndex:2},"&[disabled]":{zIndex:0}},[`${t}-icon-only`]:{fontSize:n}},Vm(`${t}-primary`,o),Vm(`${t}-danger`,a)]}};var TE=["b"],jE=["v"],sc=function(t){return Math.round(Number(t||0))},zE=function(t){if(t instanceof Mt)return t;if(t&&Qe(t)==="object"&&"h"in t&&"b"in t){var n=t,r=n.b,o=ft(n,TE);return k(k({},o),{},{v:r})}return typeof t=="string"&&/hsb/.test(t)?t.replace(/hsb/,"hsv"):t},Sr=function(e){tr(n,e);var t=ur(n);function n(r){return Zt(this,n),t.call(this,zE(r))}return Jt(n,[{key:"toHsbString",value:function(){var o=this.toHsb(),a=sc(o.s*100),l=sc(o.b*100),s=sc(o.h),c=o.a,u="hsb(".concat(s,", ").concat(a,"%, ").concat(l,"%)"),d="hsba(".concat(s,", ").concat(a,"%, ").concat(l,"%, ").concat(c.toFixed(c===0?0:2),")");return c===1?u:d}},{key:"toHsb",value:function(){var o=this.toHsv(),a=o.v,l=ft(o,jE);return k(k({},l),{},{b:a,a:this.a})}}]),n}(Mt),DE="rc-color-picker",Wo=function(t){return t instanceof Sr?t:new Sr(t)},_E=Wo("#1677ff"),w0=function(t){var n=t.offset,r=t.targetRef,o=t.containerRef,a=t.color,l=t.type,s=o.current.getBoundingClientRect(),c=s.width,u=s.height,d=r.current.getBoundingClientRect(),f=d.width,m=d.height,v=f/2,g=m/2,h=(n.x+v)/c,p=1-(n.y+g)/u,b=a.toHsb(),y=h,C=(n.x+v)/c*360;if(l)switch(l){case"hue":return Wo(k(k({},b),{},{h:C<=0?0:C}));case"alpha":return Wo(k(k({},b),{},{a:y<=0?0:y}))}return Wo({h:b.h,s:h<=0?0:h,b:p>=1?1:p,a:b.a})},E0=function(t,n){var r=t.toHsb();switch(n){case"hue":return{x:r.h/360*100,y:50};case"alpha":return{x:t.a*100,y:50};default:return{x:r.s*100,y:(1-r.b)*100}}},_d=function(t){var n=t.color,r=t.prefixCls,o=t.className,a=t.style,l=t.onClick,s="".concat(r,"-color-block");return F.createElement("div",{className:A(s,o),style:a,onClick:l},F.createElement("div",{className:"".concat(s,"-inner"),style:{background:n}}))};function BE(e){var t="touches"in e?e.touches[0]:e,n=document.documentElement.scrollLeft||document.body.scrollLeft||window.pageXOffset,r=document.documentElement.scrollTop||document.body.scrollTop||window.pageYOffset;return{pageX:t.pageX-n,pageY:t.pageY-r}}function O0(e){var t=e.targetRef,n=e.containerRef,r=e.direction,o=e.onDragChange,a=e.onDragChangeComplete,l=e.calculate,s=e.color,c=e.disabledDrag,u=i.useState({x:0,y:0}),d=J(u,2),f=d[0],m=d[1],v=i.useRef(null),g=i.useRef(null);i.useEffect(function(){m(l())},[s]),i.useEffect(function(){return function(){document.removeEventListener("mousemove",v.current),document.removeEventListener("mouseup",g.current),document.removeEventListener("touchmove",v.current),document.removeEventListener("touchend",g.current),v.current=null,g.current=null}},[]);var h=function($){var S=BE($),x=S.pageX,E=S.pageY,O=n.current.getBoundingClientRect(),w=O.x,I=O.y,P=O.width,M=O.height,R=t.current.getBoundingClientRect(),N=R.width,T=R.height,j=N/2,z=T/2,_=Math.max(0,Math.min(x-w,P))-j,B=Math.max(0,Math.min(E-I,M))-z,V={x:_,y:r==="x"?f.y:B};if(N===0&&T===0||N!==T)return!1;o==null||o(V)},p=function($){$.preventDefault(),h($)},b=function($){$.preventDefault(),document.removeEventListener("mousemove",v.current),document.removeEventListener("mouseup",g.current),document.removeEventListener("touchmove",v.current),document.removeEventListener("touchend",g.current),v.current=null,g.current=null,a==null||a()},y=function($){document.removeEventListener("mousemove",v.current),document.removeEventListener("mouseup",g.current),!c&&(h($),document.addEventListener("mousemove",p),document.addEventListener("mouseup",b),document.addEventListener("touchmove",p),document.addEventListener("touchend",b),v.current=p,g.current=b)};return[f,y]}var I0=function(t){var n=t.size,r=n===void 0?"default":n,o=t.color,a=t.prefixCls;return F.createElement("div",{className:A("".concat(a,"-handler"),D({},"".concat(a,"-handler-sm"),r==="small")),style:{backgroundColor:o}})},R0=function(t){var n=t.children,r=t.style,o=t.prefixCls;return F.createElement("div",{className:"".concat(o,"-palette"),style:k({position:"relative"},r)},n)},P0=i.forwardRef(function(e,t){var n=e.children,r=e.x,o=e.y;return F.createElement("div",{ref:t,style:{position:"absolute",left:"".concat(r,"%"),top:"".concat(o,"%"),zIndex:1,transform:"translate(-50%, -50%)"}},n)}),LE=function(t){var n=t.color,r=t.onChange,o=t.prefixCls,a=t.onChangeComplete,l=t.disabled,s=i.useRef(),c=i.useRef(),u=i.useRef(n),d=Nt(function(h){var p=w0({offset:h,targetRef:c,containerRef:s,color:n});u.current=p,r(p)}),f=O0({color:n,containerRef:s,targetRef:c,calculate:function(){return E0(n)},onDragChange:d,onDragChangeComplete:function(){return a==null?void 0:a(u.current)},disabledDrag:l}),m=J(f,2),v=m[0],g=m[1];return F.createElement("div",{ref:s,className:"".concat(o,"-select"),onMouseDown:g,onTouchStart:g},F.createElement(R0,{prefixCls:o},F.createElement(P0,{x:v.x,y:v.y,ref:c},F.createElement(I0,{color:n.toRgbString(),prefixCls:o})),F.createElement("div",{className:"".concat(o,"-saturation"),style:{backgroundColor:"hsl(".concat(n.toHsb().h,",100%, 50%)"),backgroundImage:"linear-gradient(0deg, #000, transparent),linear-gradient(90deg, #fff, hsla(0, 0%, 100%, 0))"}})))},HE=function(t,n){var r=Lt(t,{value:n}),o=J(r,2),a=o[0],l=o[1],s=i.useMemo(function(){return Wo(a)},[a]);return[s,l]},AE=function(t){var n=t.colors,r=t.children,o=t.direction,a=o===void 0?"to right":o,l=t.type,s=t.prefixCls,c=i.useMemo(function(){return n.map(function(u,d){var f=Wo(u);return l==="alpha"&&d===n.length-1&&(f=new Sr(f.setA(1))),f.toRgbString()}).join(",")},[n,l]);return F.createElement("div",{className:"".concat(s,"-gradient"),style:{position:"absolute",inset:0,background:"linear-gradient(".concat(a,", ").concat(c,")")}},r)},FE=function(t){var n=t.prefixCls,r=t.colors,o=t.disabled,a=t.onChange,l=t.onChangeComplete,s=t.color,c=t.type,u=i.useRef(),d=i.useRef(),f=i.useRef(s),m=function(S){return c==="hue"?S.getHue():S.a*100},v=Nt(function($){var S=w0({offset:$,targetRef:d,containerRef:u,color:s,type:c});f.current=S,a(m(S))}),g=O0({color:s,targetRef:d,containerRef:u,calculate:function(){return E0(s,c)},onDragChange:v,onDragChangeComplete:function(){l(m(f.current))},direction:"x",disabledDrag:o}),h=J(g,2),p=h[0],b=h[1],y=F.useMemo(function(){if(c==="hue"){var $=s.toHsb();$.s=1,$.b=1,$.a=1;var S=new Sr($);return S}return s},[s,c]),C=F.useMemo(function(){return r.map(function($){return"".concat($.color," ").concat($.percent,"%")})},[r]);return F.createElement("div",{ref:u,className:A("".concat(n,"-slider"),"".concat(n,"-slider-").concat(c)),onMouseDown:b,onTouchStart:b},F.createElement(R0,{prefixCls:n},F.createElement(P0,{x:p.x,y:p.y,ref:d},F.createElement(I0,{size:"small",color:y.toHexString(),prefixCls:n})),F.createElement(AE,{colors:C,type:c,prefixCls:n})))};function kE(e){return i.useMemo(function(){var t=e||{},n=t.slider;return[n||FE]},[e])}var VE=[{color:"rgb(255, 0, 0)",percent:0},{color:"rgb(255, 255, 0)",percent:17},{color:"rgb(0, 255, 0)",percent:33},{color:"rgb(0, 255, 255)",percent:50},{color:"rgb(0, 0, 255)",percent:67},{color:"rgb(255, 0, 255)",percent:83},{color:"rgb(255, 0, 0)",percent:100}],WE=i.forwardRef(function(e,t){var n=e.value,r=e.defaultValue,o=e.prefixCls,a=o===void 0?DE:o,l=e.onChange,s=e.onChangeComplete,c=e.className,u=e.style,d=e.panelRender,f=e.disabledAlpha,m=f===void 0?!1:f,v=e.disabled,g=v===void 0?!1:v,h=e.components,p=kE(h),b=J(p,1),y=b[0],C=HE(r||_E,n),$=J(C,2),S=$[0],x=$[1],E=i.useMemo(function(){return S.setA(1).toRgbString()},[S]),O=function(B,V){n||x(B),l==null||l(B,V)},w=function(B){return new Sr(S.setHue(B))},I=function(B){return new Sr(S.setA(B/100))},P=function(B){O(w(B),{type:"hue",value:B})},M=function(B){O(I(B),{type:"alpha",value:B})},R=function(B){s&&s(w(B))},N=function(B){s&&s(I(B))},T=A("".concat(a,"-panel"),c,D({},"".concat(a,"-panel-disabled"),g)),j={prefixCls:a,disabled:g,color:S},z=F.createElement(F.Fragment,null,F.createElement(LE,ue({onChange:O},j,{onChangeComplete:s})),F.createElement("div",{className:"".concat(a,"-slider-container")},F.createElement("div",{className:A("".concat(a,"-slider-group"),D({},"".concat(a,"-slider-group-disabled-alpha"),m))},F.createElement(y,ue({},j,{type:"hue",colors:VE,min:0,max:359,value:S.getHue(),onChange:P,onChangeComplete:R})),!m&&F.createElement(y,ue({},j,{type:"alpha",colors:[{percent:0,color:"rgba(255, 0, 4, 0)"},{percent:100,color:E}],min:0,max:100,value:S.a*100,onChange:M,onChangeComplete:N}))),F.createElement(_d,{color:S.toRgbString(),prefixCls:a})));return F.createElement("div",{className:T,style:u,ref:t},typeof d=="function"?d(z):z)});const ja=(e,t)=>(e==null?void 0:e.replace(/[^\w/]/g,"").slice(0,t?8:6))||"",KE=(e,t)=>e?ja(e,t):"";let Zn=function(){function e(t){Zt(this,e);var n;if(this.cleared=!1,t instanceof e){this.metaColor=t.metaColor.clone(),this.colors=(n=t.colors)===null||n===void 0?void 0:n.map(o=>({color:new e(o.color),percent:o.percent})),this.cleared=t.cleared;return}const r=Array.isArray(t);r&&t.length?(this.colors=t.map(({color:o,percent:a})=>({color:new e(o),percent:a})),this.metaColor=new Sr(this.colors[0].color.metaColor)):this.metaColor=new Sr(r?"":t),(!t||r&&!this.colors)&&(this.metaColor=this.metaColor.setA(0),this.cleared=!0)}return Jt(e,[{key:"toHsb",value:function(){return this.metaColor.toHsb()}},{key:"toHsbString",value:function(){return this.metaColor.toHsbString()}},{key:"toHex",value:function(){return KE(this.toHexString(),this.metaColor.a<1)}},{key:"toHexString",value:function(){return this.metaColor.toHexString()}},{key:"toRgb",value:function(){return this.metaColor.toRgb()}},{key:"toRgbString",value:function(){return this.metaColor.toRgbString()}},{key:"isGradient",value:function(){return!!this.colors&&!this.cleared}},{key:"getColors",value:function(){return this.colors||[{color:this,percent:0}]}},{key:"toCssString",value:function(){const{colors:n}=this;return n?`linear-gradient(90deg, ${n.map(o=>`${o.color.toRgbString()} ${o.percent}%`).join(", ")})`:this.metaColor.toRgbString()}},{key:"equals",value:function(n){return!n||this.isGradient()!==n.isGradient()?!1:this.isGradient()?this.colors.length===n.colors.length&&this.colors.every((r,o)=>{const a=n.colors[o];return r.percent===a.percent&&r.color.equals(a.color)}):this.toHexString()===n.toHexString()}}])}();var GE={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M765.7 486.8L314.9 134.7A7.97 7.97 0 00302 141v77.3c0 4.9 2.3 9.6 6.1 12.6l360 281.1-360 281.1c-3.9 3-6.1 7.7-6.1 12.6V883c0 6.7 7.7 10.4 12.9 6.3l450.8-352.1a31.96 31.96 0 000-50.4z"}}]},name:"right",theme:"outlined"},qE=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:GE}))},na=i.forwardRef(qE),N0=F.forwardRef(function(e,t){var n=e.prefixCls,r=e.forceRender,o=e.className,a=e.style,l=e.children,s=e.isActive,c=e.role,u=e.classNames,d=e.styles,f=F.useState(s||r),m=J(f,2),v=m[0],g=m[1];return F.useEffect(function(){(r||s)&&g(!0)},[r,s]),v?F.createElement("div",{ref:t,className:A("".concat(n,"-content"),D(D({},"".concat(n,"-content-active"),s),"".concat(n,"-content-inactive"),!s),o),style:a,role:c},F.createElement("div",{className:A("".concat(n,"-content-box"),u==null?void 0:u.body),style:d==null?void 0:d.body},l)):null});N0.displayName="PanelContent";var UE=["showArrow","headerClass","isActive","onItemClick","forceRender","className","classNames","styles","prefixCls","collapsible","accordion","panelKey","extra","header","expandIcon","openMotion","destroyInactivePanel","children"],M0=F.forwardRef(function(e,t){var n=e.showArrow,r=n===void 0?!0:n,o=e.headerClass,a=e.isActive,l=e.onItemClick,s=e.forceRender,c=e.className,u=e.classNames,d=u===void 0?{}:u,f=e.styles,m=f===void 0?{}:f,v=e.prefixCls,g=e.collapsible,h=e.accordion,p=e.panelKey,b=e.extra,y=e.header,C=e.expandIcon,$=e.openMotion,S=e.destroyInactivePanel,x=e.children,E=ft(e,UE),O=g==="disabled",w=b!=null&&typeof b!="boolean",I=D(D(D({onClick:function(){l==null||l(p)},onKeyDown:function(z){(z.key==="Enter"||z.keyCode===Ne.ENTER||z.which===Ne.ENTER)&&(l==null||l(p))},role:h?"tab":"button"},"aria-expanded",a),"aria-disabled",O),"tabIndex",O?-1:0),P=typeof C=="function"?C(e):F.createElement("i",{className:"arrow"}),M=P&&F.createElement("div",ue({className:"".concat(v,"-expand-icon")},["header","icon"].includes(g)?I:{}),P),R=A("".concat(v,"-item"),D(D({},"".concat(v,"-item-active"),a),"".concat(v,"-item-disabled"),O),c),N=A(o,"".concat(v,"-header"),D({},"".concat(v,"-collapsible-").concat(g),!!g),d.header),T=k({className:N,style:m.header},["header","icon"].includes(g)?{}:I);return F.createElement("div",ue({},E,{ref:t,className:R}),F.createElement("div",T,r&&M,F.createElement("span",ue({className:"".concat(v,"-header-text")},g==="header"?I:{}),y),w&&F.createElement("div",{className:"".concat(v,"-extra")},b)),F.createElement(En,ue({visible:a,leavedClassName:"".concat(v,"-content-hidden")},$,{forceRender:s,removeOnLeave:S}),function(j,z){var _=j.className,B=j.style;return F.createElement(N0,{ref:z,prefixCls:v,className:_,classNames:d,style:B,styles:m,isActive:a,forceRender:s,role:h?"tabpanel":void 0},x)}))}),XE=["children","label","key","collapsible","onItemClick","destroyInactivePanel"],YE=function(t,n){var r=n.prefixCls,o=n.accordion,a=n.collapsible,l=n.destroyInactivePanel,s=n.onItemClick,c=n.activeKey,u=n.openMotion,d=n.expandIcon;return t.map(function(f,m){var v=f.children,g=f.label,h=f.key,p=f.collapsible,b=f.onItemClick,y=f.destroyInactivePanel,C=ft(f,XE),$=String(h??m),S=p??a,x=y??l,E=function(I){S!=="disabled"&&(s(I),b==null||b(I))},O=!1;return o?O=c[0]===$:O=c.indexOf($)>-1,F.createElement(M0,ue({},C,{prefixCls:r,key:$,panelKey:$,isActive:O,accordion:o,openMotion:u,expandIcon:d,header:g,collapsible:S,onItemClick:E,destroyInactivePanel:x}),v)})},QE=function(t,n,r){if(!t)return null;var o=r.prefixCls,a=r.accordion,l=r.collapsible,s=r.destroyInactivePanel,c=r.onItemClick,u=r.activeKey,d=r.openMotion,f=r.expandIcon,m=t.key||String(n),v=t.props,g=v.header,h=v.headerClass,p=v.destroyInactivePanel,b=v.collapsible,y=v.onItemClick,C=!1;a?C=u[0]===m:C=u.indexOf(m)>-1;var $=b??l,S=function(O){$!=="disabled"&&(c(O),y==null||y(O))},x={key:m,panelKey:m,header:g,headerClass:h,isActive:C,prefixCls:o,destroyInactivePanel:p??s,openMotion:d,accordion:a,children:t.props.children,onItemClick:S,expandIcon:f,collapsible:$};return typeof t.type=="string"?t:(Object.keys(x).forEach(function(E){typeof x[E]>"u"&&delete x[E]}),F.cloneElement(t,x))};function ZE(e,t,n){return Array.isArray(e)?YE(e,n):xn(t).map(function(r,o){return QE(r,o,n)})}function JE(e){var t=e;if(!Array.isArray(t)){var n=Qe(t);t=n==="number"||n==="string"?[t]:[]}return t.map(function(r){return String(r)})}var e2=F.forwardRef(function(e,t){var n=e.prefixCls,r=n===void 0?"rc-collapse":n,o=e.destroyInactivePanel,a=o===void 0?!1:o,l=e.style,s=e.accordion,c=e.className,u=e.children,d=e.collapsible,f=e.openMotion,m=e.expandIcon,v=e.activeKey,g=e.defaultActiveKey,h=e.onChange,p=e.items,b=A(r,c),y=Lt([],{value:v,onChange:function(w){return h==null?void 0:h(w)},defaultValue:g,postState:JE}),C=J(y,2),$=C[0],S=C[1],x=function(w){return S(function(){if(s)return $[0]===w?[]:[w];var I=$.indexOf(w),P=I>-1;return P?$.filter(function(M){return M!==w}):[].concat(pe($),[w])})};Kt(!u,"[rc-collapse] `children` will be removed in next major version. Please use `items` instead.");var E=ZE(p,u,{prefixCls:r,accordion:s,openMotion:f,expandIcon:m,collapsible:d,destroyInactivePanel:a,onItemClick:x,activeKey:$});return F.createElement("div",ue({ref:t,className:b,style:l,role:s?"tablist":void 0},rn(e,{aria:!0,data:!0})),E)});const Bd=Object.assign(e2,{Panel:M0});Bd.Panel;const t2=i.forwardRef((e,t)=>{const{getPrefixCls:n}=i.useContext(ot),{prefixCls:r,className:o,showArrow:a=!0}=e,l=n("collapse",r),s=A({[`${l}-no-arrow`]:!a},o);return i.createElement(Bd.Panel,Object.assign({ref:t},e,{prefixCls:l,className:s}))}),ss=e=>({[e.componentCls]:{[`${e.antCls}-motion-collapse-legacy`]:{overflow:"hidden","&-active":{transition:`height ${e.motionDurationMid} ${e.motionEaseInOut},
        opacity ${e.motionDurationMid} ${e.motionEaseInOut} !important`}},[`${e.antCls}-motion-collapse`]:{overflow:"hidden",transition:`height ${e.motionDurationMid} ${e.motionEaseInOut},
        opacity ${e.motionDurationMid} ${e.motionEaseInOut} !important`}}}),n2=e=>({animationDuration:e,animationFillMode:"both"}),r2=e=>({animationDuration:e,animationFillMode:"both"}),cs=(e,t,n,r,o=!1)=>{const a=o?"&":"";return{[`
      ${a}${e}-enter,
      ${a}${e}-appear
    `]:Object.assign(Object.assign({},n2(r)),{animationPlayState:"paused"}),[`${a}${e}-leave`]:Object.assign(Object.assign({},r2(r)),{animationPlayState:"paused"}),[`
      ${a}${e}-enter${e}-enter-active,
      ${a}${e}-appear${e}-appear-active
    `]:{animationName:t,animationPlayState:"running"},[`${a}${e}-leave${e}-leave-active`]:{animationName:n,animationPlayState:"running",pointerEvents:"none"}}},o2=new $t("antFadeIn",{"0%":{opacity:0},"100%":{opacity:1}}),a2=new $t("antFadeOut",{"0%":{opacity:1},"100%":{opacity:0}}),T0=(e,t=!1)=>{const{antCls:n}=e,r=`${n}-fade`,o=t?"&":"";return[cs(r,o2,a2,e.motionDurationMid,t),{[`
        ${o}${r}-enter,
        ${o}${r}-appear
      `]:{opacity:0,animationTimingFunction:"linear"},[`${o}${r}-leave`]:{animationTimingFunction:"linear"}}]},i2=new $t("antMoveDownIn",{"0%":{transform:"translate3d(0, 100%, 0)",transformOrigin:"0 0",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1}}),l2=new $t("antMoveDownOut",{"0%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1},"100%":{transform:"translate3d(0, 100%, 0)",transformOrigin:"0 0",opacity:0}}),s2=new $t("antMoveLeftIn",{"0%":{transform:"translate3d(-100%, 0, 0)",transformOrigin:"0 0",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1}}),c2=new $t("antMoveLeftOut",{"0%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1},"100%":{transform:"translate3d(-100%, 0, 0)",transformOrigin:"0 0",opacity:0}}),u2=new $t("antMoveRightIn",{"0%":{transform:"translate3d(100%, 0, 0)",transformOrigin:"0 0",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1}}),d2=new $t("antMoveRightOut",{"0%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1},"100%":{transform:"translate3d(100%, 0, 0)",transformOrigin:"0 0",opacity:0}}),f2=new $t("antMoveUpIn",{"0%":{transform:"translate3d(0, -100%, 0)",transformOrigin:"0 0",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1}}),m2=new $t("antMoveUpOut",{"0%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1},"100%":{transform:"translate3d(0, -100%, 0)",transformOrigin:"0 0",opacity:0}}),v2={"move-up":{inKeyframes:f2,outKeyframes:m2},"move-down":{inKeyframes:i2,outKeyframes:l2},"move-left":{inKeyframes:s2,outKeyframes:c2},"move-right":{inKeyframes:u2,outKeyframes:d2}},Sl=(e,t)=>{const{antCls:n}=e,r=`${n}-${t}`,{inKeyframes:o,outKeyframes:a}=v2[t];return[cs(r,o,a,e.motionDurationMid),{[`
        ${r}-enter,
        ${r}-appear
      `]:{opacity:0,animationTimingFunction:e.motionEaseOutCirc},[`${r}-leave`]:{animationTimingFunction:e.motionEaseInOutCirc}}]},Ld=new $t("antSlideUpIn",{"0%":{transform:"scaleY(0.8)",transformOrigin:"0% 0%",opacity:0},"100%":{transform:"scaleY(1)",transformOrigin:"0% 0%",opacity:1}}),Hd=new $t("antSlideUpOut",{"0%":{transform:"scaleY(1)",transformOrigin:"0% 0%",opacity:1},"100%":{transform:"scaleY(0.8)",transformOrigin:"0% 0%",opacity:0}}),Ad=new $t("antSlideDownIn",{"0%":{transform:"scaleY(0.8)",transformOrigin:"100% 100%",opacity:0},"100%":{transform:"scaleY(1)",transformOrigin:"100% 100%",opacity:1}}),Fd=new $t("antSlideDownOut",{"0%":{transform:"scaleY(1)",transformOrigin:"100% 100%",opacity:1},"100%":{transform:"scaleY(0.8)",transformOrigin:"100% 100%",opacity:0}}),g2=new $t("antSlideLeftIn",{"0%":{transform:"scaleX(0.8)",transformOrigin:"0% 0%",opacity:0},"100%":{transform:"scaleX(1)",transformOrigin:"0% 0%",opacity:1}}),p2=new $t("antSlideLeftOut",{"0%":{transform:"scaleX(1)",transformOrigin:"0% 0%",opacity:1},"100%":{transform:"scaleX(0.8)",transformOrigin:"0% 0%",opacity:0}}),h2=new $t("antSlideRightIn",{"0%":{transform:"scaleX(0.8)",transformOrigin:"100% 0%",opacity:0},"100%":{transform:"scaleX(1)",transformOrigin:"100% 0%",opacity:1}}),b2=new $t("antSlideRightOut",{"0%":{transform:"scaleX(1)",transformOrigin:"100% 0%",opacity:1},"100%":{transform:"scaleX(0.8)",transformOrigin:"100% 0%",opacity:0}}),y2={"slide-up":{inKeyframes:Ld,outKeyframes:Hd},"slide-down":{inKeyframes:Ad,outKeyframes:Fd},"slide-left":{inKeyframes:g2,outKeyframes:p2},"slide-right":{inKeyframes:h2,outKeyframes:b2}},eo=(e,t)=>{const{antCls:n}=e,r=`${n}-${t}`,{inKeyframes:o,outKeyframes:a}=y2[t];return[cs(r,o,a,e.motionDurationMid),{[`
      ${r}-enter,
      ${r}-appear
    `]:{transform:"scale(0)",transformOrigin:"0% 0%",opacity:0,animationTimingFunction:e.motionEaseOutQuint,"&-prepare":{transform:"scale(1)"}},[`${r}-leave`]:{animationTimingFunction:e.motionEaseInQuint}}]},C2=new $t("antZoomIn",{"0%":{transform:"scale(0.2)",opacity:0},"100%":{transform:"scale(1)",opacity:1}}),S2=new $t("antZoomOut",{"0%":{transform:"scale(1)"},"100%":{transform:"scale(0.2)",opacity:0}}),Wm=new $t("antZoomBigIn",{"0%":{transform:"scale(0.8)",opacity:0},"100%":{transform:"scale(1)",opacity:1}}),Km=new $t("antZoomBigOut",{"0%":{transform:"scale(1)"},"100%":{transform:"scale(0.8)",opacity:0}}),$2=new $t("antZoomUpIn",{"0%":{transform:"scale(0.8)",transformOrigin:"50% 0%",opacity:0},"100%":{transform:"scale(1)",transformOrigin:"50% 0%"}}),x2=new $t("antZoomUpOut",{"0%":{transform:"scale(1)",transformOrigin:"50% 0%"},"100%":{transform:"scale(0.8)",transformOrigin:"50% 0%",opacity:0}}),w2=new $t("antZoomLeftIn",{"0%":{transform:"scale(0.8)",transformOrigin:"0% 50%",opacity:0},"100%":{transform:"scale(1)",transformOrigin:"0% 50%"}}),E2=new $t("antZoomLeftOut",{"0%":{transform:"scale(1)",transformOrigin:"0% 50%"},"100%":{transform:"scale(0.8)",transformOrigin:"0% 50%",opacity:0}}),O2=new $t("antZoomRightIn",{"0%":{transform:"scale(0.8)",transformOrigin:"100% 50%",opacity:0},"100%":{transform:"scale(1)",transformOrigin:"100% 50%"}}),I2=new $t("antZoomRightOut",{"0%":{transform:"scale(1)",transformOrigin:"100% 50%"},"100%":{transform:"scale(0.8)",transformOrigin:"100% 50%",opacity:0}}),R2=new $t("antZoomDownIn",{"0%":{transform:"scale(0.8)",transformOrigin:"50% 100%",opacity:0},"100%":{transform:"scale(1)",transformOrigin:"50% 100%"}}),P2=new $t("antZoomDownOut",{"0%":{transform:"scale(1)",transformOrigin:"50% 100%"},"100%":{transform:"scale(0.8)",transformOrigin:"50% 100%",opacity:0}}),N2={zoom:{inKeyframes:C2,outKeyframes:S2},"zoom-big":{inKeyframes:Wm,outKeyframes:Km},"zoom-big-fast":{inKeyframes:Wm,outKeyframes:Km},"zoom-left":{inKeyframes:w2,outKeyframes:E2},"zoom-right":{inKeyframes:O2,outKeyframes:I2},"zoom-up":{inKeyframes:$2,outKeyframes:x2},"zoom-down":{inKeyframes:R2,outKeyframes:P2}},ui=(e,t)=>{const{antCls:n}=e,r=`${n}-${t}`,{inKeyframes:o,outKeyframes:a}=N2[t];return[cs(r,o,a,t==="zoom-big-fast"?e.motionDurationFast:e.motionDurationMid),{[`
        ${r}-enter,
        ${r}-appear
      `]:{transform:"scale(0)",opacity:0,animationTimingFunction:e.motionEaseOutCirc,"&-prepare":{transform:"none"}},[`${r}-leave`]:{animationTimingFunction:e.motionEaseInOutCirc}}]},M2=e=>{const{componentCls:t,contentBg:n,padding:r,headerBg:o,headerPadding:a,collapseHeaderPaddingSM:l,collapseHeaderPaddingLG:s,collapsePanelBorderRadius:c,lineWidth:u,lineType:d,colorBorder:f,colorText:m,colorTextHeading:v,colorTextDisabled:g,fontSizeLG:h,lineHeight:p,lineHeightLG:b,marginSM:y,paddingSM:C,paddingLG:$,paddingXS:S,motionDurationSlow:x,fontSizeIcon:E,contentPadding:O,fontHeight:w,fontHeightLG:I}=e,P=`${L(u)} ${d} ${f}`;return{[t]:Object.assign(Object.assign({},Tt(e)),{backgroundColor:o,border:P,borderRadius:c,"&-rtl":{direction:"rtl"},[`& > ${t}-item`]:{borderBottom:P,"&:first-child":{[`
            &,
            & > ${t}-header`]:{borderRadius:`${L(c)} ${L(c)} 0 0`}},"&:last-child":{[`
            &,
            & > ${t}-header`]:{borderRadius:`0 0 ${L(c)} ${L(c)}`}},[`> ${t}-header`]:Object.assign(Object.assign({position:"relative",display:"flex",flexWrap:"nowrap",alignItems:"flex-start",padding:a,color:v,lineHeight:p,cursor:"pointer",transition:`all ${x}, visibility 0s`},Vn(e)),{[`> ${t}-header-text`]:{flex:"auto"},[`${t}-expand-icon`]:{height:w,display:"flex",alignItems:"center",paddingInlineEnd:y},[`${t}-arrow`]:Object.assign(Object.assign({},xo()),{fontSize:E,transition:`transform ${x}`,svg:{transition:`transform ${x}`}}),[`${t}-header-text`]:{marginInlineEnd:"auto"}}),[`${t}-collapsible-header`]:{cursor:"default",[`${t}-header-text`]:{flex:"none",cursor:"pointer"},[`${t}-expand-icon`]:{cursor:"pointer"}},[`${t}-collapsible-icon`]:{cursor:"unset",[`${t}-expand-icon`]:{cursor:"pointer"}}},[`${t}-content`]:{color:m,backgroundColor:n,borderTop:P,[`& > ${t}-content-box`]:{padding:O},"&-hidden":{display:"none"}},"&-small":{[`> ${t}-item`]:{[`> ${t}-header`]:{padding:l,paddingInlineStart:S,[`> ${t}-expand-icon`]:{marginInlineStart:e.calc(C).sub(S).equal()}},[`> ${t}-content > ${t}-content-box`]:{padding:C}}},"&-large":{[`> ${t}-item`]:{fontSize:h,lineHeight:b,[`> ${t}-header`]:{padding:s,paddingInlineStart:r,[`> ${t}-expand-icon`]:{height:I,marginInlineStart:e.calc($).sub(r).equal()}},[`> ${t}-content > ${t}-content-box`]:{padding:$}}},[`${t}-item:last-child`]:{borderBottom:0,[`> ${t}-content`]:{borderRadius:`0 0 ${L(c)} ${L(c)}`}},[`& ${t}-item-disabled > ${t}-header`]:{"\n          &,\n          & > .arrow\n        ":{color:g,cursor:"not-allowed"}},[`&${t}-icon-position-end`]:{[`& > ${t}-item`]:{[`> ${t}-header`]:{[`${t}-expand-icon`]:{order:1,paddingInlineEnd:0,paddingInlineStart:y}}}}})}},T2=e=>{const{componentCls:t}=e,n=`> ${t}-item > ${t}-header ${t}-arrow`;return{[`${t}-rtl`]:{[n]:{transform:"rotate(180deg)"}}}},j2=e=>{const{componentCls:t,headerBg:n,borderlessContentPadding:r,borderlessContentBg:o,colorBorder:a}=e;return{[`${t}-borderless`]:{backgroundColor:n,border:0,[`> ${t}-item`]:{borderBottom:`1px solid ${a}`},[`
        > ${t}-item:last-child,
        > ${t}-item:last-child ${t}-header
      `]:{borderRadius:0},[`> ${t}-item:last-child`]:{borderBottom:0},[`> ${t}-item > ${t}-content`]:{backgroundColor:o,borderTop:0},[`> ${t}-item > ${t}-content > ${t}-content-box`]:{padding:r}}}},z2=e=>{const{componentCls:t,paddingSM:n}=e;return{[`${t}-ghost`]:{backgroundColor:"transparent",border:0,[`> ${t}-item`]:{borderBottom:0,[`> ${t}-content`]:{backgroundColor:"transparent",border:0,[`> ${t}-content-box`]:{paddingBlock:n}}}}}},D2=e=>({headerPadding:`${e.paddingSM}px ${e.padding}px`,headerBg:e.colorFillAlter,contentPadding:`${e.padding}px 16px`,contentBg:e.colorBgContainer,borderlessContentPadding:`${e.paddingXXS}px 16px ${e.padding}px`,borderlessContentBg:"transparent"}),_2=It("Collapse",e=>{const t=yt(e,{collapseHeaderPaddingSM:`${L(e.paddingXS)} ${L(e.paddingSM)}`,collapseHeaderPaddingLG:`${L(e.padding)} ${L(e.paddingLG)}`,collapsePanelBorderRadius:e.borderRadiusLG});return[M2(t),j2(t),z2(t),T2(t),ss(t)]},D2),B2=i.forwardRef((e,t)=>{const{getPrefixCls:n,direction:r,expandIcon:o,className:a,style:l}=tn("collapse"),{prefixCls:s,className:c,rootClassName:u,style:d,bordered:f=!0,ghost:m,size:v,expandIconPosition:g="start",children:h,destroyInactivePanel:p,destroyOnHidden:b,expandIcon:y}=e,C=Sn(T=>{var j;return(j=v??T)!==null&&j!==void 0?j:"middle"}),$=n("collapse",s),S=n(),[x,E,O]=_2($),w=i.useMemo(()=>g==="left"?"start":g==="right"?"end":g,[g]),I=y??o,P=i.useCallback((T={})=>{const j=typeof I=="function"?I(T):i.createElement(na,{rotate:T.isActive?r==="rtl"?-90:90:void 0,"aria-label":T.isActive?"expanded":"collapsed"});return cn(j,()=>{var z;return{className:A((z=j.props)===null||z===void 0?void 0:z.className,`${$}-arrow`)}})},[I,$,r]),M=A(`${$}-icon-position-${w}`,{[`${$}-borderless`]:!f,[`${$}-rtl`]:r==="rtl",[`${$}-ghost`]:!!m,[`${$}-${C}`]:C!=="middle"},a,c,u,E,O),R=i.useMemo(()=>Object.assign(Object.assign({},os(S)),{motionAppear:!1,leavedClassName:`${$}-content-hidden`}),[S,$]),N=i.useMemo(()=>h?xn(h).map((T,j)=>{var z,_;const B=T.props;if(B!=null&&B.disabled){const V=(z=T.key)!==null&&z!==void 0?z:String(j),G=Object.assign(Object.assign({},Gt(T.props,["disabled"])),{key:V,collapsible:(_=B.collapsible)!==null&&_!==void 0?_:"disabled"});return cn(T,G)}return T}):null,[h]);return x(i.createElement(Bd,Object.assign({ref:t,openMotion:R},Gt(e,["rootClassName"]),{expandIcon:P,prefixCls:$,className:M,style:Object.assign(Object.assign({},l),d),destroyInactivePanel:b??p}),N))}),L2=Object.assign(B2,{Panel:t2}),Nn=e=>e instanceof Zn?e:new Zn(e),rl=e=>Math.round(Number(e||0)),kd=e=>rl(e.toHsb().a*100),ol=(e,t)=>{const n=e.toRgb();if(!n.r&&!n.g&&!n.b){const r=e.toHsb();return r.a=1,Nn(r)}return n.a=1,Nn(n)},j0=(e,t)=>{const n=[{percent:0,color:e[0].color}].concat(pe(e),[{percent:100,color:e[e.length-1].color}]);for(let r=0;r<n.length-1;r+=1){const o=n[r].percent,a=n[r+1].percent,l=n[r].color,s=n[r+1].color;if(o<=t&&t<=a){const c=a-o;if(c===0)return l;const u=(t-o)/c*100,d=new Sr(l),f=new Sr(s);return d.mix(f,u).toRgbString()}}return""},cc=e=>e.map(t=>(t.colors=t.colors.map(Nn),t)),z0=(e,t)=>{const{r:n,g:r,b:o,a}=e.toRgb(),l=new Sr(e.toRgbString()).onBackground(t).toHsv();return a<=.5?l.v>.5:n*.299+r*.587+o*.114>192},Gm=(e,t)=>{var n;return`panel-${(n=e.key)!==null&&n!==void 0?n:t}`},H2=({prefixCls:e,presets:t,value:n,onChange:r})=>{const[o]=Kn("ColorPicker"),[,a]=yn(),[l]=Lt(cc(t),{value:cc(t),postState:cc}),s=`${e}-presets`,c=i.useMemo(()=>l.reduce((f,m,v)=>{const{defaultOpen:g=!0}=m;return g&&f.push(Gm(m,v)),f},[]),[l]),u=f=>{r==null||r(f)},d=l.map((f,m)=>{var v;return{key:Gm(f,m),label:F.createElement("div",{className:`${s}-label`},f==null?void 0:f.label),children:F.createElement("div",{className:`${s}-items`},Array.isArray(f==null?void 0:f.colors)&&((v=f.colors)===null||v===void 0?void 0:v.length)>0?f.colors.map((g,h)=>F.createElement(_d,{key:`preset-${h}-${g.toHexString()}`,color:Nn(g).toRgbString(),prefixCls:e,className:A(`${s}-color`,{[`${s}-color-checked`]:g.toHexString()===(n==null?void 0:n.toHexString()),[`${s}-color-bright`]:z0(g,a.colorBgElevated)}),onClick:()=>u(g)})):F.createElement("span",{className:`${s}-empty`},o.presetEmpty))}});return F.createElement("div",{className:s},F.createElement(L2,{defaultActiveKey:c,ghost:!0,items:d}))},D0=e=>{const{paddingInline:t,onlyIconSize:n}=e;return yt(e,{buttonPaddingHorizontal:t,buttonPaddingVertical:0,buttonIconOnlyFontSize:n})},_0=e=>{var t,n,r,o,a,l;const s=(t=e.contentFontSize)!==null&&t!==void 0?t:e.fontSize,c=(n=e.contentFontSizeSM)!==null&&n!==void 0?n:e.fontSize,u=(r=e.contentFontSizeLG)!==null&&r!==void 0?r:e.fontSizeLG,d=(o=e.contentLineHeight)!==null&&o!==void 0?o:tl(s),f=(a=e.contentLineHeightSM)!==null&&a!==void 0?a:tl(c),m=(l=e.contentLineHeightLG)!==null&&l!==void 0?l:tl(u),v=z0(new Zn(e.colorBgSolid),"#fff")?"#000":"#fff",g=Zr.reduce((h,p)=>Object.assign(Object.assign({},h),{[`${p}ShadowColor`]:`0 ${L(e.controlOutlineWidth)} 0 ${Ta(e[`${p}1`],e.colorBgContainer)}`}),{});return Object.assign(Object.assign({},g),{fontWeight:400,iconGap:e.marginXS,defaultShadow:`0 ${e.controlOutlineWidth}px 0 ${e.controlTmpOutline}`,primaryShadow:`0 ${e.controlOutlineWidth}px 0 ${e.controlOutline}`,dangerShadow:`0 ${e.controlOutlineWidth}px 0 ${e.colorErrorOutline}`,primaryColor:e.colorTextLightSolid,dangerColor:e.colorTextLightSolid,borderColorDisabled:e.colorBorder,defaultGhostColor:e.colorBgContainer,ghostBg:"transparent",defaultGhostBorderColor:e.colorBgContainer,paddingInline:e.paddingContentHorizontal-e.lineWidth,paddingInlineLG:e.paddingContentHorizontal-e.lineWidth,paddingInlineSM:8-e.lineWidth,onlyIconSize:"inherit",onlyIconSizeSM:"inherit",onlyIconSizeLG:"inherit",groupBorderColor:e.colorPrimaryHover,linkHoverBg:"transparent",textTextColor:e.colorText,textTextHoverColor:e.colorText,textTextActiveColor:e.colorText,textHoverBg:e.colorFillTertiary,defaultColor:e.colorText,defaultBg:e.colorBgContainer,defaultBorderColor:e.colorBorder,defaultBorderColorDisabled:e.colorBorder,defaultHoverBg:e.colorBgContainer,defaultHoverColor:e.colorPrimaryHover,defaultHoverBorderColor:e.colorPrimaryHover,defaultActiveBg:e.colorBgContainer,defaultActiveColor:e.colorPrimaryActive,defaultActiveBorderColor:e.colorPrimaryActive,solidTextColor:v,contentFontSize:s,contentFontSizeSM:c,contentFontSizeLG:u,contentLineHeight:d,contentLineHeightSM:f,contentLineHeightLG:m,paddingBlock:Math.max((e.controlHeight-s*d)/2-e.lineWidth,0),paddingBlockSM:Math.max((e.controlHeightSM-c*f)/2-e.lineWidth,0),paddingBlockLG:Math.max((e.controlHeightLG-u*m)/2-e.lineWidth,0)})},A2=e=>{const{componentCls:t,iconCls:n,fontWeight:r,opacityLoading:o,motionDurationSlow:a,motionEaseInOut:l,iconGap:s,calc:c}=e;return{[t]:{outline:"none",position:"relative",display:"inline-flex",gap:s,alignItems:"center",justifyContent:"center",fontWeight:r,whiteSpace:"nowrap",textAlign:"center",backgroundImage:"none",background:"transparent",border:`${L(e.lineWidth)} ${e.lineType} transparent`,cursor:"pointer",transition:`all ${e.motionDurationMid} ${e.motionEaseInOut}`,userSelect:"none",touchAction:"manipulation",color:e.colorText,"&:disabled > *":{pointerEvents:"none"},[`${t}-icon > svg`]:xo(),"> a":{color:"currentColor"},"&:not(:disabled)":Vn(e),[`&${t}-two-chinese-chars::first-letter`]:{letterSpacing:"0.34em"},[`&${t}-two-chinese-chars > *:not(${n})`]:{marginInlineEnd:"-0.34em",letterSpacing:"0.34em"},[`&${t}-icon-only`]:{paddingInline:0,[`&${t}-compact-item`]:{flex:"none"},[`&${t}-round`]:{width:"auto"}},[`&${t}-loading`]:{opacity:o,cursor:"default"},[`${t}-loading-icon`]:{transition:["width","opacity","margin"].map(u=>`${u} ${a} ${l}`).join(",")},[`&:not(${t}-icon-end)`]:{[`${t}-loading-icon-motion`]:{"&-appear-start, &-enter-start":{marginInlineEnd:c(s).mul(-1).equal()},"&-appear-active, &-enter-active":{marginInlineEnd:0},"&-leave-start":{marginInlineEnd:0},"&-leave-active":{marginInlineEnd:c(s).mul(-1).equal()}}},"&-icon-end":{flexDirection:"row-reverse",[`${t}-loading-icon-motion`]:{"&-appear-start, &-enter-start":{marginInlineStart:c(s).mul(-1).equal()},"&-appear-active, &-enter-active":{marginInlineStart:0},"&-leave-start":{marginInlineStart:0},"&-leave-active":{marginInlineStart:c(s).mul(-1).equal()}}}}}},B0=(e,t,n)=>({[`&:not(:disabled):not(${e}-disabled)`]:{"&:hover":t,"&:active":n}}),F2=e=>({minWidth:e.controlHeight,paddingInlineStart:0,paddingInlineEnd:0,borderRadius:"50%"}),k2=e=>({borderRadius:e.controlHeight,paddingInlineStart:e.calc(e.controlHeight).div(2).equal(),paddingInlineEnd:e.calc(e.controlHeight).div(2).equal()}),V2=e=>({cursor:"not-allowed",borderColor:e.borderColorDisabled,color:e.colorTextDisabled,background:e.colorBgContainerDisabled,boxShadow:"none"}),us=(e,t,n,r,o,a,l,s)=>({[`&${e}-background-ghost`]:Object.assign(Object.assign({color:n||void 0,background:t,borderColor:r||void 0,boxShadow:"none"},B0(e,Object.assign({background:t},l),Object.assign({background:t},s))),{"&:disabled":{cursor:"not-allowed",color:o||void 0,borderColor:a||void 0}})}),W2=e=>({[`&:disabled, &${e.componentCls}-disabled`]:Object.assign({},V2(e))}),K2=e=>({[`&:disabled, &${e.componentCls}-disabled`]:{cursor:"not-allowed",color:e.colorTextDisabled}}),ds=(e,t,n,r)=>{const a=r&&["link","text"].includes(r)?K2:W2;return Object.assign(Object.assign({},a(e)),B0(e.componentCls,t,n))},fs=(e,t,n,r,o)=>({[`&${e.componentCls}-variant-solid`]:Object.assign({color:t,background:n},ds(e,r,o))}),ms=(e,t,n,r,o)=>({[`&${e.componentCls}-variant-outlined, &${e.componentCls}-variant-dashed`]:Object.assign({borderColor:t,background:n},ds(e,r,o))}),vs=e=>({[`&${e.componentCls}-variant-dashed`]:{borderStyle:"dashed"}}),gs=(e,t,n,r)=>({[`&${e.componentCls}-variant-filled`]:Object.assign({boxShadow:"none",background:t},ds(e,n,r))}),Tr=(e,t,n,r,o)=>({[`&${e.componentCls}-variant-${n}`]:Object.assign({color:t,boxShadow:"none"},ds(e,r,o,n))}),G2=e=>{const{componentCls:t}=e;return Zr.reduce((n,r)=>{const o=e[`${r}6`],a=e[`${r}1`],l=e[`${r}5`],s=e[`${r}2`],c=e[`${r}3`],u=e[`${r}7`];return Object.assign(Object.assign({},n),{[`&${t}-color-${r}`]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:o,boxShadow:e[`${r}ShadowColor`]},fs(e,e.colorTextLightSolid,o,{background:l},{background:u})),ms(e,o,e.colorBgContainer,{color:l,borderColor:l,background:e.colorBgContainer},{color:u,borderColor:u,background:e.colorBgContainer})),vs(e)),gs(e,a,{color:o,background:s},{color:o,background:c})),Tr(e,o,"link",{color:l},{color:u})),Tr(e,o,"text",{color:l,background:a},{color:u,background:c}))})},{})},q2=e=>Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:e.defaultColor,boxShadow:e.defaultShadow},fs(e,e.solidTextColor,e.colorBgSolid,{color:e.solidTextColor,background:e.colorBgSolidHover},{color:e.solidTextColor,background:e.colorBgSolidActive})),vs(e)),gs(e,e.colorFillTertiary,{color:e.defaultColor,background:e.colorFillSecondary},{color:e.defaultColor,background:e.colorFill})),us(e.componentCls,e.ghostBg,e.defaultGhostColor,e.defaultGhostBorderColor,e.colorTextDisabled,e.colorBorder)),Tr(e,e.textTextColor,"link",{color:e.colorLinkHover,background:e.linkHoverBg},{color:e.colorLinkActive})),U2=e=>Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:e.colorPrimary,boxShadow:e.primaryShadow},ms(e,e.colorPrimary,e.colorBgContainer,{color:e.colorPrimaryTextHover,borderColor:e.colorPrimaryHover,background:e.colorBgContainer},{color:e.colorPrimaryTextActive,borderColor:e.colorPrimaryActive,background:e.colorBgContainer})),vs(e)),gs(e,e.colorPrimaryBg,{color:e.colorPrimary,background:e.colorPrimaryBgHover},{color:e.colorPrimary,background:e.colorPrimaryBorder})),Tr(e,e.colorPrimaryText,"text",{color:e.colorPrimaryTextHover,background:e.colorPrimaryBg},{color:e.colorPrimaryTextActive,background:e.colorPrimaryBorder})),Tr(e,e.colorPrimaryText,"link",{color:e.colorPrimaryTextHover,background:e.linkHoverBg},{color:e.colorPrimaryTextActive})),us(e.componentCls,e.ghostBg,e.colorPrimary,e.colorPrimary,e.colorTextDisabled,e.colorBorder,{color:e.colorPrimaryHover,borderColor:e.colorPrimaryHover},{color:e.colorPrimaryActive,borderColor:e.colorPrimaryActive})),X2=e=>Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:e.colorError,boxShadow:e.dangerShadow},fs(e,e.dangerColor,e.colorError,{background:e.colorErrorHover},{background:e.colorErrorActive})),ms(e,e.colorError,e.colorBgContainer,{color:e.colorErrorHover,borderColor:e.colorErrorBorderHover},{color:e.colorErrorActive,borderColor:e.colorErrorActive})),vs(e)),gs(e,e.colorErrorBg,{color:e.colorError,background:e.colorErrorBgFilledHover},{color:e.colorError,background:e.colorErrorBgActive})),Tr(e,e.colorError,"text",{color:e.colorErrorHover,background:e.colorErrorBg},{color:e.colorErrorHover,background:e.colorErrorBgActive})),Tr(e,e.colorError,"link",{color:e.colorErrorHover},{color:e.colorErrorActive})),us(e.componentCls,e.ghostBg,e.colorError,e.colorError,e.colorTextDisabled,e.colorBorder,{color:e.colorErrorHover,borderColor:e.colorErrorHover},{color:e.colorErrorActive,borderColor:e.colorErrorActive})),Y2=e=>Object.assign(Object.assign({},Tr(e,e.colorLink,"link",{color:e.colorLinkHover},{color:e.colorLinkActive})),us(e.componentCls,e.ghostBg,e.colorInfo,e.colorInfo,e.colorTextDisabled,e.colorBorder,{color:e.colorInfoHover,borderColor:e.colorInfoHover},{color:e.colorInfoActive,borderColor:e.colorInfoActive})),Q2=e=>{const{componentCls:t}=e;return Object.assign({[`${t}-color-default`]:q2(e),[`${t}-color-primary`]:U2(e),[`${t}-color-dangerous`]:X2(e),[`${t}-color-link`]:Y2(e)},G2(e))},Z2=e=>Object.assign(Object.assign(Object.assign(Object.assign({},ms(e,e.defaultBorderColor,e.defaultBg,{color:e.defaultHoverColor,borderColor:e.defaultHoverBorderColor,background:e.defaultHoverBg},{color:e.defaultActiveColor,borderColor:e.defaultActiveBorderColor,background:e.defaultActiveBg})),Tr(e,e.textTextColor,"text",{color:e.textTextHoverColor,background:e.textHoverBg},{color:e.textTextActiveColor,background:e.colorBgTextActive})),fs(e,e.primaryColor,e.colorPrimary,{background:e.colorPrimaryHover,color:e.primaryColor},{background:e.colorPrimaryActive,color:e.primaryColor})),Tr(e,e.colorLink,"link",{color:e.colorLinkHover,background:e.linkHoverBg},{color:e.colorLinkActive})),Vd=(e,t="")=>{const{componentCls:n,controlHeight:r,fontSize:o,borderRadius:a,buttonPaddingHorizontal:l,iconCls:s,buttonPaddingVertical:c,buttonIconOnlyFontSize:u}=e;return[{[t]:{fontSize:o,height:r,padding:`${L(c)} ${L(l)}`,borderRadius:a,[`&${n}-icon-only`]:{width:r,[s]:{fontSize:u}}}},{[`${n}${n}-circle${t}`]:F2(e)},{[`${n}${n}-round${t}`]:k2(e)}]},J2=e=>{const t=yt(e,{fontSize:e.contentFontSize});return Vd(t,e.componentCls)},eO=e=>{const t=yt(e,{controlHeight:e.controlHeightSM,fontSize:e.contentFontSizeSM,padding:e.paddingXS,buttonPaddingHorizontal:e.paddingInlineSM,buttonPaddingVertical:0,borderRadius:e.borderRadiusSM,buttonIconOnlyFontSize:e.onlyIconSizeSM});return Vd(t,`${e.componentCls}-sm`)},tO=e=>{const t=yt(e,{controlHeight:e.controlHeightLG,fontSize:e.contentFontSizeLG,buttonPaddingHorizontal:e.paddingInlineLG,buttonPaddingVertical:0,borderRadius:e.borderRadiusLG,buttonIconOnlyFontSize:e.onlyIconSizeLG});return Vd(t,`${e.componentCls}-lg`)},nO=e=>{const{componentCls:t}=e;return{[t]:{[`&${t}-block`]:{width:"100%"}}}},rO=It("Button",e=>{const t=D0(e);return[A2(t),J2(t),eO(t),tO(t),nO(t),Q2(t),Z2(t),ME(t)]},_0,{unitless:{fontWeight:!0,contentLineHeight:!0,contentLineHeightSM:!0,contentLineHeightLG:!0}});function oO(e,t,n,r){const{focusElCls:o,focus:a,borderElCls:l}=n,s=l?"> *":"",c=["hover",a?"focus":null,"active"].filter(Boolean).map(u=>`&:${u} ${s}`).join(",");return{[`&-item:not(${t}-last-item)`]:{marginInlineEnd:e.calc(e.lineWidth).mul(-1).equal()},[`&-item:not(${r}-status-success)`]:{zIndex:2},"&-item":Object.assign(Object.assign({[c]:{zIndex:3}},o?{[`&${o}`]:{zIndex:3}}:{}),{[`&[disabled] ${s}`]:{zIndex:0}})}}function aO(e,t,n){const{borderElCls:r}=n,o=r?`> ${r}`:"";return{[`&-item:not(${t}-first-item):not(${t}-last-item) ${o}`]:{borderRadius:0},[`&-item:not(${t}-last-item)${t}-first-item`]:{[`& ${o}, &${e}-sm ${o}, &${e}-lg ${o}`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`&-item:not(${t}-first-item)${t}-last-item`]:{[`& ${o}, &${e}-sm ${o}, &${e}-lg ${o}`]:{borderStartStartRadius:0,borderEndStartRadius:0}}}}function di(e,t={focus:!0}){const{componentCls:n}=e,r=`${n}-compact`;return{[r]:Object.assign(Object.assign({},oO(e,r,t,n)),aO(n,r,t))}}function iO(e,t,n){return{[`&-item:not(${t}-last-item)`]:{marginBottom:e.calc(e.lineWidth).mul(-1).equal()},[`&-item:not(${n}-status-success)`]:{zIndex:2},"&-item":{"&:hover,&:focus,&:active":{zIndex:3},"&[disabled]":{zIndex:0}}}}function lO(e,t){return{[`&-item:not(${t}-first-item):not(${t}-last-item)`]:{borderRadius:0},[`&-item${t}-first-item:not(${t}-last-item)`]:{[`&, &${e}-sm, &${e}-lg`]:{borderEndEndRadius:0,borderEndStartRadius:0}},[`&-item${t}-last-item:not(${t}-first-item)`]:{[`&, &${e}-sm, &${e}-lg`]:{borderStartStartRadius:0,borderStartEndRadius:0}}}}function sO(e){const t=`${e.componentCls}-compact-vertical`;return{[t]:Object.assign(Object.assign({},iO(e,t,e.componentCls)),lO(e.componentCls,t))}}const cO=e=>{const{componentCls:t,colorPrimaryHover:n,lineWidth:r,calc:o}=e,a=o(r).mul(-1).equal(),l=s=>{const c=`${t}-compact${s?"-vertical":""}-item${t}-primary:not([disabled])`;return{[`${c} + ${c}::before`]:{position:"absolute",top:s?a:0,insetInlineStart:s?0:a,backgroundColor:n,content:'""',width:s?"100%":r,height:s?r:"100%"}}};return Object.assign(Object.assign({},l()),l(!0))},uO=ua(["Button","compact"],e=>{const t=D0(e);return[di(t),sO(t),cO(t)]},_0);var dO=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function fO(e){if(typeof e=="object"&&e){let t=e==null?void 0:e.delay;return t=!Number.isNaN(t)&&typeof t=="number"?t:0,{loading:t<=0,delay:t}}return{loading:!!e,delay:0}}const mO={default:["default","outlined"],primary:["primary","solid"],dashed:["default","dashed"],link:["link","link"],text:["default","text"]},vO=F.forwardRef((e,t)=>{var n,r;const{loading:o=!1,prefixCls:a,color:l,variant:s,type:c,danger:u=!1,shape:d,size:f,styles:m,disabled:v,className:g,rootClassName:h,children:p,icon:b,iconPosition:y="start",ghost:C=!1,block:$=!1,htmlType:S="button",classNames:x,style:E={},autoInsertSpace:O,autoFocus:w}=e,I=dO(e,["loading","prefixCls","color","variant","type","danger","shape","size","styles","disabled","className","rootClassName","children","icon","iconPosition","ghost","block","htmlType","classNames","style","autoInsertSpace","autoFocus"]),P=c||"default",{button:M}=F.useContext(ot),R=d||(M==null?void 0:M.shape)||"default",[N,T]=i.useMemo(()=>{if(l&&s)return[l,s];if(c||u){const ve=mO[P]||[];return u?["danger",ve[1]]:ve}return M!=null&&M.color&&(M!=null&&M.variant)?[M.color,M.variant]:["default","outlined"]},[c,l,s,u,M==null?void 0:M.variant,M==null?void 0:M.color]),z=N==="danger"?"dangerous":N,{getPrefixCls:_,direction:B,autoInsertSpace:V,className:G,style:q,classNames:H,styles:W}=tn("button"),K=(n=O??V)!==null&&n!==void 0?n:!0,U=_("btn",a),[te,X,ae]=rO(U),le=i.useContext(Ln),ee=v??le,Y=i.useContext(x0),re=i.useMemo(()=>fO(o),[o]),[ne,Z]=i.useState(re.loading),[Q,ie]=i.useState(!1),de=i.useRef(null),he=zr(t,de),ye=i.Children.count(p)===1&&!b&&!ac(T),oe=i.useRef(!0);F.useEffect(()=>(oe.current=!1,()=>{oe.current=!0}),[]),wt(()=>{let ve=null;re.delay>0?ve=setTimeout(()=>{ve=null,Z(!0)},re.delay):Z(re.loading);function xe(){ve&&(clearTimeout(ve),ve=null)}return xe},[re.delay,re.loading]),i.useEffect(()=>{if(!de.current||!K)return;const ve=de.current.textContent||"";ye&&Ou(ve)?Q||ie(!0):Q&&ie(!1)}),i.useEffect(()=>{w&&de.current&&de.current.focus()},[]);const ce=F.useCallback(ve=>{var xe;if(ne||ee){ve.preventDefault();return}(xe=e.onClick)===null||xe===void 0||xe.call(e,("href"in e,ve))},[e.onClick,ne,ee]),{compactSize:ge,compactItemClassnames:se}=ro(U,B),be={large:"lg",small:"sm",middle:void 0},we=Sn(ve=>{var xe,Re;return(Re=(xe=f??ge)!==null&&xe!==void 0?xe:Y)!==null&&Re!==void 0?Re:ve}),Me=we&&(r=be[we])!==null&&r!==void 0?r:"",Te=ne?"loading":b,Se=Gt(I,["navigate"]),Fe=A(U,X,ae,{[`${U}-${R}`]:R!=="default"&&R,[`${U}-${P}`]:P,[`${U}-dangerous`]:u,[`${U}-color-${z}`]:z,[`${U}-variant-${T}`]:T,[`${U}-${Me}`]:Me,[`${U}-icon-only`]:!p&&p!==0&&!!Te,[`${U}-background-ghost`]:C&&!ac(T),[`${U}-loading`]:ne,[`${U}-two-chinese-chars`]:Q&&K&&!ne,[`${U}-block`]:$,[`${U}-rtl`]:B==="rtl",[`${U}-icon-end`]:y==="end"},se,g,h,G),Ce=Object.assign(Object.assign({},q),E),me=A(x==null?void 0:x.icon,H.icon),$e=Object.assign(Object.assign({},(m==null?void 0:m.icon)||{}),W.icon||{}),Ee=b&&!ne?F.createElement(Iu,{prefixCls:U,className:me,style:$e},b):o&&typeof o=="object"&&o.icon?F.createElement(Iu,{prefixCls:U,className:me,style:$e},o.icon):F.createElement(NE,{existIcon:!!b,prefixCls:U,loading:ne,mount:oe.current}),Ie=p||p===0?PE(p,ye&&K):null;if(Se.href!==void 0)return te(F.createElement("a",Object.assign({},Se,{className:A(Fe,{[`${U}-disabled`]:ee}),href:ee?void 0:Se.href,style:Ce,onClick:ce,ref:he,tabIndex:ee?-1:0}),Ee,Ie));let fe=F.createElement("button",Object.assign({},I,{type:S,className:Fe,style:Ce,onClick:ce,disabled:ee,ref:he}),Ee,Ie,se&&F.createElement(uO,{prefixCls:U}));return ac(T)||(fe=F.createElement(ci,{component:"Button",disabled:ne},fe)),te(fe)}),er=vO;er.Group=IE;er.__ANT_BUTTON=!0;function uc(e){return!!(e!=null&&e.then)}const Wd=e=>{const{type:t,children:n,prefixCls:r,buttonProps:o,close:a,autoFocus:l,emitEvent:s,isSilent:c,quitOnNullishReturnValue:u,actionFn:d}=e,f=i.useRef(!1),m=i.useRef(null),[v,g]=ta(!1),h=(...y)=>{a==null||a.apply(void 0,y)};i.useEffect(()=>{let y=null;return l&&(y=setTimeout(()=>{var C;(C=m.current)===null||C===void 0||C.focus({preventScroll:!0})})),()=>{y&&clearTimeout(y)}},[]);const p=y=>{uc(y)&&(g(!0),y.then((...C)=>{g(!1,!0),h.apply(void 0,C),f.current=!1},C=>{if(g(!1,!0),f.current=!1,!(c!=null&&c()))return Promise.reject(C)}))},b=y=>{if(f.current)return;if(f.current=!0,!d){h();return}let C;if(s){if(C=d(y),u&&!uc(C)){f.current=!1,h(y);return}}else if(d.length)C=d(a),f.current=!1;else if(C=d(),!uc(C)){h();return}p(C)};return i.createElement(er,Object.assign({},Dd(t),{onClick:b,loading:v,prefixCls:r},o,{ref:m}),n)},fi=F.createContext({}),{Provider:L0}=fi,qm=()=>{const{autoFocusButton:e,cancelButtonProps:t,cancelTextLocale:n,isSilent:r,mergedOkCancel:o,rootPrefixCls:a,close:l,onCancel:s,onConfirm:c}=i.useContext(fi);return o?F.createElement(Wd,{isSilent:r,actionFn:s,close:(...u)=>{l==null||l.apply(void 0,u),c==null||c(!1)},autoFocus:e==="cancel",buttonProps:t,prefixCls:`${a}-btn`},n):null},Um=()=>{const{autoFocusButton:e,close:t,isSilent:n,okButtonProps:r,rootPrefixCls:o,okTextLocale:a,okType:l,onConfirm:s,onOk:c}=i.useContext(fi);return F.createElement(Wd,{isSilent:n,type:l||"primary",actionFn:c,close:(...u)=>{t==null||t.apply(void 0,u),s==null||s(!0)},autoFocus:e==="ok",buttonProps:r,prefixCls:`${o}-btn`},a)};var H0=i.createContext(null),Xm=[];function gO(e,t){var n=i.useState(function(){if(!wn())return null;var g=document.createElement("div");return g}),r=J(n,1),o=r[0],a=i.useRef(!1),l=i.useContext(H0),s=i.useState(Xm),c=J(s,2),u=c[0],d=c[1],f=l||(a.current?void 0:function(g){d(function(h){var p=[g].concat(pe(h));return p})});function m(){o.parentElement||document.body.appendChild(o),a.current=!0}function v(){var g;(g=o.parentElement)===null||g===void 0||g.removeChild(o),a.current=!1}return wt(function(){return e?l?l(m):m():v(),v},[e]),wt(function(){u.length&&(u.forEach(function(g){return g()}),d(Xm))},[u]),[o,f]}var dc;function A0(e){var t="rc-scrollbar-measure-".concat(Math.random().toString(36).substring(7)),n=document.createElement("div");n.id=t;var r=n.style;r.position="absolute",r.left="0",r.top="0",r.width="100px",r.height="100px",r.overflow="scroll";var o,a;if(e){var l=getComputedStyle(e);r.scrollbarColor=l.scrollbarColor,r.scrollbarWidth=l.scrollbarWidth;var s=getComputedStyle(e,"::-webkit-scrollbar"),c=parseInt(s.width,10),u=parseInt(s.height,10);try{var d=c?"width: ".concat(s.width,";"):"",f=u?"height: ".concat(s.height,";"):"";Ar(`
#`.concat(t,`::-webkit-scrollbar {
`).concat(d,`
`).concat(f,`
}`),t)}catch(g){console.error(g),o=c,a=u}}document.body.appendChild(n);var m=e&&o&&!isNaN(o)?o:n.offsetWidth-n.clientWidth,v=e&&a&&!isNaN(a)?a:n.offsetHeight-n.clientHeight;return document.body.removeChild(n),Ua(t),{width:m,height:v}}function Ym(e){return typeof document>"u"?0:(dc===void 0&&(dc=A0()),dc.width)}function Ru(e){return typeof document>"u"||!e||!(e instanceof Element)?{width:0,height:0}:A0(e)}function pO(){return document.body.scrollHeight>(window.innerHeight||document.documentElement.clientHeight)&&window.innerWidth>document.body.offsetWidth}var hO="rc-util-locker-".concat(Date.now()),Qm=0;function bO(e){var t=!!e,n=i.useState(function(){return Qm+=1,"".concat(hO,"_").concat(Qm)}),r=J(n,1),o=r[0];wt(function(){if(t){var a=Ru(document.body).width,l=pO();Ar(`
html body {
  overflow-y: hidden;
  `.concat(l?"width: calc(100% - ".concat(a,"px);"):"",`
}`),o)}else Ua(o);return function(){Ua(o)}},[t,o])}var yO=!1;function CO(e){return yO}var Zm=function(t){return t===!1?!1:!wn()||!t?null:typeof t=="string"?document.querySelector(t):typeof t=="function"?t():t},ps=i.forwardRef(function(e,t){var n=e.open,r=e.autoLock,o=e.getContainer;e.debug;var a=e.autoDestroy,l=a===void 0?!0:a,s=e.children,c=i.useState(n),u=J(c,2),d=u[0],f=u[1],m=d||n;i.useEffect(function(){(l||n)&&f(n)},[n,l]);var v=i.useState(function(){return Zm(o)}),g=J(v,2),h=g[0],p=g[1];i.useEffect(function(){var P=Zm(o);p(P??null)});var b=gO(m&&!h),y=J(b,2),C=y[0],$=y[1],S=h??C;bO(r&&n&&wn()&&(S===C||S===document.body));var x=null;if(s&&Nr(s)&&t){var E=s;x=E.ref}var O=zr(x,t);if(!m||!wn()||h===void 0)return null;var w=S===!1||CO(),I=s;return t&&(I=i.cloneElement(s,{ref:O})),i.createElement(H0.Provider,{value:$},w?I:Pr.createPortal(I,S))}),F0=i.createContext({});function SO(){var e=k({},Dl);return e.useId}var Jm=0,ev=SO();const mi=ev?function(t){var n=ev();return t||n}:function(t){var n=i.useState("ssr-id"),r=J(n,2),o=r[0],a=r[1];return i.useEffect(function(){var l=Jm;Jm+=1,a("rc_unique_".concat(l))},[]),t||o};function tv(e,t,n){var r=t;return!r&&n&&(r="".concat(e,"-").concat(n)),r}function nv(e,t){var n=e["page".concat(t?"Y":"X","Offset")],r="scroll".concat(t?"Top":"Left");if(typeof n!="number"){var o=e.document;n=o.documentElement[r],typeof n!="number"&&(n=o.body[r])}return n}function $O(e){var t=e.getBoundingClientRect(),n={left:t.left,top:t.top},r=e.ownerDocument,o=r.defaultView||r.parentWindow;return n.left+=nv(o),n.top+=nv(o,!0),n}const xO=i.memo(function(e){var t=e.children;return t},function(e,t){var n=t.shouldUpdate;return!n});var wO={width:0,height:0,overflow:"hidden",outline:"none"},EO={outline:"none"},k0=F.forwardRef(function(e,t){var n=e.prefixCls,r=e.className,o=e.style,a=e.title,l=e.ariaId,s=e.footer,c=e.closable,u=e.closeIcon,d=e.onClose,f=e.children,m=e.bodyStyle,v=e.bodyProps,g=e.modalRender,h=e.onMouseDown,p=e.onMouseUp,b=e.holderRef,y=e.visible,C=e.forceRender,$=e.width,S=e.height,x=e.classNames,E=e.styles,O=F.useContext(F0),w=O.panel,I=zr(b,w),P=i.useRef(),M=i.useRef();F.useImperativeHandle(t,function(){return{focus:function(){var q;(q=P.current)===null||q===void 0||q.focus({preventScroll:!0})},changeActive:function(q){var H=document,W=H.activeElement;q&&W===M.current?P.current.focus({preventScroll:!0}):!q&&W===P.current&&M.current.focus({preventScroll:!0})}}});var R={};$!==void 0&&(R.width=$),S!==void 0&&(R.height=S);var N=s?F.createElement("div",{className:A("".concat(n,"-footer"),x==null?void 0:x.footer),style:k({},E==null?void 0:E.footer)},s):null,T=a?F.createElement("div",{className:A("".concat(n,"-header"),x==null?void 0:x.header),style:k({},E==null?void 0:E.header)},F.createElement("div",{className:"".concat(n,"-title"),id:l},a)):null,j=i.useMemo(function(){return Qe(c)==="object"&&c!==null?c:c?{closeIcon:u??F.createElement("span",{className:"".concat(n,"-close-x")})}:{}},[c,u,n]),z=rn(j,!0),_=Qe(c)==="object"&&c.disabled,B=c?F.createElement("button",ue({type:"button",onClick:d,"aria-label":"Close"},z,{className:"".concat(n,"-close"),disabled:_}),j.closeIcon):null,V=F.createElement("div",{className:A("".concat(n,"-content"),x==null?void 0:x.content),style:E==null?void 0:E.content},B,T,F.createElement("div",ue({className:A("".concat(n,"-body"),x==null?void 0:x.body),style:k(k({},m),E==null?void 0:E.body)},v),f),N);return F.createElement("div",{key:"dialog-element",role:"dialog","aria-labelledby":a?l:null,"aria-modal":"true",ref:I,style:k(k({},o),R),className:A(n,r),onMouseDown:h,onMouseUp:p},F.createElement("div",{ref:P,tabIndex:0,style:EO},F.createElement(xO,{shouldUpdate:y||C},g?g(V):V)),F.createElement("div",{tabIndex:0,ref:M,style:wO}))}),V0=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.title,o=e.style,a=e.className,l=e.visible,s=e.forceRender,c=e.destroyOnClose,u=e.motionName,d=e.ariaId,f=e.onVisibleChanged,m=e.mousePosition,v=i.useRef(),g=i.useState(),h=J(g,2),p=h[0],b=h[1],y={};p&&(y.transformOrigin=p);function C(){var $=$O(v.current);b(m&&(m.x||m.y)?"".concat(m.x-$.left,"px ").concat(m.y-$.top,"px"):"")}return i.createElement(En,{visible:l,onVisibleChanged:f,onAppearPrepare:C,onEnterPrepare:C,forceRender:s,motionName:u,removeOnLeave:c,ref:v},function($,S){var x=$.className,E=$.style;return i.createElement(k0,ue({},e,{ref:t,title:r,ariaId:d,prefixCls:n,holderRef:S,style:k(k(k({},E),o),y),className:A(a,x)}))})});V0.displayName="Content";var OO=function(t){var n=t.prefixCls,r=t.style,o=t.visible,a=t.maskProps,l=t.motionName,s=t.className;return i.createElement(En,{key:"mask",visible:o,motionName:l,leavedClassName:"".concat(n,"-mask-hidden")},function(c,u){var d=c.className,f=c.style;return i.createElement("div",ue({ref:u,style:k(k({},f),r),className:A("".concat(n,"-mask"),d,s)},a))})},IO=function(t){var n=t.prefixCls,r=n===void 0?"rc-dialog":n,o=t.zIndex,a=t.visible,l=a===void 0?!1:a,s=t.keyboard,c=s===void 0?!0:s,u=t.focusTriggerAfterClose,d=u===void 0?!0:u,f=t.wrapStyle,m=t.wrapClassName,v=t.wrapProps,g=t.onClose,h=t.afterOpenChange,p=t.afterClose,b=t.transitionName,y=t.animation,C=t.closable,$=C===void 0?!0:C,S=t.mask,x=S===void 0?!0:S,E=t.maskTransitionName,O=t.maskAnimation,w=t.maskClosable,I=w===void 0?!0:w,P=t.maskStyle,M=t.maskProps,R=t.rootClassName,N=t.classNames,T=t.styles,j=i.useRef(),z=i.useRef(),_=i.useRef(),B=i.useState(l),V=J(B,2),G=V[0],q=V[1],H=mi();function W(){Zc(z.current,document.activeElement)||(j.current=document.activeElement)}function K(){if(!Zc(z.current,document.activeElement)){var Z;(Z=_.current)===null||Z===void 0||Z.focus()}}function U(Z){if(Z)K();else{if(q(!1),x&&j.current&&d){try{j.current.focus({preventScroll:!0})}catch{}j.current=null}G&&(p==null||p())}h==null||h(Z)}function te(Z){g==null||g(Z)}var X=i.useRef(!1),ae=i.useRef(),le=function(){clearTimeout(ae.current),X.current=!0},ee=function(){ae.current=setTimeout(function(){X.current=!1})},Y=null;I&&(Y=function(Q){X.current?X.current=!1:z.current===Q.target&&te(Q)});function re(Z){if(c&&Z.keyCode===Ne.ESC){Z.stopPropagation(),te(Z);return}l&&Z.keyCode===Ne.TAB&&_.current.changeActive(!Z.shiftKey)}i.useEffect(function(){l&&(q(!0),W())},[l]),i.useEffect(function(){return function(){clearTimeout(ae.current)}},[]);var ne=k(k(k({zIndex:o},f),T==null?void 0:T.wrapper),{},{display:G?null:"none"});return i.createElement("div",ue({className:A("".concat(r,"-root"),R)},rn(t,{data:!0})),i.createElement(OO,{prefixCls:r,visible:x&&l,motionName:tv(r,E,O),style:k(k({zIndex:o},P),T==null?void 0:T.mask),maskProps:M,className:N==null?void 0:N.mask}),i.createElement("div",ue({tabIndex:-1,onKeyDown:re,className:A("".concat(r,"-wrap"),m,N==null?void 0:N.wrapper),ref:z,onClick:Y,style:ne},v),i.createElement(V0,ue({},t,{onMouseDown:le,onMouseUp:ee,ref:_,closable:$,ariaId:H,prefixCls:r,visible:l&&G,onClose:te,onVisibleChanged:U,motionName:tv(r,b,y)}))))},W0=function(t){var n=t.visible,r=t.getContainer,o=t.forceRender,a=t.destroyOnClose,l=a===void 0?!1:a,s=t.afterClose,c=t.panelRef,u=i.useState(n),d=J(u,2),f=d[0],m=d[1],v=i.useMemo(function(){return{panel:c}},[c]);return i.useEffect(function(){n&&m(!0)},[n]),!o&&l&&!f?null:i.createElement(F0.Provider,{value:v},i.createElement(ps,{open:n||o||f,autoDestroy:!1,getContainer:r,autoLock:n||f},i.createElement(IO,ue({},t,{destroyOnClose:l,afterClose:function(){s==null||s(),m(!1)}}))))};W0.displayName="Dialog";var co="RC_FORM_INTERNAL_HOOKS",Yt=function(){Kt(!1,"Can not find FormContext. Please make sure you wrap Field under Form.")},ra=i.createContext({getFieldValue:Yt,getFieldsValue:Yt,getFieldError:Yt,getFieldWarning:Yt,getFieldsError:Yt,isFieldsTouched:Yt,isFieldTouched:Yt,isFieldValidating:Yt,isFieldsValidating:Yt,resetFields:Yt,setFields:Yt,setFieldValue:Yt,setFieldsValue:Yt,validateFields:Yt,submit:Yt,getInternalHooks:function(){return Yt(),{dispatch:Yt,initEntityValue:Yt,registerField:Yt,useSubscribe:Yt,setInitialValues:Yt,destroyForm:Yt,setCallbacks:Yt,registerWatch:Yt,getFields:Yt,setValidateMessages:Yt,setPreserve:Yt,getInitialValue:Yt}}}),$l=i.createContext(null);function Pu(e){return e==null?[]:Array.isArray(e)?e:[e]}function RO(e){return e&&!!e._init}function Nu(){return{default:"Validation error on field %s",required:"%s is required",enum:"%s must be one of %s",whitespace:"%s cannot be empty",date:{format:"%s date %s is invalid for format %s",parse:"%s date could not be parsed, %s is invalid ",invalid:"%s date %s is invalid"},types:{string:"%s is not a %s",method:"%s is not a %s (function)",array:"%s is not an %s",object:"%s is not an %s",number:"%s is not a %s",date:"%s is not a %s",boolean:"%s is not a %s",integer:"%s is not an %s",float:"%s is not a %s",regexp:"%s is not a valid %s",email:"%s is not a valid %s",url:"%s is not a valid %s",hex:"%s is not a valid %s"},string:{len:"%s must be exactly %s characters",min:"%s must be at least %s characters",max:"%s cannot be longer than %s characters",range:"%s must be between %s and %s characters"},number:{len:"%s must equal %s",min:"%s cannot be less than %s",max:"%s cannot be greater than %s",range:"%s must be between %s and %s"},array:{len:"%s must be exactly %s in length",min:"%s cannot be less than %s in length",max:"%s cannot be greater than %s in length",range:"%s must be between %s and %s in length"},pattern:{mismatch:"%s value %s does not match pattern %s"},clone:function(){var t=JSON.parse(JSON.stringify(this));return t.clone=this.clone,t}}}var Mu=Nu();function PO(e){try{return Function.toString.call(e).indexOf("[native code]")!==-1}catch{return typeof e=="function"}}function NO(e,t,n){if(Ul())return Reflect.construct.apply(null,arguments);var r=[null];r.push.apply(r,t);var o=new(e.bind.apply(e,r));return n&&Ga(o,n.prototype),o}function Tu(e){var t=typeof Map=="function"?new Map:void 0;return Tu=function(r){if(r===null||!PO(r))return r;if(typeof r!="function")throw new TypeError("Super expression must either be null or a function");if(t!==void 0){if(t.has(r))return t.get(r);t.set(r,o)}function o(){return NO(r,arguments,ho(this).constructor)}return o.prototype=Object.create(r.prototype,{constructor:{value:o,enumerable:!1,writable:!0,configurable:!0}}),Ga(o,r)},Tu(e)}var MO=/%[sdj%]/g,TO=function(){};function ju(e){if(!e||!e.length)return null;var t={};return e.forEach(function(n){var r=n.field;t[r]=t[r]||[],t[r].push(n)}),t}function Jn(e){for(var t=arguments.length,n=new Array(t>1?t-1:0),r=1;r<t;r++)n[r-1]=arguments[r];var o=0,a=n.length;if(typeof e=="function")return e.apply(null,n);if(typeof e=="string"){var l=e.replace(MO,function(s){if(s==="%%")return"%";if(o>=a)return s;switch(s){case"%s":return String(n[o++]);case"%d":return Number(n[o++]);case"%j":try{return JSON.stringify(n[o++])}catch{return"[Circular]"}break;default:return s}});return l}return e}function jO(e){return e==="string"||e==="url"||e==="hex"||e==="email"||e==="date"||e==="pattern"}function bn(e,t){return!!(e==null||t==="array"&&Array.isArray(e)&&!e.length||jO(t)&&typeof e=="string"&&!e)}function zO(e,t,n){var r=[],o=0,a=e.length;function l(s){r.push.apply(r,pe(s||[])),o++,o===a&&n(r)}e.forEach(function(s){t(s,l)})}function rv(e,t,n){var r=0,o=e.length;function a(l){if(l&&l.length){n(l);return}var s=r;r=r+1,s<o?t(e[s],a):n([])}a([])}function DO(e){var t=[];return Object.keys(e).forEach(function(n){t.push.apply(t,pe(e[n]||[]))}),t}var ov=function(e){tr(n,e);var t=ur(n);function n(r,o){var a;return Zt(this,n),a=t.call(this,"Async Validation Error"),D(Ve(a),"errors",void 0),D(Ve(a),"fields",void 0),a.errors=r,a.fields=o,a}return Jt(n)}(Tu(Error));function _O(e,t,n,r,o){if(t.first){var a=new Promise(function(m,v){var g=function(b){return r(b),b.length?v(new ov(b,ju(b))):m(o)},h=DO(e);rv(h,n,g)});return a.catch(function(m){return m}),a}var l=t.firstFields===!0?Object.keys(e):t.firstFields||[],s=Object.keys(e),c=s.length,u=0,d=[],f=new Promise(function(m,v){var g=function(p){if(d.push.apply(d,p),u++,u===c)return r(d),d.length?v(new ov(d,ju(d))):m(o)};s.length||(r(d),m(o)),s.forEach(function(h){var p=e[h];l.indexOf(h)!==-1?rv(p,n,g):zO(p,n,g)})});return f.catch(function(m){return m}),f}function BO(e){return!!(e&&e.message!==void 0)}function LO(e,t){for(var n=e,r=0;r<t.length;r++){if(n==null)return n;n=n[t[r]]}return n}function av(e,t){return function(n){var r;return e.fullFields?r=LO(t,e.fullFields):r=t[n.field||e.fullField],BO(n)?(n.field=n.field||e.fullField,n.fieldValue=r,n):{message:typeof n=="function"?n():n,fieldValue:r,field:n.field||e.fullField}}}function iv(e,t){if(t){for(var n in t)if(t.hasOwnProperty(n)){var r=t[n];Qe(r)==="object"&&Qe(e[n])==="object"?e[n]=k(k({},e[n]),r):e[n]=r}}return e}var Ro="enum",HO=function(t,n,r,o,a){t[Ro]=Array.isArray(t[Ro])?t[Ro]:[],t[Ro].indexOf(n)===-1&&o.push(Jn(a.messages[Ro],t.fullField,t[Ro].join(", ")))},AO=function(t,n,r,o,a){if(t.pattern){if(t.pattern instanceof RegExp)t.pattern.lastIndex=0,t.pattern.test(n)||o.push(Jn(a.messages.pattern.mismatch,t.fullField,n,t.pattern));else if(typeof t.pattern=="string"){var l=new RegExp(t.pattern);l.test(n)||o.push(Jn(a.messages.pattern.mismatch,t.fullField,n,t.pattern))}}},FO=function(t,n,r,o,a){var l=typeof t.len=="number",s=typeof t.min=="number",c=typeof t.max=="number",u=/[\uD800-\uDBFF][\uDC00-\uDFFF]/g,d=n,f=null,m=typeof n=="number",v=typeof n=="string",g=Array.isArray(n);if(m?f="number":v?f="string":g&&(f="array"),!f)return!1;g&&(d=n.length),v&&(d=n.replace(u,"_").length),l?d!==t.len&&o.push(Jn(a.messages[f].len,t.fullField,t.len)):s&&!c&&d<t.min?o.push(Jn(a.messages[f].min,t.fullField,t.min)):c&&!s&&d>t.max?o.push(Jn(a.messages[f].max,t.fullField,t.max)):s&&c&&(d<t.min||d>t.max)&&o.push(Jn(a.messages[f].range,t.fullField,t.min,t.max))},K0=function(t,n,r,o,a,l){t.required&&(!r.hasOwnProperty(t.field)||bn(n,l||t.type))&&o.push(Jn(a.messages.required,t.fullField))},Bi;const kO=function(){if(Bi)return Bi;var e="[a-fA-F\\d:]",t=function(x){return x&&x.includeBoundaries?"(?:(?<=\\s|^)(?=".concat(e,")|(?<=").concat(e,")(?=\\s|$))"):""},n="(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)(?:\\.(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)){3}",r="[a-fA-F\\d]{1,4}",o=["(?:".concat(r,":){7}(?:").concat(r,"|:)"),"(?:".concat(r,":){6}(?:").concat(n,"|:").concat(r,"|:)"),"(?:".concat(r,":){5}(?::").concat(n,"|(?::").concat(r,"){1,2}|:)"),"(?:".concat(r,":){4}(?:(?::").concat(r,"){0,1}:").concat(n,"|(?::").concat(r,"){1,3}|:)"),"(?:".concat(r,":){3}(?:(?::").concat(r,"){0,2}:").concat(n,"|(?::").concat(r,"){1,4}|:)"),"(?:".concat(r,":){2}(?:(?::").concat(r,"){0,3}:").concat(n,"|(?::").concat(r,"){1,5}|:)"),"(?:".concat(r,":){1}(?:(?::").concat(r,"){0,4}:").concat(n,"|(?::").concat(r,"){1,6}|:)"),"(?::(?:(?::".concat(r,"){0,5}:").concat(n,"|(?::").concat(r,"){1,7}|:))")],a="(?:%[0-9a-zA-Z]{1,})?",l="(?:".concat(o.join("|"),")").concat(a),s=new RegExp("(?:^".concat(n,"$)|(?:^").concat(l,"$)")),c=new RegExp("^".concat(n,"$")),u=new RegExp("^".concat(l,"$")),d=function(x){return x&&x.exact?s:new RegExp("(?:".concat(t(x)).concat(n).concat(t(x),")|(?:").concat(t(x)).concat(l).concat(t(x),")"),"g")};d.v4=function(S){return S&&S.exact?c:new RegExp("".concat(t(S)).concat(n).concat(t(S)),"g")},d.v6=function(S){return S&&S.exact?u:new RegExp("".concat(t(S)).concat(l).concat(t(S)),"g")};var f="(?:(?:[a-z]+:)?//)",m="(?:\\S+(?::\\S*)?@)?",v=d.v4().source,g=d.v6().source,h="(?:(?:[a-z\\u00a1-\\uffff0-9][-_]*)*[a-z\\u00a1-\\uffff0-9]+)",p="(?:\\.(?:[a-z\\u00a1-\\uffff0-9]-*)*[a-z\\u00a1-\\uffff0-9]+)*",b="(?:\\.(?:[a-z\\u00a1-\\uffff]{2,}))",y="(?::\\d{2,5})?",C='(?:[/?#][^\\s"]*)?',$="(?:".concat(f,"|www\\.)").concat(m,"(?:localhost|").concat(v,"|").concat(g,"|").concat(h).concat(p).concat(b,")").concat(y).concat(C);return Bi=new RegExp("(?:^".concat($,"$)"),"i"),Bi};var lv={email:/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+\.)+[a-zA-Z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]{2,}))$/,hex:/^#?([a-f0-9]{6}|[a-f0-9]{3})$/i},za={integer:function(t){return za.number(t)&&parseInt(t,10)===t},float:function(t){return za.number(t)&&!za.integer(t)},array:function(t){return Array.isArray(t)},regexp:function(t){if(t instanceof RegExp)return!0;try{return!!new RegExp(t)}catch{return!1}},date:function(t){return typeof t.getTime=="function"&&typeof t.getMonth=="function"&&typeof t.getYear=="function"&&!isNaN(t.getTime())},number:function(t){return isNaN(t)?!1:typeof t=="number"},object:function(t){return Qe(t)==="object"&&!za.array(t)},method:function(t){return typeof t=="function"},email:function(t){return typeof t=="string"&&t.length<=320&&!!t.match(lv.email)},url:function(t){return typeof t=="string"&&t.length<=2048&&!!t.match(kO())},hex:function(t){return typeof t=="string"&&!!t.match(lv.hex)}},VO=function(t,n,r,o,a){if(t.required&&n===void 0){K0(t,n,r,o,a);return}var l=["integer","float","array","regexp","object","method","email","number","date","url","hex"],s=t.type;l.indexOf(s)>-1?za[s](n)||o.push(Jn(a.messages.types[s],t.fullField,t.type)):s&&Qe(n)!==t.type&&o.push(Jn(a.messages.types[s],t.fullField,t.type))},WO=function(t,n,r,o,a){(/^\s+$/.test(n)||n==="")&&o.push(Jn(a.messages.whitespace,t.fullField))};const Bt={required:K0,whitespace:WO,type:VO,range:FO,enum:HO,pattern:AO};var KO=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a)}r(l)},GO=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(n==null&&!t.required)return r();Bt.required(t,n,o,l,a,"array"),n!=null&&(Bt.type(t,n,o,l,a),Bt.range(t,n,o,l,a))}r(l)},qO=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a),n!==void 0&&Bt.type(t,n,o,l,a)}r(l)},UO=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n,"date")&&!t.required)return r();if(Bt.required(t,n,o,l,a),!bn(n,"date")){var c;n instanceof Date?c=n:c=new Date(n),Bt.type(t,c,o,l,a),c&&Bt.range(t,c.getTime(),o,l,a)}}r(l)},XO="enum",YO=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a),n!==void 0&&Bt[XO](t,n,o,l,a)}r(l)},QO=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a),n!==void 0&&(Bt.type(t,n,o,l,a),Bt.range(t,n,o,l,a))}r(l)},ZO=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a),n!==void 0&&(Bt.type(t,n,o,l,a),Bt.range(t,n,o,l,a))}r(l)},JO=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a),n!==void 0&&Bt.type(t,n,o,l,a)}r(l)},eI=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(n===""&&(n=void 0),bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a),n!==void 0&&(Bt.type(t,n,o,l,a),Bt.range(t,n,o,l,a))}r(l)},tI=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a),n!==void 0&&Bt.type(t,n,o,l,a)}r(l)},nI=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n,"string")&&!t.required)return r();Bt.required(t,n,o,l,a),bn(n,"string")||Bt.pattern(t,n,o,l,a)}r(l)},rI=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n)&&!t.required)return r();Bt.required(t,n,o,l,a),bn(n)||Bt.type(t,n,o,l,a)}r(l)},oI=function(t,n,r,o,a){var l=[],s=Array.isArray(n)?"array":Qe(n);Bt.required(t,n,o,l,a,s),r(l)},aI=function(t,n,r,o,a){var l=[],s=t.required||!t.required&&o.hasOwnProperty(t.field);if(s){if(bn(n,"string")&&!t.required)return r();Bt.required(t,n,o,l,a,"string"),bn(n,"string")||(Bt.type(t,n,o,l,a),Bt.range(t,n,o,l,a),Bt.pattern(t,n,o,l,a),t.whitespace===!0&&Bt.whitespace(t,n,o,l,a))}r(l)},fc=function(t,n,r,o,a){var l=t.type,s=[],c=t.required||!t.required&&o.hasOwnProperty(t.field);if(c){if(bn(n,l)&&!t.required)return r();Bt.required(t,n,o,s,a,l),bn(n,l)||Bt.type(t,n,o,s,a)}r(s)};const Aa={string:aI,method:JO,number:eI,boolean:qO,regexp:rI,integer:ZO,float:QO,array:GO,object:tI,enum:YO,pattern:nI,date:UO,url:fc,hex:fc,email:fc,required:oI,any:KO};var vi=function(){function e(t){Zt(this,e),D(this,"rules",null),D(this,"_messages",Mu),this.define(t)}return Jt(e,[{key:"define",value:function(n){var r=this;if(!n)throw new Error("Cannot configure a schema with no rules");if(Qe(n)!=="object"||Array.isArray(n))throw new Error("Rules must be an object");this.rules={},Object.keys(n).forEach(function(o){var a=n[o];r.rules[o]=Array.isArray(a)?a:[a]})}},{key:"messages",value:function(n){return n&&(this._messages=iv(Nu(),n)),this._messages}},{key:"validate",value:function(n){var r=this,o=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},a=arguments.length>2&&arguments[2]!==void 0?arguments[2]:function(){},l=n,s=o,c=a;if(typeof s=="function"&&(c=s,s={}),!this.rules||Object.keys(this.rules).length===0)return c&&c(null,l),Promise.resolve(l);function u(g){var h=[],p={};function b(C){if(Array.isArray(C)){var $;h=($=h).concat.apply($,pe(C))}else h.push(C)}for(var y=0;y<g.length;y++)b(g[y]);h.length?(p=ju(h),c(h,p)):c(null,l)}if(s.messages){var d=this.messages();d===Mu&&(d=Nu()),iv(d,s.messages),s.messages=d}else s.messages=this.messages();var f={},m=s.keys||Object.keys(this.rules);m.forEach(function(g){var h=r.rules[g],p=l[g];h.forEach(function(b){var y=b;typeof y.transform=="function"&&(l===n&&(l=k({},l)),p=l[g]=y.transform(p),p!=null&&(y.type=y.type||(Array.isArray(p)?"array":Qe(p)))),typeof y=="function"?y={validator:y}:y=k({},y),y.validator=r.getValidationMethod(y),y.validator&&(y.field=g,y.fullField=y.fullField||g,y.type=r.getType(y),f[g]=f[g]||[],f[g].push({rule:y,value:p,source:l,field:g}))})});var v={};return _O(f,s,function(g,h){var p=g.rule,b=(p.type==="object"||p.type==="array")&&(Qe(p.fields)==="object"||Qe(p.defaultField)==="object");b=b&&(p.required||!p.required&&g.value),p.field=g.field;function y(E,O){return k(k({},O),{},{fullField:"".concat(p.fullField,".").concat(E),fullFields:p.fullFields?[].concat(pe(p.fullFields),[E]):[E]})}function C(){var E=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],O=Array.isArray(E)?E:[E];!s.suppressWarning&&O.length&&e.warning("async-validator:",O),O.length&&p.message!==void 0&&(O=[].concat(p.message));var w=O.map(av(p,l));if(s.first&&w.length)return v[p.field]=1,h(w);if(!b)h(w);else{if(p.required&&!g.value)return p.message!==void 0?w=[].concat(p.message).map(av(p,l)):s.error&&(w=[s.error(p,Jn(s.messages.required,p.field))]),h(w);var I={};p.defaultField&&Object.keys(g.value).map(function(R){I[R]=p.defaultField}),I=k(k({},I),g.rule.fields);var P={};Object.keys(I).forEach(function(R){var N=I[R],T=Array.isArray(N)?N:[N];P[R]=T.map(y.bind(null,R))});var M=new e(P);M.messages(s.messages),g.rule.options&&(g.rule.options.messages=s.messages,g.rule.options.error=s.error),M.validate(g.value,g.rule.options||s,function(R){var N=[];w&&w.length&&N.push.apply(N,pe(w)),R&&R.length&&N.push.apply(N,pe(R)),h(N.length?N:null)})}}var $;if(p.asyncValidator)$=p.asyncValidator(p,g.value,C,g.source,s);else if(p.validator){try{$=p.validator(p,g.value,C,g.source,s)}catch(E){var S,x;(S=(x=console).error)===null||S===void 0||S.call(x,E),s.suppressValidatorError||setTimeout(function(){throw E},0),C(E.message)}$===!0?C():$===!1?C(typeof p.message=="function"?p.message(p.fullField||p.field):p.message||"".concat(p.fullField||p.field," fails")):$ instanceof Array?C($):$ instanceof Error&&C($.message)}$&&$.then&&$.then(function(){return C()},function(E){return C(E)})},function(g){u(g)},l)}},{key:"getType",value:function(n){if(n.type===void 0&&n.pattern instanceof RegExp&&(n.type="pattern"),typeof n.validator!="function"&&n.type&&!Aa.hasOwnProperty(n.type))throw new Error(Jn("Unknown rule type %s",n.type));return n.type||"string"}},{key:"getValidationMethod",value:function(n){if(typeof n.validator=="function")return n.validator;var r=Object.keys(n),o=r.indexOf("message");return o!==-1&&r.splice(o,1),r.length===1&&r[0]==="required"?Aa.required:Aa[this.getType(n)]||void 0}}]),e}();D(vi,"register",function(t,n){if(typeof n!="function")throw new Error("Cannot register a validator by type, validator is not a function");Aa[t]=n});D(vi,"warning",TO);D(vi,"messages",Mu);D(vi,"validators",Aa);var Xn="'${name}' is not a valid ${type}",G0={default:"Validation error on field '${name}'",required:"'${name}' is required",enum:"'${name}' must be one of [${enum}]",whitespace:"'${name}' cannot be empty",date:{format:"'${name}' is invalid for format date",parse:"'${name}' could not be parsed as date",invalid:"'${name}' is invalid date"},types:{string:Xn,method:Xn,array:Xn,object:Xn,number:Xn,date:Xn,boolean:Xn,integer:Xn,float:Xn,regexp:Xn,email:Xn,url:Xn,hex:Xn},string:{len:"'${name}' must be exactly ${len} characters",min:"'${name}' must be at least ${min} characters",max:"'${name}' cannot be longer than ${max} characters",range:"'${name}' must be between ${min} and ${max} characters"},number:{len:"'${name}' must equal ${len}",min:"'${name}' cannot be less than ${min}",max:"'${name}' cannot be greater than ${max}",range:"'${name}' must be between ${min} and ${max}"},array:{len:"'${name}' must be exactly ${len} in length",min:"'${name}' cannot be less than ${min} in length",max:"'${name}' cannot be greater than ${max} in length",range:"'${name}' must be between ${min} and ${max} in length"},pattern:{mismatch:"'${name}' does not match pattern ${pattern}"}},sv=vi;function iI(e,t){return e.replace(/\\?\$\{\w+\}/g,function(n){if(n.startsWith("\\"))return n.slice(1);var r=n.slice(2,-1);return t[r]})}var cv="CODE_LOGIC_ERROR";function zu(e,t,n,r,o){return Du.apply(this,arguments)}function Du(){return Du=_n(kt().mark(function e(t,n,r,o,a){var l,s,c,u,d,f,m,v,g;return kt().wrap(function(p){for(;;)switch(p.prev=p.next){case 0:return l=k({},r),delete l.ruleIndex,sv.warning=function(){},l.validator&&(s=l.validator,l.validator=function(){try{return s.apply(void 0,arguments)}catch(b){return console.error(b),Promise.reject(cv)}}),c=null,l&&l.type==="array"&&l.defaultField&&(c=l.defaultField,delete l.defaultField),u=new sv(D({},t,[l])),d=Lo(G0,o.validateMessages),u.messages(d),f=[],p.prev=10,p.next=13,Promise.resolve(u.validate(D({},t,n),k({},o)));case 13:p.next=18;break;case 15:p.prev=15,p.t0=p.catch(10),p.t0.errors&&(f=p.t0.errors.map(function(b,y){var C=b.message,$=C===cv?d.default:C;return i.isValidElement($)?i.cloneElement($,{key:"error_".concat(y)}):$}));case 18:if(!(!f.length&&c)){p.next=23;break}return p.next=21,Promise.all(n.map(function(b,y){return zu("".concat(t,".").concat(y),b,c,o,a)}));case 21:return m=p.sent,p.abrupt("return",m.reduce(function(b,y){return[].concat(pe(b),pe(y))},[]));case 23:return v=k(k({},r),{},{name:t,enum:(r.enum||[]).join(", ")},a),g=f.map(function(b){return typeof b=="string"?iI(b,v):b}),p.abrupt("return",g);case 26:case"end":return p.stop()}},e,null,[[10,15]])})),Du.apply(this,arguments)}function lI(e,t,n,r,o,a){var l=e.join("."),s=n.map(function(d,f){var m=d.validator,v=k(k({},d),{},{ruleIndex:f});return m&&(v.validator=function(g,h,p){var b=!1,y=function(){for(var S=arguments.length,x=new Array(S),E=0;E<S;E++)x[E]=arguments[E];Promise.resolve().then(function(){Kt(!b,"Your validator function has already return a promise. `callback` will be ignored."),b||p.apply(void 0,x)})},C=m(g,h,y);b=C&&typeof C.then=="function"&&typeof C.catch=="function",Kt(b,"`callback` is deprecated. Please return a promise instead."),b&&C.then(function(){p()}).catch(function($){p($||" ")})}),v}).sort(function(d,f){var m=d.warningOnly,v=d.ruleIndex,g=f.warningOnly,h=f.ruleIndex;return!!m==!!g?v-h:m?1:-1}),c;if(o===!0)c=new Promise(function(){var d=_n(kt().mark(function f(m,v){var g,h,p;return kt().wrap(function(y){for(;;)switch(y.prev=y.next){case 0:g=0;case 1:if(!(g<s.length)){y.next=12;break}return h=s[g],y.next=5,zu(l,t,h,r,a);case 5:if(p=y.sent,!p.length){y.next=9;break}return v([{errors:p,rule:h}]),y.abrupt("return");case 9:g+=1,y.next=1;break;case 12:m([]);case 13:case"end":return y.stop()}},f)}));return function(f,m){return d.apply(this,arguments)}}());else{var u=s.map(function(d){return zu(l,t,d,r,a).then(function(f){return{errors:f,rule:d}})});c=(o?cI(u):sI(u)).then(function(d){return Promise.reject(d)})}return c.catch(function(d){return d}),c}function sI(e){return _u.apply(this,arguments)}function _u(){return _u=_n(kt().mark(function e(t){return kt().wrap(function(r){for(;;)switch(r.prev=r.next){case 0:return r.abrupt("return",Promise.all(t).then(function(o){var a,l=(a=[]).concat.apply(a,pe(o));return l}));case 1:case"end":return r.stop()}},e)})),_u.apply(this,arguments)}function cI(e){return Bu.apply(this,arguments)}function Bu(){return Bu=_n(kt().mark(function e(t){var n;return kt().wrap(function(o){for(;;)switch(o.prev=o.next){case 0:return n=0,o.abrupt("return",new Promise(function(a){t.forEach(function(l){l.then(function(s){s.errors.length&&a([s]),n+=1,n===t.length&&a([])})})}));case 2:case"end":return o.stop()}},e)})),Bu.apply(this,arguments)}function sn(e){return Pu(e)}function uv(e,t){var n={};return t.forEach(function(r){var o=Qn(e,r);n=fr(n,r,o)}),n}function Ko(e,t){var n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1;return e&&e.some(function(r){return q0(t,r,n)})}function q0(e,t){var n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1;return!e||!t||!n&&e.length!==t.length?!1:t.every(function(r,o){return e[o]===r})}function uI(e,t){if(e===t)return!0;if(!e&&t||e&&!t||!e||!t||Qe(e)!=="object"||Qe(t)!=="object")return!1;var n=Object.keys(e),r=Object.keys(t),o=new Set([].concat(n,r));return pe(o).every(function(a){var l=e[a],s=t[a];return typeof l=="function"&&typeof s=="function"?!0:l===s})}function dI(e){var t=arguments.length<=1?void 0:arguments[1];return t&&t.target&&Qe(t.target)==="object"&&e in t.target?t.target[e]:t}function dv(e,t,n){var r=e.length;if(t<0||t>=r||n<0||n>=r)return e;var o=e[t],a=t-n;return a>0?[].concat(pe(e.slice(0,n)),[o],pe(e.slice(n,t)),pe(e.slice(t+1,r))):a<0?[].concat(pe(e.slice(0,t)),pe(e.slice(t+1,n+1)),[o],pe(e.slice(n+1,r))):e}var fI=["name"],rr=[];function mc(e,t,n,r,o,a){return typeof e=="function"?e(t,n,"source"in a?{source:a.source}:{}):r!==o}var Kd=function(e){tr(n,e);var t=ur(n);function n(r){var o;if(Zt(this,n),o=t.call(this,r),D(Ve(o),"state",{resetCount:0}),D(Ve(o),"cancelRegisterFunc",null),D(Ve(o),"mounted",!1),D(Ve(o),"touched",!1),D(Ve(o),"dirty",!1),D(Ve(o),"validatePromise",void 0),D(Ve(o),"prevValidating",void 0),D(Ve(o),"errors",rr),D(Ve(o),"warnings",rr),D(Ve(o),"cancelRegister",function(){var c=o.props,u=c.preserve,d=c.isListField,f=c.name;o.cancelRegisterFunc&&o.cancelRegisterFunc(d,u,sn(f)),o.cancelRegisterFunc=null}),D(Ve(o),"getNamePath",function(){var c=o.props,u=c.name,d=c.fieldContext,f=d.prefixName,m=f===void 0?[]:f;return u!==void 0?[].concat(pe(m),pe(u)):[]}),D(Ve(o),"getRules",function(){var c=o.props,u=c.rules,d=u===void 0?[]:u,f=c.fieldContext;return d.map(function(m){return typeof m=="function"?m(f):m})}),D(Ve(o),"refresh",function(){o.mounted&&o.setState(function(c){var u=c.resetCount;return{resetCount:u+1}})}),D(Ve(o),"metaCache",null),D(Ve(o),"triggerMetaEvent",function(c){var u=o.props.onMetaChange;if(u){var d=k(k({},o.getMeta()),{},{destroy:c});hr(o.metaCache,d)||u(d),o.metaCache=d}else o.metaCache=null}),D(Ve(o),"onStoreChange",function(c,u,d){var f=o.props,m=f.shouldUpdate,v=f.dependencies,g=v===void 0?[]:v,h=f.onReset,p=d.store,b=o.getNamePath(),y=o.getValue(c),C=o.getValue(p),$=u&&Ko(u,b);switch(d.type==="valueUpdate"&&d.source==="external"&&!hr(y,C)&&(o.touched=!0,o.dirty=!0,o.validatePromise=null,o.errors=rr,o.warnings=rr,o.triggerMetaEvent()),d.type){case"reset":if(!u||$){o.touched=!1,o.dirty=!1,o.validatePromise=void 0,o.errors=rr,o.warnings=rr,o.triggerMetaEvent(),h==null||h(),o.refresh();return}break;case"remove":{if(m&&mc(m,c,p,y,C,d)){o.reRender();return}break}case"setField":{var S=d.data;if($){"touched"in S&&(o.touched=S.touched),"validating"in S&&!("originRCField"in S)&&(o.validatePromise=S.validating?Promise.resolve([]):null),"errors"in S&&(o.errors=S.errors||rr),"warnings"in S&&(o.warnings=S.warnings||rr),o.dirty=!0,o.triggerMetaEvent(),o.reRender();return}else if("value"in S&&Ko(u,b,!0)){o.reRender();return}if(m&&!b.length&&mc(m,c,p,y,C,d)){o.reRender();return}break}case"dependenciesUpdate":{var x=g.map(sn);if(x.some(function(E){return Ko(d.relatedFields,E)})){o.reRender();return}break}default:if($||(!g.length||b.length||m)&&mc(m,c,p,y,C,d)){o.reRender();return}break}m===!0&&o.reRender()}),D(Ve(o),"validateRules",function(c){var u=o.getNamePath(),d=o.getValue(),f=c||{},m=f.triggerName,v=f.validateOnly,g=v===void 0?!1:v,h=Promise.resolve().then(_n(kt().mark(function p(){var b,y,C,$,S,x,E;return kt().wrap(function(w){for(;;)switch(w.prev=w.next){case 0:if(o.mounted){w.next=2;break}return w.abrupt("return",[]);case 2:if(b=o.props,y=b.validateFirst,C=y===void 0?!1:y,$=b.messageVariables,S=b.validateDebounce,x=o.getRules(),m&&(x=x.filter(function(I){return I}).filter(function(I){var P=I.validateTrigger;if(!P)return!0;var M=Pu(P);return M.includes(m)})),!(S&&m)){w.next=10;break}return w.next=8,new Promise(function(I){setTimeout(I,S)});case 8:if(o.validatePromise===h){w.next=10;break}return w.abrupt("return",[]);case 10:return E=lI(u,d,x,c,C,$),E.catch(function(I){return I}).then(function(){var I=arguments.length>0&&arguments[0]!==void 0?arguments[0]:rr;if(o.validatePromise===h){var P;o.validatePromise=null;var M=[],R=[];(P=I.forEach)===null||P===void 0||P.call(I,function(N){var T=N.rule.warningOnly,j=N.errors,z=j===void 0?rr:j;T?R.push.apply(R,pe(z)):M.push.apply(M,pe(z))}),o.errors=M,o.warnings=R,o.triggerMetaEvent(),o.reRender()}}),w.abrupt("return",E);case 13:case"end":return w.stop()}},p)})));return g||(o.validatePromise=h,o.dirty=!0,o.errors=rr,o.warnings=rr,o.triggerMetaEvent(),o.reRender()),h}),D(Ve(o),"isFieldValidating",function(){return!!o.validatePromise}),D(Ve(o),"isFieldTouched",function(){return o.touched}),D(Ve(o),"isFieldDirty",function(){if(o.dirty||o.props.initialValue!==void 0)return!0;var c=o.props.fieldContext,u=c.getInternalHooks(co),d=u.getInitialValue;return d(o.getNamePath())!==void 0}),D(Ve(o),"getErrors",function(){return o.errors}),D(Ve(o),"getWarnings",function(){return o.warnings}),D(Ve(o),"isListField",function(){return o.props.isListField}),D(Ve(o),"isList",function(){return o.props.isList}),D(Ve(o),"isPreserve",function(){return o.props.preserve}),D(Ve(o),"getMeta",function(){o.prevValidating=o.isFieldValidating();var c={touched:o.isFieldTouched(),validating:o.prevValidating,errors:o.errors,warnings:o.warnings,name:o.getNamePath(),validated:o.validatePromise===null};return c}),D(Ve(o),"getOnlyChild",function(c){if(typeof c=="function"){var u=o.getMeta();return k(k({},o.getOnlyChild(c(o.getControlled(),u,o.props.fieldContext))),{},{isFunction:!0})}var d=xn(c);return d.length!==1||!i.isValidElement(d[0])?{child:d,isFunction:!1}:{child:d[0],isFunction:!1}}),D(Ve(o),"getValue",function(c){var u=o.props.fieldContext.getFieldsValue,d=o.getNamePath();return Qn(c||u(!0),d)}),D(Ve(o),"getControlled",function(){var c=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},u=o.props,d=u.name,f=u.trigger,m=u.validateTrigger,v=u.getValueFromEvent,g=u.normalize,h=u.valuePropName,p=u.getValueProps,b=u.fieldContext,y=m!==void 0?m:b.validateTrigger,C=o.getNamePath(),$=b.getInternalHooks,S=b.getFieldsValue,x=$(co),E=x.dispatch,O=o.getValue(),w=p||function(N){return D({},h,N)},I=c[f],P=d!==void 0?w(O):{},M=k(k({},c),P);M[f]=function(){o.touched=!0,o.dirty=!0,o.triggerMetaEvent();for(var N,T=arguments.length,j=new Array(T),z=0;z<T;z++)j[z]=arguments[z];v?N=v.apply(void 0,j):N=dI.apply(void 0,[h].concat(j)),g&&(N=g(N,O,S(!0))),N!==O&&E({type:"updateValue",namePath:C,value:N}),I&&I.apply(void 0,j)};var R=Pu(y||[]);return R.forEach(function(N){var T=M[N];M[N]=function(){T&&T.apply(void 0,arguments);var j=o.props.rules;j&&j.length&&E({type:"validateField",namePath:C,triggerName:N})}}),M}),r.fieldContext){var a=r.fieldContext.getInternalHooks,l=a(co),s=l.initEntityValue;s(Ve(o))}return o}return Jt(n,[{key:"componentDidMount",value:function(){var o=this.props,a=o.shouldUpdate,l=o.fieldContext;if(this.mounted=!0,l){var s=l.getInternalHooks,c=s(co),u=c.registerField;this.cancelRegisterFunc=u(this)}a===!0&&this.reRender()}},{key:"componentWillUnmount",value:function(){this.cancelRegister(),this.triggerMetaEvent(!0),this.mounted=!1}},{key:"reRender",value:function(){this.mounted&&this.forceUpdate()}},{key:"render",value:function(){var o=this.state.resetCount,a=this.props.children,l=this.getOnlyChild(a),s=l.child,c=l.isFunction,u;return c?u=s:i.isValidElement(s)?u=i.cloneElement(s,this.getControlled(s.props)):(Kt(!s,"`children` of Field is not validate ReactElement."),u=s),i.createElement(i.Fragment,{key:o},u)}}]),n}(i.Component);D(Kd,"contextType",ra);D(Kd,"defaultProps",{trigger:"onChange",valuePropName:"value"});function U0(e){var t,n=e.name,r=ft(e,fI),o=i.useContext(ra),a=i.useContext($l),l=n!==void 0?sn(n):void 0,s=(t=r.isListField)!==null&&t!==void 0?t:!!a,c="keep";return s||(c="_".concat((l||[]).join("_"))),i.createElement(Kd,ue({key:c,name:l,isListField:s},r,{fieldContext:o}))}function mI(e){var t=e.name,n=e.initialValue,r=e.children,o=e.rules,a=e.validateTrigger,l=e.isListField,s=i.useContext(ra),c=i.useContext($l),u=i.useRef({keys:[],id:0}),d=u.current,f=i.useMemo(function(){var h=sn(s.prefixName)||[];return[].concat(pe(h),pe(sn(t)))},[s.prefixName,t]),m=i.useMemo(function(){return k(k({},s),{},{prefixName:f})},[s,f]),v=i.useMemo(function(){return{getKey:function(p){var b=f.length,y=p[b];return[d.keys[y],p.slice(b+1)]}}},[f]);if(typeof r!="function")return Kt(!1,"Form.List only accepts function as children."),null;var g=function(p,b,y){var C=y.source;return C==="internal"?!1:p!==b};return i.createElement($l.Provider,{value:v},i.createElement(ra.Provider,{value:m},i.createElement(U0,{name:[],shouldUpdate:g,rules:o,validateTrigger:a,initialValue:n,isList:!0,isListField:l??!!c},function(h,p){var b=h.value,y=b===void 0?[]:b,C=h.onChange,$=s.getFieldValue,S=function(){var w=$(f||[]);return w||[]},x={add:function(w,I){var P=S();I>=0&&I<=P.length?(d.keys=[].concat(pe(d.keys.slice(0,I)),[d.id],pe(d.keys.slice(I))),C([].concat(pe(P.slice(0,I)),[w],pe(P.slice(I))))):(d.keys=[].concat(pe(d.keys),[d.id]),C([].concat(pe(P),[w]))),d.id+=1},remove:function(w){var I=S(),P=new Set(Array.isArray(w)?w:[w]);P.size<=0||(d.keys=d.keys.filter(function(M,R){return!P.has(R)}),C(I.filter(function(M,R){return!P.has(R)})))},move:function(w,I){if(w!==I){var P=S();w<0||w>=P.length||I<0||I>=P.length||(d.keys=dv(d.keys,w,I),C(dv(P,w,I)))}}},E=y||[];return Array.isArray(E)||(E=[]),r(E.map(function(O,w){var I=d.keys[w];return I===void 0&&(d.keys[w]=d.id,I=d.keys[w],d.id+=1),{name:w,key:I,isListField:!0}}),x,p)})))}function vI(e){var t=!1,n=e.length,r=[];return e.length?new Promise(function(o,a){e.forEach(function(l,s){l.catch(function(c){return t=!0,c}).then(function(c){n-=1,r[s]=c,!(n>0)&&(t&&a(r),o(r))})})}):Promise.resolve([])}var X0="__@field_split__";function vc(e){return e.map(function(t){return"".concat(Qe(t),":").concat(t)}).join(X0)}var Po=function(){function e(){Zt(this,e),D(this,"kvs",new Map)}return Jt(e,[{key:"set",value:function(n,r){this.kvs.set(vc(n),r)}},{key:"get",value:function(n){return this.kvs.get(vc(n))}},{key:"update",value:function(n,r){var o=this.get(n),a=r(o);a?this.set(n,a):this.delete(n)}},{key:"delete",value:function(n){this.kvs.delete(vc(n))}},{key:"map",value:function(n){return pe(this.kvs.entries()).map(function(r){var o=J(r,2),a=o[0],l=o[1],s=a.split(X0);return n({key:s.map(function(c){var u=c.match(/^([^:]*):(.*)$/),d=J(u,3),f=d[1],m=d[2];return f==="number"?Number(m):m}),value:l})})}},{key:"toJSON",value:function(){var n={};return this.map(function(r){var o=r.key,a=r.value;return n[o.join(".")]=a,null}),n}}]),e}(),gI=["name"],pI=Jt(function e(t){var n=this;Zt(this,e),D(this,"formHooked",!1),D(this,"forceRootUpdate",void 0),D(this,"subscribable",!0),D(this,"store",{}),D(this,"fieldEntities",[]),D(this,"initialValues",{}),D(this,"callbacks",{}),D(this,"validateMessages",null),D(this,"preserve",null),D(this,"lastValidatePromise",null),D(this,"getForm",function(){return{getFieldValue:n.getFieldValue,getFieldsValue:n.getFieldsValue,getFieldError:n.getFieldError,getFieldWarning:n.getFieldWarning,getFieldsError:n.getFieldsError,isFieldsTouched:n.isFieldsTouched,isFieldTouched:n.isFieldTouched,isFieldValidating:n.isFieldValidating,isFieldsValidating:n.isFieldsValidating,resetFields:n.resetFields,setFields:n.setFields,setFieldValue:n.setFieldValue,setFieldsValue:n.setFieldsValue,validateFields:n.validateFields,submit:n.submit,_init:!0,getInternalHooks:n.getInternalHooks}}),D(this,"getInternalHooks",function(r){return r===co?(n.formHooked=!0,{dispatch:n.dispatch,initEntityValue:n.initEntityValue,registerField:n.registerField,useSubscribe:n.useSubscribe,setInitialValues:n.setInitialValues,destroyForm:n.destroyForm,setCallbacks:n.setCallbacks,setValidateMessages:n.setValidateMessages,getFields:n.getFields,setPreserve:n.setPreserve,getInitialValue:n.getInitialValue,registerWatch:n.registerWatch}):(Kt(!1,"`getInternalHooks` is internal usage. Should not call directly."),null)}),D(this,"useSubscribe",function(r){n.subscribable=r}),D(this,"prevWithoutPreserves",null),D(this,"setInitialValues",function(r,o){if(n.initialValues=r||{},o){var a,l=Lo(r,n.store);(a=n.prevWithoutPreserves)===null||a===void 0||a.map(function(s){var c=s.key;l=fr(l,c,Qn(r,c))}),n.prevWithoutPreserves=null,n.updateStore(l)}}),D(this,"destroyForm",function(r){if(r)n.updateStore({});else{var o=new Po;n.getFieldEntities(!0).forEach(function(a){n.isMergedPreserve(a.isPreserve())||o.set(a.getNamePath(),!0)}),n.prevWithoutPreserves=o}}),D(this,"getInitialValue",function(r){var o=Qn(n.initialValues,r);return r.length?Lo(o):o}),D(this,"setCallbacks",function(r){n.callbacks=r}),D(this,"setValidateMessages",function(r){n.validateMessages=r}),D(this,"setPreserve",function(r){n.preserve=r}),D(this,"watchList",[]),D(this,"registerWatch",function(r){return n.watchList.push(r),function(){n.watchList=n.watchList.filter(function(o){return o!==r})}}),D(this,"notifyWatch",function(){var r=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[];if(n.watchList.length){var o=n.getFieldsValue(),a=n.getFieldsValue(!0);n.watchList.forEach(function(l){l(o,a,r)})}}),D(this,"timeoutId",null),D(this,"warningUnhooked",function(){}),D(this,"updateStore",function(r){n.store=r}),D(this,"getFieldEntities",function(){var r=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1;return r?n.fieldEntities.filter(function(o){return o.getNamePath().length}):n.fieldEntities}),D(this,"getFieldsMap",function(){var r=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1,o=new Po;return n.getFieldEntities(r).forEach(function(a){var l=a.getNamePath();o.set(l,a)}),o}),D(this,"getFieldEntitiesForNamePathList",function(r){if(!r)return n.getFieldEntities(!0);var o=n.getFieldsMap(!0);return r.map(function(a){var l=sn(a);return o.get(l)||{INVALIDATE_NAME_PATH:sn(a)}})}),D(this,"getFieldsValue",function(r,o){n.warningUnhooked();var a,l,s;if(r===!0||Array.isArray(r)?(a=r,l=o):r&&Qe(r)==="object"&&(s=r.strict,l=r.filter),a===!0&&!l)return n.store;var c=n.getFieldEntitiesForNamePathList(Array.isArray(a)?a:null),u=[];return c.forEach(function(d){var f,m,v="INVALIDATE_NAME_PATH"in d?d.INVALIDATE_NAME_PATH:d.getNamePath();if(s){var g,h;if((g=(h=d).isList)!==null&&g!==void 0&&g.call(h))return}else if(!a&&(f=(m=d).isListField)!==null&&f!==void 0&&f.call(m))return;if(!l)u.push(v);else{var p="getMeta"in d?d.getMeta():null;l(p)&&u.push(v)}}),uv(n.store,u.map(sn))}),D(this,"getFieldValue",function(r){n.warningUnhooked();var o=sn(r);return Qn(n.store,o)}),D(this,"getFieldsError",function(r){n.warningUnhooked();var o=n.getFieldEntitiesForNamePathList(r);return o.map(function(a,l){return a&&!("INVALIDATE_NAME_PATH"in a)?{name:a.getNamePath(),errors:a.getErrors(),warnings:a.getWarnings()}:{name:sn(r[l]),errors:[],warnings:[]}})}),D(this,"getFieldError",function(r){n.warningUnhooked();var o=sn(r),a=n.getFieldsError([o])[0];return a.errors}),D(this,"getFieldWarning",function(r){n.warningUnhooked();var o=sn(r),a=n.getFieldsError([o])[0];return a.warnings}),D(this,"isFieldsTouched",function(){n.warningUnhooked();for(var r=arguments.length,o=new Array(r),a=0;a<r;a++)o[a]=arguments[a];var l=o[0],s=o[1],c,u=!1;o.length===0?c=null:o.length===1?Array.isArray(l)?(c=l.map(sn),u=!1):(c=null,u=l):(c=l.map(sn),u=s);var d=n.getFieldEntities(!0),f=function(p){return p.isFieldTouched()};if(!c)return u?d.every(function(h){return f(h)||h.isList()}):d.some(f);var m=new Po;c.forEach(function(h){m.set(h,[])}),d.forEach(function(h){var p=h.getNamePath();c.forEach(function(b){b.every(function(y,C){return p[C]===y})&&m.update(b,function(y){return[].concat(pe(y),[h])})})});var v=function(p){return p.some(f)},g=m.map(function(h){var p=h.value;return p});return u?g.every(v):g.some(v)}),D(this,"isFieldTouched",function(r){return n.warningUnhooked(),n.isFieldsTouched([r])}),D(this,"isFieldsValidating",function(r){n.warningUnhooked();var o=n.getFieldEntities();if(!r)return o.some(function(l){return l.isFieldValidating()});var a=r.map(sn);return o.some(function(l){var s=l.getNamePath();return Ko(a,s)&&l.isFieldValidating()})}),D(this,"isFieldValidating",function(r){return n.warningUnhooked(),n.isFieldsValidating([r])}),D(this,"resetWithFieldInitialValue",function(){var r=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},o=new Po,a=n.getFieldEntities(!0);a.forEach(function(c){var u=c.props.initialValue,d=c.getNamePath();if(u!==void 0){var f=o.get(d)||new Set;f.add({entity:c,value:u}),o.set(d,f)}});var l=function(u){u.forEach(function(d){var f=d.props.initialValue;if(f!==void 0){var m=d.getNamePath(),v=n.getInitialValue(m);if(v!==void 0)Kt(!1,"Form already set 'initialValues' with path '".concat(m.join("."),"'. Field can not overwrite it."));else{var g=o.get(m);if(g&&g.size>1)Kt(!1,"Multiple Field with path '".concat(m.join("."),"' set 'initialValue'. Can not decide which one to pick."));else if(g){var h=n.getFieldValue(m),p=d.isListField();!p&&(!r.skipExist||h===void 0)&&n.updateStore(fr(n.store,m,pe(g)[0].value))}}}})},s;r.entities?s=r.entities:r.namePathList?(s=[],r.namePathList.forEach(function(c){var u=o.get(c);if(u){var d;(d=s).push.apply(d,pe(pe(u).map(function(f){return f.entity})))}})):s=a,l(s)}),D(this,"resetFields",function(r){n.warningUnhooked();var o=n.store;if(!r){n.updateStore(Lo(n.initialValues)),n.resetWithFieldInitialValue(),n.notifyObservers(o,null,{type:"reset"}),n.notifyWatch();return}var a=r.map(sn);a.forEach(function(l){var s=n.getInitialValue(l);n.updateStore(fr(n.store,l,s))}),n.resetWithFieldInitialValue({namePathList:a}),n.notifyObservers(o,a,{type:"reset"}),n.notifyWatch(a)}),D(this,"setFields",function(r){n.warningUnhooked();var o=n.store,a=[];r.forEach(function(l){var s=l.name,c=ft(l,gI),u=sn(s);a.push(u),"value"in c&&n.updateStore(fr(n.store,u,c.value)),n.notifyObservers(o,[u],{type:"setField",data:l})}),n.notifyWatch(a)}),D(this,"getFields",function(){var r=n.getFieldEntities(!0),o=r.map(function(a){var l=a.getNamePath(),s=a.getMeta(),c=k(k({},s),{},{name:l,value:n.getFieldValue(l)});return Object.defineProperty(c,"originRCField",{value:!0}),c});return o}),D(this,"initEntityValue",function(r){var o=r.props.initialValue;if(o!==void 0){var a=r.getNamePath(),l=Qn(n.store,a);l===void 0&&n.updateStore(fr(n.store,a,o))}}),D(this,"isMergedPreserve",function(r){var o=r!==void 0?r:n.preserve;return o??!0}),D(this,"registerField",function(r){n.fieldEntities.push(r);var o=r.getNamePath();if(n.notifyWatch([o]),r.props.initialValue!==void 0){var a=n.store;n.resetWithFieldInitialValue({entities:[r],skipExist:!0}),n.notifyObservers(a,[r.getNamePath()],{type:"valueUpdate",source:"internal"})}return function(l,s){var c=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];if(n.fieldEntities=n.fieldEntities.filter(function(f){return f!==r}),!n.isMergedPreserve(s)&&(!l||c.length>1)){var u=l?void 0:n.getInitialValue(o);if(o.length&&n.getFieldValue(o)!==u&&n.fieldEntities.every(function(f){return!q0(f.getNamePath(),o)})){var d=n.store;n.updateStore(fr(d,o,u,!0)),n.notifyObservers(d,[o],{type:"remove"}),n.triggerDependenciesUpdate(d,o)}}n.notifyWatch([o])}}),D(this,"dispatch",function(r){switch(r.type){case"updateValue":{var o=r.namePath,a=r.value;n.updateValue(o,a);break}case"validateField":{var l=r.namePath,s=r.triggerName;n.validateFields([l],{triggerName:s});break}}}),D(this,"notifyObservers",function(r,o,a){if(n.subscribable){var l=k(k({},a),{},{store:n.getFieldsValue(!0)});n.getFieldEntities().forEach(function(s){var c=s.onStoreChange;c(r,o,l)})}else n.forceRootUpdate()}),D(this,"triggerDependenciesUpdate",function(r,o){var a=n.getDependencyChildrenFields(o);return a.length&&n.validateFields(a),n.notifyObservers(r,a,{type:"dependenciesUpdate",relatedFields:[o].concat(pe(a))}),a}),D(this,"updateValue",function(r,o){var a=sn(r),l=n.store;n.updateStore(fr(n.store,a,o)),n.notifyObservers(l,[a],{type:"valueUpdate",source:"internal"}),n.notifyWatch([a]);var s=n.triggerDependenciesUpdate(l,a),c=n.callbacks.onValuesChange;if(c){var u=uv(n.store,[a]);c(u,n.getFieldsValue())}n.triggerOnFieldsChange([a].concat(pe(s)))}),D(this,"setFieldsValue",function(r){n.warningUnhooked();var o=n.store;if(r){var a=Lo(n.store,r);n.updateStore(a)}n.notifyObservers(o,null,{type:"valueUpdate",source:"external"}),n.notifyWatch()}),D(this,"setFieldValue",function(r,o){n.setFields([{name:r,value:o,errors:[],warnings:[]}])}),D(this,"getDependencyChildrenFields",function(r){var o=new Set,a=[],l=new Po;n.getFieldEntities().forEach(function(c){var u=c.props.dependencies;(u||[]).forEach(function(d){var f=sn(d);l.update(f,function(){var m=arguments.length>0&&arguments[0]!==void 0?arguments[0]:new Set;return m.add(c),m})})});var s=function c(u){var d=l.get(u)||new Set;d.forEach(function(f){if(!o.has(f)){o.add(f);var m=f.getNamePath();f.isFieldDirty()&&m.length&&(a.push(m),c(m))}})};return s(r),a}),D(this,"triggerOnFieldsChange",function(r,o){var a=n.callbacks.onFieldsChange;if(a){var l=n.getFields();if(o){var s=new Po;o.forEach(function(u){var d=u.name,f=u.errors;s.set(d,f)}),l.forEach(function(u){u.errors=s.get(u.name)||u.errors})}var c=l.filter(function(u){var d=u.name;return Ko(r,d)});c.length&&a(c,l)}}),D(this,"validateFields",function(r,o){n.warningUnhooked();var a,l;Array.isArray(r)||typeof r=="string"||typeof o=="string"?(a=r,l=o):l=r;var s=!!a,c=s?a.map(sn):[],u=[],d=String(Date.now()),f=new Set,m=l||{},v=m.recursive,g=m.dirty;n.getFieldEntities(!0).forEach(function(y){if(s||c.push(y.getNamePath()),!(!y.props.rules||!y.props.rules.length)&&!(g&&!y.isFieldDirty())){var C=y.getNamePath();if(f.add(C.join(d)),!s||Ko(c,C,v)){var $=y.validateRules(k({validateMessages:k(k({},G0),n.validateMessages)},l));u.push($.then(function(){return{name:C,errors:[],warnings:[]}}).catch(function(S){var x,E=[],O=[];return(x=S.forEach)===null||x===void 0||x.call(S,function(w){var I=w.rule.warningOnly,P=w.errors;I?O.push.apply(O,pe(P)):E.push.apply(E,pe(P))}),E.length?Promise.reject({name:C,errors:E,warnings:O}):{name:C,errors:E,warnings:O}}))}}});var h=vI(u);n.lastValidatePromise=h,h.catch(function(y){return y}).then(function(y){var C=y.map(function($){var S=$.name;return S});n.notifyObservers(n.store,C,{type:"validateFinish"}),n.triggerOnFieldsChange(C,y)});var p=h.then(function(){return n.lastValidatePromise===h?Promise.resolve(n.getFieldsValue(c)):Promise.reject([])}).catch(function(y){var C=y.filter(function($){return $&&$.errors.length});return Promise.reject({values:n.getFieldsValue(c),errorFields:C,outOfDate:n.lastValidatePromise!==h})});p.catch(function(y){return y});var b=c.filter(function(y){return f.has(y.join(d))});return n.triggerOnFieldsChange(b),p}),D(this,"submit",function(){n.warningUnhooked(),n.validateFields().then(function(r){var o=n.callbacks.onFinish;if(o)try{o(r)}catch(a){console.error(a)}}).catch(function(r){var o=n.callbacks.onFinishFailed;o&&o(r)})}),this.forceRootUpdate=t});function Y0(e){var t=i.useRef(),n=i.useState({}),r=J(n,2),o=r[1];if(!t.current)if(e)t.current=e;else{var a=function(){o({})},l=new pI(a);t.current=l.getForm()}return[t.current]}var Lu=i.createContext({triggerFormChange:function(){},triggerFormFinish:function(){},registerForm:function(){},unregisterForm:function(){}}),hI=function(t){var n=t.validateMessages,r=t.onFormChange,o=t.onFormFinish,a=t.children,l=i.useContext(Lu),s=i.useRef({});return i.createElement(Lu.Provider,{value:k(k({},l),{},{validateMessages:k(k({},l.validateMessages),n),triggerFormChange:function(u,d){r&&r(u,{changedFields:d,forms:s.current}),l.triggerFormChange(u,d)},triggerFormFinish:function(u,d){o&&o(u,{values:d,forms:s.current}),l.triggerFormFinish(u,d)},registerForm:function(u,d){u&&(s.current=k(k({},s.current),{},D({},u,d))),l.registerForm(u,d)},unregisterForm:function(u){var d=k({},s.current);delete d[u],s.current=d,l.unregisterForm(u)}})},a)},bI=["name","initialValues","fields","form","preserve","children","component","validateMessages","validateTrigger","onValuesChange","onFieldsChange","onFinish","onFinishFailed","clearOnDestroy"],yI=function(t,n){var r=t.name,o=t.initialValues,a=t.fields,l=t.form,s=t.preserve,c=t.children,u=t.component,d=u===void 0?"form":u,f=t.validateMessages,m=t.validateTrigger,v=m===void 0?"onChange":m,g=t.onValuesChange,h=t.onFieldsChange,p=t.onFinish,b=t.onFinishFailed,y=t.clearOnDestroy,C=ft(t,bI),$=i.useRef(null),S=i.useContext(Lu),x=Y0(l),E=J(x,1),O=E[0],w=O.getInternalHooks(co),I=w.useSubscribe,P=w.setInitialValues,M=w.setCallbacks,R=w.setValidateMessages,N=w.setPreserve,T=w.destroyForm;i.useImperativeHandle(n,function(){return k(k({},O),{},{nativeElement:$.current})}),i.useEffect(function(){return S.registerForm(r,O),function(){S.unregisterForm(r)}},[S,O,r]),R(k(k({},S.validateMessages),f)),M({onValuesChange:g,onFieldsChange:function(W){if(S.triggerFormChange(r,W),h){for(var K=arguments.length,U=new Array(K>1?K-1:0),te=1;te<K;te++)U[te-1]=arguments[te];h.apply(void 0,[W].concat(U))}},onFinish:function(W){S.triggerFormFinish(r,W),p&&p(W)},onFinishFailed:b}),N(s);var j=i.useRef(null);P(o,!j.current),j.current||(j.current=!0),i.useEffect(function(){return function(){return T(y)}},[]);var z,_=typeof c=="function";if(_){var B=O.getFieldsValue(!0);z=c(B,O)}else z=c;I(!_);var V=i.useRef();i.useEffect(function(){uI(V.current||[],a||[])||O.setFields(a||[]),V.current=a},[a,O]);var G=i.useMemo(function(){return k(k({},O),{},{validateTrigger:v})},[O,v]),q=i.createElement($l.Provider,{value:null},i.createElement(ra.Provider,{value:G},z));return d===!1?q:i.createElement(d,ue({},C,{ref:$,onSubmit:function(W){W.preventDefault(),W.stopPropagation(),O.submit()},onReset:function(W){var K;W.preventDefault(),O.resetFields(),(K=C.onReset)===null||K===void 0||K.call(C,W)}}),q)};function fv(e){try{return JSON.stringify(e)}catch{return Math.random()}}function CI(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];var r=t[0],o=t[1],a=o===void 0?{}:o,l=RO(a)?{form:a}:a,s=l.form,c=i.useState(),u=J(c,2),d=u[0],f=u[1],m=i.useMemo(function(){return fv(d)},[d]),v=i.useRef(m);v.current=m;var g=i.useContext(ra),h=s||g,p=h&&h._init,b=sn(r),y=i.useRef(b);return y.current=b,i.useEffect(function(){if(p){var C=h.getFieldsValue,$=h.getInternalHooks,S=$(co),x=S.registerWatch,E=function(P,M){var R=l.preserve?M:P;return typeof r=="function"?r(R):Qn(R,y.current)},O=x(function(I,P){var M=E(I,P),R=fv(M);v.current!==R&&(v.current=R,f(M))}),w=E(C(),C(!0));return d!==w&&f(w),O}},[p]),d}var SI=i.forwardRef(yI),gi=SI;gi.FormProvider=hI;gi.Field=U0;gi.List=mI;gi.useForm=Y0;gi.useWatch=CI;const Wn=i.createContext({}),$I=({children:e,status:t,override:n})=>{const r=i.useContext(Wn),o=i.useMemo(()=>{const a=Object.assign({},r);return n&&delete a.isFormItemInput,t&&(delete a.status,delete a.hasFeedback,delete a.feedbackIcon),a},[t,n,r]);return i.createElement(Wn.Provider,{value:o},e)},xI=i.createContext(void 0),jr=e=>{const{space:t,form:n,children:r}=e;if(r==null)return null;let o=r;return n&&(o=F.createElement($I,{override:!0,status:!0},o)),t&&(o=F.createElement(xE,null,o)),o};function xl(...e){const t={};return e.forEach(n=>{n&&Object.keys(n).forEach(r=>{n[r]!==void 0&&(t[r]=n[r])})}),t}function oa(e){if(!e)return;const{closable:t,closeIcon:n}=e;return{closable:t,closeIcon:n}}function mv(e){const{closable:t,closeIcon:n}=e||{};return F.useMemo(()=>{if(!t&&(t===!1||n===!1||n===null))return!1;if(t===void 0&&n===void 0)return null;let r={closeIcon:typeof n!="boolean"&&n!==null?n:void 0};return t&&typeof t=="object"&&(r=Object.assign(Object.assign({},r),t)),r},[t,n])}const wI={};function Gd(e,t,n=wI){const r=mv(e),o=mv(t),[a]=Kn("global",br.global),l=typeof r!="boolean"?!!(r!=null&&r.disabled):!1,s=F.useMemo(()=>Object.assign({closeIcon:F.createElement(Fr,null)},n),[n]),c=F.useMemo(()=>r===!1?!1:r?xl(s,o,r):o===!1?!1:o?xl(s,o):s.closable?s:!1,[r,o,s]);return F.useMemo(()=>{var u,d;if(c===!1)return[!1,null,l,{}];const{closeIconRender:f}=s,{closeIcon:m}=c;let v=m;const g=rn(c,!0);return v!=null&&(f&&(v=f(m)),v=F.isValidElement(v)?F.cloneElement(v,Object.assign(Object.assign(Object.assign({},v.props),{"aria-label":(d=(u=v.props)===null||u===void 0?void 0:u["aria-label"])!==null&&d!==void 0?d:a.close}),g)):F.createElement("span",Object.assign({"aria-label":a.close},g),v)),[!0,v,l,g]},[c,s])}var Q0=function(t){if(wn()&&window.document.documentElement){var n=Array.isArray(t)?t:[t],r=window.document.documentElement;return n.some(function(o){return o in r.style})}return!1},EI=function(t,n){if(!Q0(t))return!1;var r=document.createElement("div"),o=r.style[t];return r.style[t]=n,r.style[t]!==o};function Hu(e,t){return!Array.isArray(e)&&t!==void 0?EI(e,t):Q0(e)}const OI=()=>wn()&&window.document.documentElement,hs=e=>{const{prefixCls:t,className:n,style:r,size:o,shape:a}=e,l=A({[`${t}-lg`]:o==="large",[`${t}-sm`]:o==="small"}),s=A({[`${t}-circle`]:a==="circle",[`${t}-square`]:a==="square",[`${t}-round`]:a==="round"}),c=i.useMemo(()=>typeof o=="number"?{width:o,height:o,lineHeight:`${o}px`}:{},[o]);return i.createElement("span",{className:A(t,l,s,n),style:Object.assign(Object.assign({},c),r)})},II=new $t("ant-skeleton-loading",{"0%":{backgroundPosition:"100% 50%"},"100%":{backgroundPosition:"0 50%"}}),bs=e=>({height:e,lineHeight:L(e)}),Go=e=>Object.assign({width:e},bs(e)),RI=e=>({background:e.skeletonLoadingBackground,backgroundSize:"400% 100%",animationName:II,animationDuration:e.skeletonLoadingMotionDuration,animationTimingFunction:"ease",animationIterationCount:"infinite"}),gc=(e,t)=>Object.assign({width:t(e).mul(5).equal(),minWidth:t(e).mul(5).equal()},bs(e)),PI=e=>{const{skeletonAvatarCls:t,gradientFromColor:n,controlHeight:r,controlHeightLG:o,controlHeightSM:a}=e;return{[t]:Object.assign({display:"inline-block",verticalAlign:"top",background:n},Go(r)),[`${t}${t}-circle`]:{borderRadius:"50%"},[`${t}${t}-lg`]:Object.assign({},Go(o)),[`${t}${t}-sm`]:Object.assign({},Go(a))}},NI=e=>{const{controlHeight:t,borderRadiusSM:n,skeletonInputCls:r,controlHeightLG:o,controlHeightSM:a,gradientFromColor:l,calc:s}=e;return{[r]:Object.assign({display:"inline-block",verticalAlign:"top",background:l,borderRadius:n},gc(t,s)),[`${r}-lg`]:Object.assign({},gc(o,s)),[`${r}-sm`]:Object.assign({},gc(a,s))}},vv=e=>Object.assign({width:e},bs(e)),MI=e=>{const{skeletonImageCls:t,imageSizeBase:n,gradientFromColor:r,borderRadiusSM:o,calc:a}=e;return{[t]:Object.assign(Object.assign({display:"inline-flex",alignItems:"center",justifyContent:"center",verticalAlign:"middle",background:r,borderRadius:o},vv(a(n).mul(2).equal())),{[`${t}-path`]:{fill:"#bfbfbf"},[`${t}-svg`]:Object.assign(Object.assign({},vv(n)),{maxWidth:a(n).mul(4).equal(),maxHeight:a(n).mul(4).equal()}),[`${t}-svg${t}-svg-circle`]:{borderRadius:"50%"}}),[`${t}${t}-circle`]:{borderRadius:"50%"}}},pc=(e,t,n)=>{const{skeletonButtonCls:r}=e;return{[`${n}${r}-circle`]:{width:t,minWidth:t,borderRadius:"50%"},[`${n}${r}-round`]:{borderRadius:t}}},hc=(e,t)=>Object.assign({width:t(e).mul(2).equal(),minWidth:t(e).mul(2).equal()},bs(e)),TI=e=>{const{borderRadiusSM:t,skeletonButtonCls:n,controlHeight:r,controlHeightLG:o,controlHeightSM:a,gradientFromColor:l,calc:s}=e;return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({[n]:Object.assign({display:"inline-block",verticalAlign:"top",background:l,borderRadius:t,width:s(r).mul(2).equal(),minWidth:s(r).mul(2).equal()},hc(r,s))},pc(e,r,n)),{[`${n}-lg`]:Object.assign({},hc(o,s))}),pc(e,o,`${n}-lg`)),{[`${n}-sm`]:Object.assign({},hc(a,s))}),pc(e,a,`${n}-sm`))},jI=e=>{const{componentCls:t,skeletonAvatarCls:n,skeletonTitleCls:r,skeletonParagraphCls:o,skeletonButtonCls:a,skeletonInputCls:l,skeletonImageCls:s,controlHeight:c,controlHeightLG:u,controlHeightSM:d,gradientFromColor:f,padding:m,marginSM:v,borderRadius:g,titleHeight:h,blockRadius:p,paragraphLiHeight:b,controlHeightXS:y,paragraphMarginTop:C}=e;return{[t]:{display:"table",width:"100%",[`${t}-header`]:{display:"table-cell",paddingInlineEnd:m,verticalAlign:"top",[n]:Object.assign({display:"inline-block",verticalAlign:"top",background:f},Go(c)),[`${n}-circle`]:{borderRadius:"50%"},[`${n}-lg`]:Object.assign({},Go(u)),[`${n}-sm`]:Object.assign({},Go(d))},[`${t}-content`]:{display:"table-cell",width:"100%",verticalAlign:"top",[r]:{width:"100%",height:h,background:f,borderRadius:p,[`+ ${o}`]:{marginBlockStart:d}},[o]:{padding:0,"> li":{width:"100%",height:b,listStyle:"none",background:f,borderRadius:p,"+ li":{marginBlockStart:y}}},[`${o}> li:last-child:not(:first-child):not(:nth-child(2))`]:{width:"61%"}},[`&-round ${t}-content`]:{[`${r}, ${o} > li`]:{borderRadius:g}}},[`${t}-with-avatar ${t}-content`]:{[r]:{marginBlockStart:v,[`+ ${o}`]:{marginBlockStart:C}}},[`${t}${t}-element`]:Object.assign(Object.assign(Object.assign(Object.assign({display:"inline-block",width:"auto"},TI(e)),PI(e)),NI(e)),MI(e)),[`${t}${t}-block`]:{width:"100%",[a]:{width:"100%"},[l]:{width:"100%"}},[`${t}${t}-active`]:{[`
        ${r},
        ${o} > li,
        ${n},
        ${a},
        ${l},
        ${s}
      `]:Object.assign({},RI(e))}}},zI=e=>{const{colorFillContent:t,colorFill:n}=e,r=t,o=n;return{color:r,colorGradientEnd:o,gradientFromColor:r,gradientToColor:o,titleHeight:e.controlHeight/2,blockRadius:e.borderRadiusSM,paragraphMarginTop:e.marginLG+e.marginXXS,paragraphLiHeight:e.controlHeight/2}},va=It("Skeleton",e=>{const{componentCls:t,calc:n}=e,r=yt(e,{skeletonAvatarCls:`${t}-avatar`,skeletonTitleCls:`${t}-title`,skeletonParagraphCls:`${t}-paragraph`,skeletonButtonCls:`${t}-button`,skeletonInputCls:`${t}-input`,skeletonImageCls:`${t}-image`,imageSizeBase:n(e.controlHeight).mul(1.5).equal(),borderRadius:100,skeletonLoadingBackground:`linear-gradient(90deg, ${e.gradientFromColor} 25%, ${e.gradientToColor} 37%, ${e.gradientFromColor} 63%)`,skeletonLoadingMotionDuration:"1.4s"});return jI(r)},zI,{deprecatedTokens:[["color","gradientFromColor"],["colorGradientEnd","gradientToColor"]]}),DI=e=>{const{prefixCls:t,className:n,rootClassName:r,active:o,shape:a="circle",size:l="default"}=e,{getPrefixCls:s}=i.useContext(ot),c=s("skeleton",t),[u,d,f]=va(c),m=Gt(e,["prefixCls","className"]),v=A(c,`${c}-element`,{[`${c}-active`]:o},n,r,d,f);return u(i.createElement("div",{className:v},i.createElement(hs,Object.assign({prefixCls:`${c}-avatar`,shape:a,size:l},m))))},_I=e=>{const{prefixCls:t,className:n,rootClassName:r,active:o,block:a=!1,size:l="default"}=e,{getPrefixCls:s}=i.useContext(ot),c=s("skeleton",t),[u,d,f]=va(c),m=Gt(e,["prefixCls"]),v=A(c,`${c}-element`,{[`${c}-active`]:o,[`${c}-block`]:a},n,r,d,f);return u(i.createElement("div",{className:v},i.createElement(hs,Object.assign({prefixCls:`${c}-button`,size:l},m))))},BI="M365.714286 329.142857q0 45.714286-32.036571 77.677714t-77.677714 32.036571-77.677714-32.036571-32.036571-77.677714 32.036571-77.677714 77.677714-32.036571 77.677714 32.036571 32.036571 77.677714zM950.857143 548.571429l0 256-804.571429 0 0-109.714286 182.857143-182.857143 91.428571 91.428571 292.571429-292.571429zM1005.714286 146.285714l-914.285714 0q-7.460571 0-12.873143 5.412571t-5.412571 12.873143l0 694.857143q0 7.460571 5.412571 12.873143t12.873143 5.412571l914.285714 0q7.460571 0 12.873143-5.412571t5.412571-12.873143l0-694.857143q0-7.460571-5.412571-12.873143t-12.873143-5.412571zM1097.142857 164.571429l0 694.857143q0 37.741714-26.843429 64.585143t-64.585143 26.843429l-914.285714 0q-37.741714 0-64.585143-26.843429t-26.843429-64.585143l0-694.857143q0-37.741714 26.843429-64.585143t64.585143-26.843429l914.285714 0q37.741714 0 64.585143 26.843429t26.843429 64.585143z",LI=e=>{const{prefixCls:t,className:n,rootClassName:r,style:o,active:a}=e,{getPrefixCls:l}=i.useContext(ot),s=l("skeleton",t),[c,u,d]=va(s),f=A(s,`${s}-element`,{[`${s}-active`]:a},n,r,u,d);return c(i.createElement("div",{className:f},i.createElement("div",{className:A(`${s}-image`,n),style:o},i.createElement("svg",{viewBox:"0 0 1098 1024",xmlns:"http://www.w3.org/2000/svg",className:`${s}-image-svg`},i.createElement("title",null,"Image placeholder"),i.createElement("path",{d:BI,className:`${s}-image-path`})))))},HI=e=>{const{prefixCls:t,className:n,rootClassName:r,active:o,block:a,size:l="default"}=e,{getPrefixCls:s}=i.useContext(ot),c=s("skeleton",t),[u,d,f]=va(c),m=Gt(e,["prefixCls"]),v=A(c,`${c}-element`,{[`${c}-active`]:o,[`${c}-block`]:a},n,r,d,f);return u(i.createElement("div",{className:v},i.createElement(hs,Object.assign({prefixCls:`${c}-input`,size:l},m))))},AI=e=>{const{prefixCls:t,className:n,rootClassName:r,style:o,active:a,children:l}=e,{getPrefixCls:s}=i.useContext(ot),c=s("skeleton",t),[u,d,f]=va(c),m=A(c,`${c}-element`,{[`${c}-active`]:a},d,n,r,f);return u(i.createElement("div",{className:m},i.createElement("div",{className:A(`${c}-image`,n),style:o},l)))},FI=(e,t)=>{const{width:n,rows:r=2}=t;if(Array.isArray(n))return n[e];if(r-1===e)return n},kI=e=>{const{prefixCls:t,className:n,style:r,rows:o=0}=e,a=Array.from({length:o}).map((l,s)=>i.createElement("li",{key:s,style:{width:FI(s,e)}}));return i.createElement("ul",{className:A(t,n),style:r},a)},VI=({prefixCls:e,className:t,width:n,style:r})=>i.createElement("h3",{className:A(e,t),style:Object.assign({width:n},r)});function bc(e){return e&&typeof e=="object"?e:{}}function WI(e,t){return e&&!t?{size:"large",shape:"square"}:{size:"large",shape:"circle"}}function KI(e,t){return!e&&t?{width:"38%"}:e&&t?{width:"50%"}:{}}function GI(e,t){const n={};return(!e||!t)&&(n.width="61%"),!e&&t?n.rows=3:n.rows=2,n}const kr=e=>{const{prefixCls:t,loading:n,className:r,rootClassName:o,style:a,children:l,avatar:s=!1,title:c=!0,paragraph:u=!0,active:d,round:f}=e,{getPrefixCls:m,direction:v,className:g,style:h}=tn("skeleton"),p=m("skeleton",t),[b,y,C]=va(p);if(n||!("loading"in e)){const $=!!s,S=!!c,x=!!u;let E;if($){const I=Object.assign(Object.assign({prefixCls:`${p}-avatar`},WI(S,x)),bc(s));E=i.createElement("div",{className:`${p}-header`},i.createElement(hs,Object.assign({},I)))}let O;if(S||x){let I;if(S){const M=Object.assign(Object.assign({prefixCls:`${p}-title`},KI($,x)),bc(c));I=i.createElement(VI,Object.assign({},M))}let P;if(x){const M=Object.assign(Object.assign({prefixCls:`${p}-paragraph`},GI($,S)),bc(u));P=i.createElement(kI,Object.assign({},M))}O=i.createElement("div",{className:`${p}-content`},I,P)}const w=A(p,{[`${p}-with-avatar`]:$,[`${p}-active`]:d,[`${p}-rtl`]:v==="rtl",[`${p}-round`]:f},g,r,o,y,C);return b(i.createElement("div",{className:w,style:Object.assign(Object.assign({},h),a)},E,O))}return l??null};kr.Button=_I;kr.Avatar=DI;kr.Input=HI;kr.Image=LI;kr.Node=AI;function gv(){}const qI=i.createContext({add:gv,remove:gv});function Z0(e){const t=i.useContext(qI),n=i.useRef(null);return Nt(o=>{if(o){const a=e?o.querySelector(e):o;t.add(a),n.current=a}else t.remove(n.current)})}const pv=()=>{const{cancelButtonProps:e,cancelTextLocale:t,onCancel:n}=i.useContext(fi);return F.createElement(er,Object.assign({onClick:n},e),t)},hv=()=>{const{confirmLoading:e,okButtonProps:t,okType:n,okTextLocale:r,onOk:o}=i.useContext(fi);return F.createElement(er,Object.assign({},Dd(n),{loading:e,onClick:o},t),r)};function J0(e,t){return F.createElement("span",{className:`${e}-close-x`},t||F.createElement(Fr,{className:`${e}-close-icon`}))}const eb=e=>{const{okText:t,okType:n="primary",cancelText:r,confirmLoading:o,onOk:a,onCancel:l,okButtonProps:s,cancelButtonProps:c,footer:u}=e,[d]=Kn("Modal",Nh()),f=t||(d==null?void 0:d.okText),m=r||(d==null?void 0:d.cancelText),v={confirmLoading:o,okButtonProps:s,cancelButtonProps:c,okTextLocale:f,cancelTextLocale:m,okType:n,onOk:a,onCancel:l},g=F.useMemo(()=>v,pe(Object.values(v)));let h;return typeof u=="function"||typeof u>"u"?(h=F.createElement(F.Fragment,null,F.createElement(pv,null),F.createElement(hv,null)),typeof u=="function"&&(h=u(h,{OkBtn:hv,CancelBtn:pv})),h=F.createElement(L0,{value:g},h)):h=u,F.createElement(Lh,{disabled:!1},h)},UI=e=>{const{componentCls:t}=e;return{[t]:{display:"flex",flexFlow:"row wrap",minWidth:0,"&::before, &::after":{display:"flex"},"&-no-wrap":{flexWrap:"nowrap"},"&-start":{justifyContent:"flex-start"},"&-center":{justifyContent:"center"},"&-end":{justifyContent:"flex-end"},"&-space-between":{justifyContent:"space-between"},"&-space-around":{justifyContent:"space-around"},"&-space-evenly":{justifyContent:"space-evenly"},"&-top":{alignItems:"flex-start"},"&-middle":{alignItems:"center"},"&-bottom":{alignItems:"flex-end"}}}},XI=e=>{const{componentCls:t}=e;return{[t]:{position:"relative",maxWidth:"100%",minHeight:1}}},YI=(e,t)=>{const{prefixCls:n,componentCls:r,gridColumns:o}=e,a={};for(let l=o;l>=0;l--)l===0?(a[`${r}${t}-${l}`]={display:"none"},a[`${r}-push-${l}`]={insetInlineStart:"auto"},a[`${r}-pull-${l}`]={insetInlineEnd:"auto"},a[`${r}${t}-push-${l}`]={insetInlineStart:"auto"},a[`${r}${t}-pull-${l}`]={insetInlineEnd:"auto"},a[`${r}${t}-offset-${l}`]={marginInlineStart:0},a[`${r}${t}-order-${l}`]={order:0}):(a[`${r}${t}-${l}`]=[{"--ant-display":"block",display:"block"},{display:"var(--ant-display)",flex:`0 0 ${l/o*100}%`,maxWidth:`${l/o*100}%`}],a[`${r}${t}-push-${l}`]={insetInlineStart:`${l/o*100}%`},a[`${r}${t}-pull-${l}`]={insetInlineEnd:`${l/o*100}%`},a[`${r}${t}-offset-${l}`]={marginInlineStart:`${l/o*100}%`},a[`${r}${t}-order-${l}`]={order:l});return a[`${r}${t}-flex`]={flex:`var(--${n}${t}-flex)`},a},Au=(e,t)=>YI(e,t),QI=(e,t,n)=>({[`@media (min-width: ${L(t)})`]:Object.assign({},Au(e,n))}),ZI=()=>({}),JI=()=>({}),eR=It("Grid",UI,ZI),tb=e=>({xs:e.screenXSMin,sm:e.screenSMMin,md:e.screenMDMin,lg:e.screenLGMin,xl:e.screenXLMin,xxl:e.screenXXLMin}),tR=It("Grid",e=>{const t=yt(e,{gridColumns:24}),n=tb(t);return delete n.xs,[XI(t),Au(t,""),Au(t,"-xs"),Object.keys(n).map(r=>QI(t,n[r],`-${r}`)).reduce((r,o)=>Object.assign(Object.assign({},r),o),{})]},JI);function bv(e){return{position:e,inset:0}}const nR=e=>{const{componentCls:t,antCls:n}=e;return[{[`${t}-root`]:{[`${t}${n}-zoom-enter, ${t}${n}-zoom-appear`]:{transform:"none",opacity:0,animationDuration:e.motionDurationSlow,userSelect:"none"},[`${t}${n}-zoom-leave ${t}-content`]:{pointerEvents:"none"},[`${t}-mask`]:Object.assign(Object.assign({},bv("fixed")),{zIndex:e.zIndexPopupBase,height:"100%",backgroundColor:e.colorBgMask,pointerEvents:"none",[`${t}-hidden`]:{display:"none"}}),[`${t}-wrap`]:Object.assign(Object.assign({},bv("fixed")),{zIndex:e.zIndexPopupBase,overflow:"auto",outline:0,WebkitOverflowScrolling:"touch"})}},{[`${t}-root`]:T0(e)}]},rR=e=>{const{componentCls:t}=e;return[{[`${t}-root`]:{[`${t}-wrap-rtl`]:{direction:"rtl"},[`${t}-centered`]:{textAlign:"center","&::before":{display:"inline-block",width:0,height:"100%",verticalAlign:"middle",content:'""'},[t]:{top:0,display:"inline-block",paddingBottom:0,textAlign:"start",verticalAlign:"middle"}},[`@media (max-width: ${e.screenSMMax}px)`]:{[t]:{maxWidth:"calc(100vw - 16px)",margin:`${L(e.marginXS)} auto`},[`${t}-centered`]:{[t]:{flex:1}}}}},{[t]:Object.assign(Object.assign({},Tt(e)),{pointerEvents:"none",position:"relative",top:100,width:"auto",maxWidth:`calc(100vw - ${L(e.calc(e.margin).mul(2).equal())})`,margin:"0 auto",paddingBottom:e.paddingLG,[`${t}-title`]:{margin:0,color:e.titleColor,fontWeight:e.fontWeightStrong,fontSize:e.titleFontSize,lineHeight:e.titleLineHeight,wordWrap:"break-word"},[`${t}-content`]:{position:"relative",backgroundColor:e.contentBg,backgroundClip:"padding-box",border:0,borderRadius:e.borderRadiusLG,boxShadow:e.boxShadow,pointerEvents:"auto",padding:e.contentPadding},[`${t}-close`]:Object.assign({position:"absolute",top:e.calc(e.modalHeaderHeight).sub(e.modalCloseBtnSize).div(2).equal(),insetInlineEnd:e.calc(e.modalHeaderHeight).sub(e.modalCloseBtnSize).div(2).equal(),zIndex:e.calc(e.zIndexPopupBase).add(10).equal(),padding:0,color:e.modalCloseIconColor,fontWeight:e.fontWeightStrong,lineHeight:1,textDecoration:"none",background:"transparent",borderRadius:e.borderRadiusSM,width:e.modalCloseBtnSize,height:e.modalCloseBtnSize,border:0,outline:0,cursor:"pointer",transition:`color ${e.motionDurationMid}, background-color ${e.motionDurationMid}`,"&-x":{display:"flex",fontSize:e.fontSizeLG,fontStyle:"normal",lineHeight:L(e.modalCloseBtnSize),justifyContent:"center",textTransform:"none",textRendering:"auto"},"&:disabled":{pointerEvents:"none"},"&:hover":{color:e.modalCloseIconHoverColor,backgroundColor:e.colorBgTextHover,textDecoration:"none"},"&:active":{backgroundColor:e.colorBgTextActive}},Vn(e)),[`${t}-header`]:{color:e.colorText,background:e.headerBg,borderRadius:`${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)} 0 0`,marginBottom:e.headerMarginBottom,padding:e.headerPadding,borderBottom:e.headerBorderBottom},[`${t}-body`]:{fontSize:e.fontSize,lineHeight:e.lineHeight,wordWrap:"break-word",padding:e.bodyPadding,[`${t}-body-skeleton`]:{width:"100%",height:"100%",display:"flex",justifyContent:"center",alignItems:"center",margin:`${L(e.margin)} auto`}},[`${t}-footer`]:{textAlign:"end",background:e.footerBg,marginTop:e.footerMarginTop,padding:e.footerPadding,borderTop:e.footerBorderTop,borderRadius:e.footerBorderRadius,[`> ${e.antCls}-btn + ${e.antCls}-btn`]:{marginInlineStart:e.marginXS}},[`${t}-open`]:{overflow:"hidden"}})},{[`${t}-pure-panel`]:{top:"auto",padding:0,display:"flex",flexDirection:"column",[`${t}-content,
          ${t}-body,
          ${t}-confirm-body-wrapper`]:{display:"flex",flexDirection:"column",flex:"auto"},[`${t}-confirm-body`]:{marginBottom:"auto"}}}]},oR=e=>{const{componentCls:t}=e;return{[`${t}-root`]:{[`${t}-wrap-rtl`]:{direction:"rtl",[`${t}-confirm-body`]:{direction:"rtl"}}}}},aR=e=>{const{componentCls:t}=e,n=tb(e),r=Object.assign({},n);delete r.xs;const o=`--${t.replace(".","")}-`,a=Object.keys(r).map(l=>({[`@media (min-width: ${L(r[l])})`]:{width:`var(${o}${l}-width)`}}));return{[`${t}-root`]:{[t]:[].concat(pe(Object.keys(n).map((l,s)=>{const c=Object.keys(n)[s-1];return c?{[`${o}${l}-width`]:`var(${o}${c}-width)`}:null})),[{width:`var(${o}xs-width)`}],pe(a))}}},nb=e=>{const t=e.padding,n=e.fontSizeHeading5,r=e.lineHeightHeading5;return yt(e,{modalHeaderHeight:e.calc(e.calc(r).mul(n).equal()).add(e.calc(t).mul(2).equal()).equal(),modalFooterBorderColorSplit:e.colorSplit,modalFooterBorderStyle:e.lineType,modalFooterBorderWidth:e.lineWidth,modalCloseIconColor:e.colorIcon,modalCloseIconHoverColor:e.colorIconHover,modalCloseBtnSize:e.controlHeight,modalConfirmIconSize:e.fontHeight,modalTitleHeight:e.calc(e.titleFontSize).mul(e.titleLineHeight).equal()})},rb=e=>({footerBg:"transparent",headerBg:e.colorBgElevated,titleLineHeight:e.lineHeightHeading5,titleFontSize:e.fontSizeHeading5,contentBg:e.colorBgElevated,titleColor:e.colorTextHeading,contentPadding:e.wireframe?0:`${L(e.paddingMD)} ${L(e.paddingContentHorizontalLG)}`,headerPadding:e.wireframe?`${L(e.padding)} ${L(e.paddingLG)}`:0,headerBorderBottom:e.wireframe?`${L(e.lineWidth)} ${e.lineType} ${e.colorSplit}`:"none",headerMarginBottom:e.wireframe?0:e.marginXS,bodyPadding:e.wireframe?e.paddingLG:0,footerPadding:e.wireframe?`${L(e.paddingXS)} ${L(e.padding)}`:0,footerBorderTop:e.wireframe?`${L(e.lineWidth)} ${e.lineType} ${e.colorSplit}`:"none",footerBorderRadius:e.wireframe?`0 0 ${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)}`:0,footerMarginTop:e.wireframe?0:e.marginSM,confirmBodyPadding:e.wireframe?`${L(e.padding*2)} ${L(e.padding*2)} ${L(e.paddingLG)}`:0,confirmIconMarginInlineEnd:e.wireframe?e.margin:e.marginSM,confirmBtnsMarginTop:e.wireframe?e.marginLG:e.marginSM}),ob=It("Modal",e=>{const t=nb(e);return[rR(t),oR(t),nR(t),ui(t,"zoom"),aR(t)]},rb,{unitless:{titleLineHeight:!0}});var iR=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};let Fu;const lR=e=>{Fu={x:e.pageX,y:e.pageY},setTimeout(()=>{Fu=null},100)};OI()&&document.documentElement.addEventListener("click",lR,!0);const ab=e=>{const{prefixCls:t,className:n,rootClassName:r,open:o,wrapClassName:a,centered:l,getContainer:s,focusTriggerAfterClose:c=!0,style:u,visible:d,width:f=520,footer:m,classNames:v,styles:g,children:h,loading:p,confirmLoading:b,zIndex:y,mousePosition:C,onOk:$,onCancel:S,destroyOnHidden:x,destroyOnClose:E,panelRef:O=null}=e,w=iR(e,["prefixCls","className","rootClassName","open","wrapClassName","centered","getContainer","focusTriggerAfterClose","style","visible","width","footer","classNames","styles","children","loading","confirmLoading","zIndex","mousePosition","onOk","onCancel","destroyOnHidden","destroyOnClose","panelRef"]),{getPopupContainer:I,getPrefixCls:P,direction:M,modal:R}=i.useContext(ot),N=Z=>{b||S==null||S(Z)},T=Z=>{$==null||$(Z)},j=P("modal",t),z=P(),_=Cn(j),[B,V,G]=ob(j,_),q=A(a,{[`${j}-centered`]:l??(R==null?void 0:R.centered),[`${j}-wrap-rtl`]:M==="rtl"}),H=m!==null&&!p?i.createElement(eb,Object.assign({},e,{onOk:T,onCancel:N})):null,[W,K,U,te]=Gd(oa(e),oa(R),{closable:!0,closeIcon:i.createElement(Fr,{className:`${j}-close-icon`}),closeIconRender:Z=>J0(j,Z)}),X=Z0(`.${j}-content`),ae=un(O,X),[le,ee]=ma("Modal",y),[Y,re]=i.useMemo(()=>f&&typeof f=="object"?[void 0,f]:[f,void 0],[f]),ne=i.useMemo(()=>{const Z={};return re&&Object.keys(re).forEach(Q=>{const ie=re[Q];ie!==void 0&&(Z[`--${j}-${Q}-width`]=typeof ie=="number"?`${ie}px`:ie)}),Z},[re]);return B(i.createElement(jr,{form:!0,space:!0},i.createElement(li.Provider,{value:ee},i.createElement(W0,Object.assign({width:Y},w,{zIndex:le,getContainer:s===void 0?I:s,prefixCls:j,rootClassName:A(V,r,G,_),footer:H,visible:o??d,mousePosition:C??Fu,onClose:N,closable:W&&Object.assign({disabled:U,closeIcon:K},te),closeIcon:K,focusTriggerAfterClose:c,transitionName:Mr(z,"zoom",e.transitionName),maskTransitionName:Mr(z,"fade",e.maskTransitionName),className:A(V,n,R==null?void 0:R.className),style:Object.assign(Object.assign(Object.assign({},R==null?void 0:R.style),u),ne),classNames:Object.assign(Object.assign(Object.assign({},R==null?void 0:R.classNames),v),{wrapper:A(q,v==null?void 0:v.wrapper)}),styles:Object.assign(Object.assign({},R==null?void 0:R.styles),g),panelRef:ae,destroyOnClose:x??E}),p?i.createElement(kr,{active:!0,title:!1,paragraph:{rows:4},className:`${j}-body-skeleton`}):h))))},sR=e=>{const{componentCls:t,titleFontSize:n,titleLineHeight:r,modalConfirmIconSize:o,fontSize:a,lineHeight:l,modalTitleHeight:s,fontHeight:c,confirmBodyPadding:u}=e,d=`${t}-confirm`;return{[d]:{"&-rtl":{direction:"rtl"},[`${e.antCls}-modal-header`]:{display:"none"},[`${d}-body-wrapper`]:Object.assign({},yr()),[`&${t} ${t}-body`]:{padding:u},[`${d}-body`]:{display:"flex",flexWrap:"nowrap",alignItems:"start",[`> ${e.iconCls}`]:{flex:"none",fontSize:o,marginInlineEnd:e.confirmIconMarginInlineEnd,marginTop:e.calc(e.calc(c).sub(o).equal()).div(2).equal()},[`&-has-title > ${e.iconCls}`]:{marginTop:e.calc(e.calc(s).sub(o).equal()).div(2).equal()}},[`${d}-paragraph`]:{display:"flex",flexDirection:"column",flex:"auto",rowGap:e.marginXS,maxWidth:`calc(100% - ${L(e.marginSM)})`},[`${e.iconCls} + ${d}-paragraph`]:{maxWidth:`calc(100% - ${L(e.calc(e.modalConfirmIconSize).add(e.marginSM).equal())})`},[`${d}-title`]:{color:e.colorTextHeading,fontWeight:e.fontWeightStrong,fontSize:n,lineHeight:r},[`${d}-content`]:{color:e.colorText,fontSize:a,lineHeight:l},[`${d}-btns`]:{textAlign:"end",marginTop:e.confirmBtnsMarginTop,[`${e.antCls}-btn + ${e.antCls}-btn`]:{marginBottom:0,marginInlineStart:e.marginXS}}},[`${d}-error ${d}-body > ${e.iconCls}`]:{color:e.colorError},[`${d}-warning ${d}-body > ${e.iconCls},
        ${d}-confirm ${d}-body > ${e.iconCls}`]:{color:e.colorWarning},[`${d}-info ${d}-body > ${e.iconCls}`]:{color:e.colorInfo},[`${d}-success ${d}-body > ${e.iconCls}`]:{color:e.colorSuccess}}},cR=ua(["Modal","confirm"],e=>{const t=nb(e);return sR(t)},rb,{order:-1e3});var uR=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function ib(e){const{prefixCls:t,icon:n,okText:r,cancelText:o,confirmPrefixCls:a,type:l,okCancel:s,footer:c,locale:u}=e,d=uR(e,["prefixCls","icon","okText","cancelText","confirmPrefixCls","type","okCancel","footer","locale"]);let f=n;if(!n&&n!==null)switch(l){case"info":f=i.createElement(ts,null);break;case"success":f=i.createElement(ii,null);break;case"error":f=i.createElement(wo,null);break;default:f=i.createElement(fa,null)}const m=s??l==="confirm",v=e.autoFocusButton===null?!1:e.autoFocusButton||"ok",[g]=Kn("Modal"),h=u||g,p=r||(m?h==null?void 0:h.okText:h==null?void 0:h.justOkText),b=o||(h==null?void 0:h.cancelText),y=Object.assign({autoFocusButton:v,cancelTextLocale:b,okTextLocale:p,mergedOkCancel:m},d),C=i.useMemo(()=>y,pe(Object.values(y))),$=i.createElement(i.Fragment,null,i.createElement(qm,null),i.createElement(Um,null)),S=e.title!==void 0&&e.title!==null,x=`${a}-body`;return i.createElement("div",{className:`${a}-body-wrapper`},i.createElement("div",{className:A(x,{[`${x}-has-title`]:S})},f,i.createElement("div",{className:`${a}-paragraph`},S&&i.createElement("span",{className:`${a}-title`},e.title),i.createElement("div",{className:`${a}-content`},e.content))),c===void 0||typeof c=="function"?i.createElement(L0,{value:C},i.createElement("div",{className:`${a}-btns`},typeof c=="function"?c($,{OkBtn:Um,CancelBtn:qm}):$)):c,i.createElement(cR,{prefixCls:t}))}const dR=e=>{const{close:t,zIndex:n,maskStyle:r,direction:o,prefixCls:a,wrapClassName:l,rootPrefixCls:s,bodyStyle:c,closable:u=!1,onConfirm:d,styles:f}=e,m=`${a}-confirm`,v=e.width||416,g=e.style||{},h=e.mask===void 0?!0:e.mask,p=e.maskClosable===void 0?!1:e.maskClosable,b=A(m,`${m}-${e.type}`,{[`${m}-rtl`]:o==="rtl"},e.className),[,y]=yn(),C=i.useMemo(()=>n!==void 0?n:y.zIndexPopupBase+Td,[n,y]);return i.createElement(ab,Object.assign({},e,{className:b,wrapClassName:A({[`${m}-centered`]:!!e.centered},l),onCancel:()=>{t==null||t({triggerCancel:!0}),d==null||d(!1)},title:"",footer:null,transitionName:Mr(s||"","zoom",e.transitionName),maskTransitionName:Mr(s||"","fade",e.maskTransitionName),mask:h,maskClosable:p,style:g,styles:Object.assign({body:c,mask:r},f),width:v,zIndex:C,closable:u}),i.createElement(ib,Object.assign({},e,{confirmPrefixCls:m})))},lb=e=>{const{rootPrefixCls:t,iconPrefixCls:n,direction:r,theme:o}=e;return i.createElement(wr,{prefixCls:t,iconPrefixCls:n,direction:r,theme:o},i.createElement(dR,Object.assign({},e)))},uo=[];let sb="";function cb(){return sb}const fR=e=>{var t,n;const{prefixCls:r,getContainer:o,direction:a}=e,l=Nh(),s=i.useContext(ot),c=cb()||s.getPrefixCls(),u=r||`${c}-modal`;let d=o;return d===!1&&(d=void 0),F.createElement(lb,Object.assign({},e,{rootPrefixCls:c,prefixCls:u,iconPrefixCls:s.iconPrefixCls,theme:s.theme,direction:a??s.direction,locale:(n=(t=s.locale)===null||t===void 0?void 0:t.Modal)!==null&&n!==void 0?n:l,getContainer:d}))};function pi(e){const t=Pd(),n=document.createDocumentFragment();let r=Object.assign(Object.assign({},e),{close:c,open:!0}),o,a;function l(...d){var f;if(d.some(g=>g==null?void 0:g.triggerCancel)){var v;(f=e.onCancel)===null||f===void 0||(v=f).call.apply(v,[e,()=>{}].concat(pe(d.slice(1))))}for(let g=0;g<uo.length;g++)if(uo[g]===c){uo.splice(g,1);break}a()}function s(d){clearTimeout(o),o=setTimeout(()=>{const f=t.getPrefixCls(void 0,cb()),m=t.getIconPrefixCls(),v=t.getTheme(),g=F.createElement(fR,Object.assign({},d));a=rs()(F.createElement(wr,{prefixCls:f,iconPrefixCls:m,theme:v},t.holderRender?t.holderRender(g):g),n)})}function c(...d){r=Object.assign(Object.assign({},r),{open:!1,afterClose:()=>{typeof e.afterClose=="function"&&e.afterClose(),l.apply(this,d)}}),r.visible&&delete r.visible,s(r)}function u(d){typeof d=="function"?r=d(r):r=Object.assign(Object.assign({},r),d),s(r)}return s(r),uo.push(c),{destroy:c,update:u}}function ub(e){return Object.assign(Object.assign({},e),{type:"warning"})}function db(e){return Object.assign(Object.assign({},e),{type:"info"})}function fb(e){return Object.assign(Object.assign({},e),{type:"success"})}function mb(e){return Object.assign(Object.assign({},e),{type:"error"})}function vb(e){return Object.assign(Object.assign({},e),{type:"confirm"})}function mR({rootPrefixCls:e}){sb=e}var vR=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const gR=(e,t)=>{var n,{afterClose:r,config:o}=e,a=vR(e,["afterClose","config"]);const[l,s]=i.useState(!0),[c,u]=i.useState(o),{direction:d,getPrefixCls:f}=i.useContext(ot),m=f("modal"),v=f(),g=()=>{var y;r(),(y=c.afterClose)===null||y===void 0||y.call(c)},h=(...y)=>{var C;if(s(!1),y.some(x=>x==null?void 0:x.triggerCancel)){var S;(C=c.onCancel)===null||C===void 0||(S=C).call.apply(S,[c,()=>{}].concat(pe(y.slice(1))))}};i.useImperativeHandle(t,()=>({destroy:h,update:y=>{u(C=>{const $=typeof y=="function"?y(C):y;return Object.assign(Object.assign({},C),$)})}}));const p=(n=c.okCancel)!==null&&n!==void 0?n:c.type==="confirm",[b]=Kn("Modal",br.Modal);return i.createElement(lb,Object.assign({prefixCls:m,rootPrefixCls:v},c,{close:h,open:l,afterClose:g,okText:c.okText||(p?b==null?void 0:b.okText:b==null?void 0:b.justOkText),direction:c.direction||d,cancelText:c.cancelText||(b==null?void 0:b.cancelText)},a))},pR=i.forwardRef(gR);let yv=0;const hR=i.memo(i.forwardRef((e,t)=>{const[n,r]=Zw();return i.useImperativeHandle(t,()=>({patchElement:r}),[]),i.createElement(i.Fragment,null,n)}));function bR(){const e=i.useRef(null),[t,n]=i.useState([]);i.useEffect(()=>{t.length&&(pe(t).forEach(l=>{l()}),n([]))},[t]);const r=i.useCallback(a=>function(s){var c;yv+=1;const u=i.createRef();let d;const f=new Promise(p=>{d=p});let m=!1,v;const g=i.createElement(pR,{key:`modal-${yv}`,config:a(s),ref:u,afterClose:()=>{v==null||v()},isSilent:()=>m,onConfirm:p=>{d(p)}});return v=(c=e.current)===null||c===void 0?void 0:c.patchElement(g),v&&uo.push(v),{destroy:()=>{function p(){var b;(b=u.current)===null||b===void 0||b.destroy()}u.current?p():n(b=>[].concat(pe(b),[p]))},update:p=>{function b(){var y;(y=u.current)===null||y===void 0||y.update(p)}u.current?b():n(y=>[].concat(pe(y),[b]))},then:p=>(m=!0,f.then(p))}},[]);return[i.useMemo(()=>({info:r(db),success:r(fb),error:r(mb),warning:r(ub),confirm:r(vb)}),[]),i.createElement(hR,{key:"modal-holder",ref:e})]}const yR=e=>{const{componentCls:t,notificationMarginEdge:n,animationMaxHeight:r}=e,o=`${t}-notice`,a=new $t("antNotificationFadeIn",{"0%":{transform:"translate3d(100%, 0, 0)",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",opacity:1}}),l=new $t("antNotificationTopFadeIn",{"0%":{top:-r,opacity:0},"100%":{top:0,opacity:1}}),s=new $t("antNotificationBottomFadeIn",{"0%":{bottom:e.calc(r).mul(-1).equal(),opacity:0},"100%":{bottom:0,opacity:1}}),c=new $t("antNotificationLeftFadeIn",{"0%":{transform:"translate3d(-100%, 0, 0)",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",opacity:1}});return{[t]:{[`&${t}-top, &${t}-bottom`]:{marginInline:0,[o]:{marginInline:"auto auto"}},[`&${t}-top`]:{[`${t}-fade-enter${t}-fade-enter-active, ${t}-fade-appear${t}-fade-appear-active`]:{animationName:l}},[`&${t}-bottom`]:{[`${t}-fade-enter${t}-fade-enter-active, ${t}-fade-appear${t}-fade-appear-active`]:{animationName:s}},[`&${t}-topRight, &${t}-bottomRight`]:{[`${t}-fade-enter${t}-fade-enter-active, ${t}-fade-appear${t}-fade-appear-active`]:{animationName:a}},[`&${t}-topLeft, &${t}-bottomLeft`]:{marginRight:{value:0,_skip_check_:!0},marginLeft:{value:n,_skip_check_:!0},[o]:{marginInlineEnd:"auto",marginInlineStart:0},[`${t}-fade-enter${t}-fade-enter-active, ${t}-fade-appear${t}-fade-appear-active`]:{animationName:c}}}}},CR=["top","topLeft","topRight","bottom","bottomLeft","bottomRight"],SR={topLeft:"left",topRight:"right",bottomLeft:"left",bottomRight:"right",top:"left",bottom:"left"},$R=(e,t)=>{const{componentCls:n}=e;return{[`${n}-${t}`]:{[`&${n}-stack > ${n}-notice-wrapper`]:{[t.startsWith("top")?"top":"bottom"]:0,[SR[t]]:{value:0,_skip_check_:!0}}}}},xR=e=>{const t={};for(let n=1;n<e.notificationStackLayer;n++)t[`&:nth-last-child(${n+1})`]={overflow:"hidden",[`& > ${e.componentCls}-notice`]:{opacity:0,transition:`opacity ${e.motionDurationMid}`}};return Object.assign({[`&:not(:nth-last-child(-n+${e.notificationStackLayer}))`]:{opacity:0,overflow:"hidden",color:"transparent",pointerEvents:"none"}},t)},wR=e=>{const t={};for(let n=1;n<e.notificationStackLayer;n++)t[`&:nth-last-child(${n+1})`]={background:e.colorBgBlur,backdropFilter:"blur(10px)","-webkit-backdrop-filter":"blur(10px)"};return Object.assign({},t)},ER=e=>{const{componentCls:t}=e;return Object.assign({[`${t}-stack`]:{[`& > ${t}-notice-wrapper`]:Object.assign({transition:`transform ${e.motionDurationSlow}, backdrop-filter 0s`,willChange:"transform, opacity",position:"absolute"},xR(e))},[`${t}-stack:not(${t}-stack-expanded)`]:{[`& > ${t}-notice-wrapper`]:Object.assign({},wR(e))},[`${t}-stack${t}-stack-expanded`]:{[`& > ${t}-notice-wrapper`]:{"&:not(:nth-last-child(-n + 1))":{opacity:1,overflow:"unset",color:"inherit",pointerEvents:"auto",[`& > ${e.componentCls}-notice`]:{opacity:1}},"&:after":{content:'""',position:"absolute",height:e.margin,width:"100%",insetInline:0,bottom:e.calc(e.margin).mul(-1).equal(),background:"transparent",pointerEvents:"auto"}}}},CR.map(n=>$R(e,n)).reduce((n,r)=>Object.assign(Object.assign({},n),r),{}))},gb=e=>{const{iconCls:t,componentCls:n,boxShadow:r,fontSizeLG:o,notificationMarginBottom:a,borderRadiusLG:l,colorSuccess:s,colorInfo:c,colorWarning:u,colorError:d,colorTextHeading:f,notificationBg:m,notificationPadding:v,notificationMarginEdge:g,notificationProgressBg:h,notificationProgressHeight:p,fontSize:b,lineHeight:y,width:C,notificationIconSize:$,colorText:S}=e,x=`${n}-notice`;return{position:"relative",marginBottom:a,marginInlineStart:"auto",background:m,borderRadius:l,boxShadow:r,[x]:{padding:v,width:C,maxWidth:`calc(100vw - ${L(e.calc(g).mul(2).equal())})`,overflow:"hidden",lineHeight:y,wordWrap:"break-word"},[`${x}-message`]:{color:f,fontSize:o,lineHeight:e.lineHeightLG},[`${x}-description`]:{fontSize:b,color:S,marginTop:e.marginXS},[`${x}-closable ${x}-message`]:{paddingInlineEnd:e.paddingLG},[`${x}-with-icon ${x}-message`]:{marginInlineStart:e.calc(e.marginSM).add($).equal(),fontSize:o},[`${x}-with-icon ${x}-description`]:{marginInlineStart:e.calc(e.marginSM).add($).equal(),fontSize:b},[`${x}-icon`]:{position:"absolute",fontSize:$,lineHeight:1,[`&-success${t}`]:{color:s},[`&-info${t}`]:{color:c},[`&-warning${t}`]:{color:u},[`&-error${t}`]:{color:d}},[`${x}-close`]:Object.assign({position:"absolute",top:e.notificationPaddingVertical,insetInlineEnd:e.notificationPaddingHorizontal,color:e.colorIcon,outline:"none",width:e.notificationCloseButtonSize,height:e.notificationCloseButtonSize,borderRadius:e.borderRadiusSM,transition:`background-color ${e.motionDurationMid}, color ${e.motionDurationMid}`,display:"flex",alignItems:"center",justifyContent:"center",background:"none",border:"none","&:hover":{color:e.colorIconHover,backgroundColor:e.colorBgTextHover},"&:active":{backgroundColor:e.colorBgTextActive}},Vn(e)),[`${x}-progress`]:{position:"absolute",display:"block",appearance:"none",inlineSize:`calc(100% - ${L(l)} * 2)`,left:{_skip_check_:!0,value:l},right:{_skip_check_:!0,value:l},bottom:0,blockSize:p,border:0,"&, &::-webkit-progress-bar":{borderRadius:l,backgroundColor:"rgba(0, 0, 0, 0.04)"},"&::-moz-progress-bar":{background:h},"&::-webkit-progress-value":{borderRadius:l,background:h}},[`${x}-actions`]:{float:"right",marginTop:e.marginSM}}},OR=e=>{const{componentCls:t,notificationMarginBottom:n,notificationMarginEdge:r,motionDurationMid:o,motionEaseInOut:a}=e,l=`${t}-notice`,s=new $t("antNotificationFadeOut",{"0%":{maxHeight:e.animationMaxHeight,marginBottom:n},"100%":{maxHeight:0,marginBottom:0,paddingTop:0,paddingBottom:0,opacity:0}});return[{[t]:Object.assign(Object.assign({},Tt(e)),{position:"fixed",zIndex:e.zIndexPopup,marginRight:{value:r,_skip_check_:!0},[`${t}-hook-holder`]:{position:"relative"},[`${t}-fade-appear-prepare`]:{opacity:"0 !important"},[`${t}-fade-enter, ${t}-fade-appear`]:{animationDuration:e.motionDurationMid,animationTimingFunction:a,animationFillMode:"both",opacity:0,animationPlayState:"paused"},[`${t}-fade-leave`]:{animationTimingFunction:a,animationFillMode:"both",animationDuration:o,animationPlayState:"paused"},[`${t}-fade-enter${t}-fade-enter-active, ${t}-fade-appear${t}-fade-appear-active`]:{animationPlayState:"running"},[`${t}-fade-leave${t}-fade-leave-active`]:{animationName:s,animationPlayState:"running"},"&-rtl":{direction:"rtl",[`${l}-actions`]:{float:"left"}}})},{[t]:{[`${l}-wrapper`]:Object.assign({},gb(e))}}]},pb=e=>({zIndexPopup:e.zIndexPopupBase+Td+50,width:384}),hb=e=>{const t=e.paddingMD,n=e.paddingLG;return yt(e,{notificationBg:e.colorBgElevated,notificationPaddingVertical:t,notificationPaddingHorizontal:n,notificationIconSize:e.calc(e.fontSizeLG).mul(e.lineHeightLG).equal(),notificationCloseButtonSize:e.calc(e.controlHeightLG).mul(.55).equal(),notificationMarginBottom:e.margin,notificationPadding:`${L(e.paddingMD)} ${L(e.paddingContentHorizontalLG)}`,notificationMarginEdge:e.marginLG,animationMaxHeight:150,notificationStackLayer:3,notificationProgressHeight:2,notificationProgressBg:`linear-gradient(90deg, ${e.colorPrimaryBorderHover}, ${e.colorPrimary})`})},bb=It("Notification",e=>{const t=hb(e);return[OR(t),yR(t),ER(t)]},pb),IR=ua(["Notification","PurePanel"],e=>{const t=`${e.componentCls}-notice`,n=hb(e);return{[`${t}-pure-panel`]:Object.assign(Object.assign({},gb(n)),{width:n.width,maxWidth:`calc(100vw - ${L(e.calc(n.notificationMarginEdge).mul(2).equal())})`,margin:0})}},pb);var RR=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function qd(e,t){return t===null||t===!1?null:t||i.createElement(Fr,{className:`${e}-close-icon`})}const PR={success:ii,info:ts,error:wo,warning:fa},yb=e=>{const{prefixCls:t,icon:n,type:r,message:o,description:a,actions:l,role:s="alert"}=e;let c=null;return n?c=i.createElement("span",{className:`${t}-icon`},n):r&&(c=i.createElement(PR[r]||null,{className:A(`${t}-icon`,`${t}-icon-${r}`)})),i.createElement("div",{className:A({[`${t}-with-icon`]:c}),role:s},c,i.createElement("div",{className:`${t}-message`},o),a&&i.createElement("div",{className:`${t}-description`},a),l&&i.createElement("div",{className:`${t}-actions`},l))},NR=e=>{const{prefixCls:t,className:n,icon:r,type:o,message:a,description:l,btn:s,actions:c,closable:u=!0,closeIcon:d,className:f}=e,m=RR(e,["prefixCls","className","icon","type","message","description","btn","actions","closable","closeIcon","className"]),{getPrefixCls:v}=i.useContext(ot),g=c??s,h=t||v("notification"),p=`${h}-notice`,b=Cn(h),[y,C,$]=bb(h,b);return y(i.createElement("div",{className:A(`${p}-pure-panel`,C,n,$,b)},i.createElement(IR,{prefixCls:h}),i.createElement(Md,Object.assign({},m,{prefixCls:h,eventKey:"pure",duration:null,closable:u,className:A({notificationClassName:f}),closeIcon:qd(h,d),content:i.createElement(yb,{prefixCls:p,icon:r,type:o,message:a,description:l,actions:g})}))))};function MR(e,t,n){let r;switch(e){case"top":r={left:"50%",transform:"translateX(-50%)",right:"auto",top:t,bottom:"auto"};break;case"topLeft":r={left:0,top:t,bottom:"auto"};break;case"topRight":r={right:0,top:t,bottom:"auto"};break;case"bottom":r={left:"50%",transform:"translateX(-50%)",right:"auto",top:"auto",bottom:n};break;case"bottomLeft":r={left:0,top:"auto",bottom:n};break;default:r={right:0,top:"auto",bottom:n};break}return r}function TR(e){return{motionName:`${e}-fade`}}function jR(e,t,n){return typeof e<"u"?e:typeof(t==null?void 0:t.closeIcon)<"u"?t.closeIcon:n==null?void 0:n.closeIcon}var zR=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Cv=24,DR=4.5,_R="topRight",BR=({children:e,prefixCls:t})=>{const n=Cn(t),[r,o,a]=bb(t,n);return r(F.createElement(m0,{classNames:{list:A(o,a,n)}},e))},LR=(e,{prefixCls:t,key:n})=>F.createElement(BR,{prefixCls:t,key:n},e),HR=F.forwardRef((e,t)=>{const{top:n,bottom:r,prefixCls:o,getContainer:a,maxCount:l,rtl:s,onAllRemoved:c,stack:u,duration:d,pauseOnHover:f=!0,showProgress:m}=e,{getPrefixCls:v,getPopupContainer:g,notification:h,direction:p}=i.useContext(ot),[,b]=yn(),y=o||v("notification"),C=O=>MR(O,n??Cv,r??Cv),$=()=>A({[`${y}-rtl`]:s??p==="rtl"}),S=()=>TR(y),[x,E]=v0({prefixCls:y,style:C,className:$,motion:S,closable:!0,closeIcon:qd(y),duration:d??DR,getContainer:()=>(a==null?void 0:a())||(g==null?void 0:g())||document.body,maxCount:l,pauseOnHover:f,showProgress:m,onAllRemoved:c,renderNotifications:LR,stack:u===!1?!1:{threshold:typeof u=="object"?u==null?void 0:u.threshold:void 0,offset:8,gap:b.margin}});return F.useImperativeHandle(t,()=>Object.assign(Object.assign({},x),{prefixCls:y,notification:h})),E});function Cb(e){const t=F.useRef(null);return no(),[F.useMemo(()=>{const r=s=>{var c;if(!t.current)return;const{open:u,prefixCls:d,notification:f}=t.current,m=`${d}-notice`,{message:v,description:g,icon:h,type:p,btn:b,actions:y,className:C,style:$,role:S="alert",closeIcon:x,closable:E}=s,O=zR(s,["message","description","icon","type","btn","actions","className","style","role","closeIcon","closable"]),w=y??b,I=qd(m,jR(x,e,f));return u(Object.assign(Object.assign({placement:(c=e==null?void 0:e.placement)!==null&&c!==void 0?c:_R},O),{content:F.createElement(yb,{prefixCls:m,icon:h,type:p,message:v,description:g,actions:w,role:S}),className:A(p&&`${m}-${p}`,C,f==null?void 0:f.className),style:Object.assign(Object.assign({},f==null?void 0:f.style),$),closeIcon:I,closable:E??!!I}))},a={open:r,destroy:s=>{var c,u;s!==void 0?(c=t.current)===null||c===void 0||c.close(s):(u=t.current)===null||u===void 0||u.destroy()}};return["success","info","warning","error"].forEach(s=>{a[s]=c=>r(Object.assign(Object.assign({},c),{type:s}))}),a},[]),F.createElement(HR,Object.assign({key:"notification-holder"},e,{ref:t}))]}function AR(e){return Cb(e)}const Sb=F.createContext({});function $b(e){return t=>i.createElement(wr,{theme:{token:{motion:!1,zIndexPopupBase:0}}},i.createElement(e,Object.assign({},t)))}const Ud=(e,t,n,r,o)=>$b(l=>{const{prefixCls:s,style:c}=l,u=i.useRef(null),[d,f]=i.useState(0),[m,v]=i.useState(0),[g,h]=Lt(!1,{value:l.open}),{getPrefixCls:p}=i.useContext(ot),b=p(r||"select",s);i.useEffect(()=>{if(h(!0),typeof ResizeObserver<"u"){const $=new ResizeObserver(x=>{const E=x[0].target;f(E.offsetHeight+8),v(E.offsetWidth)}),S=setInterval(()=>{var x;const E=o?`.${o(b)}`:`.${b}-dropdown`,O=(x=u.current)===null||x===void 0?void 0:x.querySelector(E);O&&(clearInterval(S),$.observe(O))},10);return()=>{clearInterval(S),$.disconnect()}}},[]);let y=Object.assign(Object.assign({},l),{style:Object.assign(Object.assign({},c),{margin:0}),open:g,visible:g,getPopupContainer:()=>u.current});n&&(y=n(y)),t&&Object.assign(y,{[t]:{overflow:{adjustX:!1,adjustY:!1}}});const C={paddingBottom:d,position:"relative",minWidth:m};return i.createElement("div",{ref:u,style:C},i.createElement(e,Object.assign({},y)))}),ys=function(){if(typeof navigator>"u"||typeof window>"u")return!1;var e=navigator.userAgent||navigator.vendor||window.opera;return/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino|android|ipad|playbook|silk/i.test(e)||/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw-(n|u)|c55\/|capi|ccwa|cdm-|cell|chtm|cldc|cmd-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc-s|devi|dica|dmob|do(c|p)o|ds(12|-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(-|_)|g1 u|g560|gene|gf-5|g-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd-(m|p|t)|hei-|hi(pt|ta)|hp( i|ip)|hs-c|ht(c(-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i-(20|go|ma)|i230|iac( |-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|-[a-w])|libw|lynx|m1-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|-([1-8]|c))|phil|pire|pl(ay|uc)|pn-2|po(ck|rt|se)|prox|psio|pt-g|qa-a|qc(07|12|21|32|60|-[2-7]|i-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h-|oo|p-)|sdk\/|se(c(-|0|1)|47|mc|nd|ri)|sgh-|shar|sie(-|m)|sk-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h-|v-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl-|tdg-|tel(i|m)|tim-|t-mo|to(pl|sh)|ts(70|m-|m3|m5)|tx-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas-|your|zeto|zte-/i.test(e==null?void 0:e.substr(0,4))};var Cs=function(t){var n=t.className,r=t.customizeIcon,o=t.customizeIconProps,a=t.children,l=t.onMouseDown,s=t.onClick,c=typeof r=="function"?r(o):r;return i.createElement("span",{className:n,onMouseDown:function(d){d.preventDefault(),l==null||l(d)},style:{userSelect:"none",WebkitUserSelect:"none"},unselectable:"on",onClick:s,"aria-hidden":!0},c!==void 0?c:i.createElement("span",{className:A(n.split(/\s+/).map(function(u){return"".concat(u,"-icon")}))},a))},FR=function(t,n,r,o,a){var l=arguments.length>5&&arguments[5]!==void 0?arguments[5]:!1,s=arguments.length>6?arguments[6]:void 0,c=arguments.length>7?arguments[7]:void 0,u=F.useMemo(function(){if(Qe(o)==="object")return o.clearIcon;if(a)return a},[o,a]),d=F.useMemo(function(){return!!(!l&&o&&(r.length||s)&&!(c==="combobox"&&s===""))},[o,l,r.length,s,c]);return{allowClear:d,clearIcon:F.createElement(Cs,{className:"".concat(t,"-clear"),onMouseDown:n,customizeIcon:u},"×")}},xb=i.createContext(null);function kR(){return i.useContext(xb)}function VR(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:10,t=i.useState(!1),n=J(t,2),r=n[0],o=n[1],a=i.useRef(null),l=function(){window.clearTimeout(a.current)};i.useEffect(function(){return l},[]);var s=function(u,d){l(),a.current=window.setTimeout(function(){o(u),d&&d()},e)};return[r,s,l]}function wb(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:250,t=i.useRef(null),n=i.useRef(null);i.useEffect(function(){return function(){window.clearTimeout(n.current)}},[]);function r(o){(o||t.current===null)&&(t.current=o),window.clearTimeout(n.current),n.current=window.setTimeout(function(){t.current=null},e)}return[function(){return t.current},r]}function WR(e,t,n,r){var o=i.useRef(null);o.current={open:t,triggerOpen:n,customizedTrigger:r},i.useEffect(function(){function a(l){var s;if(!((s=o.current)!==null&&s!==void 0&&s.customizedTrigger)){var c=l.target;c.shadowRoot&&l.composed&&(c=l.composedPath()[0]||c),o.current.open&&e().filter(function(u){return u}).every(function(u){return!u.contains(c)&&u!==c})&&o.current.triggerOpen(!1)}}return window.addEventListener("mousedown",a),function(){return window.removeEventListener("mousedown",a)}},[])}function KR(e){return e&&![Ne.ESC,Ne.SHIFT,Ne.BACKSPACE,Ne.TAB,Ne.WIN_KEY,Ne.ALT,Ne.META,Ne.WIN_KEY_RIGHT,Ne.CTRL,Ne.SEMICOLON,Ne.EQUALS,Ne.CAPS_LOCK,Ne.CONTEXT_MENU,Ne.F1,Ne.F2,Ne.F3,Ne.F4,Ne.F5,Ne.F6,Ne.F7,Ne.F8,Ne.F9,Ne.F10,Ne.F11,Ne.F12].includes(e)}var GR=["prefixCls","invalidate","item","renderItem","responsive","responsiveDisabled","registerSize","itemKey","className","style","children","display","order","component"],No=void 0;function qR(e,t){var n=e.prefixCls,r=e.invalidate,o=e.item,a=e.renderItem,l=e.responsive,s=e.responsiveDisabled,c=e.registerSize,u=e.itemKey,d=e.className,f=e.style,m=e.children,v=e.display,g=e.order,h=e.component,p=h===void 0?"div":h,b=ft(e,GR),y=l&&!v;function C(O){c(u,O)}i.useEffect(function(){return function(){C(null)}},[]);var $=a&&o!==No?a(o,{index:g}):m,S;r||(S={opacity:y?0:1,height:y?0:No,overflowY:y?"hidden":No,order:l?g:No,pointerEvents:y?"none":No,position:y?"absolute":No});var x={};y&&(x["aria-hidden"]=!0);var E=i.createElement(p,ue({className:A(!r&&n,d),style:k(k({},S),f)},x,b,{ref:t}),$);return l&&(E=i.createElement(Bn,{onResize:function(w){var I=w.offsetWidth;C(I)},disabled:s},E)),E}var Fa=i.forwardRef(qR);Fa.displayName="Item";function UR(e){if(typeof MessageChannel>"u")Et(e);else{var t=new MessageChannel;t.port1.onmessage=function(){return e()},t.port2.postMessage(void 0)}}function XR(){var e=i.useRef(null),t=function(r){e.current||(e.current=[],UR(function(){Pr.unstable_batchedUpdates(function(){e.current.forEach(function(o){o()}),e.current=null})})),e.current.push(r)};return t}function Ia(e,t){var n=i.useState(t),r=J(n,2),o=r[0],a=r[1],l=Nt(function(s){e(function(){a(s)})});return[o,l]}var wl=F.createContext(null),YR=["component"],QR=["className"],ZR=["className"],JR=function(t,n){var r=i.useContext(wl);if(!r){var o=t.component,a=o===void 0?"div":o,l=ft(t,YR);return i.createElement(a,ue({},l,{ref:n}))}var s=r.className,c=ft(r,QR),u=t.className,d=ft(t,ZR);return i.createElement(wl.Provider,{value:null},i.createElement(Fa,ue({ref:n,className:A(s,u)},c,d)))},Eb=i.forwardRef(JR);Eb.displayName="RawItem";var eP=["prefixCls","data","renderItem","renderRawItem","itemKey","itemWidth","ssr","style","className","maxCount","renderRest","renderRawRest","suffix","component","itemComponent","onVisibleChange"],Ob="responsive",Ib="invalidate";function tP(e){return"+ ".concat(e.length," ...")}function nP(e,t){var n=e.prefixCls,r=n===void 0?"rc-overflow":n,o=e.data,a=o===void 0?[]:o,l=e.renderItem,s=e.renderRawItem,c=e.itemKey,u=e.itemWidth,d=u===void 0?10:u,f=e.ssr,m=e.style,v=e.className,g=e.maxCount,h=e.renderRest,p=e.renderRawRest,b=e.suffix,y=e.component,C=y===void 0?"div":y,$=e.itemComponent,S=e.onVisibleChange,x=ft(e,eP),E=f==="full",O=XR(),w=Ia(O,null),I=J(w,2),P=I[0],M=I[1],R=P||0,N=Ia(O,new Map),T=J(N,2),j=T[0],z=T[1],_=Ia(O,0),B=J(_,2),V=B[0],G=B[1],q=Ia(O,0),H=J(q,2),W=H[0],K=H[1],U=Ia(O,0),te=J(U,2),X=te[0],ae=te[1],le=i.useState(null),ee=J(le,2),Y=ee[0],re=ee[1],ne=i.useState(null),Z=J(ne,2),Q=Z[0],ie=Z[1],de=i.useMemo(function(){return Q===null&&E?Number.MAX_SAFE_INTEGER:Q||0},[Q,P]),he=i.useState(!1),ye=J(he,2),oe=ye[0],ce=ye[1],ge="".concat(r,"-item"),se=Math.max(V,W),be=g===Ob,we=a.length&&be,Me=g===Ib,Te=we||typeof g=="number"&&a.length>g,Se=i.useMemo(function(){var Xe=a;return we?P===null&&E?Xe=a:Xe=a.slice(0,Math.min(a.length,R/d)):typeof g=="number"&&(Xe=a.slice(0,g)),Xe},[a,d,P,g,we]),Fe=i.useMemo(function(){return we?a.slice(de+1):a.slice(Se.length)},[a,Se,we,de]),Ce=i.useCallback(function(Xe,He){var je;return typeof c=="function"?c(Xe):(je=c&&(Xe==null?void 0:Xe[c]))!==null&&je!==void 0?je:He},[c]),me=i.useCallback(l||function(Xe){return Xe},[l]);function $e(Xe,He,je){Q===Xe&&(He===void 0||He===Y)||(ie(Xe),je||(ce(Xe<a.length-1),S==null||S(Xe)),He!==void 0&&re(He))}function Ee(Xe,He){M(He.clientWidth)}function Ie(Xe,He){z(function(je){var rt=new Map(je);return He===null?rt.delete(Xe):rt.set(Xe,He),rt})}function fe(Xe,He){K(He),G(W)}function ve(Xe,He){ae(He)}function xe(Xe){return j.get(Ce(Se[Xe],Xe))}wt(function(){if(R&&typeof se=="number"&&Se){var Xe=X,He=Se.length,je=He-1;if(!He){$e(0,null);return}for(var rt=0;rt<He;rt+=1){var et=xe(rt);if(E&&(et=et||0),et===void 0){$e(rt-1,void 0,!0);break}if(Xe+=et,je===0&&Xe<=R||rt===je-1&&Xe+xe(je)<=R){$e(je,null);break}else if(Xe+se>R){$e(rt-1,Xe-et-X+W);break}}b&&xe(0)+X>R&&re(null)}},[R,j,W,X,Ce,Se]);var Re=oe&&!!Fe.length,it={};Y!==null&&we&&(it={position:"absolute",left:Y,top:0});var dt={prefixCls:ge,responsive:we,component:$,invalidate:Me},Oe=s?function(Xe,He){var je=Ce(Xe,He);return i.createElement(wl.Provider,{key:je,value:k(k({},dt),{},{order:He,item:Xe,itemKey:je,registerSize:Ie,display:He<=de})},s(Xe,He))}:function(Xe,He){var je=Ce(Xe,He);return i.createElement(Fa,ue({},dt,{order:He,key:je,item:Xe,renderItem:me,itemKey:je,registerSize:Ie,display:He<=de}))},Le={order:Re?de:Number.MAX_SAFE_INTEGER,className:"".concat(ge,"-rest"),registerSize:fe,display:Re},Ue=h||tP,ke=p?i.createElement(wl.Provider,{value:k(k({},dt),Le)},p(Fe)):i.createElement(Fa,ue({},dt,Le),typeof Ue=="function"?Ue(Fe):Ue),Je=i.createElement(C,ue({className:A(!Me&&r,v),style:m,ref:t},x),Se.map(Oe),Te?ke:null,b&&i.createElement(Fa,ue({},dt,{responsive:be,responsiveDisabled:!we,order:de,className:"".concat(ge,"-suffix"),registerSize:ve,display:!0,style:it}),b));return be?i.createElement(Bn,{onResize:Ee,disabled:!we},Je):Je}var Rr=i.forwardRef(nP);Rr.displayName="Overflow";Rr.Item=Eb;Rr.RESPONSIVE=Ob;Rr.INVALIDATE=Ib;function rP(e,t,n){var r=k(k({},e),t);return Object.keys(t).forEach(function(o){var a=t[o];typeof a=="function"&&(r[o]=function(){for(var l,s=arguments.length,c=new Array(s),u=0;u<s;u++)c[u]=arguments[u];return a.apply(void 0,c),(l=e[o])===null||l===void 0?void 0:l.call.apply(l,[e].concat(c))})}),r}var oP=["prefixCls","id","inputElement","autoFocus","autoComplete","editable","activeDescendantId","value","open","attrs"],aP=function(t,n){var r=t.prefixCls,o=t.id,a=t.inputElement,l=t.autoFocus,s=t.autoComplete,c=t.editable,u=t.activeDescendantId,d=t.value,f=t.open,m=t.attrs,v=ft(t,oP),g=a||i.createElement("input",null),h=g,p=h.ref,b=h.props;return"maxLength"in g.props,g=i.cloneElement(g,k(k(k({type:"search"},rP(v,b)),{},{id:o,ref:un(n,p),autoComplete:s||"off",autoFocus:l,className:A("".concat(r,"-selection-search-input"),b==null?void 0:b.className),role:"combobox","aria-expanded":f||!1,"aria-haspopup":"listbox","aria-owns":"".concat(o,"_list"),"aria-autocomplete":"list","aria-controls":"".concat(o,"_list"),"aria-activedescendant":f?u:void 0},m),{},{value:c?d:"",readOnly:!c,unselectable:c?null:"on",style:k(k({},b.style),{},{opacity:c?null:0})})),g},Rb=i.forwardRef(aP);function Pb(e){return Array.isArray(e)?e:e!==void 0?[e]:[]}var iP=typeof window<"u"&&window.document&&window.document.documentElement,lP=iP;function sP(e){return e!=null}function cP(e){return!e&&e!==0}function Sv(e){return["string","number"].includes(Qe(e))}function Nb(e){var t=void 0;return e&&(Sv(e.title)?t=e.title.toString():Sv(e.label)&&(t=e.label.toString())),t}function uP(e,t){lP?i.useLayoutEffect(e,t):i.useEffect(e,t)}function dP(e){var t;return(t=e.key)!==null&&t!==void 0?t:e.value}var $v=function(t){t.preventDefault(),t.stopPropagation()},fP=function(t){var n=t.id,r=t.prefixCls,o=t.values,a=t.open,l=t.searchValue,s=t.autoClearSearchValue,c=t.inputRef,u=t.placeholder,d=t.disabled,f=t.mode,m=t.showSearch,v=t.autoFocus,g=t.autoComplete,h=t.activeDescendantId,p=t.tabIndex,b=t.removeIcon,y=t.maxTagCount,C=t.maxTagTextLength,$=t.maxTagPlaceholder,S=$===void 0?function(ne){return"+ ".concat(ne.length," ...")}:$,x=t.tagRender,E=t.onToggleOpen,O=t.onRemove,w=t.onInputChange,I=t.onInputPaste,P=t.onInputKeyDown,M=t.onInputMouseDown,R=t.onInputCompositionStart,N=t.onInputCompositionEnd,T=t.onInputBlur,j=i.useRef(null),z=i.useState(0),_=J(z,2),B=_[0],V=_[1],G=i.useState(!1),q=J(G,2),H=q[0],W=q[1],K="".concat(r,"-selection"),U=a||f==="multiple"&&s===!1||f==="tags"?l:"",te=f==="tags"||f==="multiple"&&s===!1||m&&(a||H);uP(function(){V(j.current.scrollWidth)},[U]);var X=function(Z,Q,ie,de,he){return i.createElement("span",{title:Nb(Z),className:A("".concat(K,"-item"),D({},"".concat(K,"-item-disabled"),ie))},i.createElement("span",{className:"".concat(K,"-item-content")},Q),de&&i.createElement(Cs,{className:"".concat(K,"-item-remove"),onMouseDown:$v,onClick:he,customizeIcon:b},"×"))},ae=function(Z,Q,ie,de,he,ye){var oe=function(ge){$v(ge),E(!a)};return i.createElement("span",{onMouseDown:oe},x({label:Q,value:Z,disabled:ie,closable:de,onClose:he,isMaxTag:!!ye}))},le=function(Z){var Q=Z.disabled,ie=Z.label,de=Z.value,he=!d&&!Q,ye=ie;if(typeof C=="number"&&(typeof ie=="string"||typeof ie=="number")){var oe=String(ye);oe.length>C&&(ye="".concat(oe.slice(0,C),"..."))}var ce=function(se){se&&se.stopPropagation(),O(Z)};return typeof x=="function"?ae(de,ye,Q,he,ce):X(Z,ye,Q,he,ce)},ee=function(Z){if(!o.length)return null;var Q=typeof S=="function"?S(Z):S;return typeof x=="function"?ae(void 0,Q,!1,!1,void 0,!0):X({title:Q},Q,!1)},Y=i.createElement("div",{className:"".concat(K,"-search"),style:{width:B},onFocus:function(){W(!0)},onBlur:function(){W(!1)}},i.createElement(Rb,{ref:c,open:a,prefixCls:r,id:n,inputElement:null,disabled:d,autoFocus:v,autoComplete:g,editable:te,activeDescendantId:h,value:U,onKeyDown:P,onMouseDown:M,onChange:w,onPaste:I,onCompositionStart:R,onCompositionEnd:N,onBlur:T,tabIndex:p,attrs:rn(t,!0)}),i.createElement("span",{ref:j,className:"".concat(K,"-search-mirror"),"aria-hidden":!0},U," ")),re=i.createElement(Rr,{prefixCls:"".concat(K,"-overflow"),data:o,renderItem:le,renderRest:ee,suffix:Y,itemKey:dP,maxCount:y});return i.createElement("span",{className:"".concat(K,"-wrap")},re,!o.length&&!U&&i.createElement("span",{className:"".concat(K,"-placeholder")},u))},mP=function(t){var n=t.inputElement,r=t.prefixCls,o=t.id,a=t.inputRef,l=t.disabled,s=t.autoFocus,c=t.autoComplete,u=t.activeDescendantId,d=t.mode,f=t.open,m=t.values,v=t.placeholder,g=t.tabIndex,h=t.showSearch,p=t.searchValue,b=t.activeValue,y=t.maxLength,C=t.onInputKeyDown,$=t.onInputMouseDown,S=t.onInputChange,x=t.onInputPaste,E=t.onInputCompositionStart,O=t.onInputCompositionEnd,w=t.onInputBlur,I=t.title,P=i.useState(!1),M=J(P,2),R=M[0],N=M[1],T=d==="combobox",j=T||h,z=m[0],_=p||"";T&&b&&!R&&(_=b),i.useEffect(function(){T&&N(!1)},[T,b]);var B=d!=="combobox"&&!f&&!h?!1:!!_,V=I===void 0?Nb(z):I,G=i.useMemo(function(){return z?null:i.createElement("span",{className:"".concat(r,"-selection-placeholder"),style:B?{visibility:"hidden"}:void 0},v)},[z,B,v,r]);return i.createElement("span",{className:"".concat(r,"-selection-wrap")},i.createElement("span",{className:"".concat(r,"-selection-search")},i.createElement(Rb,{ref:a,prefixCls:r,id:o,open:f,inputElement:n,disabled:l,autoFocus:s,autoComplete:c,editable:j,activeDescendantId:u,value:_,onKeyDown:C,onMouseDown:$,onChange:function(H){N(!0),S(H)},onPaste:x,onCompositionStart:E,onCompositionEnd:O,onBlur:w,tabIndex:g,attrs:rn(t,!0),maxLength:T?y:void 0})),!T&&z?i.createElement("span",{className:"".concat(r,"-selection-item"),title:V,style:B?{visibility:"hidden"}:void 0},z.label):null,G)},vP=function(t,n){var r=i.useRef(null),o=i.useRef(!1),a=t.prefixCls,l=t.open,s=t.mode,c=t.showSearch,u=t.tokenWithEnter,d=t.disabled,f=t.prefix,m=t.autoClearSearchValue,v=t.onSearch,g=t.onSearchSubmit,h=t.onToggleOpen,p=t.onInputKeyDown,b=t.onInputBlur,y=t.domRef;i.useImperativeHandle(n,function(){return{focus:function(V){r.current.focus(V)},blur:function(){r.current.blur()}}});var C=wb(0),$=J(C,2),S=$[0],x=$[1],E=function(V){var G=V.which,q=r.current instanceof HTMLTextAreaElement;!q&&l&&(G===Ne.UP||G===Ne.DOWN)&&V.preventDefault(),p&&p(V),G===Ne.ENTER&&s==="tags"&&!o.current&&!l&&(g==null||g(V.target.value)),!(q&&!l&&~[Ne.UP,Ne.DOWN,Ne.LEFT,Ne.RIGHT].indexOf(G))&&KR(G)&&h(!0)},O=function(){x(!0)},w=i.useRef(null),I=function(V){v(V,!0,o.current)!==!1&&h(!0)},P=function(){o.current=!0},M=function(V){o.current=!1,s!=="combobox"&&I(V.target.value)},R=function(V){var G=V.target.value;if(u&&w.current&&/[\r\n]/.test(w.current)){var q=w.current.replace(/[\r\n]+$/,"").replace(/\r\n/g," ").replace(/[\r\n]/g," ");G=G.replace(q,w.current)}w.current=null,I(G)},N=function(V){var G=V.clipboardData,q=G==null?void 0:G.getData("text");w.current=q||""},T=function(V){var G=V.target;if(G!==r.current){var q=document.body.style.msTouchAction!==void 0;q?setTimeout(function(){r.current.focus()}):r.current.focus()}},j=function(V){var G=S();V.target!==r.current&&!G&&!(s==="combobox"&&d)&&V.preventDefault(),(s!=="combobox"&&(!c||!G)||!l)&&(l&&m!==!1&&v("",!0,!1),h())},z={inputRef:r,onInputKeyDown:E,onInputMouseDown:O,onInputChange:R,onInputPaste:N,onInputCompositionStart:P,onInputCompositionEnd:M,onInputBlur:b},_=s==="multiple"||s==="tags"?i.createElement(fP,ue({},t,z)):i.createElement(mP,ue({},t,z));return i.createElement("div",{ref:y,className:"".concat(a,"-selector"),onClick:T,onMouseDown:j},f&&i.createElement("div",{className:"".concat(a,"-prefix")},f),_)},gP=i.forwardRef(vP);function pP(e){var t=e.prefixCls,n=e.align,r=e.arrow,o=e.arrowPos,a=r||{},l=a.className,s=a.content,c=o.x,u=c===void 0?0:c,d=o.y,f=d===void 0?0:d,m=i.useRef();if(!n||!n.points)return null;var v={position:"absolute"};if(n.autoArrow!==!1){var g=n.points[0],h=n.points[1],p=g[0],b=g[1],y=h[0],C=h[1];p===y||!["t","b"].includes(p)?v.top=f:p==="t"?v.top=0:v.bottom=0,b===C||!["l","r"].includes(b)?v.left=u:b==="l"?v.left=0:v.right=0}return i.createElement("div",{ref:m,className:A("".concat(t,"-arrow"),l),style:v},s)}function hP(e){var t=e.prefixCls,n=e.open,r=e.zIndex,o=e.mask,a=e.motion;return o?i.createElement(En,ue({},a,{motionAppear:!0,visible:n,removeOnLeave:!0}),function(l){var s=l.className;return i.createElement("div",{style:{zIndex:r},className:A("".concat(t,"-mask"),s)})}):null}var bP=i.memo(function(e){var t=e.children;return t},function(e,t){return t.cache}),yP=i.forwardRef(function(e,t){var n=e.popup,r=e.className,o=e.prefixCls,a=e.style,l=e.target,s=e.onVisibleChanged,c=e.open,u=e.keepDom,d=e.fresh,f=e.onClick,m=e.mask,v=e.arrow,g=e.arrowPos,h=e.align,p=e.motion,b=e.maskMotion,y=e.forceRender,C=e.getPopupContainer,$=e.autoDestroy,S=e.portal,x=e.zIndex,E=e.onMouseEnter,O=e.onMouseLeave,w=e.onPointerEnter,I=e.onPointerDownCapture,P=e.ready,M=e.offsetX,R=e.offsetY,N=e.offsetR,T=e.offsetB,j=e.onAlign,z=e.onPrepare,_=e.stretch,B=e.targetWidth,V=e.targetHeight,G=typeof n=="function"?n():n,q=c||u,H=(C==null?void 0:C.length)>0,W=i.useState(!C||!H),K=J(W,2),U=K[0],te=K[1];if(wt(function(){!U&&H&&l&&te(!0)},[U,H,l]),!U)return null;var X="auto",ae={left:"-1000vw",top:"-1000vh",right:X,bottom:X};if(P||!c){var le,ee=h.points,Y=h.dynamicInset||((le=h._experimental)===null||le===void 0?void 0:le.dynamicInset),re=Y&&ee[0][1]==="r",ne=Y&&ee[0][0]==="b";re?(ae.right=N,ae.left=X):(ae.left=M,ae.right=X),ne?(ae.bottom=T,ae.top=X):(ae.top=R,ae.bottom=X)}var Z={};return _&&(_.includes("height")&&V?Z.height=V:_.includes("minHeight")&&V&&(Z.minHeight=V),_.includes("width")&&B?Z.width=B:_.includes("minWidth")&&B&&(Z.minWidth=B)),c||(Z.pointerEvents="none"),i.createElement(S,{open:y||q,getContainer:C&&function(){return C(l)},autoDestroy:$},i.createElement(hP,{prefixCls:o,open:c,zIndex:x,mask:m,motion:b}),i.createElement(Bn,{onResize:j,disabled:!c},function(Q){return i.createElement(En,ue({motionAppear:!0,motionEnter:!0,motionLeave:!0,removeOnLeave:!1,forceRender:y,leavedClassName:"".concat(o,"-hidden")},p,{onAppearPrepare:z,onEnterPrepare:z,visible:c,onVisibleChanged:function(de){var he;p==null||(he=p.onVisibleChanged)===null||he===void 0||he.call(p,de),s(de)}}),function(ie,de){var he=ie.className,ye=ie.style,oe=A(o,he,r);return i.createElement("div",{ref:un(Q,t,de),className:oe,style:k(k(k(k({"--arrow-x":"".concat(g.x||0,"px"),"--arrow-y":"".concat(g.y||0,"px")},ae),Z),ye),{},{boxSizing:"border-box",zIndex:x},a),onMouseEnter:E,onMouseLeave:O,onPointerEnter:w,onClick:f,onPointerDownCapture:I},v&&i.createElement(pP,{prefixCls:o,arrow:v,arrowPos:g,align:h}),i.createElement(bP,{cache:!c&&!d},G))})}))}),CP=i.forwardRef(function(e,t){var n=e.children,r=e.getTriggerDOMNode,o=Nr(n),a=i.useCallback(function(s){Ka(t,r?r(s):s)},[r]),l=zr(a,$o(n));return o?i.cloneElement(n,{ref:l}):n}),xv=i.createContext(null);function wv(e){return e?Array.isArray(e)?e:[e]:[]}function SP(e,t,n,r){return i.useMemo(function(){var o=wv(n??t),a=wv(r??t),l=new Set(o),s=new Set(a);return e&&(l.has("hover")&&(l.delete("hover"),l.add("click")),s.has("hover")&&(s.delete("hover"),s.add("click"))),[l,s]},[e,t,n,r])}function $P(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],n=arguments.length>2?arguments[2]:void 0;return n?e[0]===t[0]:e[0]===t[0]&&e[1]===t[1]}function xP(e,t,n,r){for(var o=n.points,a=Object.keys(e),l=0;l<a.length;l+=1){var s,c=a[l];if($P((s=e[c])===null||s===void 0?void 0:s.points,o,r))return"".concat(t,"-placement-").concat(c)}return""}function Ev(e,t,n,r){return t||(n?{motionName:"".concat(e,"-").concat(n)}:r?{motionName:r}:null)}function hi(e){return e.ownerDocument.defaultView}function ku(e){for(var t=[],n=e==null?void 0:e.parentElement,r=["hidden","scroll","clip","auto"];n;){var o=hi(n).getComputedStyle(n),a=o.overflowX,l=o.overflowY,s=o.overflow;[a,l,s].some(function(c){return r.includes(c)})&&t.push(n),n=n.parentElement}return t}function Za(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:1;return Number.isNaN(e)?t:e}function Ra(e){return Za(parseFloat(e),0)}function Ov(e,t){var n=k({},e);return(t||[]).forEach(function(r){if(!(r instanceof HTMLBodyElement||r instanceof HTMLHtmlElement)){var o=hi(r).getComputedStyle(r),a=o.overflow,l=o.overflowClipMargin,s=o.borderTopWidth,c=o.borderBottomWidth,u=o.borderLeftWidth,d=o.borderRightWidth,f=r.getBoundingClientRect(),m=r.offsetHeight,v=r.clientHeight,g=r.offsetWidth,h=r.clientWidth,p=Ra(s),b=Ra(c),y=Ra(u),C=Ra(d),$=Za(Math.round(f.width/g*1e3)/1e3),S=Za(Math.round(f.height/m*1e3)/1e3),x=(g-h-y-C)*$,E=(m-v-p-b)*S,O=p*S,w=b*S,I=y*$,P=C*$,M=0,R=0;if(a==="clip"){var N=Ra(l);M=N*$,R=N*S}var T=f.x+I-M,j=f.y+O-R,z=T+f.width+2*M-I-P-x,_=j+f.height+2*R-O-w-E;n.left=Math.max(n.left,T),n.top=Math.max(n.top,j),n.right=Math.min(n.right,z),n.bottom=Math.min(n.bottom,_)}}),n}function Iv(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0,n="".concat(t),r=n.match(/^(.*)\%$/);return r?e*(parseFloat(r[1])/100):parseFloat(n)}function Rv(e,t){var n=t||[],r=J(n,2),o=r[0],a=r[1];return[Iv(e.width,o),Iv(e.height,a)]}function Pv(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:"";return[e[0],e[1]]}function Mo(e,t){var n=t[0],r=t[1],o,a;return n==="t"?a=e.y:n==="b"?a=e.y+e.height:a=e.y+e.height/2,r==="l"?o=e.x:r==="r"?o=e.x+e.width:o=e.x+e.width/2,{x:o,y:a}}function Vr(e,t){var n={t:"b",b:"t",l:"r",r:"l"};return e.map(function(r,o){return o===t?n[r]||"c":r}).join("")}function wP(e,t,n,r,o,a,l){var s=i.useState({ready:!1,offsetX:0,offsetY:0,offsetR:0,offsetB:0,arrowX:0,arrowY:0,scaleX:1,scaleY:1,align:o[r]||{}}),c=J(s,2),u=c[0],d=c[1],f=i.useRef(0),m=i.useMemo(function(){return t?ku(t):[]},[t]),v=i.useRef({}),g=function(){v.current={}};e||g();var h=Nt(function(){if(t&&n&&e){let Wt=function(qn,Pn){var Fn=arguments.length>2&&arguments[2]!==void 0?arguments[2]:be,_r=q.x+qn,Ii=q.y+Pn,Fs=_r+ne,ks=Ii+re,Vs=Math.max(_r,Fn.left),pt=Math.max(Ii,Fn.top),xt=Math.min(Fs,Fn.right),en=Math.min(ks,Fn.bottom);return Math.max(0,(xt-Vs)*(en-pt))},Gn=function(){Pt=q.y+rt,Rt=Pt+re,jt=q.x+je,zt=jt+ne};var y,C,$,S,x=t,E=x.ownerDocument,O=hi(x),w=O.getComputedStyle(x),I=w.position,P=x.style.left,M=x.style.top,R=x.style.right,N=x.style.bottom,T=x.style.overflow,j=k(k({},o[r]),a),z=E.createElement("div");(y=x.parentElement)===null||y===void 0||y.appendChild(z),z.style.left="".concat(x.offsetLeft,"px"),z.style.top="".concat(x.offsetTop,"px"),z.style.position=I,z.style.height="".concat(x.offsetHeight,"px"),z.style.width="".concat(x.offsetWidth,"px"),x.style.left="0",x.style.top="0",x.style.right="auto",x.style.bottom="auto",x.style.overflow="hidden";var _;if(Array.isArray(n))_={x:n[0],y:n[1],width:0,height:0};else{var B,V,G=n.getBoundingClientRect();G.x=(B=G.x)!==null&&B!==void 0?B:G.left,G.y=(V=G.y)!==null&&V!==void 0?V:G.top,_={x:G.x,y:G.y,width:G.width,height:G.height}}var q=x.getBoundingClientRect(),H=O.getComputedStyle(x),W=H.height,K=H.width;q.x=(C=q.x)!==null&&C!==void 0?C:q.left,q.y=($=q.y)!==null&&$!==void 0?$:q.top;var U=E.documentElement,te=U.clientWidth,X=U.clientHeight,ae=U.scrollWidth,le=U.scrollHeight,ee=U.scrollTop,Y=U.scrollLeft,re=q.height,ne=q.width,Z=_.height,Q=_.width,ie={left:0,top:0,right:te,bottom:X},de={left:-Y,top:-ee,right:ae-Y,bottom:le-ee},he=j.htmlRegion,ye="visible",oe="visibleFirst";he!=="scroll"&&he!==oe&&(he=ye);var ce=he===oe,ge=Ov(de,m),se=Ov(ie,m),be=he===ye?se:ge,we=ce?se:be;x.style.left="auto",x.style.top="auto",x.style.right="0",x.style.bottom="0";var Me=x.getBoundingClientRect();x.style.left=P,x.style.top=M,x.style.right=R,x.style.bottom=N,x.style.overflow=T,(S=x.parentElement)===null||S===void 0||S.removeChild(z);var Te=Za(Math.round(ne/parseFloat(K)*1e3)/1e3),Se=Za(Math.round(re/parseFloat(W)*1e3)/1e3);if(Te===0||Se===0||Wa(n)&&!as(n))return;var Fe=j.offset,Ce=j.targetOffset,me=Rv(q,Fe),$e=J(me,2),Ee=$e[0],Ie=$e[1],fe=Rv(_,Ce),ve=J(fe,2),xe=ve[0],Re=ve[1];_.x-=xe,_.y-=Re;var it=j.points||[],dt=J(it,2),Oe=dt[0],Le=dt[1],Ue=Pv(Le),ke=Pv(Oe),Je=Mo(_,Ue),Xe=Mo(q,ke),He=k({},j),je=Je.x-Xe.x+Ee,rt=Je.y-Xe.y+Ie,et=Wt(je,rt),Pe=Wt(je,rt,se),qe=Mo(_,["t","l"]),We=Mo(q,["t","l"]),tt=Mo(_,["b","r"]),mt=Mo(q,["b","r"]),ct=j.overflow||{},Ke=ct.adjustX,Ye=ct.adjustY,at=ct.shiftX,gt=ct.shiftY,Ot=function(Pn){return typeof Pn=="boolean"?Pn:Pn>=0},Pt,Rt,jt,zt;Gn();var Dt=Ot(Ye),De=ke[0]===Ue[0];if(Dt&&ke[0]==="t"&&(Rt>we.bottom||v.current.bt)){var Ze=rt;De?Ze-=re-Z:Ze=qe.y-mt.y-Ie;var Ge=Wt(je,Ze),Be=Wt(je,Ze,se);Ge>et||Ge===et&&(!ce||Be>=Pe)?(v.current.bt=!0,rt=Ze,Ie=-Ie,He.points=[Vr(ke,0),Vr(Ue,0)]):v.current.bt=!1}if(Dt&&ke[0]==="b"&&(Pt<we.top||v.current.tb)){var ze=rt;De?ze+=re-Z:ze=tt.y-We.y-Ie;var _e=Wt(je,ze),lt=Wt(je,ze,se);_e>et||_e===et&&(!ce||lt>=Pe)?(v.current.tb=!0,rt=ze,Ie=-Ie,He.points=[Vr(ke,0),Vr(Ue,0)]):v.current.tb=!1}var Ct=Ot(Ke),Ae=ke[1]===Ue[1];if(Ct&&ke[1]==="l"&&(zt>we.right||v.current.rl)){var nt=je;Ae?nt-=ne-Q:nt=qe.x-mt.x-Ee;var ht=Wt(nt,rt),Ft=Wt(nt,rt,se);ht>et||ht===et&&(!ce||Ft>=Pe)?(v.current.rl=!0,je=nt,Ee=-Ee,He.points=[Vr(ke,1),Vr(Ue,1)]):v.current.rl=!1}if(Ct&&ke[1]==="r"&&(jt<we.left||v.current.lr)){var qt=je;Ae?qt+=ne-Q:qt=tt.x-We.x-Ee;var Qt=Wt(qt,rt),ln=Wt(qt,rt,se);Qt>et||Qt===et&&(!ce||ln>=Pe)?(v.current.lr=!0,je=qt,Ee=-Ee,He.points=[Vr(ke,1),Vr(Ue,1)]):v.current.lr=!1}Gn();var on=at===!0?0:at;typeof on=="number"&&(jt<se.left&&(je-=jt-se.left-Ee,_.x+Q<se.left+on&&(je+=_.x-se.left+Q-on)),zt>se.right&&(je-=zt-se.right-Ee,_.x>se.right-on&&(je+=_.x-se.right+on)));var Tn=gt===!0?0:gt;typeof Tn=="number"&&(Pt<se.top&&(rt-=Pt-se.top-Ie,_.y+Z<se.top+Tn&&(rt+=_.y-se.top+Z-Tn)),Rt>se.bottom&&(rt-=Rt-se.bottom-Ie,_.y>se.bottom-Tn&&(rt+=_.y-se.bottom+Tn)));var On=q.x+je,In=On+ne,An=q.y+rt,At=An+re,ut=_.x,st=ut+Q,_t=_.y,Ht=_t+Z,Vt=Math.max(On,ut),Xt=Math.min(In,st),vn=(Vt+Xt)/2,dn=vn-On,gn=Math.max(An,_t),pn=Math.min(At,Ht),Rn=(gn+pn)/2,St=Rn-An;l==null||l(t,He);var bt=Me.right-q.x-(je+q.width),nn=Me.bottom-q.y-(rt+q.height);Te===1&&(je=Math.round(je),bt=Math.round(bt)),Se===1&&(rt=Math.round(rt),nn=Math.round(nn));var jn={ready:!0,offsetX:je/Te,offsetY:rt/Se,offsetR:bt/Te,offsetB:nn/Se,arrowX:dn/Te,arrowY:St/Se,scaleX:Te,scaleY:Se,align:He};d(jn)}}),p=function(){f.current+=1;var C=f.current;Promise.resolve().then(function(){f.current===C&&h()})},b=function(){d(function(C){return k(k({},C),{},{ready:!1})})};return wt(b,[r]),wt(function(){e||b()},[e]),[u.ready,u.offsetX,u.offsetY,u.offsetR,u.offsetB,u.arrowX,u.arrowY,u.scaleX,u.scaleY,u.align,p]}function EP(e,t,n,r,o){wt(function(){if(e&&t&&n){let f=function(){r(),o()};var a=t,l=n,s=ku(a),c=ku(l),u=hi(l),d=new Set([u].concat(pe(s),pe(c)));return d.forEach(function(m){m.addEventListener("scroll",f,{passive:!0})}),u.addEventListener("resize",f,{passive:!0}),r(),function(){d.forEach(function(m){m.removeEventListener("scroll",f),u.removeEventListener("resize",f)})}}},[e,t,n])}function OP(e,t,n,r,o,a,l,s){var c=i.useRef(e);c.current=e;var u=i.useRef(!1);i.useEffect(function(){if(t&&r&&(!o||a)){var f=function(){u.current=!1},m=function(p){var b;c.current&&!l(((b=p.composedPath)===null||b===void 0||(b=b.call(p))===null||b===void 0?void 0:b[0])||p.target)&&!u.current&&s(!1)},v=hi(r);v.addEventListener("pointerdown",f,!0),v.addEventListener("mousedown",m,!0),v.addEventListener("contextmenu",m,!0);var g=bl(n);return g&&(g.addEventListener("mousedown",m,!0),g.addEventListener("contextmenu",m,!0)),function(){v.removeEventListener("pointerdown",f,!0),v.removeEventListener("mousedown",m,!0),v.removeEventListener("contextmenu",m,!0),g&&(g.removeEventListener("mousedown",m,!0),g.removeEventListener("contextmenu",m,!0))}}},[t,n,r,o,a]);function d(){u.current=!0}return d}var IP=["prefixCls","children","action","showAction","hideAction","popupVisible","defaultPopupVisible","onPopupVisibleChange","afterPopupVisibleChange","mouseEnterDelay","mouseLeaveDelay","focusDelay","blurDelay","mask","maskClosable","getPopupContainer","forceRender","autoDestroy","destroyPopupOnHide","popup","popupClassName","popupStyle","popupPlacement","builtinPlacements","popupAlign","zIndex","stretch","getPopupClassNameFromAlign","fresh","alignPoint","onPopupClick","onPopupAlign","arrow","popupMotion","maskMotion","popupTransitionName","popupAnimation","maskTransitionName","maskAnimation","className","getTriggerDOMNode"];function RP(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:ps,t=i.forwardRef(function(n,r){var o=n.prefixCls,a=o===void 0?"rc-trigger-popup":o,l=n.children,s=n.action,c=s===void 0?"hover":s,u=n.showAction,d=n.hideAction,f=n.popupVisible,m=n.defaultPopupVisible,v=n.onPopupVisibleChange,g=n.afterPopupVisibleChange,h=n.mouseEnterDelay,p=n.mouseLeaveDelay,b=p===void 0?.1:p,y=n.focusDelay,C=n.blurDelay,$=n.mask,S=n.maskClosable,x=S===void 0?!0:S,E=n.getPopupContainer,O=n.forceRender,w=n.autoDestroy,I=n.destroyPopupOnHide,P=n.popup,M=n.popupClassName,R=n.popupStyle,N=n.popupPlacement,T=n.builtinPlacements,j=T===void 0?{}:T,z=n.popupAlign,_=n.zIndex,B=n.stretch,V=n.getPopupClassNameFromAlign,G=n.fresh,q=n.alignPoint,H=n.onPopupClick,W=n.onPopupAlign,K=n.arrow,U=n.popupMotion,te=n.maskMotion,X=n.popupTransitionName,ae=n.popupAnimation,le=n.maskTransitionName,ee=n.maskAnimation,Y=n.className,re=n.getTriggerDOMNode,ne=ft(n,IP),Z=w||I||!1,Q=i.useState(!1),ie=J(Q,2),de=ie[0],he=ie[1];wt(function(){he(ys())},[]);var ye=i.useRef({}),oe=i.useContext(xv),ce=i.useMemo(function(){return{registerSubPopup:function(xt,en){ye.current[xt]=en,oe==null||oe.registerSubPopup(xt,en)}}},[oe]),ge=mi(),se=i.useState(null),be=J(se,2),we=be[0],Me=be[1],Te=i.useRef(null),Se=Nt(function(pt){Te.current=pt,Wa(pt)&&we!==pt&&Me(pt),oe==null||oe.registerSubPopup(ge,pt)}),Fe=i.useState(null),Ce=J(Fe,2),me=Ce[0],$e=Ce[1],Ee=i.useRef(null),Ie=Nt(function(pt){Wa(pt)&&me!==pt&&($e(pt),Ee.current=pt)}),fe=i.Children.only(l),ve=(fe==null?void 0:fe.props)||{},xe={},Re=Nt(function(pt){var xt,en,hn=me;return(hn==null?void 0:hn.contains(pt))||((xt=bl(hn))===null||xt===void 0?void 0:xt.host)===pt||pt===hn||(we==null?void 0:we.contains(pt))||((en=bl(we))===null||en===void 0?void 0:en.host)===pt||pt===we||Object.values(ye.current).some(function(an){return(an==null?void 0:an.contains(pt))||pt===an})}),it=Ev(a,U,ae,X),dt=Ev(a,te,ee,le),Oe=i.useState(m||!1),Le=J(Oe,2),Ue=Le[0],ke=Le[1],Je=f??Ue,Xe=Nt(function(pt){f===void 0&&ke(pt)});wt(function(){ke(f||!1)},[f]);var He=i.useRef(Je);He.current=Je;var je=i.useRef([]);je.current=[];var rt=Nt(function(pt){var xt;Xe(pt),((xt=je.current[je.current.length-1])!==null&&xt!==void 0?xt:Je)!==pt&&(je.current.push(pt),v==null||v(pt))}),et=i.useRef(),Pe=function(){clearTimeout(et.current)},qe=function(xt){var en=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0;Pe(),en===0?rt(xt):et.current=setTimeout(function(){rt(xt)},en*1e3)};i.useEffect(function(){return Pe},[]);var We=i.useState(!1),tt=J(We,2),mt=tt[0],ct=tt[1];wt(function(pt){(!pt||Je)&&ct(!0)},[Je]);var Ke=i.useState(null),Ye=J(Ke,2),at=Ye[0],gt=Ye[1],Ot=i.useState(null),Pt=J(Ot,2),Rt=Pt[0],jt=Pt[1],zt=function(xt){jt([xt.clientX,xt.clientY])},Dt=wP(Je,we,q&&Rt!==null?Rt:me,N,j,z,W),De=J(Dt,11),Ze=De[0],Ge=De[1],Be=De[2],ze=De[3],_e=De[4],lt=De[5],Ct=De[6],Ae=De[7],nt=De[8],ht=De[9],Ft=De[10],qt=SP(de,c,u,d),Qt=J(qt,2),ln=Qt[0],on=Qt[1],Tn=ln.has("click"),On=on.has("click")||on.has("contextMenu"),In=Nt(function(){mt||Ft()}),An=function(){He.current&&q&&On&&qe(!1)};EP(Je,me,we,In,An),wt(function(){In()},[Rt,N]),wt(function(){Je&&!(j!=null&&j[N])&&In()},[JSON.stringify(z)]);var At=i.useMemo(function(){var pt=xP(j,a,ht,q);return A(pt,V==null?void 0:V(ht))},[ht,V,j,a,q]);i.useImperativeHandle(r,function(){return{nativeElement:Ee.current,popupElement:Te.current,forceAlign:In}});var ut=i.useState(0),st=J(ut,2),_t=st[0],Ht=st[1],Vt=i.useState(0),Xt=J(Vt,2),vn=Xt[0],dn=Xt[1],gn=function(){if(B&&me){var xt=me.getBoundingClientRect();Ht(xt.width),dn(xt.height)}},pn=function(){gn(),In()},Rn=function(xt){ct(!1),Ft(),g==null||g(xt)},St=function(){return new Promise(function(xt){gn(),gt(function(){return xt})})};wt(function(){at&&(Ft(),at(),gt(null))},[at]);function bt(pt,xt,en,hn){xe[pt]=function(an){var Ri;hn==null||hn(an),qe(xt,en);for(var Ws=arguments.length,Vf=new Array(Ws>1?Ws-1:0),Pi=1;Pi<Ws;Pi++)Vf[Pi-1]=arguments[Pi];(Ri=ve[pt])===null||Ri===void 0||Ri.call.apply(Ri,[ve,an].concat(Vf))}}(Tn||On)&&(xe.onClick=function(pt){var xt;He.current&&On?qe(!1):!He.current&&Tn&&(zt(pt),qe(!0));for(var en=arguments.length,hn=new Array(en>1?en-1:0),an=1;an<en;an++)hn[an-1]=arguments[an];(xt=ve.onClick)===null||xt===void 0||xt.call.apply(xt,[ve,pt].concat(hn))});var nn=OP(Je,On,me,we,$,x,Re,qe),jn=ln.has("hover"),Wt=on.has("hover"),Gn,qn;jn&&(bt("onMouseEnter",!0,h,function(pt){zt(pt)}),bt("onPointerEnter",!0,h,function(pt){zt(pt)}),Gn=function(xt){(Je||mt)&&we!==null&&we!==void 0&&we.contains(xt.target)&&qe(!0,h)},q&&(xe.onMouseMove=function(pt){var xt;(xt=ve.onMouseMove)===null||xt===void 0||xt.call(ve,pt)})),Wt&&(bt("onMouseLeave",!1,b),bt("onPointerLeave",!1,b),qn=function(){qe(!1,b)}),ln.has("focus")&&bt("onFocus",!0,y),on.has("focus")&&bt("onBlur",!1,C),ln.has("contextMenu")&&(xe.onContextMenu=function(pt){var xt;He.current&&on.has("contextMenu")?qe(!1):(zt(pt),qe(!0)),pt.preventDefault();for(var en=arguments.length,hn=new Array(en>1?en-1:0),an=1;an<en;an++)hn[an-1]=arguments[an];(xt=ve.onContextMenu)===null||xt===void 0||xt.call.apply(xt,[ve,pt].concat(hn))}),Y&&(xe.className=A(ve.className,Y));var Pn=i.useRef(!1);Pn.current||(Pn.current=O||Je||mt);var Fn=k(k({},ve),xe),_r={},Ii=["onContextMenu","onClick","onMouseDown","onTouchStart","onMouseEnter","onMouseLeave","onFocus","onBlur"];Ii.forEach(function(pt){ne[pt]&&(_r[pt]=function(){for(var xt,en=arguments.length,hn=new Array(en),an=0;an<en;an++)hn[an]=arguments[an];(xt=Fn[pt])===null||xt===void 0||xt.call.apply(xt,[Fn].concat(hn)),ne[pt].apply(ne,hn)})});var Fs=i.cloneElement(fe,k(k({},Fn),_r)),ks={x:lt,y:Ct},Vs=K?k({},K!==!0?K:{}):null;return i.createElement(i.Fragment,null,i.createElement(Bn,{disabled:!Je,ref:Ie,onResize:pn},i.createElement(CP,{getTriggerDOMNode:re},Fs)),Pn.current&&i.createElement(xv.Provider,{value:ce},i.createElement(yP,{portal:e,ref:Se,prefixCls:a,popup:P,className:A(M,At),style:R,target:me,onMouseEnter:Gn,onMouseLeave:qn,onPointerEnter:Gn,zIndex:_,open:Je,keepDom:mt,fresh:G,onClick:H,onPointerDownCapture:nn,mask:$,motion:it,maskMotion:dt,onVisibleChanged:Rn,onPrepare:St,forceRender:O,autoDestroy:Z,getPopupContainer:E,align:ht,arrow:Vs,arrowPos:ks,ready:Ze,offsetX:Ge,offsetY:Be,offsetR:ze,offsetB:_e,onAlign:In,stretch:B,targetWidth:_t/Ae,targetHeight:vn/nt})))});return t}const Ss=RP(ps);var PP=["prefixCls","disabled","visible","children","popupElement","animation","transitionName","dropdownStyle","dropdownClassName","direction","placement","builtinPlacements","dropdownMatchSelectWidth","dropdownRender","dropdownAlign","getPopupContainer","empty","getTriggerDOMNode","onPopupVisibleChange","onPopupMouseEnter"],NP=function(t){var n=t===!0?0:1;return{bottomLeft:{points:["tl","bl"],offset:[0,4],overflow:{adjustX:n,adjustY:1},htmlRegion:"scroll"},bottomRight:{points:["tr","br"],offset:[0,4],overflow:{adjustX:n,adjustY:1},htmlRegion:"scroll"},topLeft:{points:["bl","tl"],offset:[0,-4],overflow:{adjustX:n,adjustY:1},htmlRegion:"scroll"},topRight:{points:["br","tr"],offset:[0,-4],overflow:{adjustX:n,adjustY:1},htmlRegion:"scroll"}}},MP=function(t,n){var r=t.prefixCls;t.disabled;var o=t.visible,a=t.children,l=t.popupElement,s=t.animation,c=t.transitionName,u=t.dropdownStyle,d=t.dropdownClassName,f=t.direction,m=f===void 0?"ltr":f,v=t.placement,g=t.builtinPlacements,h=t.dropdownMatchSelectWidth,p=t.dropdownRender,b=t.dropdownAlign,y=t.getPopupContainer,C=t.empty,$=t.getTriggerDOMNode,S=t.onPopupVisibleChange,x=t.onPopupMouseEnter,E=ft(t,PP),O="".concat(r,"-dropdown"),w=l;p&&(w=p(l));var I=i.useMemo(function(){return g||NP(h)},[g,h]),P=s?"".concat(O,"-").concat(s):c,M=typeof h=="number",R=i.useMemo(function(){return M?null:h===!1?"minWidth":"width"},[h,M]),N=u;M&&(N=k(k({},N),{},{width:h}));var T=i.useRef(null);return i.useImperativeHandle(n,function(){return{getPopupElement:function(){var z;return(z=T.current)===null||z===void 0?void 0:z.popupElement}}}),i.createElement(Ss,ue({},E,{showAction:S?["click"]:[],hideAction:S?["click"]:[],popupPlacement:v||(m==="rtl"?"bottomRight":"bottomLeft"),builtinPlacements:I,prefixCls:O,popupTransitionName:P,popup:i.createElement("div",{onMouseEnter:x},w),ref:T,stretch:R,popupAlign:b,popupVisible:o,getPopupContainer:y,popupClassName:A(d,D({},"".concat(O,"-empty"),C)),popupStyle:N,getTriggerDOMNode:$,onPopupVisibleChange:S}),a)},TP=i.forwardRef(MP);function Nv(e,t){var n=e.key,r;return"value"in e&&(r=e.value),n??(r!==void 0?r:"rc-index-key-".concat(t))}function Vu(e){return typeof e<"u"&&!Number.isNaN(e)}function Mb(e,t){var n=e||{},r=n.label,o=n.value,a=n.options,l=n.groupLabel,s=r||(t?"children":"label");return{label:s,value:o||"value",options:a||"options",groupLabel:l||s}}function jP(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=t.fieldNames,r=t.childrenAsData,o=[],a=Mb(n,!1),l=a.label,s=a.value,c=a.options,u=a.groupLabel;function d(f,m){Array.isArray(f)&&f.forEach(function(v){if(m||!(c in v)){var g=v[s];o.push({key:Nv(v,o.length),groupOption:m,data:v,label:v[l],value:g})}else{var h=v[u];h===void 0&&r&&(h=v.label),o.push({key:Nv(v,o.length),group:!0,data:v,label:h}),d(v[c],!0)}})}return d(e,!1),o}function Wu(e){var t=k({},e);return"props"in t||Object.defineProperty(t,"props",{get:function(){return Kt(!1,"Return type is option instead of Option instance. Please read value directly instead of reading from `props`."),t}}),t}var zP=function(t,n,r){if(!n||!n.length)return null;var o=!1,a=function s(c,u){var d=Oh(u),f=d[0],m=d.slice(1);if(!f)return[c];var v=c.split(f);return o=o||v.length>1,v.reduce(function(g,h){return[].concat(pe(g),pe(s(h,m)))},[]).filter(Boolean)},l=a(t,n);return o?typeof r<"u"?l.slice(0,r):l:null},Xd=i.createContext(null);function DP(e){var t=e.visible,n=e.values;if(!t)return null;var r=50;return i.createElement("span",{"aria-live":"polite",style:{width:0,height:0,position:"absolute",overflow:"hidden",opacity:0}},"".concat(n.slice(0,r).map(function(o){var a=o.label,l=o.value;return["number","string"].includes(Qe(a))?a:l}).join(", ")),n.length>r?", ...":null)}var _P=["id","prefixCls","className","showSearch","tagRender","direction","omitDomProps","displayValues","onDisplayValuesChange","emptyOptions","notFoundContent","onClear","mode","disabled","loading","getInputElement","getRawInputElement","open","defaultOpen","onDropdownVisibleChange","activeValue","onActiveValueChange","activeDescendantId","searchValue","autoClearSearchValue","onSearch","onSearchSplit","tokenSeparators","allowClear","prefix","suffixIcon","clearIcon","OptionList","animation","transitionName","dropdownStyle","dropdownClassName","dropdownMatchSelectWidth","dropdownRender","dropdownAlign","placement","builtinPlacements","getPopupContainer","showAction","onFocus","onBlur","onKeyUp","onKeyDown","onMouseDown"],BP=["value","onChange","removeIcon","placeholder","autoFocus","maxTagCount","maxTagTextLength","maxTagPlaceholder","choiceTransitionName","onInputKeyDown","onPopupScroll","tabIndex"],Ku=function(t){return t==="tags"||t==="multiple"},LP=i.forwardRef(function(e,t){var n,r=e.id,o=e.prefixCls,a=e.className,l=e.showSearch,s=e.tagRender,c=e.direction,u=e.omitDomProps,d=e.displayValues,f=e.onDisplayValuesChange,m=e.emptyOptions,v=e.notFoundContent,g=v===void 0?"Not Found":v,h=e.onClear,p=e.mode,b=e.disabled,y=e.loading,C=e.getInputElement,$=e.getRawInputElement,S=e.open,x=e.defaultOpen,E=e.onDropdownVisibleChange,O=e.activeValue,w=e.onActiveValueChange,I=e.activeDescendantId,P=e.searchValue,M=e.autoClearSearchValue,R=e.onSearch,N=e.onSearchSplit,T=e.tokenSeparators,j=e.allowClear,z=e.prefix,_=e.suffixIcon,B=e.clearIcon,V=e.OptionList,G=e.animation,q=e.transitionName,H=e.dropdownStyle,W=e.dropdownClassName,K=e.dropdownMatchSelectWidth,U=e.dropdownRender,te=e.dropdownAlign,X=e.placement,ae=e.builtinPlacements,le=e.getPopupContainer,ee=e.showAction,Y=ee===void 0?[]:ee,re=e.onFocus,ne=e.onBlur,Z=e.onKeyUp,Q=e.onKeyDown,ie=e.onMouseDown,de=ft(e,_P),he=Ku(p),ye=(l!==void 0?l:he)||p==="combobox",oe=k({},de);BP.forEach(function(ut){delete oe[ut]}),u==null||u.forEach(function(ut){delete oe[ut]});var ce=i.useState(!1),ge=J(ce,2),se=ge[0],be=ge[1];i.useEffect(function(){be(ys())},[]);var we=i.useRef(null),Me=i.useRef(null),Te=i.useRef(null),Se=i.useRef(null),Fe=i.useRef(null),Ce=i.useRef(!1),me=VR(),$e=J(me,3),Ee=$e[0],Ie=$e[1],fe=$e[2];i.useImperativeHandle(t,function(){var ut,st;return{focus:(ut=Se.current)===null||ut===void 0?void 0:ut.focus,blur:(st=Se.current)===null||st===void 0?void 0:st.blur,scrollTo:function(Ht){var Vt;return(Vt=Fe.current)===null||Vt===void 0?void 0:Vt.scrollTo(Ht)},nativeElement:we.current||Me.current}});var ve=i.useMemo(function(){var ut;if(p!=="combobox")return P;var st=(ut=d[0])===null||ut===void 0?void 0:ut.value;return typeof st=="string"||typeof st=="number"?String(st):""},[P,p,d]),xe=p==="combobox"&&typeof C=="function"&&C()||null,Re=typeof $=="function"&&$(),it=zr(Me,Re==null||(n=Re.props)===null||n===void 0?void 0:n.ref),dt=i.useState(!1),Oe=J(dt,2),Le=Oe[0],Ue=Oe[1];wt(function(){Ue(!0)},[]);var ke=Lt(!1,{defaultValue:x,value:S}),Je=J(ke,2),Xe=Je[0],He=Je[1],je=Le?Xe:!1,rt=!g&&m;(b||rt&&je&&p==="combobox")&&(je=!1);var et=rt?!1:je,Pe=i.useCallback(function(ut){var st=ut!==void 0?ut:!je;b||(He(st),je!==st&&(E==null||E(st)))},[b,je,He,E]),qe=i.useMemo(function(){return(T||[]).some(function(ut){return[`
`,`\r
`].includes(ut)})},[T]),We=i.useContext(Xd)||{},tt=We.maxCount,mt=We.rawValues,ct=function(st,_t,Ht){if(!(he&&Vu(tt)&&(mt==null?void 0:mt.size)>=tt)){var Vt=!0,Xt=st;w==null||w(null);var vn=zP(st,T,Vu(tt)?tt-mt.size:void 0),dn=Ht?null:vn;return p!=="combobox"&&dn&&(Xt="",N==null||N(dn),Pe(!1),Vt=!1),R&&ve!==Xt&&R(Xt,{source:_t?"typing":"effect"}),Vt}},Ke=function(st){!st||!st.trim()||R(st,{source:"submit"})};i.useEffect(function(){!je&&!he&&p!=="combobox"&&ct("",!1,!1)},[je]),i.useEffect(function(){Xe&&b&&He(!1),b&&!Ce.current&&Ie(!1)},[b]);var Ye=wb(),at=J(Ye,2),gt=at[0],Ot=at[1],Pt=i.useRef(!1),Rt=function(st){var _t=gt(),Ht=st.key,Vt=Ht==="Enter";if(Vt&&(p!=="combobox"&&st.preventDefault(),je||Pe(!0)),Ot(!!ve),Ht==="Backspace"&&!_t&&he&&!ve&&d.length){for(var Xt=pe(d),vn=null,dn=Xt.length-1;dn>=0;dn-=1){var gn=Xt[dn];if(!gn.disabled){Xt.splice(dn,1),vn=gn;break}}vn&&f(Xt,{type:"remove",values:[vn]})}for(var pn=arguments.length,Rn=new Array(pn>1?pn-1:0),St=1;St<pn;St++)Rn[St-1]=arguments[St];if(je&&(!Vt||!Pt.current)){var bt;Vt&&(Pt.current=!0),(bt=Fe.current)===null||bt===void 0||bt.onKeyDown.apply(bt,[st].concat(Rn))}Q==null||Q.apply(void 0,[st].concat(Rn))},jt=function(st){for(var _t=arguments.length,Ht=new Array(_t>1?_t-1:0),Vt=1;Vt<_t;Vt++)Ht[Vt-1]=arguments[Vt];if(je){var Xt;(Xt=Fe.current)===null||Xt===void 0||Xt.onKeyUp.apply(Xt,[st].concat(Ht))}st.key==="Enter"&&(Pt.current=!1),Z==null||Z.apply(void 0,[st].concat(Ht))},zt=function(st){var _t=d.filter(function(Ht){return Ht!==st});f(_t,{type:"remove",values:[st]})},Dt=function(){Pt.current=!1},De=i.useRef(!1),Ze=function(){Ie(!0),b||(re&&!De.current&&re.apply(void 0,arguments),Y.includes("focus")&&Pe(!0)),De.current=!0},Ge=function(){Ce.current=!0,Ie(!1,function(){De.current=!1,Ce.current=!1,Pe(!1)}),!b&&(ve&&(p==="tags"?R(ve,{source:"submit"}):p==="multiple"&&R("",{source:"blur"})),ne&&ne.apply(void 0,arguments))},Be=[];i.useEffect(function(){return function(){Be.forEach(function(ut){return clearTimeout(ut)}),Be.splice(0,Be.length)}},[]);var ze=function(st){var _t,Ht=st.target,Vt=(_t=Te.current)===null||_t===void 0?void 0:_t.getPopupElement();if(Vt&&Vt.contains(Ht)){var Xt=setTimeout(function(){var pn=Be.indexOf(Xt);if(pn!==-1&&Be.splice(pn,1),fe(),!se&&!Vt.contains(document.activeElement)){var Rn;(Rn=Se.current)===null||Rn===void 0||Rn.focus()}});Be.push(Xt)}for(var vn=arguments.length,dn=new Array(vn>1?vn-1:0),gn=1;gn<vn;gn++)dn[gn-1]=arguments[gn];ie==null||ie.apply(void 0,[st].concat(dn))},_e=i.useState({}),lt=J(_e,2),Ct=lt[1];function Ae(){Ct({})}var nt;Re&&(nt=function(st){Pe(st)}),WR(function(){var ut;return[we.current,(ut=Te.current)===null||ut===void 0?void 0:ut.getPopupElement()]},et,Pe,!!Re);var ht=i.useMemo(function(){return k(k({},e),{},{notFoundContent:g,open:je,triggerOpen:et,id:r,showSearch:ye,multiple:he,toggleOpen:Pe})},[e,g,et,je,r,ye,he,Pe]),Ft=!!_||y,qt;Ft&&(qt=i.createElement(Cs,{className:A("".concat(o,"-arrow"),D({},"".concat(o,"-arrow-loading"),y)),customizeIcon:_,customizeIconProps:{loading:y,searchValue:ve,open:je,focused:Ee,showSearch:ye}}));var Qt=function(){var st;h==null||h(),(st=Se.current)===null||st===void 0||st.focus(),f([],{type:"clear",values:d}),ct("",!1,!1)},ln=FR(o,Qt,d,j,B,b,ve,p),on=ln.allowClear,Tn=ln.clearIcon,On=i.createElement(V,{ref:Fe}),In=A(o,a,D(D(D(D(D(D(D(D(D(D({},"".concat(o,"-focused"),Ee),"".concat(o,"-multiple"),he),"".concat(o,"-single"),!he),"".concat(o,"-allow-clear"),j),"".concat(o,"-show-arrow"),Ft),"".concat(o,"-disabled"),b),"".concat(o,"-loading"),y),"".concat(o,"-open"),je),"".concat(o,"-customize-input"),xe),"".concat(o,"-show-search"),ye)),An=i.createElement(TP,{ref:Te,disabled:b,prefixCls:o,visible:et,popupElement:On,animation:G,transitionName:q,dropdownStyle:H,dropdownClassName:W,direction:c,dropdownMatchSelectWidth:K,dropdownRender:U,dropdownAlign:te,placement:X,builtinPlacements:ae,getPopupContainer:le,empty:m,getTriggerDOMNode:function(st){return Me.current||st},onPopupVisibleChange:nt,onPopupMouseEnter:Ae},Re?i.cloneElement(Re,{ref:it}):i.createElement(gP,ue({},e,{domRef:Me,prefixCls:o,inputElement:xe,ref:Se,id:r,prefix:z,showSearch:ye,autoClearSearchValue:M,mode:p,activeDescendantId:I,tagRender:s,values:d,open:je,onToggleOpen:Pe,activeValue:O,searchValue:ve,onSearch:ct,onSearchSubmit:Ke,onRemove:zt,tokenWithEnter:qe,onInputBlur:Dt}))),At;return Re?At=An:At=i.createElement("div",ue({className:In},oe,{ref:we,onMouseDown:ze,onKeyDown:Rt,onKeyUp:jt,onFocus:Ze,onBlur:Ge}),i.createElement(DP,{visible:Ee&&!je,values:d}),An,qt,on&&Tn),i.createElement(xb.Provider,{value:ht},At)}),Yd=function(){return null};Yd.isSelectOptGroup=!0;var Qd=function(){return null};Qd.isSelectOption=!0;var Tb=i.forwardRef(function(e,t){var n=e.height,r=e.offsetY,o=e.offsetX,a=e.children,l=e.prefixCls,s=e.onInnerResize,c=e.innerProps,u=e.rtl,d=e.extra,f={},m={display:"flex",flexDirection:"column"};return r!==void 0&&(f={height:n,position:"relative",overflow:"hidden"},m=k(k({},m),{},D(D(D(D(D({transform:"translateY(".concat(r,"px)")},u?"marginRight":"marginLeft",-o),"position","absolute"),"left",0),"right",0),"top",0))),i.createElement("div",{style:f},i.createElement(Bn,{onResize:function(g){var h=g.offsetHeight;h&&s&&s()}},i.createElement("div",ue({style:m,className:A(D({},"".concat(l,"-holder-inner"),l)),ref:t},c),a,d)))});Tb.displayName="Filler";function HP(e){var t=e.children,n=e.setRef,r=i.useCallback(function(o){n(o)},[]);return i.cloneElement(t,{ref:r})}function AP(e,t,n,r,o,a,l,s){var c=s.getKey;return e.slice(t,n+1).map(function(u,d){var f=t+d,m=l(u,f,{style:{width:r},offsetX:o}),v=c(u);return i.createElement(HP,{key:v,setRef:function(h){return a(u,h)}},m)})}function FP(e,t,n){var r=e.length,o=t.length,a,l;if(r===0&&o===0)return null;r<o?(a=e,l=t):(a=t,l=e);var s={__EMPTY_ITEM__:!0};function c(g){return g!==void 0?n(g):s}for(var u=null,d=Math.abs(r-o)!==1,f=0;f<l.length;f+=1){var m=c(a[f]),v=c(l[f]);if(m!==v){u=f,d=d||m!==c(l[f+1]);break}}return u===null?null:{index:u,multiple:d}}function kP(e,t,n){var r=i.useState(e),o=J(r,2),a=o[0],l=o[1],s=i.useState(null),c=J(s,2),u=c[0],d=c[1];return i.useEffect(function(){var f=FP(a||[],e||[],t);(f==null?void 0:f.index)!==void 0&&d(e[f.index]),l(e)},[e]),[u]}var Mv=(typeof navigator>"u"?"undefined":Qe(navigator))==="object"&&/Firefox/i.test(navigator.userAgent);const jb=function(e,t,n,r){var o=i.useRef(!1),a=i.useRef(null);function l(){clearTimeout(a.current),o.current=!0,a.current=setTimeout(function(){o.current=!1},50)}var s=i.useRef({top:e,bottom:t,left:n,right:r});return s.current.top=e,s.current.bottom=t,s.current.left=n,s.current.right=r,function(c,u){var d=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1,f=c?u<0&&s.current.left||u>0&&s.current.right:u<0&&s.current.top||u>0&&s.current.bottom;return d&&f?(clearTimeout(a.current),o.current=!1):(!f||o.current)&&l(),!o.current&&f}};function VP(e,t,n,r,o,a,l){var s=i.useRef(0),c=i.useRef(null),u=i.useRef(null),d=i.useRef(!1),f=jb(t,n,r,o);function m(y,C){if(Et.cancel(c.current),!f(!1,C)){var $=y;if(!$._virtualHandled)$._virtualHandled=!0;else return;s.current+=C,u.current=C,Mv||$.preventDefault(),c.current=Et(function(){var S=d.current?10:1;l(s.current*S,!1),s.current=0})}}function v(y,C){l(C,!0),Mv||y.preventDefault()}var g=i.useRef(null),h=i.useRef(null);function p(y){if(e){Et.cancel(h.current),h.current=Et(function(){g.current=null},2);var C=y.deltaX,$=y.deltaY,S=y.shiftKey,x=C,E=$;(g.current==="sx"||!g.current&&S&&$&&!C)&&(x=$,E=0,g.current="sx");var O=Math.abs(x),w=Math.abs(E);g.current===null&&(g.current=a&&O>w?"x":"y"),g.current==="y"?m(y,E):v(y,x)}}function b(y){e&&(d.current=y.detail===u.current)}return[p,b]}function WP(e,t,n,r){var o=i.useMemo(function(){return[new Map,[]]},[e,n.id,r]),a=J(o,2),l=a[0],s=a[1],c=function(d){var f=arguments.length>1&&arguments[1]!==void 0?arguments[1]:d,m=l.get(d),v=l.get(f);if(m===void 0||v===void 0)for(var g=e.length,h=s.length;h<g;h+=1){var p,b=e[h],y=t(b);l.set(y,h);var C=(p=n.get(y))!==null&&p!==void 0?p:r;if(s[h]=(s[h-1]||0)+C,y===d&&(m=h),y===f&&(v=h),m!==void 0&&v!==void 0)break}return{top:s[m-1]||0,bottom:s[v]}};return c}var KP=function(){function e(){Zt(this,e),D(this,"maps",void 0),D(this,"id",0),D(this,"diffRecords",new Map),this.maps=Object.create(null)}return Jt(e,[{key:"set",value:function(n,r){this.diffRecords.set(n,this.maps[n]),this.maps[n]=r,this.id+=1}},{key:"get",value:function(n){return this.maps[n]}},{key:"resetRecord",value:function(){this.diffRecords.clear()}},{key:"getRecord",value:function(){return this.diffRecords}}]),e}();function Tv(e){var t=parseFloat(e);return isNaN(t)?0:t}function GP(e,t,n){var r=i.useState(0),o=J(r,2),a=o[0],l=o[1],s=i.useRef(new Map),c=i.useRef(new KP),u=i.useRef(0);function d(){u.current+=1}function f(){var v=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1;d();var g=function(){var b=!1;s.current.forEach(function(y,C){if(y&&y.offsetParent){var $=y.offsetHeight,S=getComputedStyle(y),x=S.marginTop,E=S.marginBottom,O=Tv(x),w=Tv(E),I=$+O+w;c.current.get(C)!==I&&(c.current.set(C,I),b=!0)}}),b&&l(function(y){return y+1})};if(v)g();else{u.current+=1;var h=u.current;Promise.resolve().then(function(){h===u.current&&g()})}}function m(v,g){var h=e(v);s.current.get(h),g?(s.current.set(h,g),f()):s.current.delete(h)}return i.useEffect(function(){return d},[]),[m,f,c.current,a]}var jv=14/15;function qP(e,t,n){var r=i.useRef(!1),o=i.useRef(0),a=i.useRef(0),l=i.useRef(null),s=i.useRef(null),c,u=function(v){if(r.current){var g=Math.ceil(v.touches[0].pageX),h=Math.ceil(v.touches[0].pageY),p=o.current-g,b=a.current-h,y=Math.abs(p)>Math.abs(b);y?o.current=g:a.current=h;var C=n(y,y?p:b,!1,v);C&&v.preventDefault(),clearInterval(s.current),C&&(s.current=setInterval(function(){y?p*=jv:b*=jv;var $=Math.floor(y?p:b);(!n(y,$,!0)||Math.abs($)<=.1)&&clearInterval(s.current)},16))}},d=function(){r.current=!1,c()},f=function(v){c(),v.touches.length===1&&!r.current&&(r.current=!0,o.current=Math.ceil(v.touches[0].pageX),a.current=Math.ceil(v.touches[0].pageY),l.current=v.target,l.current.addEventListener("touchmove",u,{passive:!1}),l.current.addEventListener("touchend",d,{passive:!0}))};c=function(){l.current&&(l.current.removeEventListener("touchmove",u),l.current.removeEventListener("touchend",d))},wt(function(){return e&&t.current.addEventListener("touchstart",f,{passive:!0}),function(){var m;(m=t.current)===null||m===void 0||m.removeEventListener("touchstart",f),c(),clearInterval(s.current)}},[e])}function zv(e){return Math.floor(Math.pow(e,.5))}function Gu(e,t){var n="touches"in e?e.touches[0]:e;return n[t?"pageX":"pageY"]-window[t?"scrollX":"scrollY"]}function UP(e,t,n){i.useEffect(function(){var r=t.current;if(e&&r){var o=!1,a,l,s=function(){Et.cancel(a)},c=function m(){s(),a=Et(function(){n(l),m()})},u=function(v){if(!(v.target.draggable||v.button!==0)){var g=v;g._virtualHandled||(g._virtualHandled=!0,o=!0)}},d=function(){o=!1,s()},f=function(v){if(o){var g=Gu(v,!1),h=r.getBoundingClientRect(),p=h.top,b=h.bottom;if(g<=p){var y=p-g;l=-zv(y),c()}else if(g>=b){var C=g-b;l=zv(C),c()}else s()}};return r.addEventListener("mousedown",u),r.ownerDocument.addEventListener("mouseup",d),r.ownerDocument.addEventListener("mousemove",f),function(){r.removeEventListener("mousedown",u),r.ownerDocument.removeEventListener("mouseup",d),r.ownerDocument.removeEventListener("mousemove",f),s()}}},[e])}var XP=10;function YP(e,t,n,r,o,a,l,s){var c=i.useRef(),u=i.useState(null),d=J(u,2),f=d[0],m=d[1];return wt(function(){if(f&&f.times<XP){if(!e.current){m(function(B){return k({},B)});return}a();var v=f.targetAlign,g=f.originAlign,h=f.index,p=f.offset,b=e.current.clientHeight,y=!1,C=v,$=null;if(b){for(var S=v||g,x=0,E=0,O=0,w=Math.min(t.length-1,h),I=0;I<=w;I+=1){var P=o(t[I]);E=x;var M=n.get(P);O=E+(M===void 0?r:M),x=O}for(var R=S==="top"?p:b-p,N=w;N>=0;N-=1){var T=o(t[N]),j=n.get(T);if(j===void 0){y=!0;break}if(R-=j,R<=0)break}switch(S){case"top":$=E-p;break;case"bottom":$=O-b+p;break;default:{var z=e.current.scrollTop,_=z+b;E<z?C="top":O>_&&(C="bottom")}}$!==null&&l($),$!==f.lastTop&&(y=!0)}y&&m(k(k({},f),{},{times:f.times+1,targetAlign:C,lastTop:$}))}},[f,e.current]),function(v){if(v==null){s();return}if(Et.cancel(c.current),typeof v=="number")l(v);else if(v&&Qe(v)==="object"){var g,h=v.align;"index"in v?g=v.index:g=t.findIndex(function(y){return o(y)===v.key});var p=v.offset,b=p===void 0?0:p;m({times:0,index:g,offset:b,originAlign:h})}}}var Dv=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.rtl,o=e.scrollOffset,a=e.scrollRange,l=e.onStartMove,s=e.onStopMove,c=e.onScroll,u=e.horizontal,d=e.spinSize,f=e.containerSize,m=e.style,v=e.thumbStyle,g=e.showScrollBar,h=i.useState(!1),p=J(h,2),b=p[0],y=p[1],C=i.useState(null),$=J(C,2),S=$[0],x=$[1],E=i.useState(null),O=J(E,2),w=O[0],I=O[1],P=!r,M=i.useRef(),R=i.useRef(),N=i.useState(g),T=J(N,2),j=T[0],z=T[1],_=i.useRef(),B=function(){g===!0||g===!1||(clearTimeout(_.current),z(!0),_.current=setTimeout(function(){z(!1)},3e3))},V=a-f||0,G=f-d||0,q=i.useMemo(function(){if(o===0||V===0)return 0;var ee=o/V;return ee*G},[o,V,G]),H=function(Y){Y.stopPropagation(),Y.preventDefault()},W=i.useRef({top:q,dragging:b,pageY:S,startTop:w});W.current={top:q,dragging:b,pageY:S,startTop:w};var K=function(Y){y(!0),x(Gu(Y,u)),I(W.current.top),l(),Y.stopPropagation(),Y.preventDefault()};i.useEffect(function(){var ee=function(Z){Z.preventDefault()},Y=M.current,re=R.current;return Y.addEventListener("touchstart",ee,{passive:!1}),re.addEventListener("touchstart",K,{passive:!1}),function(){Y.removeEventListener("touchstart",ee),re.removeEventListener("touchstart",K)}},[]);var U=i.useRef();U.current=V;var te=i.useRef();te.current=G,i.useEffect(function(){if(b){var ee,Y=function(Z){var Q=W.current,ie=Q.dragging,de=Q.pageY,he=Q.startTop;Et.cancel(ee);var ye=M.current.getBoundingClientRect(),oe=f/(u?ye.width:ye.height);if(ie){var ce=(Gu(Z,u)-de)*oe,ge=he;!P&&u?ge-=ce:ge+=ce;var se=U.current,be=te.current,we=be?ge/be:0,Me=Math.ceil(we*se);Me=Math.max(Me,0),Me=Math.min(Me,se),ee=Et(function(){c(Me,u)})}},re=function(){y(!1),s()};return window.addEventListener("mousemove",Y,{passive:!0}),window.addEventListener("touchmove",Y,{passive:!0}),window.addEventListener("mouseup",re,{passive:!0}),window.addEventListener("touchend",re,{passive:!0}),function(){window.removeEventListener("mousemove",Y),window.removeEventListener("touchmove",Y),window.removeEventListener("mouseup",re),window.removeEventListener("touchend",re),Et.cancel(ee)}}},[b]),i.useEffect(function(){return B(),function(){clearTimeout(_.current)}},[o]),i.useImperativeHandle(t,function(){return{delayHidden:B}});var X="".concat(n,"-scrollbar"),ae={position:"absolute",visibility:j?null:"hidden"},le={position:"absolute",borderRadius:99,background:"var(--rc-virtual-list-scrollbar-bg, rgba(0, 0, 0, 0.5))",cursor:"pointer",userSelect:"none"};return u?(Object.assign(ae,{height:8,left:0,right:0,bottom:0}),Object.assign(le,D({height:"100%",width:d},P?"left":"right",q))):(Object.assign(ae,D({width:8,top:0,bottom:0},P?"right":"left",0)),Object.assign(le,{width:"100%",height:d,top:q})),i.createElement("div",{ref:M,className:A(X,D(D(D({},"".concat(X,"-horizontal"),u),"".concat(X,"-vertical"),!u),"".concat(X,"-visible"),j)),style:k(k({},ae),m),onMouseDown:H,onMouseMove:B},i.createElement("div",{ref:R,className:A("".concat(X,"-thumb"),D({},"".concat(X,"-thumb-moving"),b)),style:k(k({},le),v),onMouseDown:K}))}),QP=20;function _v(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:0,t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0,n=e/t*e;return isNaN(n)&&(n=0),n=Math.max(n,QP),Math.floor(n)}var ZP=["prefixCls","className","height","itemHeight","fullHeight","style","data","children","itemKey","virtual","direction","scrollWidth","component","onScroll","onVirtualScroll","onVisibleChange","innerProps","extraRender","styles","showScrollBar"],JP=[],eN={overflowY:"auto",overflowAnchor:"none"};function tN(e,t){var n=e.prefixCls,r=n===void 0?"rc-virtual-list":n,o=e.className,a=e.height,l=e.itemHeight,s=e.fullHeight,c=s===void 0?!0:s,u=e.style,d=e.data,f=e.children,m=e.itemKey,v=e.virtual,g=e.direction,h=e.scrollWidth,p=e.component,b=p===void 0?"div":p,y=e.onScroll,C=e.onVirtualScroll,$=e.onVisibleChange,S=e.innerProps,x=e.extraRender,E=e.styles,O=e.showScrollBar,w=O===void 0?"optional":O,I=ft(e,ZP),P=i.useCallback(function(De){return typeof m=="function"?m(De):De==null?void 0:De[m]},[m]),M=GP(P),R=J(M,4),N=R[0],T=R[1],j=R[2],z=R[3],_=!!(v!==!1&&a&&l),B=i.useMemo(function(){return Object.values(j.maps).reduce(function(De,Ze){return De+Ze},0)},[j.id,j.maps]),V=_&&d&&(Math.max(l*d.length,B)>a||!!h),G=g==="rtl",q=A(r,D({},"".concat(r,"-rtl"),G),o),H=d||JP,W=i.useRef(),K=i.useRef(),U=i.useRef(),te=i.useState(0),X=J(te,2),ae=X[0],le=X[1],ee=i.useState(0),Y=J(ee,2),re=Y[0],ne=Y[1],Z=i.useState(!1),Q=J(Z,2),ie=Q[0],de=Q[1],he=function(){de(!0)},ye=function(){de(!1)},oe={getKey:P};function ce(De){le(function(Ze){var Ge;typeof De=="function"?Ge=De(Ze):Ge=De;var Be=Ue(Ge);return W.current.scrollTop=Be,Be})}var ge=i.useRef({start:0,end:H.length}),se=i.useRef(),be=kP(H,P),we=J(be,1),Me=we[0];se.current=Me;var Te=i.useMemo(function(){if(!_)return{scrollHeight:void 0,start:0,end:H.length-1,offset:void 0};if(!V){var De;return{scrollHeight:((De=K.current)===null||De===void 0?void 0:De.offsetHeight)||0,start:0,end:H.length-1,offset:void 0}}for(var Ze=0,Ge,Be,ze,_e=H.length,lt=0;lt<_e;lt+=1){var Ct=H[lt],Ae=P(Ct),nt=j.get(Ae),ht=Ze+(nt===void 0?l:nt);ht>=ae&&Ge===void 0&&(Ge=lt,Be=Ze),ht>ae+a&&ze===void 0&&(ze=lt),Ze=ht}return Ge===void 0&&(Ge=0,Be=0,ze=Math.ceil(a/l)),ze===void 0&&(ze=H.length-1),ze=Math.min(ze+1,H.length-1),{scrollHeight:Ze,start:Ge,end:ze,offset:Be}},[V,_,ae,H,z,a]),Se=Te.scrollHeight,Fe=Te.start,Ce=Te.end,me=Te.offset;ge.current.start=Fe,ge.current.end=Ce,i.useLayoutEffect(function(){var De=j.getRecord();if(De.size===1){var Ze=Array.from(De.keys())[0],Ge=De.get(Ze),Be=H[Fe];if(Be&&Ge===void 0){var ze=P(Be);if(ze===Ze){var _e=j.get(Ze),lt=_e-l;ce(function(Ct){return Ct+lt})}}}j.resetRecord()},[Se]);var $e=i.useState({width:0,height:a}),Ee=J($e,2),Ie=Ee[0],fe=Ee[1],ve=function(Ze){fe({width:Ze.offsetWidth,height:Ze.offsetHeight})},xe=i.useRef(),Re=i.useRef(),it=i.useMemo(function(){return _v(Ie.width,h)},[Ie.width,h]),dt=i.useMemo(function(){return _v(Ie.height,Se)},[Ie.height,Se]),Oe=Se-a,Le=i.useRef(Oe);Le.current=Oe;function Ue(De){var Ze=De;return Number.isNaN(Le.current)||(Ze=Math.min(Ze,Le.current)),Ze=Math.max(Ze,0),Ze}var ke=ae<=0,Je=ae>=Oe,Xe=re<=0,He=re>=h,je=jb(ke,Je,Xe,He),rt=function(){return{x:G?-re:re,y:ae}},et=i.useRef(rt()),Pe=Nt(function(De){if(C){var Ze=k(k({},rt()),De);(et.current.x!==Ze.x||et.current.y!==Ze.y)&&(C(Ze),et.current=Ze)}});function qe(De,Ze){var Ge=De;Ze?(Pr.flushSync(function(){ne(Ge)}),Pe()):ce(Ge)}function We(De){var Ze=De.currentTarget.scrollTop;Ze!==ae&&ce(Ze),y==null||y(De),Pe()}var tt=function(Ze){var Ge=Ze,Be=h?h-Ie.width:0;return Ge=Math.max(Ge,0),Ge=Math.min(Ge,Be),Ge},mt=Nt(function(De,Ze){Ze?(Pr.flushSync(function(){ne(function(Ge){var Be=Ge+(G?-De:De);return tt(Be)})}),Pe()):ce(function(Ge){var Be=Ge+De;return Be})}),ct=VP(_,ke,Je,Xe,He,!!h,mt),Ke=J(ct,2),Ye=Ke[0],at=Ke[1];qP(_,W,function(De,Ze,Ge,Be){var ze=Be;return je(De,Ze,Ge)?!1:!ze||!ze._virtualHandled?(ze&&(ze._virtualHandled=!0),Ye({preventDefault:function(){},deltaX:De?Ze:0,deltaY:De?0:Ze}),!0):!1}),UP(V,W,function(De){ce(function(Ze){return Ze+De})}),wt(function(){function De(Ge){var Be=ke&&Ge.detail<0,ze=Je&&Ge.detail>0;_&&!Be&&!ze&&Ge.preventDefault()}var Ze=W.current;return Ze.addEventListener("wheel",Ye,{passive:!1}),Ze.addEventListener("DOMMouseScroll",at,{passive:!0}),Ze.addEventListener("MozMousePixelScroll",De,{passive:!1}),function(){Ze.removeEventListener("wheel",Ye),Ze.removeEventListener("DOMMouseScroll",at),Ze.removeEventListener("MozMousePixelScroll",De)}},[_,ke,Je]),wt(function(){if(h){var De=tt(re);ne(De),Pe({x:De})}},[Ie.width,h]);var gt=function(){var Ze,Ge;(Ze=xe.current)===null||Ze===void 0||Ze.delayHidden(),(Ge=Re.current)===null||Ge===void 0||Ge.delayHidden()},Ot=YP(W,H,j,l,P,function(){return T(!0)},ce,gt);i.useImperativeHandle(t,function(){return{nativeElement:U.current,getScrollInfo:rt,scrollTo:function(Ze){function Ge(Be){return Be&&Qe(Be)==="object"&&("left"in Be||"top"in Be)}Ge(Ze)?(Ze.left!==void 0&&ne(tt(Ze.left)),Ot(Ze.top)):Ot(Ze)}}}),wt(function(){if($){var De=H.slice(Fe,Ce+1);$(De,H)}},[Fe,Ce,H]);var Pt=WP(H,P,j,l),Rt=x==null?void 0:x({start:Fe,end:Ce,virtual:V,offsetX:re,offsetY:me,rtl:G,getSize:Pt}),jt=AP(H,Fe,Ce,h,re,N,f,oe),zt=null;a&&(zt=k(D({},c?"height":"maxHeight",a),eN),_&&(zt.overflowY="hidden",h&&(zt.overflowX="hidden"),ie&&(zt.pointerEvents="none")));var Dt={};return G&&(Dt.dir="rtl"),i.createElement("div",ue({ref:U,style:k(k({},u),{},{position:"relative"}),className:q},Dt,I),i.createElement(Bn,{onResize:ve},i.createElement(b,{className:"".concat(r,"-holder"),style:zt,ref:W,onScroll:We,onMouseEnter:gt},i.createElement(Tb,{prefixCls:r,height:Se,offsetX:re,offsetY:me,scrollWidth:h,onInnerResize:T,ref:K,innerProps:S,rtl:G,extra:Rt},jt))),V&&Se>a&&i.createElement(Dv,{ref:xe,prefixCls:r,scrollOffset:ae,scrollRange:Se,rtl:G,onScroll:qe,onStartMove:he,onStopMove:ye,spinSize:dt,containerSize:Ie.height,style:E==null?void 0:E.verticalScrollBar,thumbStyle:E==null?void 0:E.verticalScrollBarThumb,showScrollBar:w}),V&&h>Ie.width&&i.createElement(Dv,{ref:Re,prefixCls:r,scrollOffset:re,scrollRange:h,rtl:G,onScroll:qe,onStartMove:he,onStopMove:ye,spinSize:it,containerSize:Ie.width,horizontal:!0,style:E==null?void 0:E.horizontalScrollBar,thumbStyle:E==null?void 0:E.horizontalScrollBarThumb,showScrollBar:w}))}var $s=i.forwardRef(tN);$s.displayName="List";function nN(){return/(mac\sos|macintosh)/i.test(navigator.appVersion)}var rN=["disabled","title","children","style","className"];function Bv(e){return typeof e=="string"||typeof e=="number"}var oN=function(t,n){var r=kR(),o=r.prefixCls,a=r.id,l=r.open,s=r.multiple,c=r.mode,u=r.searchValue,d=r.toggleOpen,f=r.notFoundContent,m=r.onPopupScroll,v=i.useContext(Xd),g=v.maxCount,h=v.flattenOptions,p=v.onActiveValue,b=v.defaultActiveFirstOption,y=v.onSelect,C=v.menuItemSelectedIcon,$=v.rawValues,S=v.fieldNames,x=v.virtual,E=v.direction,O=v.listHeight,w=v.listItemHeight,I=v.optionRender,P="".concat(o,"-item"),M=So(function(){return h},[l,h],function(ee,Y){return Y[0]&&ee[1]!==Y[1]}),R=i.useRef(null),N=i.useMemo(function(){return s&&Vu(g)&&($==null?void 0:$.size)>=g},[s,g,$==null?void 0:$.size]),T=function(Y){Y.preventDefault()},j=function(Y){var re;(re=R.current)===null||re===void 0||re.scrollTo(typeof Y=="number"?{index:Y}:Y)},z=i.useCallback(function(ee){return c==="combobox"?!1:$.has(ee)},[c,pe($).toString(),$.size]),_=function(Y){for(var re=arguments.length>1&&arguments[1]!==void 0?arguments[1]:1,ne=M.length,Z=0;Z<ne;Z+=1){var Q=(Y+Z*re+ne)%ne,ie=M[Q]||{},de=ie.group,he=ie.data;if(!de&&!(he!=null&&he.disabled)&&(z(he.value)||!N))return Q}return-1},B=i.useState(function(){return _(0)}),V=J(B,2),G=V[0],q=V[1],H=function(Y){var re=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;q(Y);var ne={source:re?"keyboard":"mouse"},Z=M[Y];if(!Z){p(null,-1,ne);return}p(Z.value,Y,ne)};i.useEffect(function(){H(b!==!1?_(0):-1)},[M.length,u]);var W=i.useCallback(function(ee){return c==="combobox"?String(ee).toLowerCase()===u.toLowerCase():$.has(ee)},[c,u,pe($).toString(),$.size]);i.useEffect(function(){var ee=setTimeout(function(){if(!s&&l&&$.size===1){var re=Array.from($)[0],ne=M.findIndex(function(Z){var Q=Z.data;return u?String(Q.value).startsWith(u):Q.value===re});ne!==-1&&(H(ne),j(ne))}});if(l){var Y;(Y=R.current)===null||Y===void 0||Y.scrollTo(void 0)}return function(){return clearTimeout(ee)}},[l,u]);var K=function(Y){Y!==void 0&&y(Y,{selected:!$.has(Y)}),s||d(!1)};if(i.useImperativeHandle(n,function(){return{onKeyDown:function(Y){var re=Y.which,ne=Y.ctrlKey;switch(re){case Ne.N:case Ne.P:case Ne.UP:case Ne.DOWN:{var Z=0;if(re===Ne.UP?Z=-1:re===Ne.DOWN?Z=1:nN()&&ne&&(re===Ne.N?Z=1:re===Ne.P&&(Z=-1)),Z!==0){var Q=_(G+Z,Z);j(Q),H(Q,!0)}break}case Ne.TAB:case Ne.ENTER:{var ie,de=M[G];de&&!(de!=null&&(ie=de.data)!==null&&ie!==void 0&&ie.disabled)&&!N?K(de.value):K(void 0),l&&Y.preventDefault();break}case Ne.ESC:d(!1),l&&Y.stopPropagation()}},onKeyUp:function(){},scrollTo:function(Y){j(Y)}}}),M.length===0)return i.createElement("div",{role:"listbox",id:"".concat(a,"_list"),className:"".concat(P,"-empty"),onMouseDown:T},f);var U=Object.keys(S).map(function(ee){return S[ee]}),te=function(Y){return Y.label};function X(ee,Y){var re=ee.group;return{role:re?"presentation":"option",id:"".concat(a,"_list_").concat(Y)}}var ae=function(Y){var re=M[Y];if(!re)return null;var ne=re.data||{},Z=ne.value,Q=re.group,ie=rn(ne,!0),de=te(re);return re?i.createElement("div",ue({"aria-label":typeof de=="string"&&!Q?de:null},ie,{key:Y},X(re,Y),{"aria-selected":W(Z)}),Z):null},le={role:"listbox",id:"".concat(a,"_list")};return i.createElement(i.Fragment,null,x&&i.createElement("div",ue({},le,{style:{height:0,width:0,overflow:"hidden"}}),ae(G-1),ae(G),ae(G+1)),i.createElement($s,{itemKey:"key",ref:R,data:M,height:O,itemHeight:w,fullHeight:!1,onMouseDown:T,onScroll:m,virtual:x,direction:E,innerProps:x?null:le},function(ee,Y){var re=ee.group,ne=ee.groupOption,Z=ee.data,Q=ee.label,ie=ee.value,de=Z.key;if(re){var he,ye=(he=Z.title)!==null&&he!==void 0?he:Bv(Q)?Q.toString():void 0;return i.createElement("div",{className:A(P,"".concat(P,"-group"),Z.className),title:ye},Q!==void 0?Q:de)}var oe=Z.disabled,ce=Z.title;Z.children;var ge=Z.style,se=Z.className,be=ft(Z,rN),we=Gt(be,U),Me=z(ie),Te=oe||!Me&&N,Se="".concat(P,"-option"),Fe=A(P,Se,se,D(D(D(D({},"".concat(Se,"-grouped"),ne),"".concat(Se,"-active"),G===Y&&!Te),"".concat(Se,"-disabled"),Te),"".concat(Se,"-selected"),Me)),Ce=te(ee),me=!C||typeof C=="function"||Me,$e=typeof Ce=="number"?Ce:Ce||ie,Ee=Bv($e)?$e.toString():void 0;return ce!==void 0&&(Ee=ce),i.createElement("div",ue({},rn(we),x?{}:X(ee,Y),{"aria-selected":W(ie),className:Fe,title:Ee,onMouseMove:function(){G===Y||Te||H(Y)},onClick:function(){Te||K(ie)},style:ge}),i.createElement("div",{className:"".concat(Se,"-content")},typeof I=="function"?I(ee,{index:Y}):$e),i.isValidElement(C)||Me,me&&i.createElement(Cs,{className:"".concat(P,"-option-state"),customizeIcon:C,customizeIconProps:{value:ie,disabled:Te,isSelected:Me}},Me?"✓":null))}))},aN=i.forwardRef(oN);const iN=function(e,t){var n=i.useRef({values:new Map,options:new Map}),r=i.useMemo(function(){var a=n.current,l=a.values,s=a.options,c=e.map(function(f){if(f.label===void 0){var m;return k(k({},f),{},{label:(m=l.get(f.value))===null||m===void 0?void 0:m.label})}return f}),u=new Map,d=new Map;return c.forEach(function(f){u.set(f.value,f),d.set(f.value,t.get(f.value)||s.get(f.value))}),n.current.values=u,n.current.options=d,c},[e,t]),o=i.useCallback(function(a){return t.get(a)||n.current.options.get(a)},[t]);return[r,o]};function yc(e,t){return Pb(e).join("").toUpperCase().includes(t)}const lN=function(e,t,n,r,o){return i.useMemo(function(){if(!n||r===!1)return e;var a=t.options,l=t.label,s=t.value,c=[],u=typeof r=="function",d=n.toUpperCase(),f=u?r:function(v,g){return o?yc(g[o],d):g[a]?yc(g[l!=="children"?l:"label"],d):yc(g[s],d)},m=u?function(v){return Wu(v)}:function(v){return v};return e.forEach(function(v){if(v[a]){var g=f(n,m(v));if(g)c.push(v);else{var h=v[a].filter(function(p){return f(n,m(p))});h.length&&c.push(k(k({},v),{},D({},a,h)))}return}f(n,m(v))&&c.push(v)}),c},[e,r,o,n,t])};var Lv=0,sN=wn();function cN(){var e;return sN?(e=Lv,Lv+=1):e="TEST_OR_SSR",e}function uN(e){var t=i.useState(),n=J(t,2),r=n[0],o=n[1];return i.useEffect(function(){o("rc_select_".concat(cN()))},[]),e||r}var dN=["children","value"],fN=["children"];function mN(e){var t=e,n=t.key,r=t.props,o=r.children,a=r.value,l=ft(r,dN);return k({key:n,value:a!==void 0?a:n,children:o},l)}function zb(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;return xn(e).map(function(n,r){if(!i.isValidElement(n)||!n.type)return null;var o=n,a=o.type.isSelectOptGroup,l=o.key,s=o.props,c=s.children,u=ft(s,fN);return t||!a?mN(n):k(k({key:"__RC_SELECT_GRP__".concat(l===null?r:l,"__"),label:l},u),{},{options:zb(c)})}).filter(function(n){return n})}var vN=function(t,n,r,o,a){return i.useMemo(function(){var l=t,s=!t;s&&(l=zb(n));var c=new Map,u=new Map,d=function(v,g,h){h&&typeof h=="string"&&v.set(g[h],g)},f=function m(v){for(var g=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,h=0;h<v.length;h+=1){var p=v[h];!p[r.options]||g?(c.set(p[r.value],p),d(u,p,r.label),d(u,p,o),d(u,p,a)):m(p[r.options],!0)}};return f(l),{options:l,valueOptions:c,labelOptions:u}},[t,n,r,o,a])};function Hv(e){var t=i.useRef();t.current=e;var n=i.useCallback(function(){return t.current.apply(t,arguments)},[]);return n}var gN=["id","mode","prefixCls","backfill","fieldNames","inputValue","searchValue","onSearch","autoClearSearchValue","onSelect","onDeselect","dropdownMatchSelectWidth","filterOption","filterSort","optionFilterProp","optionLabelProp","options","optionRender","children","defaultActiveFirstOption","menuItemSelectedIcon","virtual","direction","listHeight","listItemHeight","labelRender","value","defaultValue","labelInValue","onChange","maxCount"],pN=["inputValue"];function hN(e){return!e||Qe(e)!=="object"}var bN=i.forwardRef(function(e,t){var n=e.id,r=e.mode,o=e.prefixCls,a=o===void 0?"rc-select":o,l=e.backfill,s=e.fieldNames,c=e.inputValue,u=e.searchValue,d=e.onSearch,f=e.autoClearSearchValue,m=f===void 0?!0:f,v=e.onSelect,g=e.onDeselect,h=e.dropdownMatchSelectWidth,p=h===void 0?!0:h,b=e.filterOption,y=e.filterSort,C=e.optionFilterProp,$=e.optionLabelProp,S=e.options,x=e.optionRender,E=e.children,O=e.defaultActiveFirstOption,w=e.menuItemSelectedIcon,I=e.virtual,P=e.direction,M=e.listHeight,R=M===void 0?200:M,N=e.listItemHeight,T=N===void 0?20:N,j=e.labelRender,z=e.value,_=e.defaultValue,B=e.labelInValue,V=e.onChange,G=e.maxCount,q=ft(e,gN),H=uN(n),W=Ku(r),K=!!(!S&&E),U=i.useMemo(function(){return b===void 0&&r==="combobox"?!1:b},[b,r]),te=i.useMemo(function(){return Mb(s,K)},[JSON.stringify(s),K]),X=Lt("",{value:u!==void 0?u:c,postState:function(qe){return qe||""}}),ae=J(X,2),le=ae[0],ee=ae[1],Y=vN(S,E,te,C,$),re=Y.valueOptions,ne=Y.labelOptions,Z=Y.options,Q=i.useCallback(function(Pe){var qe=Pb(Pe);return qe.map(function(We){var tt,mt,ct,Ke,Ye;if(hN(We))tt=We;else{var at;ct=We.key,mt=We.label,tt=(at=We.value)!==null&&at!==void 0?at:ct}var gt=re.get(tt);if(gt){var Ot;mt===void 0&&(mt=gt==null?void 0:gt[$||te.label]),ct===void 0&&(ct=(Ot=gt==null?void 0:gt.key)!==null&&Ot!==void 0?Ot:tt),Ke=gt==null?void 0:gt.disabled,Ye=gt==null?void 0:gt.title}return{label:mt,value:tt,key:ct,disabled:Ke,title:Ye}})},[te,$,re]),ie=Lt(_,{value:z}),de=J(ie,2),he=de[0],ye=de[1],oe=i.useMemo(function(){var Pe,qe=W&&he===null?[]:he,We=Q(qe);return r==="combobox"&&cP((Pe=We[0])===null||Pe===void 0?void 0:Pe.value)?[]:We},[he,Q,r,W]),ce=iN(oe,re),ge=J(ce,2),se=ge[0],be=ge[1],we=i.useMemo(function(){if(!r&&se.length===1){var Pe=se[0];if(Pe.value===null&&(Pe.label===null||Pe.label===void 0))return[]}return se.map(function(qe){var We;return k(k({},qe),{},{label:(We=typeof j=="function"?j(qe):qe.label)!==null&&We!==void 0?We:qe.value})})},[r,se,j]),Me=i.useMemo(function(){return new Set(se.map(function(Pe){return Pe.value}))},[se]);i.useEffect(function(){if(r==="combobox"){var Pe,qe=(Pe=se[0])===null||Pe===void 0?void 0:Pe.value;ee(sP(qe)?String(qe):"")}},[se]);var Te=Hv(function(Pe,qe){var We=qe??Pe;return D(D({},te.value,Pe),te.label,We)}),Se=i.useMemo(function(){if(r!=="tags")return Z;var Pe=pe(Z),qe=function(tt){return re.has(tt)};return pe(se).sort(function(We,tt){return We.value<tt.value?-1:1}).forEach(function(We){var tt=We.value;qe(tt)||Pe.push(Te(tt,We.label))}),Pe},[Te,Z,re,se,r]),Fe=lN(Se,te,le,U,C),Ce=i.useMemo(function(){return r!=="tags"||!le||Fe.some(function(Pe){return Pe[C||"value"]===le})||Fe.some(function(Pe){return Pe[te.value]===le})?Fe:[Te(le)].concat(pe(Fe))},[Te,C,r,Fe,le,te]),me=function Pe(qe){var We=pe(qe).sort(function(tt,mt){return y(tt,mt,{searchValue:le})});return We.map(function(tt){return Array.isArray(tt.options)?k(k({},tt),{},{options:tt.options.length>0?Pe(tt.options):tt.options}):tt})},$e=i.useMemo(function(){return y?me(Ce):Ce},[Ce,y,le]),Ee=i.useMemo(function(){return jP($e,{fieldNames:te,childrenAsData:K})},[$e,te,K]),Ie=function(qe){var We=Q(qe);if(ye(We),V&&(We.length!==se.length||We.some(function(ct,Ke){var Ye;return((Ye=se[Ke])===null||Ye===void 0?void 0:Ye.value)!==(ct==null?void 0:ct.value)}))){var tt=B?We:We.map(function(ct){return ct.value}),mt=We.map(function(ct){return Wu(be(ct.value))});V(W?tt:tt[0],W?mt:mt[0])}},fe=i.useState(null),ve=J(fe,2),xe=ve[0],Re=ve[1],it=i.useState(0),dt=J(it,2),Oe=dt[0],Le=dt[1],Ue=O!==void 0?O:r!=="combobox",ke=i.useCallback(function(Pe,qe){var We=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},tt=We.source,mt=tt===void 0?"keyboard":tt;Le(qe),l&&r==="combobox"&&Pe!==null&&mt==="keyboard"&&Re(String(Pe))},[l,r]),Je=function(qe,We,tt){var mt=function(){var zt,Dt=be(qe);return[B?{label:Dt==null?void 0:Dt[te.label],value:qe,key:(zt=Dt==null?void 0:Dt.key)!==null&&zt!==void 0?zt:qe}:qe,Wu(Dt)]};if(We&&v){var ct=mt(),Ke=J(ct,2),Ye=Ke[0],at=Ke[1];v(Ye,at)}else if(!We&&g&&tt!=="clear"){var gt=mt(),Ot=J(gt,2),Pt=Ot[0],Rt=Ot[1];g(Pt,Rt)}},Xe=Hv(function(Pe,qe){var We,tt=W?qe.selected:!0;tt?We=W?[].concat(pe(se),[Pe]):[Pe]:We=se.filter(function(mt){return mt.value!==Pe}),Ie(We),Je(Pe,tt),r==="combobox"?Re(""):(!Ku||m)&&(ee(""),Re(""))}),He=function(qe,We){Ie(qe);var tt=We.type,mt=We.values;(tt==="remove"||tt==="clear")&&mt.forEach(function(ct){Je(ct.value,!1,tt)})},je=function(qe,We){if(ee(qe),Re(null),We.source==="submit"){var tt=(qe||"").trim();if(tt){var mt=Array.from(new Set([].concat(pe(Me),[tt])));Ie(mt),Je(tt,!0),ee("")}return}We.source!=="blur"&&(r==="combobox"&&Ie(qe),d==null||d(qe))},rt=function(qe){var We=qe;r!=="tags"&&(We=qe.map(function(mt){var ct=ne.get(mt);return ct==null?void 0:ct.value}).filter(function(mt){return mt!==void 0}));var tt=Array.from(new Set([].concat(pe(Me),pe(We))));Ie(tt),tt.forEach(function(mt){Je(mt,!0)})},et=i.useMemo(function(){var Pe=I!==!1&&p!==!1;return k(k({},Y),{},{flattenOptions:Ee,onActiveValue:ke,defaultActiveFirstOption:Ue,onSelect:Xe,menuItemSelectedIcon:w,rawValues:Me,fieldNames:te,virtual:Pe,direction:P,listHeight:R,listItemHeight:T,childrenAsData:K,maxCount:G,optionRender:x})},[G,Y,Ee,ke,Ue,Xe,w,Me,te,I,p,P,R,T,K,x]);return i.createElement(Xd.Provider,{value:et},i.createElement(LP,ue({},q,{id:H,prefixCls:a,ref:t,omitDomProps:pN,mode:r,displayValues:we,onDisplayValuesChange:He,direction:P,searchValue:le,onSearch:je,autoClearSearchValue:m,onSearchSplit:rt,dropdownMatchSelectWidth:p,OptionList:aN,emptyOptions:!Ee.length,activeValue:xe,activeDescendantId:"".concat(H,"_list_").concat(Oe)})))}),Zd=bN;Zd.Option=Qd;Zd.OptGroup=Yd;function yo(e,t,n){return A({[`${e}-status-success`]:t==="success",[`${e}-status-warning`]:t==="warning",[`${e}-status-error`]:t==="error",[`${e}-status-validating`]:t==="validating",[`${e}-has-feedback`]:n})}const bi=(e,t)=>t||e,yN=()=>{const[,e]=yn(),[t]=Kn("Empty"),r=new Mt(e.colorBgBase).toHsl().l<.5?{opacity:.65}:{};return i.createElement("svg",{style:r,width:"184",height:"152",viewBox:"0 0 184 152",xmlns:"http://www.w3.org/2000/svg"},i.createElement("title",null,(t==null?void 0:t.description)||"Empty"),i.createElement("g",{fill:"none",fillRule:"evenodd"},i.createElement("g",{transform:"translate(24 31.67)"},i.createElement("ellipse",{fillOpacity:".8",fill:"#F5F5F7",cx:"67.797",cy:"106.89",rx:"67.797",ry:"12.668"}),i.createElement("path",{d:"M122.034 69.674L98.109 40.229c-1.148-1.386-2.826-2.225-4.593-2.225h-51.44c-1.766 0-3.444.839-4.592 2.225L13.56 69.674v15.383h108.475V69.674z",fill:"#AEB8C2"}),i.createElement("path",{d:"M101.537 86.214L80.63 61.102c-1.001-1.207-2.507-1.867-4.048-1.867H31.724c-1.54 0-3.047.66-4.048 1.867L6.769 86.214v13.792h94.768V86.214z",fill:"url(#linearGradient-1)",transform:"translate(13.56)"}),i.createElement("path",{d:"M33.83 0h67.933a4 4 0 0 1 4 4v93.344a4 4 0 0 1-4 4H33.83a4 4 0 0 1-4-4V4a4 4 0 0 1 4-4z",fill:"#F5F5F7"}),i.createElement("path",{d:"M42.678 9.953h50.237a2 2 0 0 1 2 2V36.91a2 2 0 0 1-2 2H42.678a2 2 0 0 1-2-2V11.953a2 2 0 0 1 2-2zM42.94 49.767h49.713a2.262 2.262 0 1 1 0 4.524H42.94a2.262 2.262 0 0 1 0-4.524zM42.94 61.53h49.713a2.262 2.262 0 1 1 0 4.525H42.94a2.262 2.262 0 0 1 0-4.525zM121.813 105.032c-.775 3.071-3.497 5.36-6.735 5.36H20.515c-3.238 0-5.96-2.29-6.734-5.36a7.309 7.309 0 0 1-.222-1.79V69.675h26.318c2.907 0 5.25 2.448 5.25 5.42v.04c0 2.971 2.37 5.37 5.277 5.37h34.785c2.907 0 5.277-2.421 5.277-5.393V75.1c0-2.972 2.343-5.426 5.25-5.426h26.318v33.569c0 .617-.077 1.216-.221 1.789z",fill:"#DCE0E6"})),i.createElement("path",{d:"M149.121 33.292l-6.83 2.65a1 1 0 0 1-1.317-1.23l1.937-6.207c-2.589-2.944-4.109-6.534-4.109-10.408C138.802 8.102 148.92 0 161.402 0 173.881 0 184 8.102 184 18.097c0 9.995-10.118 18.097-22.599 18.097-4.528 0-8.744-1.066-12.28-2.902z",fill:"#DCE0E6"}),i.createElement("g",{transform:"translate(149.65 15.383)",fill:"#FFF"},i.createElement("ellipse",{cx:"20.654",cy:"3.167",rx:"2.849",ry:"2.815"}),i.createElement("path",{d:"M5.698 5.63H0L2.898.704zM9.259.704h4.985V5.63H9.259z"}))))},CN=()=>{const[,e]=yn(),[t]=Kn("Empty"),{colorFill:n,colorFillTertiary:r,colorFillQuaternary:o,colorBgContainer:a}=e,{borderColor:l,shadowColor:s,contentColor:c}=i.useMemo(()=>({borderColor:new Mt(n).onBackground(a).toHexString(),shadowColor:new Mt(r).onBackground(a).toHexString(),contentColor:new Mt(o).onBackground(a).toHexString()}),[n,r,o,a]);return i.createElement("svg",{width:"64",height:"41",viewBox:"0 0 64 41",xmlns:"http://www.w3.org/2000/svg"},i.createElement("title",null,(t==null?void 0:t.description)||"Empty"),i.createElement("g",{transform:"translate(0 1)",fill:"none",fillRule:"evenodd"},i.createElement("ellipse",{fill:s,cx:"32",cy:"33",rx:"32",ry:"7"}),i.createElement("g",{fillRule:"nonzero",stroke:l},i.createElement("path",{d:"M55 12.76L44.854 1.258C44.367.474 43.656 0 42.907 0H21.093c-.749 0-1.46.474-1.947 1.257L9 12.761V22h46v-9.24z"}),i.createElement("path",{d:"M41.613 15.931c0-1.605.994-2.93 2.227-2.931H55v18.137C55 33.26 53.68 35 52.05 35h-40.1C10.32 35 9 33.259 9 31.137V13h11.16c1.233 0 2.227 1.323 2.227 2.928v.022c0 1.605 1.005 2.901 2.237 2.901h14.752c1.232 0 2.237-1.308 2.237-2.913v-.007z",fill:c}))))},SN=e=>{const{componentCls:t,margin:n,marginXS:r,marginXL:o,fontSize:a,lineHeight:l}=e;return{[t]:{marginInline:r,fontSize:a,lineHeight:l,textAlign:"center",[`${t}-image`]:{height:e.emptyImgHeight,marginBottom:r,opacity:e.opacityImage,img:{height:"100%"},svg:{maxWidth:"100%",height:"100%",margin:"auto"}},[`${t}-description`]:{color:e.colorTextDescription},[`${t}-footer`]:{marginTop:n},"&-normal":{marginBlock:o,color:e.colorTextDescription,[`${t}-description`]:{color:e.colorTextDescription},[`${t}-image`]:{height:e.emptyImgHeightMD}},"&-small":{marginBlock:r,color:e.colorTextDescription,[`${t}-image`]:{height:e.emptyImgHeightSM}}}}},$N=It("Empty",e=>{const{componentCls:t,controlHeightLG:n,calc:r}=e,o=yt(e,{emptyImgCls:`${t}-img`,emptyImgHeight:r(n).mul(2.5).equal(),emptyImgHeightMD:n,emptyImgHeightSM:r(n).mul(.875).equal()});return SN(o)});var xN=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Db=i.createElement(yN,null),_b=i.createElement(CN,null),Hr=e=>{var t;const{className:n,rootClassName:r,prefixCls:o,image:a,description:l,children:s,imageStyle:c,style:u,classNames:d,styles:f}=e,m=xN(e,["className","rootClassName","prefixCls","image","description","children","imageStyle","style","classNames","styles"]),{getPrefixCls:v,direction:g,className:h,style:p,classNames:b,styles:y,image:C}=tn("empty"),$=v("empty",o),[S,x,E]=$N($),[O]=Kn("Empty"),w=typeof l<"u"?l:O==null?void 0:O.description,I=typeof w=="string"?w:"empty",P=(t=a??C)!==null&&t!==void 0?t:Db;let M=null;return typeof P=="string"?M=i.createElement("img",{alt:I,src:P}):M=P,S(i.createElement("div",Object.assign({className:A(x,E,$,h,{[`${$}-normal`]:P===_b,[`${$}-rtl`]:g==="rtl"},n,r,b.root,d==null?void 0:d.root),style:Object.assign(Object.assign(Object.assign(Object.assign({},y.root),p),f==null?void 0:f.root),u)},m),i.createElement("div",{className:A(`${$}-image`,b.image,d==null?void 0:d.image),style:Object.assign(Object.assign(Object.assign({},c),y.image),f==null?void 0:f.image)},M),w&&i.createElement("div",{className:A(`${$}-description`,b.description,d==null?void 0:d.description),style:Object.assign(Object.assign({},y.description),f==null?void 0:f.description)},w),s&&i.createElement("div",{className:A(`${$}-footer`,b.footer,d==null?void 0:d.footer),style:Object.assign(Object.assign({},y.footer),f==null?void 0:f.footer)},s)))};Hr.PRESENTED_IMAGE_DEFAULT=Db;Hr.PRESENTED_IMAGE_SIMPLE=_b;const Bb=e=>{const{componentName:t}=e,{getPrefixCls:n}=i.useContext(ot),r=n("empty");switch(t){case"Table":case"List":return F.createElement(Hr,{image:Hr.PRESENTED_IMAGE_SIMPLE});case"Select":case"TreeSelect":case"Cascader":case"Transfer":case"Mentions":return F.createElement(Hr,{image:Hr.PRESENTED_IMAGE_SIMPLE,className:`${r}-small`});case"Table.filter":return null;default:return F.createElement(Hr,null)}},yi=(e,t,n=void 0)=>{var r,o;const{variant:a,[e]:l}=i.useContext(ot),s=i.useContext(xI),c=l==null?void 0:l.variant;let u;typeof t<"u"?u=t:n===!1?u="borderless":u=(o=(r=s??c)!==null&&r!==void 0?r:a)!==null&&o!==void 0?o:"outlined";const d=_$.includes(u);return[u,d]},wN=e=>{const n={overflow:{adjustX:!0,adjustY:!0,shiftY:!0},htmlRegion:e==="scroll"?"scroll":"visible",dynamicInset:!0};return{bottomLeft:Object.assign(Object.assign({},n),{points:["tl","bl"],offset:[0,4]}),bottomRight:Object.assign(Object.assign({},n),{points:["tr","br"],offset:[0,4]}),topLeft:Object.assign(Object.assign({},n),{points:["bl","tl"],offset:[0,-4]}),topRight:Object.assign(Object.assign({},n),{points:["br","tr"],offset:[0,-4]})}};function EN(e,t){return e||wN(t)}const Av=e=>{const{optionHeight:t,optionFontSize:n,optionLineHeight:r,optionPadding:o}=e;return{position:"relative",display:"block",minHeight:t,padding:o,color:e.colorText,fontWeight:"normal",fontSize:n,lineHeight:r,boxSizing:"border-box"}},ON=e=>{const{antCls:t,componentCls:n}=e,r=`${n}-item`,o=`&${t}-slide-up-enter${t}-slide-up-enter-active`,a=`&${t}-slide-up-appear${t}-slide-up-appear-active`,l=`&${t}-slide-up-leave${t}-slide-up-leave-active`,s=`${n}-dropdown-placement-`,c=`${r}-option-selected`;return[{[`${n}-dropdown`]:Object.assign(Object.assign({},Tt(e)),{position:"absolute",top:-9999,zIndex:e.zIndexPopup,boxSizing:"border-box",padding:e.paddingXXS,overflow:"hidden",fontSize:e.fontSize,fontVariant:"initial",backgroundColor:e.colorBgElevated,borderRadius:e.borderRadiusLG,outline:"none",boxShadow:e.boxShadowSecondary,[`
          ${o}${s}bottomLeft,
          ${a}${s}bottomLeft
        `]:{animationName:Ld},[`
          ${o}${s}topLeft,
          ${a}${s}topLeft,
          ${o}${s}topRight,
          ${a}${s}topRight
        `]:{animationName:Ad},[`${l}${s}bottomLeft`]:{animationName:Hd},[`
          ${l}${s}topLeft,
          ${l}${s}topRight
        `]:{animationName:Fd},"&-hidden":{display:"none"},[r]:Object.assign(Object.assign({},Av(e)),{cursor:"pointer",transition:`background ${e.motionDurationSlow} ease`,borderRadius:e.borderRadiusSM,"&-group":{color:e.colorTextDescription,fontSize:e.fontSizeSM,cursor:"default"},"&-option":{display:"flex","&-content":Object.assign({flex:"auto"},sr),"&-state":{flex:"none",display:"flex",alignItems:"center"},[`&-active:not(${r}-option-disabled)`]:{backgroundColor:e.optionActiveBg},[`&-selected:not(${r}-option-disabled)`]:{color:e.optionSelectedColor,fontWeight:e.optionSelectedFontWeight,backgroundColor:e.optionSelectedBg,[`${r}-option-state`]:{color:e.colorPrimary}},"&-disabled":{[`&${r}-option-selected`]:{backgroundColor:e.colorBgContainerDisabled},color:e.colorTextDisabled,cursor:"not-allowed"},"&-grouped":{paddingInlineStart:e.calc(e.controlPaddingHorizontal).mul(2).equal()}},"&-empty":Object.assign(Object.assign({},Av(e)),{color:e.colorTextDisabled})}),[`${c}:has(+ ${c})`]:{borderEndStartRadius:0,borderEndEndRadius:0,[`& + ${c}`]:{borderStartStartRadius:0,borderStartEndRadius:0}},"&-rtl":{direction:"rtl"}})},eo(e,"slide-up"),eo(e,"slide-down"),Sl(e,"move-up"),Sl(e,"move-down")]},IN=e=>{const{multipleSelectItemHeight:t,paddingXXS:n,lineWidth:r,INTERNAL_FIXED_ITEM_MARGIN:o}=e,a=e.max(e.calc(n).sub(r).equal(),0),l=e.max(e.calc(a).sub(o).equal(),0);return{basePadding:a,containerPadding:l,itemHeight:L(t),itemLineHeight:L(e.calc(t).sub(e.calc(e.lineWidth).mul(2)).equal())}},RN=e=>{const{multipleSelectItemHeight:t,selectHeight:n,lineWidth:r}=e;return e.calc(n).sub(t).div(2).sub(r).equal()},PN=e=>{const{componentCls:t,iconCls:n,borderRadiusSM:r,motionDurationSlow:o,paddingXS:a,multipleItemColorDisabled:l,multipleItemBorderColorDisabled:s,colorIcon:c,colorIconHover:u,INTERNAL_FIXED_ITEM_MARGIN:d}=e;return{[`${t}-selection-overflow`]:{position:"relative",display:"flex",flex:"auto",flexWrap:"wrap",maxWidth:"100%","&-item":{flex:"none",alignSelf:"center",maxWidth:"calc(100% - 4px)",display:"inline-flex"},[`${t}-selection-item`]:{display:"flex",alignSelf:"center",flex:"none",boxSizing:"border-box",maxWidth:"100%",marginBlock:d,borderRadius:r,cursor:"default",transition:`font-size ${o}, line-height ${o}, height ${o}`,marginInlineEnd:e.calc(d).mul(2).equal(),paddingInlineStart:a,paddingInlineEnd:e.calc(a).div(2).equal(),[`${t}-disabled&`]:{color:l,borderColor:s,cursor:"not-allowed"},"&-content":{display:"inline-block",marginInlineEnd:e.calc(a).div(2).equal(),overflow:"hidden",whiteSpace:"pre",textOverflow:"ellipsis"},"&-remove":Object.assign(Object.assign({},xo()),{display:"inline-flex",alignItems:"center",color:c,fontWeight:"bold",fontSize:10,lineHeight:"inherit",cursor:"pointer",[`> ${n}`]:{verticalAlign:"-0.2em"},"&:hover":{color:u}})}}}},NN=(e,t)=>{const{componentCls:n,INTERNAL_FIXED_ITEM_MARGIN:r}=e,o=`${n}-selection-overflow`,a=e.multipleSelectItemHeight,l=RN(e),s=t?`${n}-${t}`:"",c=IN(e);return{[`${n}-multiple${s}`]:Object.assign(Object.assign({},PN(e)),{[`${n}-selector`]:{display:"flex",alignItems:"center",width:"100%",height:"100%",paddingInline:c.basePadding,paddingBlock:c.containerPadding,borderRadius:e.borderRadius,[`${n}-disabled&`]:{background:e.multipleSelectorBgDisabled,cursor:"not-allowed"},"&:after":{display:"inline-block",width:0,margin:`${L(r)} 0`,lineHeight:L(a),visibility:"hidden",content:'"\\a0"'}},[`${n}-selection-item`]:{height:c.itemHeight,lineHeight:L(c.itemLineHeight)},[`${n}-selection-wrap`]:{alignSelf:"flex-start","&:after":{lineHeight:L(a),marginBlock:r}},[`${n}-prefix`]:{marginInlineStart:e.calc(e.inputPaddingHorizontalBase).sub(c.basePadding).equal()},[`${o}-item + ${o}-item,
        ${n}-prefix + ${n}-selection-wrap
      `]:{[`${n}-selection-search`]:{marginInlineStart:0},[`${n}-selection-placeholder`]:{insetInlineStart:0}},[`${o}-item-suffix`]:{minHeight:c.itemHeight,marginBlock:r},[`${n}-selection-search`]:{display:"inline-flex",position:"relative",maxWidth:"100%",marginInlineStart:e.calc(e.inputPaddingHorizontalBase).sub(l).equal(),"\n          &-input,\n          &-mirror\n        ":{height:a,fontFamily:e.fontFamily,lineHeight:L(a),transition:`all ${e.motionDurationSlow}`},"&-input":{width:"100%",minWidth:4.1},"&-mirror":{position:"absolute",top:0,insetInlineStart:0,insetInlineEnd:"auto",zIndex:999,whiteSpace:"pre",visibility:"hidden"}},[`${n}-selection-placeholder`]:{position:"absolute",top:"50%",insetInlineStart:e.calc(e.inputPaddingHorizontalBase).sub(c.basePadding).equal(),insetInlineEnd:e.inputPaddingHorizontalBase,transform:"translateY(-50%)",transition:`all ${e.motionDurationSlow}`}})}};function Cc(e,t){const{componentCls:n}=e,r=t?`${n}-${t}`:"",o={[`${n}-multiple${r}`]:{fontSize:e.fontSize,[`${n}-selector`]:{[`${n}-show-search&`]:{cursor:"text"}},[`
        &${n}-show-arrow ${n}-selector,
        &${n}-allow-clear ${n}-selector
      `]:{paddingInlineEnd:e.calc(e.fontSizeIcon).add(e.controlPaddingHorizontal).equal()}}};return[NN(e,t),o]}const MN=e=>{const{componentCls:t}=e,n=yt(e,{selectHeight:e.controlHeightSM,multipleSelectItemHeight:e.multipleItemHeightSM,borderRadius:e.borderRadiusSM,borderRadiusSM:e.borderRadiusXS}),r=yt(e,{fontSize:e.fontSizeLG,selectHeight:e.controlHeightLG,multipleSelectItemHeight:e.multipleItemHeightLG,borderRadius:e.borderRadiusLG,borderRadiusSM:e.borderRadius});return[Cc(e),Cc(n,"sm"),{[`${t}-multiple${t}-sm`]:{[`${t}-selection-placeholder`]:{insetInline:e.calc(e.controlPaddingHorizontalSM).sub(e.lineWidth).equal()},[`${t}-selection-search`]:{marginInlineStart:2}}},Cc(r,"lg")]};function Sc(e,t){const{componentCls:n,inputPaddingHorizontalBase:r,borderRadius:o}=e,a=e.calc(e.controlHeight).sub(e.calc(e.lineWidth).mul(2)).equal(),l=t?`${n}-${t}`:"";return{[`${n}-single${l}`]:{fontSize:e.fontSize,height:e.controlHeight,[`${n}-selector`]:Object.assign(Object.assign({},Tt(e,!0)),{display:"flex",borderRadius:o,flex:"1 1 auto",[`${n}-selection-wrap:after`]:{lineHeight:L(a)},[`${n}-selection-search`]:{position:"absolute",inset:0,width:"100%","&-input":{width:"100%",WebkitAppearance:"textfield"}},[`
          ${n}-selection-item,
          ${n}-selection-placeholder
        `]:{display:"block",padding:0,lineHeight:L(a),transition:`all ${e.motionDurationSlow}, visibility 0s`,alignSelf:"center"},[`${n}-selection-placeholder`]:{transition:"none",pointerEvents:"none"},[["&:after",`${n}-selection-item:empty:after`,`${n}-selection-placeholder:empty:after`].join(",")]:{display:"inline-block",width:0,visibility:"hidden",content:'"\\a0"'}}),[`
        &${n}-show-arrow ${n}-selection-item,
        &${n}-show-arrow ${n}-selection-search,
        &${n}-show-arrow ${n}-selection-placeholder
      `]:{paddingInlineEnd:e.showArrowPaddingInlineEnd},[`&${n}-open ${n}-selection-item`]:{color:e.colorTextPlaceholder},[`&:not(${n}-customize-input)`]:{[`${n}-selector`]:{width:"100%",height:"100%",alignItems:"center",padding:`0 ${L(r)}`,[`${n}-selection-search-input`]:{height:a,fontSize:e.fontSize},"&:after":{lineHeight:L(a)}}},[`&${n}-customize-input`]:{[`${n}-selector`]:{"&:after":{display:"none"},[`${n}-selection-search`]:{position:"static",width:"100%"},[`${n}-selection-placeholder`]:{position:"absolute",insetInlineStart:0,insetInlineEnd:0,padding:`0 ${L(r)}`,"&:after":{display:"none"}}}}}}}function TN(e){const{componentCls:t}=e,n=e.calc(e.controlPaddingHorizontalSM).sub(e.lineWidth).equal();return[Sc(e),Sc(yt(e,{controlHeight:e.controlHeightSM,borderRadius:e.borderRadiusSM}),"sm"),{[`${t}-single${t}-sm`]:{[`&:not(${t}-customize-input)`]:{[`${t}-selector`]:{padding:`0 ${L(n)}`},[`&${t}-show-arrow ${t}-selection-search`]:{insetInlineEnd:e.calc(n).add(e.calc(e.fontSize).mul(1.5)).equal()},[`
            &${t}-show-arrow ${t}-selection-item,
            &${t}-show-arrow ${t}-selection-placeholder
          `]:{paddingInlineEnd:e.calc(e.fontSize).mul(1.5).equal()}}}},Sc(yt(e,{controlHeight:e.singleItemHeightLG,fontSize:e.fontSizeLG,borderRadius:e.borderRadiusLG}),"lg")]}const jN=e=>{const{fontSize:t,lineHeight:n,lineWidth:r,controlHeight:o,controlHeightSM:a,controlHeightLG:l,paddingXXS:s,controlPaddingHorizontal:c,zIndexPopupBase:u,colorText:d,fontWeightStrong:f,controlItemBgActive:m,controlItemBgHover:v,colorBgContainer:g,colorFillSecondary:h,colorBgContainerDisabled:p,colorTextDisabled:b,colorPrimaryHover:y,colorPrimary:C,controlOutline:$}=e,S=s*2,x=r*2,E=Math.min(o-S,o-x),O=Math.min(a-S,a-x),w=Math.min(l-S,l-x);return{INTERNAL_FIXED_ITEM_MARGIN:Math.floor(s/2),zIndexPopup:u+50,optionSelectedColor:d,optionSelectedFontWeight:f,optionSelectedBg:m,optionActiveBg:v,optionPadding:`${(o-t*n)/2}px ${c}px`,optionFontSize:t,optionLineHeight:n,optionHeight:o,selectorBg:g,clearBg:g,singleItemHeightLG:l,multipleItemBg:h,multipleItemBorderColor:"transparent",multipleItemHeight:E,multipleItemHeightSM:O,multipleItemHeightLG:w,multipleSelectorBgDisabled:p,multipleItemColorDisabled:b,multipleItemBorderColorDisabled:"transparent",showArrowPaddingInlineEnd:Math.ceil(e.fontSize*1.25),hoverBorderColor:y,activeBorderColor:C,activeOutlineColor:$,selectAffixPadding:s}},Lb=(e,t)=>{const{componentCls:n,antCls:r,controlOutlineWidth:o}=e;return{[`&:not(${n}-customize-input) ${n}-selector`]:{border:`${L(e.lineWidth)} ${e.lineType} ${t.borderColor}`,background:e.selectorBg},[`&:not(${n}-disabled):not(${n}-customize-input):not(${r}-pagination-size-changer)`]:{[`&:hover ${n}-selector`]:{borderColor:t.hoverBorderHover},[`${n}-focused& ${n}-selector`]:{borderColor:t.activeBorderColor,boxShadow:`0 0 0 ${L(o)} ${t.activeOutlineColor}`,outline:0},[`${n}-prefix`]:{color:t.color}}}},Fv=(e,t)=>({[`&${e.componentCls}-status-${t.status}`]:Object.assign({},Lb(e,t))}),zN=e=>({"&-outlined":Object.assign(Object.assign(Object.assign(Object.assign({},Lb(e,{borderColor:e.colorBorder,hoverBorderHover:e.hoverBorderColor,activeBorderColor:e.activeBorderColor,activeOutlineColor:e.activeOutlineColor,color:e.colorText})),Fv(e,{status:"error",borderColor:e.colorError,hoverBorderHover:e.colorErrorHover,activeBorderColor:e.colorError,activeOutlineColor:e.colorErrorOutline,color:e.colorError})),Fv(e,{status:"warning",borderColor:e.colorWarning,hoverBorderHover:e.colorWarningHover,activeBorderColor:e.colorWarning,activeOutlineColor:e.colorWarningOutline,color:e.colorWarning})),{[`&${e.componentCls}-disabled`]:{[`&:not(${e.componentCls}-customize-input) ${e.componentCls}-selector`]:{background:e.colorBgContainerDisabled,color:e.colorTextDisabled}},[`&${e.componentCls}-multiple ${e.componentCls}-selection-item`]:{background:e.multipleItemBg,border:`${L(e.lineWidth)} ${e.lineType} ${e.multipleItemBorderColor}`}})}),Hb=(e,t)=>{const{componentCls:n,antCls:r}=e;return{[`&:not(${n}-customize-input) ${n}-selector`]:{background:t.bg,border:`${L(e.lineWidth)} ${e.lineType} transparent`,color:t.color},[`&:not(${n}-disabled):not(${n}-customize-input):not(${r}-pagination-size-changer)`]:{[`&:hover ${n}-selector`]:{background:t.hoverBg},[`${n}-focused& ${n}-selector`]:{background:e.selectorBg,borderColor:t.activeBorderColor,outline:0}}}},kv=(e,t)=>({[`&${e.componentCls}-status-${t.status}`]:Object.assign({},Hb(e,t))}),DN=e=>({"&-filled":Object.assign(Object.assign(Object.assign(Object.assign({},Hb(e,{bg:e.colorFillTertiary,hoverBg:e.colorFillSecondary,activeBorderColor:e.activeBorderColor,color:e.colorText})),kv(e,{status:"error",bg:e.colorErrorBg,hoverBg:e.colorErrorBgHover,activeBorderColor:e.colorError,color:e.colorError})),kv(e,{status:"warning",bg:e.colorWarningBg,hoverBg:e.colorWarningBgHover,activeBorderColor:e.colorWarning,color:e.colorWarning})),{[`&${e.componentCls}-disabled`]:{[`&:not(${e.componentCls}-customize-input) ${e.componentCls}-selector`]:{borderColor:e.colorBorder,background:e.colorBgContainerDisabled,color:e.colorTextDisabled}},[`&${e.componentCls}-multiple ${e.componentCls}-selection-item`]:{background:e.colorBgContainer,border:`${L(e.lineWidth)} ${e.lineType} ${e.colorSplit}`}})}),_N=e=>({"&-borderless":{[`${e.componentCls}-selector`]:{background:"transparent",border:`${L(e.lineWidth)} ${e.lineType} transparent`},[`&${e.componentCls}-disabled`]:{[`&:not(${e.componentCls}-customize-input) ${e.componentCls}-selector`]:{color:e.colorTextDisabled}},[`&${e.componentCls}-multiple ${e.componentCls}-selection-item`]:{background:e.multipleItemBg,border:`${L(e.lineWidth)} ${e.lineType} ${e.multipleItemBorderColor}`},[`&${e.componentCls}-status-error`]:{[`${e.componentCls}-prefix, ${e.componentCls}-selection-item`]:{color:e.colorError}},[`&${e.componentCls}-status-warning`]:{[`${e.componentCls}-prefix, ${e.componentCls}-selection-item`]:{color:e.colorWarning}}}}),Ab=(e,t)=>{const{componentCls:n,antCls:r}=e;return{[`&:not(${n}-customize-input) ${n}-selector`]:{borderWidth:`0 0 ${L(e.lineWidth)} 0`,borderStyle:`none none ${e.lineType} none`,borderColor:t.borderColor,background:e.selectorBg,borderRadius:0},[`&:not(${n}-disabled):not(${n}-customize-input):not(${r}-pagination-size-changer)`]:{[`&:hover ${n}-selector`]:{borderColor:t.hoverBorderHover},[`${n}-focused& ${n}-selector`]:{borderColor:t.activeBorderColor,outline:0},[`${n}-prefix`]:{color:t.color}}}},Vv=(e,t)=>({[`&${e.componentCls}-status-${t.status}`]:Object.assign({},Ab(e,t))}),BN=e=>({"&-underlined":Object.assign(Object.assign(Object.assign(Object.assign({},Ab(e,{borderColor:e.colorBorder,hoverBorderHover:e.hoverBorderColor,activeBorderColor:e.activeBorderColor,activeOutlineColor:e.activeOutlineColor,color:e.colorText})),Vv(e,{status:"error",borderColor:e.colorError,hoverBorderHover:e.colorErrorHover,activeBorderColor:e.colorError,activeOutlineColor:e.colorErrorOutline,color:e.colorError})),Vv(e,{status:"warning",borderColor:e.colorWarning,hoverBorderHover:e.colorWarningHover,activeBorderColor:e.colorWarning,activeOutlineColor:e.colorWarningOutline,color:e.colorWarning})),{[`&${e.componentCls}-disabled`]:{[`&:not(${e.componentCls}-customize-input) ${e.componentCls}-selector`]:{color:e.colorTextDisabled}},[`&${e.componentCls}-multiple ${e.componentCls}-selection-item`]:{background:e.multipleItemBg,border:`${L(e.lineWidth)} ${e.lineType} ${e.multipleItemBorderColor}`}})}),LN=e=>({[e.componentCls]:Object.assign(Object.assign(Object.assign(Object.assign({},zN(e)),DN(e)),_N(e)),BN(e))}),HN=e=>{const{componentCls:t}=e;return{position:"relative",transition:`all ${e.motionDurationMid} ${e.motionEaseInOut}`,input:{cursor:"pointer"},[`${t}-show-search&`]:{cursor:"text",input:{cursor:"auto",color:"inherit",height:"100%"}},[`${t}-disabled&`]:{cursor:"not-allowed",input:{cursor:"not-allowed"}}}},AN=e=>{const{componentCls:t}=e;return{[`${t}-selection-search-input`]:{margin:0,padding:0,background:"transparent",border:"none",outline:"none",appearance:"none",fontFamily:"inherit","&::-webkit-search-cancel-button":{display:"none",appearance:"none"}}}},FN=e=>{const{antCls:t,componentCls:n,inputPaddingHorizontalBase:r,iconCls:o}=e,a={[`${n}-clear`]:{opacity:1,background:e.colorBgBase,borderRadius:"50%"}};return{[n]:Object.assign(Object.assign({},Tt(e)),{position:"relative",display:"inline-flex",cursor:"pointer",[`&:not(${n}-customize-input) ${n}-selector`]:Object.assign(Object.assign({},HN(e)),AN(e)),[`${n}-selection-item`]:Object.assign(Object.assign({flex:1,fontWeight:"normal",position:"relative",userSelect:"none"},sr),{[`> ${t}-typography`]:{display:"inline"}}),[`${n}-selection-placeholder`]:Object.assign(Object.assign({},sr),{flex:1,color:e.colorTextPlaceholder,pointerEvents:"none"}),[`${n}-arrow`]:Object.assign(Object.assign({},xo()),{position:"absolute",top:"50%",insetInlineStart:"auto",insetInlineEnd:r,height:e.fontSizeIcon,marginTop:e.calc(e.fontSizeIcon).mul(-1).div(2).equal(),color:e.colorTextQuaternary,fontSize:e.fontSizeIcon,lineHeight:1,textAlign:"center",pointerEvents:"none",display:"flex",alignItems:"center",transition:`opacity ${e.motionDurationSlow} ease`,[o]:{verticalAlign:"top",transition:`transform ${e.motionDurationSlow}`,"> svg":{verticalAlign:"top"},[`&:not(${n}-suffix)`]:{pointerEvents:"auto"}},[`${n}-disabled &`]:{cursor:"not-allowed"},"> *:not(:last-child)":{marginInlineEnd:8}}),[`${n}-selection-wrap`]:{display:"flex",width:"100%",position:"relative",minWidth:0,"&:after":{content:'"\\a0"',width:0,overflow:"hidden"}},[`${n}-prefix`]:{flex:"none",marginInlineEnd:e.selectAffixPadding},[`${n}-clear`]:{position:"absolute",top:"50%",insetInlineStart:"auto",insetInlineEnd:r,zIndex:1,display:"inline-block",width:e.fontSizeIcon,height:e.fontSizeIcon,marginTop:e.calc(e.fontSizeIcon).mul(-1).div(2).equal(),color:e.colorTextQuaternary,fontSize:e.fontSizeIcon,fontStyle:"normal",lineHeight:1,textAlign:"center",textTransform:"none",cursor:"pointer",opacity:0,transition:`color ${e.motionDurationMid} ease, opacity ${e.motionDurationSlow} ease`,textRendering:"auto",transform:"translateZ(0)","&:before":{display:"block"},"&:hover":{color:e.colorIcon}},"@media(hover:none)":a,"&:hover":a}),[`${n}-status`]:{"&-error, &-warning, &-success, &-validating":{[`&${n}-has-feedback`]:{[`${n}-clear`]:{insetInlineEnd:e.calc(r).add(e.fontSize).add(e.paddingXS).equal()}}}}}},kN=e=>{const{componentCls:t}=e;return[{[t]:{[`&${t}-in-form-item`]:{width:"100%"}}},FN(e),TN(e),MN(e),ON(e),{[`${t}-rtl`]:{direction:"rtl"}},di(e,{borderElCls:`${t}-selector`,focusElCls:`${t}-focused`})]},VN=It("Select",(e,{rootPrefixCls:t})=>{const n=yt(e,{rootPrefixCls:t,inputPaddingHorizontalBase:e.calc(e.paddingSM).sub(1).equal(),multipleSelectItemHeight:e.multipleItemHeight,selectHeight:e.controlHeight});return[kN(n),LN(n)]},jN,{unitless:{optionLineHeight:!0,optionSelectedFontWeight:!0}});var WN={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M912 190h-69.9c-9.8 0-19.1 4.5-25.1 12.2L404.7 724.5 207 474a32 32 0 00-25.1-12.2H112c-6.7 0-10.4 7.7-6.3 12.9l273.9 347c12.8 16.2 37.4 16.2 50.3 0l488.4-618.9c4.1-5.1.4-12.8-6.3-12.8z"}}]},name:"check",theme:"outlined"},KN=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:WN}))},Jd=i.forwardRef(KN),GN={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M884 256h-75c-5.1 0-9.9 2.5-12.9 6.6L512 654.2 227.9 262.6c-3-4.1-7.8-6.6-12.9-6.6h-75c-6.5 0-10.3 7.4-6.5 12.7l352.6 486.1c12.8 17.6 39 17.6 51.7 0l352.6-486.1c3.9-5.3.1-12.7-6.4-12.7z"}}]},name:"down",theme:"outlined"},qN=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:GN}))},ef=i.forwardRef(qN),UN={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M909.6 854.5L649.9 594.8C690.2 542.7 712 479 712 412c0-80.2-31.3-155.4-87.9-212.1-56.6-56.7-132-87.9-212.1-87.9s-155.5 31.3-212.1 87.9C143.2 256.5 112 331.8 112 412c0 80.1 31.3 155.5 87.9 212.1C256.5 680.8 331.8 712 412 712c67 0 130.6-21.8 182.7-62l259.7 259.6a8.2 8.2 0 0011.6 0l43.6-43.5a8.2 8.2 0 000-11.6zM570.4 570.4C528 612.7 471.8 636 412 636s-116-23.3-158.4-65.6C211.3 528 188 471.8 188 412s23.3-116.1 65.6-158.4C296 211.3 352.2 188 412 188s116.1 23.2 158.4 65.6S636 352.2 636 412s-23.3 116.1-65.6 158.4z"}}]},name:"search",theme:"outlined"},XN=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:UN}))},tf=i.forwardRef(XN);function YN({suffixIcon:e,clearIcon:t,menuItemSelectedIcon:n,removeIcon:r,loading:o,multiple:a,hasFeedback:l,prefixCls:s,showSuffixIcon:c,feedbackIcon:u,showArrow:d,componentName:f}){const m=t??i.createElement(wo,null),v=b=>e===null&&!l&&!d?null:i.createElement(i.Fragment,null,c!==!1&&b,l&&u);let g=null;if(e!==void 0)g=v(e);else if(o)g=v(i.createElement(Jr,{spin:!0}));else{const b=`${s}-suffix`;g=({open:y,showSearch:C})=>v(y&&C?i.createElement(tf,{className:b}):i.createElement(ef,{className:b}))}let h=null;n!==void 0?h=n:a?h=i.createElement(Jd,null):h=null;let p=null;return r!==void 0?p=r:p=i.createElement(Fr,null),{clearIcon:m,suffixIcon:g,itemIcon:h,removeIcon:p}}function QN(e){return F.useMemo(()=>{if(e)return(...t)=>F.createElement(jr,{space:!0},e.apply(void 0,t))},[e])}function ZN(e,t){return t!==void 0?t:e!==null}var JN=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Fb="SECRET_COMBOBOX_MODE_DO_NOT_USE",e4=(e,t)=>{var n,r,o,a,l;const{prefixCls:s,bordered:c,className:u,rootClassName:d,getPopupContainer:f,popupClassName:m,dropdownClassName:v,listHeight:g=256,placement:h,listItemHeight:p,size:b,disabled:y,notFoundContent:C,status:$,builtinPlacements:S,dropdownMatchSelectWidth:x,popupMatchSelectWidth:E,direction:O,style:w,allowClear:I,variant:P,dropdownStyle:M,transitionName:R,tagRender:N,maxCount:T,prefix:j,dropdownRender:z,popupRender:_,onDropdownVisibleChange:B,onOpenChange:V,styles:G,classNames:q}=e,H=JN(e,["prefixCls","bordered","className","rootClassName","getPopupContainer","popupClassName","dropdownClassName","listHeight","placement","listItemHeight","size","disabled","notFoundContent","status","builtinPlacements","dropdownMatchSelectWidth","popupMatchSelectWidth","direction","style","allowClear","variant","dropdownStyle","transitionName","tagRender","maxCount","prefix","dropdownRender","popupRender","onDropdownVisibleChange","onOpenChange","styles","classNames"]),{getPopupContainer:W,getPrefixCls:K,renderEmpty:U,direction:te,virtual:X,popupMatchSelectWidth:ae,popupOverflow:le}=i.useContext(ot),{showSearch:ee,style:Y,styles:re,className:ne,classNames:Z}=tn("select"),[,Q]=yn(),ie=p??(Q==null?void 0:Q.controlHeight),de=K("select",s),he=K(),ye=O??te,{compactSize:oe,compactItemClassnames:ce}=ro(de,ye),[ge,se]=yi("select",P,c),be=Cn(de),[we,Me,Te]=VN(de,be),Se=i.useMemo(()=>{const{mode:tt}=e;if(tt!=="combobox")return tt===Fb?"combobox":tt},[e.mode]),Fe=Se==="multiple"||Se==="tags",Ce=ZN(e.suffixIcon,e.showArrow),me=(n=E??x)!==null&&n!==void 0?n:ae,$e=((r=G==null?void 0:G.popup)===null||r===void 0?void 0:r.root)||((o=re.popup)===null||o===void 0?void 0:o.root)||M,Ee=QN(_||z),Ie=V||B,{status:fe,hasFeedback:ve,isFormItemInput:xe,feedbackIcon:Re}=i.useContext(Wn),it=bi(fe,$);let dt;C!==void 0?dt=C:Se==="combobox"?dt=null:dt=(U==null?void 0:U("Select"))||i.createElement(Bb,{componentName:"Select"});const{suffixIcon:Oe,itemIcon:Le,removeIcon:Ue,clearIcon:ke}=YN(Object.assign(Object.assign({},H),{multiple:Fe,hasFeedback:ve,feedbackIcon:Re,showSuffixIcon:Ce,prefixCls:de,componentName:"Select"})),Je=I===!0?{clearIcon:ke}:I,Xe=Gt(H,["suffixIcon","itemIcon"]),He=A(((a=q==null?void 0:q.popup)===null||a===void 0?void 0:a.root)||((l=Z==null?void 0:Z.popup)===null||l===void 0?void 0:l.root)||m||v,{[`${de}-dropdown-${ye}`]:ye==="rtl"},d,Z.root,q==null?void 0:q.root,Te,be,Me),je=Sn(tt=>{var mt;return(mt=b??oe)!==null&&mt!==void 0?mt:tt}),rt=i.useContext(Ln),et=y??rt,Pe=A({[`${de}-lg`]:je==="large",[`${de}-sm`]:je==="small",[`${de}-rtl`]:ye==="rtl",[`${de}-${ge}`]:se,[`${de}-in-form-item`]:xe},yo(de,it,ve),ce,ne,u,Z.root,q==null?void 0:q.root,d,Te,be,Me),qe=i.useMemo(()=>h!==void 0?h:ye==="rtl"?"bottomRight":"bottomLeft",[h,ye]),[We]=ma("SelectLike",$e==null?void 0:$e.zIndex);return we(i.createElement(Zd,Object.assign({ref:t,virtual:X,showSearch:ee},Xe,{style:Object.assign(Object.assign(Object.assign(Object.assign({},re.root),G==null?void 0:G.root),Y),w),dropdownMatchSelectWidth:me,transitionName:Mr(he,"slide-up",R),builtinPlacements:EN(S,le),listHeight:g,listItemHeight:ie,mode:Se,prefixCls:de,placement:qe,direction:ye,prefix:j,suffixIcon:Oe,menuItemSelectedIcon:Le,removeIcon:Ue,allowClear:Je,notFoundContent:dt,className:Pe,getPopupContainer:f||W,dropdownClassName:He,disabled:et,dropdownStyle:Object.assign(Object.assign({},$e),{zIndex:We}),maxCount:Fe?T:void 0,tagRender:Fe?N:void 0,dropdownRender:Ee,onDropdownVisibleChange:Ie})))},Eo=i.forwardRef(e4),t4=Ud(Eo,"dropdownAlign");Eo.SECRET_COMBOBOX_MODE_DO_NOT_USE=Fb;Eo.Option=Qd;Eo.OptGroup=Yd;Eo._InternalPanelDoNotUseOrYouWillBeFired=t4;const kb=(e,t)=>{typeof(e==null?void 0:e.addEventListener)<"u"?e.addEventListener("change",t):typeof(e==null?void 0:e.addListener)<"u"&&e.addListener(t)},Vb=(e,t)=>{typeof(e==null?void 0:e.removeEventListener)<"u"?e.removeEventListener("change",t):typeof(e==null?void 0:e.removeListener)<"u"&&e.removeListener(t)},aa=["xxl","xl","lg","md","sm","xs"],n4=e=>({xs:`(max-width: ${e.screenXSMax}px)`,sm:`(min-width: ${e.screenSM}px)`,md:`(min-width: ${e.screenMD}px)`,lg:`(min-width: ${e.screenLG}px)`,xl:`(min-width: ${e.screenXL}px)`,xxl:`(min-width: ${e.screenXXL}px)`}),r4=e=>{const t=e,n=[].concat(aa).reverse();return n.forEach((r,o)=>{const a=r.toUpperCase(),l=`screen${a}Min`,s=`screen${a}`;if(!(t[l]<=t[s]))throw new Error(`${l}<=${s} fails : !(${t[l]}<=${t[s]})`);if(o<n.length-1){const c=`screen${a}Max`;if(!(t[s]<=t[c]))throw new Error(`${s}<=${c} fails : !(${t[s]}<=${t[c]})`);const d=`screen${n[o+1].toUpperCase()}Min`;if(!(t[c]<=t[d]))throw new Error(`${c}<=${d} fails : !(${t[c]}<=${t[d]})`)}}),e},Wb=(e,t)=>{if(t){for(const n of aa)if(e[n]&&(t==null?void 0:t[n])!==void 0)return t[n]}},o4=()=>{const[,e]=yn(),t=n4(r4(e));return F.useMemo(()=>{const n=new Map;let r=-1,o={};return{responsiveMap:t,matchHandlers:{},dispatch(a){return o=a,n.forEach(l=>l(o)),n.size>=1},subscribe(a){return n.size||this.register(),r+=1,n.set(r,a),a(o),r},unsubscribe(a){n.delete(a),n.size||this.unregister()},register(){Object.entries(t).forEach(([a,l])=>{const s=({matches:u})=>{this.dispatch(Object.assign(Object.assign({},o),{[a]:u}))},c=window.matchMedia(l);kb(c,s),this.matchHandlers[l]={mql:c,listener:s},s(c)})},unregister(){Object.values(t).forEach(a=>{const l=this.matchHandlers[a];Vb(l==null?void 0:l.mql,l==null?void 0:l.listener)}),n.clear()}}},[e])};function nf(){const[,e]=i.useReducer(t=>t+1,0);return e}function xs(e=!0,t={}){const n=i.useRef(t),r=nf(),o=o4();return wt(()=>{const a=o.subscribe(l=>{n.current=l,e&&r()});return()=>o.unsubscribe(a)},[]),n.current}const ia=e=>e?typeof e=="function"?e():e:null;function rf(e){var t=e.children,n=e.prefixCls,r=e.id,o=e.overlayInnerStyle,a=e.bodyClassName,l=e.className,s=e.style;return i.createElement("div",{className:A("".concat(n,"-content"),l),style:s},i.createElement("div",{className:A("".concat(n,"-inner"),a),id:r,role:"tooltip",style:o},typeof t=="function"?t():t))}var To={shiftX:64,adjustY:1},jo={adjustX:1,shiftY:!0},or=[0,0],a4={left:{points:["cr","cl"],overflow:jo,offset:[-4,0],targetOffset:or},right:{points:["cl","cr"],overflow:jo,offset:[4,0],targetOffset:or},top:{points:["bc","tc"],overflow:To,offset:[0,-4],targetOffset:or},bottom:{points:["tc","bc"],overflow:To,offset:[0,4],targetOffset:or},topLeft:{points:["bl","tl"],overflow:To,offset:[0,-4],targetOffset:or},leftTop:{points:["tr","tl"],overflow:jo,offset:[-4,0],targetOffset:or},topRight:{points:["br","tr"],overflow:To,offset:[0,-4],targetOffset:or},rightTop:{points:["tl","tr"],overflow:jo,offset:[4,0],targetOffset:or},bottomRight:{points:["tr","br"],overflow:To,offset:[0,4],targetOffset:or},rightBottom:{points:["bl","br"],overflow:jo,offset:[4,0],targetOffset:or},bottomLeft:{points:["tl","bl"],overflow:To,offset:[0,4],targetOffset:or},leftBottom:{points:["br","bl"],overflow:jo,offset:[-4,0],targetOffset:or}},i4=["overlayClassName","trigger","mouseEnterDelay","mouseLeaveDelay","overlayStyle","prefixCls","children","onVisibleChange","afterVisibleChange","transitionName","animation","motion","placement","align","destroyTooltipOnHide","defaultVisible","getTooltipContainer","overlayInnerStyle","arrowContent","overlay","id","showArrow","classNames","styles"],l4=function(t,n){var r=t.overlayClassName,o=t.trigger,a=o===void 0?["hover"]:o,l=t.mouseEnterDelay,s=l===void 0?0:l,c=t.mouseLeaveDelay,u=c===void 0?.1:c,d=t.overlayStyle,f=t.prefixCls,m=f===void 0?"rc-tooltip":f,v=t.children,g=t.onVisibleChange,h=t.afterVisibleChange,p=t.transitionName,b=t.animation,y=t.motion,C=t.placement,$=C===void 0?"right":C,S=t.align,x=S===void 0?{}:S,E=t.destroyTooltipOnHide,O=E===void 0?!1:E,w=t.defaultVisible,I=t.getTooltipContainer,P=t.overlayInnerStyle;t.arrowContent;var M=t.overlay,R=t.id,N=t.showArrow,T=N===void 0?!0:N,j=t.classNames,z=t.styles,_=ft(t,i4),B=mi(R),V=i.useRef(null);i.useImperativeHandle(n,function(){return V.current});var G=k({},_);"visible"in t&&(G.popupVisible=t.visible);var q=function(){return i.createElement(rf,{key:"content",prefixCls:m,id:B,bodyClassName:j==null?void 0:j.body,overlayInnerStyle:k(k({},P),z==null?void 0:z.body)},M)},H=function(){var K=i.Children.only(v),U=(K==null?void 0:K.props)||{},te=k(k({},U),{},{"aria-describedby":M?B:null});return i.cloneElement(v,te)};return i.createElement(Ss,ue({popupClassName:A(r,j==null?void 0:j.root),prefixCls:m,popup:q,action:a,builtinPlacements:a4,popupPlacement:$,ref:V,popupAlign:x,getPopupContainer:I,onPopupVisibleChange:g,afterPopupVisibleChange:h,popupTransitionName:p,popupAnimation:b,popupMotion:y,defaultPopupVisible:w,autoDestroy:O,mouseLeaveDelay:u,popupStyle:k(k({},d),z==null?void 0:z.root),mouseEnterDelay:s,arrow:T},G),H())};const s4=i.forwardRef(l4);function of(e){const{sizePopupArrow:t,borderRadiusXS:n,borderRadiusOuter:r}=e,o=t/2,a=0,l=o,s=r*1/Math.sqrt(2),c=o-r*(1-1/Math.sqrt(2)),u=o-n*(1/Math.sqrt(2)),d=r*(Math.sqrt(2)-1)+n*(1/Math.sqrt(2)),f=2*o-u,m=d,v=2*o-s,g=c,h=2*o-a,p=l,b=o*Math.sqrt(2)+r*(Math.sqrt(2)-2),y=r*(Math.sqrt(2)-1),C=`polygon(${y}px 100%, 50% ${y}px, ${2*o-y}px 100%, ${y}px 100%)`,$=`path('M ${a} ${l} A ${r} ${r} 0 0 0 ${s} ${c} L ${u} ${d} A ${n} ${n} 0 0 1 ${f} ${m} L ${v} ${g} A ${r} ${r} 0 0 0 ${h} ${p} Z')`;return{arrowShadowWidth:b,arrowPath:$,arrowPolygon:C}}const c4=(e,t,n)=>{const{sizePopupArrow:r,arrowPolygon:o,arrowPath:a,arrowShadowWidth:l,borderRadiusXS:s,calc:c}=e;return{pointerEvents:"none",width:r,height:r,overflow:"hidden","&::before":{position:"absolute",bottom:0,insetInlineStart:0,width:r,height:c(r).div(2).equal(),background:t,clipPath:{_multi_value_:!0,value:[o,a]},content:'""'},"&::after":{content:'""',position:"absolute",width:l,height:l,bottom:0,insetInline:0,margin:"auto",borderRadius:{_skip_check_:!0,value:`0 0 ${L(s)} 0`},transform:"translateY(50%) rotate(-135deg)",boxShadow:n,zIndex:0,background:"transparent"}}},Kb=8;function ws(e){const{contentRadius:t,limitVerticalRadius:n}=e,r=t>12?t+2:12;return{arrowOffsetHorizontal:r,arrowOffsetVertical:n?Kb:r}}function Li(e,t){return e?t:{}}function af(e,t,n){const{componentCls:r,boxShadowPopoverArrow:o,arrowOffsetVertical:a,arrowOffsetHorizontal:l}=e,{arrowDistance:s=0,arrowPlacement:c={left:!0,right:!0,top:!0,bottom:!0}}=n||{};return{[r]:Object.assign(Object.assign(Object.assign(Object.assign({[`${r}-arrow`]:[Object.assign(Object.assign({position:"absolute",zIndex:1,display:"block"},c4(e,t,o)),{"&:before":{background:t}})]},Li(!!c.top,{[[`&-placement-top > ${r}-arrow`,`&-placement-topLeft > ${r}-arrow`,`&-placement-topRight > ${r}-arrow`].join(",")]:{bottom:s,transform:"translateY(100%) rotate(180deg)"},[`&-placement-top > ${r}-arrow`]:{left:{_skip_check_:!0,value:"50%"},transform:"translateX(-50%) translateY(100%) rotate(180deg)"},"&-placement-topLeft":{"--arrow-offset-horizontal":l,[`> ${r}-arrow`]:{left:{_skip_check_:!0,value:l}}},"&-placement-topRight":{"--arrow-offset-horizontal":`calc(100% - ${L(l)})`,[`> ${r}-arrow`]:{right:{_skip_check_:!0,value:l}}}})),Li(!!c.bottom,{[[`&-placement-bottom > ${r}-arrow`,`&-placement-bottomLeft > ${r}-arrow`,`&-placement-bottomRight > ${r}-arrow`].join(",")]:{top:s,transform:"translateY(-100%)"},[`&-placement-bottom > ${r}-arrow`]:{left:{_skip_check_:!0,value:"50%"},transform:"translateX(-50%) translateY(-100%)"},"&-placement-bottomLeft":{"--arrow-offset-horizontal":l,[`> ${r}-arrow`]:{left:{_skip_check_:!0,value:l}}},"&-placement-bottomRight":{"--arrow-offset-horizontal":`calc(100% - ${L(l)})`,[`> ${r}-arrow`]:{right:{_skip_check_:!0,value:l}}}})),Li(!!c.left,{[[`&-placement-left > ${r}-arrow`,`&-placement-leftTop > ${r}-arrow`,`&-placement-leftBottom > ${r}-arrow`].join(",")]:{right:{_skip_check_:!0,value:s},transform:"translateX(100%) rotate(90deg)"},[`&-placement-left > ${r}-arrow`]:{top:{_skip_check_:!0,value:"50%"},transform:"translateY(-50%) translateX(100%) rotate(90deg)"},[`&-placement-leftTop > ${r}-arrow`]:{top:a},[`&-placement-leftBottom > ${r}-arrow`]:{bottom:a}})),Li(!!c.right,{[[`&-placement-right > ${r}-arrow`,`&-placement-rightTop > ${r}-arrow`,`&-placement-rightBottom > ${r}-arrow`].join(",")]:{left:{_skip_check_:!0,value:s},transform:"translateX(-100%) rotate(-90deg)"},[`&-placement-right > ${r}-arrow`]:{top:{_skip_check_:!0,value:"50%"},transform:"translateY(-50%) translateX(-100%) rotate(-90deg)"},[`&-placement-rightTop > ${r}-arrow`]:{top:a},[`&-placement-rightBottom > ${r}-arrow`]:{bottom:a}}))}}function u4(e,t,n,r){if(r===!1)return{adjustX:!1,adjustY:!1};const o=r&&typeof r=="object"?r:{},a={};switch(e){case"top":case"bottom":a.shiftX=t.arrowOffsetHorizontal*2+n,a.shiftY=!0,a.adjustY=!0;break;case"left":case"right":a.shiftY=t.arrowOffsetVertical*2+n,a.shiftX=!0,a.adjustX=!0;break}const l=Object.assign(Object.assign({},a),o);return l.shiftX||(l.adjustX=!0),l.shiftY||(l.adjustY=!0),l}const Wv={left:{points:["cr","cl"]},right:{points:["cl","cr"]},top:{points:["bc","tc"]},bottom:{points:["tc","bc"]},topLeft:{points:["bl","tl"]},leftTop:{points:["tr","tl"]},topRight:{points:["br","tr"]},rightTop:{points:["tl","tr"]},bottomRight:{points:["tr","br"]},rightBottom:{points:["bl","br"]},bottomLeft:{points:["tl","bl"]},leftBottom:{points:["br","bl"]}},d4={topLeft:{points:["bl","tc"]},leftTop:{points:["tr","cl"]},topRight:{points:["br","tc"]},rightTop:{points:["tl","cr"]},bottomRight:{points:["tr","bc"]},rightBottom:{points:["bl","cr"]},bottomLeft:{points:["tl","bc"]},leftBottom:{points:["br","cl"]}},f4=new Set(["topLeft","topRight","bottomLeft","bottomRight","leftTop","leftBottom","rightTop","rightBottom"]);function Gb(e){const{arrowWidth:t,autoAdjustOverflow:n,arrowPointAtCenter:r,offset:o,borderRadius:a,visibleFirst:l}=e,s=t/2,c={},u=ws({contentRadius:a,limitVerticalRadius:!0});return Object.keys(Wv).forEach(d=>{const f=r&&d4[d]||Wv[d],m=Object.assign(Object.assign({},f),{offset:[0,0],dynamicInset:!0});switch(c[d]=m,f4.has(d)&&(m.autoArrow=!1),d){case"top":case"topLeft":case"topRight":m.offset[1]=-s-o;break;case"bottom":case"bottomLeft":case"bottomRight":m.offset[1]=s+o;break;case"left":case"leftTop":case"leftBottom":m.offset[0]=-s-o;break;case"right":case"rightTop":case"rightBottom":m.offset[0]=s+o;break}if(r)switch(d){case"topLeft":case"bottomLeft":m.offset[0]=-u.arrowOffsetHorizontal-s;break;case"topRight":case"bottomRight":m.offset[0]=u.arrowOffsetHorizontal+s;break;case"leftTop":case"rightTop":m.offset[1]=-u.arrowOffsetHorizontal*2+s;break;case"leftBottom":case"rightBottom":m.offset[1]=u.arrowOffsetHorizontal*2-s;break}m.overflow=u4(d,u,t,n),l&&(m.htmlRegion="visibleFirst")}),c}const m4=e=>{const{calc:t,componentCls:n,tooltipMaxWidth:r,tooltipColor:o,tooltipBg:a,tooltipBorderRadius:l,zIndexPopup:s,controlHeight:c,boxShadowSecondary:u,paddingSM:d,paddingXS:f,arrowOffsetHorizontal:m,sizePopupArrow:v}=e,g=t(l).add(v).add(m).equal(),h=t(l).mul(2).add(v).equal();return[{[n]:Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),{position:"absolute",zIndex:s,display:"block",width:"max-content",maxWidth:r,visibility:"visible","--valid-offset-x":"var(--arrow-offset-horizontal, var(--arrow-x))",transformOrigin:["var(--valid-offset-x, 50%)","var(--arrow-y, 50%)"].join(" "),"&-hidden":{display:"none"},"--antd-arrow-background-color":a,[`${n}-inner`]:{minWidth:h,minHeight:c,padding:`${L(e.calc(d).div(2).equal())} ${L(f)}`,color:`var(--ant-tooltip-color, ${o})`,textAlign:"start",textDecoration:"none",wordWrap:"break-word",backgroundColor:a,borderRadius:l,boxShadow:u,boxSizing:"border-box"},[["&-placement-topLeft","&-placement-topRight","&-placement-bottomLeft","&-placement-bottomRight"].join(",")]:{minWidth:g},[["&-placement-left","&-placement-leftTop","&-placement-leftBottom","&-placement-right","&-placement-rightTop","&-placement-rightBottom"].join(",")]:{[`${n}-inner`]:{borderRadius:e.min(l,Kb)}},[`${n}-content`]:{position:"relative"}}),es(e,(p,{darkColor:b})=>({[`&${n}-${p}`]:{[`${n}-inner`]:{backgroundColor:b},[`${n}-arrow`]:{"--antd-arrow-background-color":b}}}))),{"&-rtl":{direction:"rtl"}})},af(e,"var(--antd-arrow-background-color)"),{[`${n}-pure`]:{position:"relative",maxWidth:"none",margin:e.sizePopupArrow}}]},v4=e=>Object.assign(Object.assign({zIndexPopup:e.zIndexPopupBase+70},ws({contentRadius:e.borderRadius,limitVerticalRadius:!0})),of(yt(e,{borderRadiusOuter:Math.min(e.borderRadiusOuter,4)}))),qb=(e,t=!0)=>It("Tooltip",r=>{const{borderRadius:o,colorTextLightSolid:a,colorBgSpotlight:l}=r,s=yt(r,{tooltipMaxWidth:250,tooltipColor:a,tooltipBorderRadius:o,tooltipBg:l});return[m4(s),ui(r,"zoom-big-fast")]},v4,{resetStyle:!1,injectStyle:t})(e),g4=Zr.map(e=>`${e}-inverse`),p4=["success","processing","error","default","warning"];function Es(e,t=!0){return t?[].concat(pe(g4),pe(Zr)).includes(e):Zr.includes(e)}function h4(e){return p4.includes(e)}function Ub(e,t){const n=Es(t),r=A({[`${e}-${t}`]:t&&n}),o={},a={},l=Nn(t).toRgb(),c=(.299*l.r+.587*l.g+.114*l.b)/255<.5?"#FFF":"#000";return t&&!n&&(o.background=t,o["--ant-tooltip-color"]=c,a["--antd-arrow-background-color"]=t),{className:r,overlayStyle:o,arrowStyle:a}}const b4=e=>{const{prefixCls:t,className:n,placement:r="top",title:o,color:a,overlayInnerStyle:l}=e,{getPrefixCls:s}=i.useContext(ot),c=s("tooltip",t),[u,d,f]=qb(c),m=Ub(c,a),v=m.arrowStyle,g=Object.assign(Object.assign({},l),m.overlayStyle),h=A(d,f,c,`${c}-pure`,`${c}-placement-${r}`,n,m.className);return u(i.createElement("div",{className:h,style:v},i.createElement("div",{className:`${c}-arrow`}),i.createElement(rf,Object.assign({},e,{className:d,prefixCls:c,overlayInnerStyle:g}),o)))};var y4=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const C4=i.forwardRef((e,t)=>{var n,r;const{prefixCls:o,openClassName:a,getTooltipContainer:l,color:s,overlayInnerStyle:c,children:u,afterOpenChange:d,afterVisibleChange:f,destroyTooltipOnHide:m,destroyOnHidden:v,arrow:g=!0,title:h,overlay:p,builtinPlacements:b,arrowPointAtCenter:y=!1,autoAdjustOverflow:C=!0,motion:$,getPopupContainer:S,placement:x="top",mouseEnterDelay:E=.1,mouseLeaveDelay:O=.1,overlayStyle:w,rootClassName:I,overlayClassName:P,styles:M,classNames:R}=e,N=y4(e,["prefixCls","openClassName","getTooltipContainer","color","overlayInnerStyle","children","afterOpenChange","afterVisibleChange","destroyTooltipOnHide","destroyOnHidden","arrow","title","overlay","builtinPlacements","arrowPointAtCenter","autoAdjustOverflow","motion","getPopupContainer","placement","mouseEnterDelay","mouseLeaveDelay","overlayStyle","rootClassName","overlayClassName","styles","classNames"]),T=!!g,[,j]=yn(),{getPopupContainer:z,getPrefixCls:_,direction:B,className:V,style:G,classNames:q,styles:H}=tn("tooltip"),W=no(),K=i.useRef(null),U=()=>{var Ce;(Ce=K.current)===null||Ce===void 0||Ce.forceAlign()};i.useImperativeHandle(t,()=>{var Ce,me;return{forceAlign:U,forcePopupAlign:()=>{W.deprecated(!1,"forcePopupAlign","forceAlign"),U()},nativeElement:(Ce=K.current)===null||Ce===void 0?void 0:Ce.nativeElement,popupElement:(me=K.current)===null||me===void 0?void 0:me.popupElement}});const[te,X]=Lt(!1,{value:(n=e.open)!==null&&n!==void 0?n:e.visible,defaultValue:(r=e.defaultOpen)!==null&&r!==void 0?r:e.defaultVisible}),ae=!h&&!p&&h!==0,le=Ce=>{var me,$e;X(ae?!1:Ce),ae||((me=e.onOpenChange)===null||me===void 0||me.call(e,Ce),($e=e.onVisibleChange)===null||$e===void 0||$e.call(e,Ce))},ee=i.useMemo(()=>{var Ce,me;let $e=y;return typeof g=="object"&&($e=(me=(Ce=g.pointAtCenter)!==null&&Ce!==void 0?Ce:g.arrowPointAtCenter)!==null&&me!==void 0?me:y),b||Gb({arrowPointAtCenter:$e,autoAdjustOverflow:C,arrowWidth:T?j.sizePopupArrow:0,borderRadius:j.borderRadius,offset:j.marginXXS,visibleFirst:!0})},[y,g,b,j]),Y=i.useMemo(()=>h===0?h:p||h||"",[p,h]),re=i.createElement(jr,{space:!0},typeof Y=="function"?Y():Y),ne=_("tooltip",o),Z=_(),Q=e["data-popover-inject"];let ie=te;!("open"in e)&&!("visible"in e)&&ae&&(ie=!1);const de=i.isValidElement(u)&&!u0(u)?u:i.createElement("span",null,u),he=de.props,ye=!he.className||typeof he.className=="string"?A(he.className,a||`${ne}-open`):he.className,[oe,ce,ge]=qb(ne,!Q),se=Ub(ne,s),be=se.arrowStyle,we=A(P,{[`${ne}-rtl`]:B==="rtl"},se.className,I,ce,ge,V,q.root,R==null?void 0:R.root),Me=A(q.body,R==null?void 0:R.body),[Te,Se]=ma("Tooltip",N.zIndex),Fe=i.createElement(s4,Object.assign({},N,{zIndex:Te,showArrow:T,placement:x,mouseEnterDelay:E,mouseLeaveDelay:O,prefixCls:ne,classNames:{root:we,body:Me},styles:{root:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},be),H.root),G),w),M==null?void 0:M.root),body:Object.assign(Object.assign(Object.assign(Object.assign({},H.body),c),M==null?void 0:M.body),se.overlayStyle)},getTooltipContainer:S||l||z,ref:K,builtinPlacements:ee,overlay:re,visible:ie,onVisibleChange:le,afterVisibleChange:d??f,arrowContent:i.createElement("span",{className:`${ne}-arrow-content`}),motion:{motionName:Mr(Z,"zoom-big-fast",e.transitionName),motionDeadline:1e3},destroyTooltipOnHide:v??!!m}),ie?cn(de,{className:ye}):de);return oe(i.createElement(li.Provider,{value:Se},Fe))}),$r=C4;$r._InternalPanelDoNotUseOrYouWillBeFired=b4;const S4=e=>{const{componentCls:t,popoverColor:n,titleMinWidth:r,fontWeightStrong:o,innerPadding:a,boxShadowSecondary:l,colorTextHeading:s,borderRadiusLG:c,zIndexPopup:u,titleMarginBottom:d,colorBgElevated:f,popoverBg:m,titleBorderBottom:v,innerContentPadding:g,titlePadding:h}=e;return[{[t]:Object.assign(Object.assign({},Tt(e)),{position:"absolute",top:0,left:{_skip_check_:!0,value:0},zIndex:u,fontWeight:"normal",whiteSpace:"normal",textAlign:"start",cursor:"auto",userSelect:"text","--valid-offset-x":"var(--arrow-offset-horizontal, var(--arrow-x))",transformOrigin:["var(--valid-offset-x, 50%)","var(--arrow-y, 50%)"].join(" "),"--antd-arrow-background-color":f,width:"max-content",maxWidth:"100vw","&-rtl":{direction:"rtl"},"&-hidden":{display:"none"},[`${t}-content`]:{position:"relative"},[`${t}-inner`]:{backgroundColor:m,backgroundClip:"padding-box",borderRadius:c,boxShadow:l,padding:a},[`${t}-title`]:{minWidth:r,marginBottom:d,color:s,fontWeight:o,borderBottom:v,padding:h},[`${t}-inner-content`]:{color:n,padding:g}})},af(e,"var(--antd-arrow-background-color)"),{[`${t}-pure`]:{position:"relative",maxWidth:"none",margin:e.sizePopupArrow,display:"inline-block",[`${t}-content`]:{display:"inline-block"}}}]},$4=e=>{const{componentCls:t}=e;return{[t]:Zr.map(n=>{const r=e[`${n}6`];return{[`&${t}-${n}`]:{"--antd-arrow-background-color":r,[`${t}-inner`]:{backgroundColor:r},[`${t}-arrow`]:{background:"transparent"}}}})}},x4=e=>{const{lineWidth:t,controlHeight:n,fontHeight:r,padding:o,wireframe:a,zIndexPopupBase:l,borderRadiusLG:s,marginXS:c,lineType:u,colorSplit:d,paddingSM:f}=e,m=n-r,v=m/2,g=m/2-t,h=o;return Object.assign(Object.assign(Object.assign({titleMinWidth:177,zIndexPopup:l+30},of(e)),ws({contentRadius:s,limitVerticalRadius:!0})),{innerPadding:a?0:12,titleMarginBottom:a?0:c,titlePadding:a?`${v}px ${h}px ${g}px`:0,titleBorderBottom:a?`${t}px ${u} ${d}`:"none",innerContentPadding:a?`${f}px ${h}px`:0})},Xb=It("Popover",e=>{const{colorBgElevated:t,colorText:n}=e,r=yt(e,{popoverBg:t,popoverColor:n});return[S4(r),$4(r),ui(r,"zoom-big")]},x4,{resetStyle:!1,deprecatedTokens:[["width","titleMinWidth"],["minWidth","titleMinWidth"]]});var w4=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Yb=({title:e,content:t,prefixCls:n})=>!e&&!t?null:i.createElement(i.Fragment,null,e&&i.createElement("div",{className:`${n}-title`},e),t&&i.createElement("div",{className:`${n}-inner-content`},t)),E4=e=>{const{hashId:t,prefixCls:n,className:r,style:o,placement:a="top",title:l,content:s,children:c}=e,u=ia(l),d=ia(s),f=A(t,n,`${n}-pure`,`${n}-placement-${a}`,r);return i.createElement("div",{className:f,style:o},i.createElement("div",{className:`${n}-arrow`}),i.createElement(rf,Object.assign({},e,{className:t,prefixCls:n}),c||i.createElement(Yb,{prefixCls:n,title:u,content:d})))},Qb=e=>{const{prefixCls:t,className:n}=e,r=w4(e,["prefixCls","className"]),{getPrefixCls:o}=i.useContext(ot),a=o("popover",t),[l,s,c]=Xb(a);return l(i.createElement(E4,Object.assign({},r,{prefixCls:a,hashId:s,className:A(n,c)})))};var O4=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const I4=i.forwardRef((e,t)=>{var n,r;const{prefixCls:o,title:a,content:l,overlayClassName:s,placement:c="top",trigger:u="hover",children:d,mouseEnterDelay:f=.1,mouseLeaveDelay:m=.1,onOpenChange:v,overlayStyle:g={},styles:h,classNames:p}=e,b=O4(e,["prefixCls","title","content","overlayClassName","placement","trigger","children","mouseEnterDelay","mouseLeaveDelay","onOpenChange","overlayStyle","styles","classNames"]),{getPrefixCls:y,className:C,style:$,classNames:S,styles:x}=tn("popover"),E=y("popover",o),[O,w,I]=Xb(E),P=y(),M=A(s,w,I,C,S.root,p==null?void 0:p.root),R=A(S.body,p==null?void 0:p.body),[N,T]=Lt(!1,{value:(n=e.open)!==null&&n!==void 0?n:e.visible,defaultValue:(r=e.defaultOpen)!==null&&r!==void 0?r:e.defaultVisible}),j=(G,q)=>{T(G,!0),v==null||v(G,q)},z=G=>{G.keyCode===Ne.ESC&&j(!1,G)},_=G=>{j(G)},B=ia(a),V=ia(l);return O(i.createElement($r,Object.assign({placement:c,trigger:u,mouseEnterDelay:f,mouseLeaveDelay:m},b,{prefixCls:E,classNames:{root:M,body:R},styles:{root:Object.assign(Object.assign(Object.assign(Object.assign({},x.root),$),g),h==null?void 0:h.root),body:Object.assign(Object.assign({},x.body),h==null?void 0:h.body)},ref:t,open:N,onOpenChange:_,overlay:B||V?i.createElement(Yb,{prefixCls:E,title:B,content:V}):null,transitionName:Mr(P,"zoom-big",b.transitionName),"data-popover-inject":!0}),cn(d,{onKeyDown:G=>{var q,H;i.isValidElement(d)&&((H=d==null?void 0:(q=d.props).onKeyDown)===null||H===void 0||H.call(q,G)),z(G)}})))}),lf=I4;lf._InternalPanelDoNotUseOrYouWillBeFired=Qb;const R4=new $t("antStatusProcessing",{"0%":{transform:"scale(0.8)",opacity:.5},"100%":{transform:"scale(2.4)",opacity:0}}),P4=new $t("antZoomBadgeIn",{"0%":{transform:"scale(0) translate(50%, -50%)",opacity:0},"100%":{transform:"scale(1) translate(50%, -50%)"}}),N4=new $t("antZoomBadgeOut",{"0%":{transform:"scale(1) translate(50%, -50%)"},"100%":{transform:"scale(0) translate(50%, -50%)",opacity:0}}),M4=new $t("antNoWrapperZoomBadgeIn",{"0%":{transform:"scale(0)",opacity:0},"100%":{transform:"scale(1)"}}),T4=new $t("antNoWrapperZoomBadgeOut",{"0%":{transform:"scale(1)"},"100%":{transform:"scale(0)",opacity:0}}),j4=new $t("antBadgeLoadingCircle",{"0%":{transformOrigin:"50%"},"100%":{transform:"translate(50%, -50%) rotate(360deg)",transformOrigin:"50%"}}),z4=e=>{const{componentCls:t,iconCls:n,antCls:r,badgeShadowSize:o,textFontSize:a,textFontSizeSM:l,statusSize:s,dotSize:c,textFontWeight:u,indicatorHeight:d,indicatorHeightSM:f,marginXS:m,calc:v}=e,g=`${r}-scroll-number`,h=es(e,(p,{darkColor:b})=>({[`&${t} ${t}-color-${p}`]:{background:b,[`&:not(${t}-count)`]:{color:b},"a:hover &":{background:b}}}));return{[t]:Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),{position:"relative",display:"inline-block",width:"fit-content",lineHeight:1,[`${t}-count`]:{display:"inline-flex",justifyContent:"center",zIndex:e.indicatorZIndex,minWidth:d,height:d,color:e.badgeTextColor,fontWeight:u,fontSize:a,lineHeight:L(d),whiteSpace:"nowrap",textAlign:"center",background:e.badgeColor,borderRadius:v(d).div(2).equal(),boxShadow:`0 0 0 ${L(o)} ${e.badgeShadowColor}`,transition:`background ${e.motionDurationMid}`,a:{color:e.badgeTextColor},"a:hover":{color:e.badgeTextColor},"a:hover &":{background:e.badgeColorHover}},[`${t}-count-sm`]:{minWidth:f,height:f,fontSize:l,lineHeight:L(f),borderRadius:v(f).div(2).equal()},[`${t}-multiple-words`]:{padding:`0 ${L(e.paddingXS)}`,bdi:{unicodeBidi:"plaintext"}},[`${t}-dot`]:{zIndex:e.indicatorZIndex,width:c,minWidth:c,height:c,background:e.badgeColor,borderRadius:"100%",boxShadow:`0 0 0 ${L(o)} ${e.badgeShadowColor}`},[`${t}-count, ${t}-dot, ${g}-custom-component`]:{position:"absolute",top:0,insetInlineEnd:0,transform:"translate(50%, -50%)",transformOrigin:"100% 0%",[`&${n}-spin`]:{animationName:j4,animationDuration:"1s",animationIterationCount:"infinite",animationTimingFunction:"linear"}},[`&${t}-status`]:{lineHeight:"inherit",verticalAlign:"baseline",[`${t}-status-dot`]:{position:"relative",top:-1,display:"inline-block",width:s,height:s,verticalAlign:"middle",borderRadius:"50%"},[`${t}-status-success`]:{backgroundColor:e.colorSuccess},[`${t}-status-processing`]:{overflow:"visible",color:e.colorInfo,backgroundColor:e.colorInfo,borderColor:"currentcolor","&::after":{position:"absolute",top:0,insetInlineStart:0,width:"100%",height:"100%",borderWidth:o,borderStyle:"solid",borderColor:"inherit",borderRadius:"50%",animationName:R4,animationDuration:e.badgeProcessingDuration,animationIterationCount:"infinite",animationTimingFunction:"ease-in-out",content:'""'}},[`${t}-status-default`]:{backgroundColor:e.colorTextPlaceholder},[`${t}-status-error`]:{backgroundColor:e.colorError},[`${t}-status-warning`]:{backgroundColor:e.colorWarning},[`${t}-status-text`]:{marginInlineStart:m,color:e.colorText,fontSize:e.fontSize}}}),h),{[`${t}-zoom-appear, ${t}-zoom-enter`]:{animationName:P4,animationDuration:e.motionDurationSlow,animationTimingFunction:e.motionEaseOutBack,animationFillMode:"both"},[`${t}-zoom-leave`]:{animationName:N4,animationDuration:e.motionDurationSlow,animationTimingFunction:e.motionEaseOutBack,animationFillMode:"both"},[`&${t}-not-a-wrapper`]:{[`${t}-zoom-appear, ${t}-zoom-enter`]:{animationName:M4,animationDuration:e.motionDurationSlow,animationTimingFunction:e.motionEaseOutBack},[`${t}-zoom-leave`]:{animationName:T4,animationDuration:e.motionDurationSlow,animationTimingFunction:e.motionEaseOutBack},[`&:not(${t}-status)`]:{verticalAlign:"middle"},[`${g}-custom-component, ${t}-count`]:{transform:"none"},[`${g}-custom-component, ${g}`]:{position:"relative",top:"auto",display:"block",transformOrigin:"50% 50%"}},[g]:{overflow:"hidden",transition:`all ${e.motionDurationMid} ${e.motionEaseOutBack}`,[`${g}-only`]:{position:"relative",display:"inline-block",height:d,transition:`all ${e.motionDurationSlow} ${e.motionEaseOutBack}`,WebkitTransformStyle:"preserve-3d",WebkitBackfaceVisibility:"hidden",[`> p${g}-only-unit`]:{height:d,margin:0,WebkitTransformStyle:"preserve-3d",WebkitBackfaceVisibility:"hidden"}},[`${g}-symbol`]:{verticalAlign:"top"}},"&-rtl":{direction:"rtl",[`${t}-count, ${t}-dot, ${g}-custom-component`]:{transform:"translate(-50%, -50%)"}}})}},Zb=e=>{const{fontHeight:t,lineWidth:n,marginXS:r,colorBorderBg:o}=e,a=t,l=n,s=e.colorTextLightSolid,c=e.colorError,u=e.colorErrorHover;return yt(e,{badgeFontHeight:a,badgeShadowSize:l,badgeTextColor:s,badgeColor:c,badgeColorHover:u,badgeShadowColor:o,badgeProcessingDuration:"1.2s",badgeRibbonOffset:r,badgeRibbonCornerTransform:"scaleY(0.75)",badgeRibbonCornerFilter:"brightness(75%)"})},Jb=e=>{const{fontSize:t,lineHeight:n,fontSizeSM:r,lineWidth:o}=e;return{indicatorZIndex:"auto",indicatorHeight:Math.round(t*n)-2*o,indicatorHeightSM:t,dotSize:r/2,textFontSize:r,textFontSizeSM:r,textFontWeight:"normal",statusSize:r/2}},D4=It("Badge",e=>{const t=Zb(e);return z4(t)},Jb),_4=e=>{const{antCls:t,badgeFontHeight:n,marginXS:r,badgeRibbonOffset:o,calc:a}=e,l=`${t}-ribbon`,s=`${t}-ribbon-wrapper`,c=es(e,(u,{darkColor:d})=>({[`&${l}-color-${u}`]:{background:d,color:d}}));return{[s]:{position:"relative"},[l]:Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),{position:"absolute",top:r,padding:`0 ${L(e.paddingXS)}`,color:e.colorPrimary,lineHeight:L(n),whiteSpace:"nowrap",backgroundColor:e.colorPrimary,borderRadius:e.borderRadiusSM,[`${l}-text`]:{color:e.badgeTextColor},[`${l}-corner`]:{position:"absolute",top:"100%",width:o,height:o,color:"currentcolor",border:`${L(a(o).div(2).equal())} solid`,transform:e.badgeRibbonCornerTransform,transformOrigin:"top",filter:e.badgeRibbonCornerFilter}}),c),{[`&${l}-placement-end`]:{insetInlineEnd:a(o).mul(-1).equal(),borderEndEndRadius:0,[`${l}-corner`]:{insetInlineEnd:0,borderInlineEndColor:"transparent",borderBlockEndColor:"transparent"}},[`&${l}-placement-start`]:{insetInlineStart:a(o).mul(-1).equal(),borderEndStartRadius:0,[`${l}-corner`]:{insetInlineStart:0,borderBlockEndColor:"transparent",borderInlineStartColor:"transparent"}},"&-rtl":{direction:"rtl"}})}},B4=It(["Badge","Ribbon"],e=>{const t=Zb(e);return _4(t)},Jb),L4=e=>{const{className:t,prefixCls:n,style:r,color:o,children:a,text:l,placement:s="end",rootClassName:c}=e,{getPrefixCls:u,direction:d}=i.useContext(ot),f=u("ribbon",n),m=`${f}-wrapper`,[v,g,h]=B4(f,m),p=Es(o,!1),b=A(f,`${f}-placement-${s}`,{[`${f}-rtl`]:d==="rtl",[`${f}-color-${o}`]:p},t),y={},C={};return o&&!p&&(y.background=o,C.color=o),v(i.createElement("div",{className:A(m,c,g,h)},a,i.createElement("div",{className:A(b,g),style:Object.assign(Object.assign({},y),r)},i.createElement("span",{className:`${f}-text`},l),i.createElement("div",{className:`${f}-corner`,style:C}))))},Kv=e=>{const{prefixCls:t,value:n,current:r,offset:o=0}=e;let a;return o&&(a={position:"absolute",top:`${o}00%`,left:0}),i.createElement("span",{style:a,className:A(`${t}-only-unit`,{current:r})},n)};function H4(e,t,n){let r=e,o=0;for(;(r+10)%10!==t;)r+=n,o+=n;return o}const A4=e=>{const{prefixCls:t,count:n,value:r}=e,o=Number(r),a=Math.abs(n),[l,s]=i.useState(o),[c,u]=i.useState(a),d=()=>{s(o),u(a)};i.useEffect(()=>{const v=setTimeout(d,1e3);return()=>clearTimeout(v)},[o]);let f,m;if(l===o||Number.isNaN(o)||Number.isNaN(l))f=[i.createElement(Kv,Object.assign({},e,{key:o,current:!0}))],m={transition:"none"};else{f=[];const v=o+10,g=[];for(let y=o;y<=v;y+=1)g.push(y);const h=c<a?1:-1,p=g.findIndex(y=>y%10===l);f=(h<0?g.slice(0,p+1):g.slice(p)).map((y,C)=>{const $=y%10;return i.createElement(Kv,Object.assign({},e,{key:y,value:$,offset:h<0?C-p:C,current:C===p}))}),m={transform:`translateY(${-H4(l,o,h)}00%)`}}return i.createElement("span",{className:`${t}-only`,style:m,onTransitionEnd:d},f)};var F4=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const k4=i.forwardRef((e,t)=>{const{prefixCls:n,count:r,className:o,motionClassName:a,style:l,title:s,show:c,component:u="sup",children:d}=e,f=F4(e,["prefixCls","count","className","motionClassName","style","title","show","component","children"]),{getPrefixCls:m}=i.useContext(ot),v=m("scroll-number",n),g=Object.assign(Object.assign({},f),{"data-show":c,style:l,className:A(v,o,a),title:s});let h=r;if(r&&Number(r)%1===0){const p=String(r).split("");h=i.createElement("bdi",null,p.map((b,y)=>i.createElement(A4,{prefixCls:v,count:Number(r),value:b,key:p.length-y})))}return l!=null&&l.borderColor&&(g.style=Object.assign(Object.assign({},l),{boxShadow:`0 0 0 1px ${l.borderColor} inset`})),d?cn(d,p=>({className:A(`${v}-custom-component`,p==null?void 0:p.className,a)})):i.createElement(u,Object.assign({},g,{ref:t}),h)});var V4=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const W4=i.forwardRef((e,t)=>{var n,r,o,a,l;const{prefixCls:s,scrollNumberPrefixCls:c,children:u,status:d,text:f,color:m,count:v=null,overflowCount:g=99,dot:h=!1,size:p="default",title:b,offset:y,style:C,className:$,rootClassName:S,classNames:x,styles:E,showZero:O=!1}=e,w=V4(e,["prefixCls","scrollNumberPrefixCls","children","status","text","color","count","overflowCount","dot","size","title","offset","style","className","rootClassName","classNames","styles","showZero"]),{getPrefixCls:I,direction:P,badge:M}=i.useContext(ot),R=I("badge",s),[N,T,j]=D4(R),z=v>g?`${g}+`:v,_=z==="0"||z===0,B=v===null||_&&!O,V=(d!=null||m!=null)&&B,G=d!=null||!_,q=h&&!_,H=q?"":z,W=i.useMemo(()=>(H==null||H===""||_&&!O)&&!q,[H,_,O,q]),K=i.useRef(v);W||(K.current=v);const U=K.current,te=i.useRef(H);W||(te.current=H);const X=te.current,ae=i.useRef(q);W||(ae.current=q);const le=i.useMemo(()=>{if(!y)return Object.assign(Object.assign({},M==null?void 0:M.style),C);const de={marginTop:y[1]};return P==="rtl"?de.left=parseInt(y[0],10):de.right=-parseInt(y[0],10),Object.assign(Object.assign(Object.assign({},de),M==null?void 0:M.style),C)},[P,y,C,M==null?void 0:M.style]),ee=b??(typeof U=="string"||typeof U=="number"?U:void 0),Y=W||!f?null:i.createElement("span",{className:`${R}-status-text`},f),re=!U||typeof U!="object"?void 0:cn(U,de=>({style:Object.assign(Object.assign({},le),de.style)})),ne=Es(m,!1),Z=A(x==null?void 0:x.indicator,(n=M==null?void 0:M.classNames)===null||n===void 0?void 0:n.indicator,{[`${R}-status-dot`]:V,[`${R}-status-${d}`]:!!d,[`${R}-color-${m}`]:ne}),Q={};m&&!ne&&(Q.color=m,Q.background=m);const ie=A(R,{[`${R}-status`]:V,[`${R}-not-a-wrapper`]:!u,[`${R}-rtl`]:P==="rtl"},$,S,M==null?void 0:M.className,(r=M==null?void 0:M.classNames)===null||r===void 0?void 0:r.root,x==null?void 0:x.root,T,j);if(!u&&V&&(f||G||!B)){const de=le.color;return N(i.createElement("span",Object.assign({},w,{className:ie,style:Object.assign(Object.assign(Object.assign({},E==null?void 0:E.root),(o=M==null?void 0:M.styles)===null||o===void 0?void 0:o.root),le)}),i.createElement("span",{className:Z,style:Object.assign(Object.assign(Object.assign({},E==null?void 0:E.indicator),(a=M==null?void 0:M.styles)===null||a===void 0?void 0:a.indicator),Q)}),f&&i.createElement("span",{style:{color:de},className:`${R}-status-text`},f)))}return N(i.createElement("span",Object.assign({ref:t},w,{className:ie,style:Object.assign(Object.assign({},(l=M==null?void 0:M.styles)===null||l===void 0?void 0:l.root),E==null?void 0:E.root)}),u,i.createElement(En,{visible:!W,motionName:`${R}-zoom`,motionAppear:!1,motionDeadline:1e3},({className:de})=>{var he,ye;const oe=I("scroll-number",c),ce=ae.current,ge=A(x==null?void 0:x.indicator,(he=M==null?void 0:M.classNames)===null||he===void 0?void 0:he.indicator,{[`${R}-dot`]:ce,[`${R}-count`]:!ce,[`${R}-count-sm`]:p==="small",[`${R}-multiple-words`]:!ce&&X&&X.toString().length>1,[`${R}-status-${d}`]:!!d,[`${R}-color-${m}`]:ne});let se=Object.assign(Object.assign(Object.assign({},E==null?void 0:E.indicator),(ye=M==null?void 0:M.styles)===null||ye===void 0?void 0:ye.indicator),le);return m&&!ne&&(se=se||{},se.background=m),i.createElement(k4,{prefixCls:oe,show:!W,motionClassName:de,className:ge,count:X,title:ee,style:se,key:"scrollNumber"},re)}),Y))}),K4=W4;K4.Ribbon=L4;var G4={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M724 218.3V141c0-6.7-7.7-10.4-12.9-6.3L260.3 486.8a31.86 31.86 0 000 50.3l450.8 352.1c5.3 4.1 12.9.4 12.9-6.3v-77.3c0-4.9-2.3-9.6-6.1-12.6l-360-281 360-281.1c3.8-3 6.1-7.7 6.1-12.6z"}}]},name:"left",theme:"outlined"},q4=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:G4}))},Ja=i.forwardRef(q4),U4=Ne.ESC,X4=Ne.TAB;function Y4(e){var t=e.visible,n=e.triggerRef,r=e.onVisibleChange,o=e.autoFocus,a=e.overlayRef,l=i.useRef(!1),s=function(){if(t){var f,m;(f=n.current)===null||f===void 0||(m=f.focus)===null||m===void 0||m.call(f),r==null||r(!1)}},c=function(){var f;return(f=a.current)!==null&&f!==void 0&&f.focus?(a.current.focus(),l.current=!0,!0):!1},u=function(f){switch(f.keyCode){case U4:s();break;case X4:{var m=!1;l.current||(m=c()),m?f.preventDefault():s();break}}};i.useEffect(function(){return t?(window.addEventListener("keydown",u),o&&Et(c,3),function(){window.removeEventListener("keydown",u),l.current=!1}):function(){l.current=!1}},[t])}var Q4=i.forwardRef(function(e,t){var n=e.overlay,r=e.arrow,o=e.prefixCls,a=i.useMemo(function(){var s;return typeof n=="function"?s=n():s=n,s},[n]),l=un(t,$o(a));return F.createElement(F.Fragment,null,r&&F.createElement("div",{className:"".concat(o,"-arrow")}),F.cloneElement(a,{ref:Nr(a)?l:void 0}))}),zo={adjustX:1,adjustY:1},Do=[0,0],Z4={topLeft:{points:["bl","tl"],overflow:zo,offset:[0,-4],targetOffset:Do},top:{points:["bc","tc"],overflow:zo,offset:[0,-4],targetOffset:Do},topRight:{points:["br","tr"],overflow:zo,offset:[0,-4],targetOffset:Do},bottomLeft:{points:["tl","bl"],overflow:zo,offset:[0,4],targetOffset:Do},bottom:{points:["tc","bc"],overflow:zo,offset:[0,4],targetOffset:Do},bottomRight:{points:["tr","br"],overflow:zo,offset:[0,4],targetOffset:Do}},J4=["arrow","prefixCls","transitionName","animation","align","placement","placements","getPopupContainer","showAction","hideAction","overlayClassName","overlayStyle","visible","trigger","autoFocus","overlay","children","onVisibleChange"];function e3(e,t){var n,r=e.arrow,o=r===void 0?!1:r,a=e.prefixCls,l=a===void 0?"rc-dropdown":a,s=e.transitionName,c=e.animation,u=e.align,d=e.placement,f=d===void 0?"bottomLeft":d,m=e.placements,v=m===void 0?Z4:m,g=e.getPopupContainer,h=e.showAction,p=e.hideAction,b=e.overlayClassName,y=e.overlayStyle,C=e.visible,$=e.trigger,S=$===void 0?["hover"]:$,x=e.autoFocus,E=e.overlay,O=e.children,w=e.onVisibleChange,I=ft(e,J4),P=F.useState(),M=J(P,2),R=M[0],N=M[1],T="visible"in e?C:R,j=F.useRef(null),z=F.useRef(null),_=F.useRef(null);F.useImperativeHandle(t,function(){return j.current});var B=function(X){N(X),w==null||w(X)};Y4({visible:T,triggerRef:_,onVisibleChange:B,autoFocus:x,overlayRef:z});var V=function(X){var ae=e.onOverlayClick;N(!1),ae&&ae(X)},G=function(){return F.createElement(Q4,{ref:z,overlay:E,prefixCls:l,arrow:o})},q=function(){return typeof E=="function"?G:G()},H=function(){var X=e.minOverlayWidthMatchTrigger,ae=e.alignPoint;return"minOverlayWidthMatchTrigger"in e?X:!ae},W=function(){var X=e.openClassName;return X!==void 0?X:"".concat(l,"-open")},K=F.cloneElement(O,{className:A((n=O.props)===null||n===void 0?void 0:n.className,T&&W()),ref:Nr(O)?un(_,$o(O)):void 0}),U=p;return!U&&S.indexOf("contextMenu")!==-1&&(U=["click"]),F.createElement(Ss,ue({builtinPlacements:v},I,{prefixCls:l,ref:j,popupClassName:A(b,D({},"".concat(l,"-show-arrow"),o)),popupStyle:y,action:S,showAction:h,hideAction:U,popupPlacement:f,popupAlign:u,popupTransitionName:s,popupAnimation:c,popupVisible:T,stretch:H()?"minWidth":"",popup:q(),onPopupVisibleChange:B,onPopupClick:V,getPopupContainer:g}),K)}const ey=F.forwardRef(e3),t3=e=>typeof e!="object"&&typeof e!="function"||e===null;var ty=i.createContext(null);function ny(e,t){return e===void 0?null:"".concat(e,"-").concat(t)}function ry(e){var t=i.useContext(ty);return ny(t,e)}var n3=["children","locked"],xr=i.createContext(null);function r3(e,t){var n=k({},e);return Object.keys(t).forEach(function(r){var o=t[r];o!==void 0&&(n[r]=o)}),n}function ei(e){var t=e.children,n=e.locked,r=ft(e,n3),o=i.useContext(xr),a=So(function(){return r3(o,r)},[o,r],function(l,s){return!n&&(l[0]!==s[0]||!hr(l[1],s[1],!0))});return i.createElement(xr.Provider,{value:a},t)}var o3=[],oy=i.createContext(null);function Os(){return i.useContext(oy)}var ay=i.createContext(o3);function ga(e){var t=i.useContext(ay);return i.useMemo(function(){return e!==void 0?[].concat(pe(t),[e]):t},[t,e])}var iy=i.createContext(null),sf=i.createContext({});function Gv(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;if(as(e)){var n=e.nodeName.toLowerCase(),r=["input","select","textarea","button"].includes(n)||e.isContentEditable||n==="a"&&!!e.getAttribute("href"),o=e.getAttribute("tabindex"),a=Number(o),l=null;return o&&!Number.isNaN(a)?l=a:r&&l===null&&(l=0),r&&e.disabled&&(l=null),l!==null&&(l>=0||t&&l<0)}return!1}function a3(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,n=pe(e.querySelectorAll("*")).filter(function(r){return Gv(r,t)});return Gv(e,t)&&n.unshift(e),n}var qu=Ne.LEFT,Uu=Ne.RIGHT,Xu=Ne.UP,al=Ne.DOWN,il=Ne.ENTER,ly=Ne.ESC,Pa=Ne.HOME,Na=Ne.END,qv=[Xu,al,qu,Uu];function i3(e,t,n,r){var o,a="prev",l="next",s="children",c="parent";if(e==="inline"&&r===il)return{inlineTrigger:!0};var u=D(D({},Xu,a),al,l),d=D(D(D(D({},qu,n?l:a),Uu,n?a:l),al,s),il,s),f=D(D(D(D(D(D({},Xu,a),al,l),il,s),ly,c),qu,n?s:c),Uu,n?c:s),m={inline:u,horizontal:d,vertical:f,inlineSub:u,horizontalSub:f,verticalSub:f},v=(o=m["".concat(e).concat(t?"":"Sub")])===null||o===void 0?void 0:o[r];switch(v){case a:return{offset:-1,sibling:!0};case l:return{offset:1,sibling:!0};case c:return{offset:-1,sibling:!1};case s:return{offset:1,sibling:!1};default:return null}}function l3(e){for(var t=e;t;){if(t.getAttribute("data-menu-list"))return t;t=t.parentElement}return null}function s3(e,t){for(var n=e||document.activeElement;n;){if(t.has(n))return n;n=n.parentElement}return null}function cf(e,t){var n=a3(e,!0);return n.filter(function(r){return t.has(r)})}function Uv(e,t,n){var r=arguments.length>3&&arguments[3]!==void 0?arguments[3]:1;if(!e)return null;var o=cf(e,t),a=o.length,l=o.findIndex(function(s){return n===s});return r<0?l===-1?l=a-1:l-=1:r>0&&(l+=1),l=(l+a)%a,o[l]}var Yu=function(t,n){var r=new Set,o=new Map,a=new Map;return t.forEach(function(l){var s=document.querySelector("[data-menu-id='".concat(ny(n,l),"']"));s&&(r.add(s),a.set(s,l),o.set(l,s))}),{elements:r,key2element:o,element2key:a}};function c3(e,t,n,r,o,a,l,s,c,u){var d=i.useRef(),f=i.useRef();f.current=t;var m=function(){Et.cancel(d.current)};return i.useEffect(function(){return function(){m()}},[]),function(v){var g=v.which;if([].concat(qv,[il,ly,Pa,Na]).includes(g)){var h=a(),p=Yu(h,r),b=p,y=b.elements,C=b.key2element,$=b.element2key,S=C.get(t),x=s3(S,y),E=$.get(x),O=i3(e,l(E,!0).length===1,n,g);if(!O&&g!==Pa&&g!==Na)return;(qv.includes(g)||[Pa,Na].includes(g))&&v.preventDefault();var w=function(z){if(z){var _=z,B=z.querySelector("a");B!=null&&B.getAttribute("href")&&(_=B);var V=$.get(z);s(V),m(),d.current=Et(function(){f.current===V&&_.focus()})}};if([Pa,Na].includes(g)||O.sibling||!x){var I;!x||e==="inline"?I=o.current:I=l3(x);var P,M=cf(I,y);g===Pa?P=M[0]:g===Na?P=M[M.length-1]:P=Uv(I,y,x,O.offset),w(P)}else if(O.inlineTrigger)c(E);else if(O.offset>0)c(E,!0),m(),d.current=Et(function(){p=Yu(h,r);var j=x.getAttribute("aria-controls"),z=document.getElementById(j),_=Uv(z,p.elements);w(_)},5);else if(O.offset<0){var R=l(E,!0),N=R[R.length-2],T=C.get(N);c(N,!1),w(T)}}u==null||u(v)}}function u3(e){Promise.resolve().then(e)}var uf="__RC_UTIL_PATH_SPLIT__",Xv=function(t){return t.join(uf)},d3=function(t){return t.split(uf)},Qu="rc-menu-more";function f3(){var e=i.useState({}),t=J(e,2),n=t[1],r=i.useRef(new Map),o=i.useRef(new Map),a=i.useState([]),l=J(a,2),s=l[0],c=l[1],u=i.useRef(0),d=i.useRef(!1),f=function(){d.current||n({})},m=i.useCallback(function(C,$){var S=Xv($);o.current.set(S,C),r.current.set(C,S),u.current+=1;var x=u.current;u3(function(){x===u.current&&f()})},[]),v=i.useCallback(function(C,$){var S=Xv($);o.current.delete(S),r.current.delete(C)},[]),g=i.useCallback(function(C){c(C)},[]),h=i.useCallback(function(C,$){var S=r.current.get(C)||"",x=d3(S);return $&&s.includes(x[0])&&x.unshift(Qu),x},[s]),p=i.useCallback(function(C,$){return C.filter(function(S){return S!==void 0}).some(function(S){var x=h(S,!0);return x.includes($)})},[h]),b=function(){var $=pe(r.current.keys());return s.length&&$.push(Qu),$},y=i.useCallback(function(C){var $="".concat(r.current.get(C)).concat(uf),S=new Set;return pe(o.current.keys()).forEach(function(x){x.startsWith($)&&S.add(o.current.get(x))}),S},[]);return i.useEffect(function(){return function(){d.current=!0}},[]),{registerPath:m,unregisterPath:v,refreshOverflowKeys:g,isSubPathKey:p,getKeyPath:h,getKeys:b,getSubPathKeys:y}}function Da(e){var t=i.useRef(e);t.current=e;var n=i.useCallback(function(){for(var r,o=arguments.length,a=new Array(o),l=0;l<o;l++)a[l]=arguments[l];return(r=t.current)===null||r===void 0?void 0:r.call.apply(r,[t].concat(a))},[]);return e?n:void 0}var m3=Math.random().toFixed(5).toString().slice(2),Yv=0;function v3(e){var t=Lt(e,{value:e}),n=J(t,2),r=n[0],o=n[1];return i.useEffect(function(){Yv+=1;var a="".concat(m3,"-").concat(Yv);o("rc-menu-uuid-".concat(a))},[]),r}function sy(e,t,n,r){var o=i.useContext(xr),a=o.activeKey,l=o.onActive,s=o.onInactive,c={active:a===e};return t||(c.onMouseEnter=function(u){n==null||n({key:e,domEvent:u}),l(e)},c.onMouseLeave=function(u){r==null||r({key:e,domEvent:u}),s(e)}),c}function cy(e){var t=i.useContext(xr),n=t.mode,r=t.rtl,o=t.inlineIndent;if(n!=="inline")return null;var a=e;return r?{paddingRight:a*o}:{paddingLeft:a*o}}function uy(e){var t=e.icon,n=e.props,r=e.children,o;return t===null||t===!1?null:(typeof t=="function"?o=i.createElement(t,k({},n)):typeof t!="boolean"&&(o=t),o||r||null)}var g3=["item"];function El(e){var t=e.item,n=ft(e,g3);return Object.defineProperty(n,"item",{get:function(){return Kt(!1,"`info.item` is deprecated since we will move to function component that not provides React Node instance in future."),t}}),n}var p3=["title","attribute","elementRef"],h3=["style","className","eventKey","warnKey","disabled","itemIcon","children","role","onMouseEnter","onMouseLeave","onClick","onKeyDown","onFocus"],b3=["active"],y3=function(e){tr(n,e);var t=ur(n);function n(){return Zt(this,n),t.apply(this,arguments)}return Jt(n,[{key:"render",value:function(){var o=this.props,a=o.title,l=o.attribute,s=o.elementRef,c=ft(o,p3),u=Gt(c,["eventKey","popupClassName","popupOffset","onTitleClick"]);return Kt(!l,"`attribute` of Menu.Item is deprecated. Please pass attribute directly."),i.createElement(Rr.Item,ue({},l,{title:typeof a=="string"?a:void 0},u,{ref:s}))}}]),n}(i.Component),C3=i.forwardRef(function(e,t){var n=e.style,r=e.className,o=e.eventKey;e.warnKey;var a=e.disabled,l=e.itemIcon,s=e.children,c=e.role,u=e.onMouseEnter,d=e.onMouseLeave,f=e.onClick,m=e.onKeyDown,v=e.onFocus,g=ft(e,h3),h=ry(o),p=i.useContext(xr),b=p.prefixCls,y=p.onItemClick,C=p.disabled,$=p.overflowDisabled,S=p.itemIcon,x=p.selectedKeys,E=p.onActive,O=i.useContext(sf),w=O._internalRenderMenuItem,I="".concat(b,"-item"),P=i.useRef(),M=i.useRef(),R=C||a,N=zr(t,M),T=ga(o),j=function(ae){return{key:o,keyPath:pe(T).reverse(),item:P.current,domEvent:ae}},z=l||S,_=sy(o,R,u,d),B=_.active,V=ft(_,b3),G=x.includes(o),q=cy(T.length),H=function(ae){if(!R){var le=j(ae);f==null||f(El(le)),y(le)}},W=function(ae){if(m==null||m(ae),ae.which===Ne.ENTER){var le=j(ae);f==null||f(El(le)),y(le)}},K=function(ae){E(o),v==null||v(ae)},U={};e.role==="option"&&(U["aria-selected"]=G);var te=i.createElement(y3,ue({ref:P,elementRef:N,role:c===null?"none":c||"menuitem",tabIndex:a?null:-1,"data-menu-id":$&&h?null:h},Gt(g,["extra"]),V,U,{component:"li","aria-disabled":a,style:k(k({},q),n),className:A(I,D(D(D({},"".concat(I,"-active"),B),"".concat(I,"-selected"),G),"".concat(I,"-disabled"),R),r),onClick:H,onKeyDown:W,onFocus:K}),s,i.createElement(uy,{props:k(k({},e),{},{isSelected:G}),icon:z}));return w&&(te=w(te,e,{selected:G})),te});function S3(e,t){var n=e.eventKey,r=Os(),o=ga(n);return i.useEffect(function(){if(r)return r.registerPath(n,o),function(){r.unregisterPath(n,o)}},[o]),r?null:i.createElement(C3,ue({},e,{ref:t}))}const Ci=i.forwardRef(S3);var $3=["className","children"],x3=function(t,n){var r=t.className,o=t.children,a=ft(t,$3),l=i.useContext(xr),s=l.prefixCls,c=l.mode,u=l.rtl;return i.createElement("ul",ue({className:A(s,u&&"".concat(s,"-rtl"),"".concat(s,"-sub"),"".concat(s,"-").concat(c==="inline"?"inline":"vertical"),r),role:"menu"},a,{"data-menu-list":!0,ref:n}),o)},df=i.forwardRef(x3);df.displayName="SubMenuList";function ff(e,t){return xn(e).map(function(n,r){if(i.isValidElement(n)){var o,a,l=n.key,s=(o=(a=n.props)===null||a===void 0?void 0:a.eventKey)!==null&&o!==void 0?o:l,c=s==null;c&&(s="tmp_key-".concat([].concat(pe(t),[r]).join("-")));var u={key:s,eventKey:s};return i.cloneElement(n,u)}return n})}var Dn={adjustX:1,adjustY:1},w3={topLeft:{points:["bl","tl"],overflow:Dn},topRight:{points:["br","tr"],overflow:Dn},bottomLeft:{points:["tl","bl"],overflow:Dn},bottomRight:{points:["tr","br"],overflow:Dn},leftTop:{points:["tr","tl"],overflow:Dn},leftBottom:{points:["br","bl"],overflow:Dn},rightTop:{points:["tl","tr"],overflow:Dn},rightBottom:{points:["bl","br"],overflow:Dn}},E3={topLeft:{points:["bl","tl"],overflow:Dn},topRight:{points:["br","tr"],overflow:Dn},bottomLeft:{points:["tl","bl"],overflow:Dn},bottomRight:{points:["tr","br"],overflow:Dn},rightTop:{points:["tr","tl"],overflow:Dn},rightBottom:{points:["br","bl"],overflow:Dn},leftTop:{points:["tl","tr"],overflow:Dn},leftBottom:{points:["bl","br"],overflow:Dn}};function dy(e,t,n){if(t)return t;if(n)return n[e]||n.other}var O3={horizontal:"bottomLeft",vertical:"rightTop","vertical-left":"rightTop","vertical-right":"leftTop"};function I3(e){var t=e.prefixCls,n=e.visible,r=e.children,o=e.popup,a=e.popupStyle,l=e.popupClassName,s=e.popupOffset,c=e.disabled,u=e.mode,d=e.onVisibleChange,f=i.useContext(xr),m=f.getPopupContainer,v=f.rtl,g=f.subMenuOpenDelay,h=f.subMenuCloseDelay,p=f.builtinPlacements,b=f.triggerSubMenuAction,y=f.forceSubMenuRender,C=f.rootClassName,$=f.motion,S=f.defaultMotions,x=i.useState(!1),E=J(x,2),O=E[0],w=E[1],I=k(v?k({},E3):k({},w3),p),P=O3[u],M=dy(u,$,S),R=i.useRef(M);u!=="inline"&&(R.current=M);var N=k(k({},R.current),{},{leavedClassName:"".concat(t,"-hidden"),removeOnLeave:!1,motionAppear:!0}),T=i.useRef();return i.useEffect(function(){return T.current=Et(function(){w(n)}),function(){Et.cancel(T.current)}},[n]),i.createElement(Ss,{prefixCls:t,popupClassName:A("".concat(t,"-popup"),D({},"".concat(t,"-rtl"),v),l,C),stretch:u==="horizontal"?"minWidth":null,getPopupContainer:m,builtinPlacements:I,popupPlacement:P,popupVisible:O,popup:o,popupStyle:a,popupAlign:s&&{offset:s},action:c?[]:[b],mouseEnterDelay:g,mouseLeaveDelay:h,onPopupVisibleChange:d,forceRender:y,popupMotion:N,fresh:!0},r)}function R3(e){var t=e.id,n=e.open,r=e.keyPath,o=e.children,a="inline",l=i.useContext(xr),s=l.prefixCls,c=l.forceSubMenuRender,u=l.motion,d=l.defaultMotions,f=l.mode,m=i.useRef(!1);m.current=f===a;var v=i.useState(!m.current),g=J(v,2),h=g[0],p=g[1],b=m.current?n:!1;i.useEffect(function(){m.current&&p(!1)},[f]);var y=k({},dy(a,u,d));r.length>1&&(y.motionAppear=!1);var C=y.onVisibleChanged;return y.onVisibleChanged=function($){return!m.current&&!$&&p(!0),C==null?void 0:C($)},h?null:i.createElement(ei,{mode:a,locked:!m.current},i.createElement(En,ue({visible:b},y,{forceRender:c,removeOnLeave:!1,leavedClassName:"".concat(s,"-hidden")}),function($){var S=$.className,x=$.style;return i.createElement(df,{id:t,className:S,style:x},o)}))}var P3=["style","className","title","eventKey","warnKey","disabled","internalPopupClose","children","itemIcon","expandIcon","popupClassName","popupOffset","popupStyle","onClick","onMouseEnter","onMouseLeave","onTitleClick","onTitleMouseEnter","onTitleMouseLeave"],N3=["active"],M3=i.forwardRef(function(e,t){var n=e.style,r=e.className,o=e.title,a=e.eventKey;e.warnKey;var l=e.disabled,s=e.internalPopupClose,c=e.children,u=e.itemIcon,d=e.expandIcon,f=e.popupClassName,m=e.popupOffset,v=e.popupStyle,g=e.onClick,h=e.onMouseEnter,p=e.onMouseLeave,b=e.onTitleClick,y=e.onTitleMouseEnter,C=e.onTitleMouseLeave,$=ft(e,P3),S=ry(a),x=i.useContext(xr),E=x.prefixCls,O=x.mode,w=x.openKeys,I=x.disabled,P=x.overflowDisabled,M=x.activeKey,R=x.selectedKeys,N=x.itemIcon,T=x.expandIcon,j=x.onItemClick,z=x.onOpenChange,_=x.onActive,B=i.useContext(sf),V=B._internalRenderSubMenuItem,G=i.useContext(iy),q=G.isSubPathKey,H=ga(),W="".concat(E,"-submenu"),K=I||l,U=i.useRef(),te=i.useRef(),X=u??N,ae=d??T,le=w.includes(a),ee=!P&&le,Y=q(R,a),re=sy(a,K,y,C),ne=re.active,Z=ft(re,N3),Q=i.useState(!1),ie=J(Q,2),de=ie[0],he=ie[1],ye=function(fe){K||he(fe)},oe=function(fe){ye(!0),h==null||h({key:a,domEvent:fe})},ce=function(fe){ye(!1),p==null||p({key:a,domEvent:fe})},ge=i.useMemo(function(){return ne||(O!=="inline"?de||q([M],a):!1)},[O,ne,M,de,a,q]),se=cy(H.length),be=function(fe){K||(b==null||b({key:a,domEvent:fe}),O==="inline"&&z(a,!le))},we=Da(function(Ie){g==null||g(El(Ie)),j(Ie)}),Me=function(fe){O!=="inline"&&z(a,fe)},Te=function(){_(a)},Se=S&&"".concat(S,"-popup"),Fe=i.useMemo(function(){return i.createElement(uy,{icon:O!=="horizontal"?ae:void 0,props:k(k({},e),{},{isOpen:ee,isSubMenu:!0})},i.createElement("i",{className:"".concat(W,"-arrow")}))},[O,ae,e,ee,W]),Ce=i.createElement("div",ue({role:"menuitem",style:se,className:"".concat(W,"-title"),tabIndex:K?null:-1,ref:U,title:typeof o=="string"?o:null,"data-menu-id":P&&S?null:S,"aria-expanded":ee,"aria-haspopup":!0,"aria-controls":Se,"aria-disabled":K,onClick:be,onFocus:Te},Z),o,Fe),me=i.useRef(O);if(O!=="inline"&&H.length>1?me.current="vertical":me.current=O,!P){var $e=me.current;Ce=i.createElement(I3,{mode:$e,prefixCls:W,visible:!s&&ee&&O!=="inline",popupClassName:f,popupOffset:m,popupStyle:v,popup:i.createElement(ei,{mode:$e==="horizontal"?"vertical":$e},i.createElement(df,{id:Se,ref:te},c)),disabled:K,onVisibleChange:Me},Ce)}var Ee=i.createElement(Rr.Item,ue({ref:t,role:"none"},$,{component:"li",style:n,className:A(W,"".concat(W,"-").concat(O),r,D(D(D(D({},"".concat(W,"-open"),ee),"".concat(W,"-active"),ge),"".concat(W,"-selected"),Y),"".concat(W,"-disabled"),K)),onMouseEnter:oe,onMouseLeave:ce}),Ce,!P&&i.createElement(R3,{id:Se,open:ee,keyPath:H},c));return V&&(Ee=V(Ee,e,{selected:Y,active:ge,open:ee,disabled:K})),i.createElement(ei,{onItemClick:we,mode:O==="horizontal"?"vertical":O,itemIcon:X,expandIcon:ae},Ee)}),Is=i.forwardRef(function(e,t){var n=e.eventKey,r=e.children,o=ga(n),a=ff(r,o),l=Os();i.useEffect(function(){if(l)return l.registerPath(n,o),function(){l.unregisterPath(n,o)}},[o]);var s;return l?s=a:s=i.createElement(M3,ue({ref:t},e),a),i.createElement(ay.Provider,{value:o},s)});function mf(e){var t=e.className,n=e.style,r=i.useContext(xr),o=r.prefixCls,a=Os();return a?null:i.createElement("li",{role:"separator",className:A("".concat(o,"-item-divider"),t),style:n})}var T3=["className","title","eventKey","children"],j3=i.forwardRef(function(e,t){var n=e.className,r=e.title;e.eventKey;var o=e.children,a=ft(e,T3),l=i.useContext(xr),s=l.prefixCls,c="".concat(s,"-item-group");return i.createElement("li",ue({ref:t,role:"presentation"},a,{onClick:function(d){return d.stopPropagation()},className:A(c,n)}),i.createElement("div",{role:"presentation",className:"".concat(c,"-title"),title:typeof r=="string"?r:void 0},r),i.createElement("ul",{role:"group",className:"".concat(c,"-list")},o))}),vf=i.forwardRef(function(e,t){var n=e.eventKey,r=e.children,o=ga(n),a=ff(r,o),l=Os();return l?a:i.createElement(j3,ue({ref:t},Gt(e,["warnKey"])),a)}),z3=["label","children","key","type","extra"];function Zu(e,t,n){var r=t.item,o=t.group,a=t.submenu,l=t.divider;return(e||[]).map(function(s,c){if(s&&Qe(s)==="object"){var u=s,d=u.label,f=u.children,m=u.key,v=u.type,g=u.extra,h=ft(u,z3),p=m??"tmp-".concat(c);return f||v==="group"?v==="group"?i.createElement(o,ue({key:p},h,{title:d}),Zu(f,t,n)):i.createElement(a,ue({key:p},h,{title:d}),Zu(f,t,n)):v==="divider"?i.createElement(l,ue({key:p},h)):i.createElement(r,ue({key:p},h,{extra:g}),d,(!!g||g===0)&&i.createElement("span",{className:"".concat(n,"-item-extra")},g))}return null}).filter(function(s){return s})}function Qv(e,t,n,r,o){var a=e,l=k({divider:mf,item:Ci,group:vf,submenu:Is},r);return t&&(a=Zu(t,l,o)),ff(a,n)}var D3=["prefixCls","rootClassName","style","className","tabIndex","items","children","direction","id","mode","inlineCollapsed","disabled","disabledOverflow","subMenuOpenDelay","subMenuCloseDelay","forceSubMenuRender","defaultOpenKeys","openKeys","activeKey","defaultActiveFirst","selectable","multiple","defaultSelectedKeys","selectedKeys","onSelect","onDeselect","inlineIndent","motion","defaultMotions","triggerSubMenuAction","builtinPlacements","itemIcon","expandIcon","overflowedIndicator","overflowedIndicatorPopupClassName","getPopupContainer","onClick","onOpenChange","onKeyDown","openAnimation","openTransitionName","_internalRenderMenuItem","_internalRenderSubMenuItem","_internalComponents"],ao=[],_3=i.forwardRef(function(e,t){var n,r=e,o=r.prefixCls,a=o===void 0?"rc-menu":o,l=r.rootClassName,s=r.style,c=r.className,u=r.tabIndex,d=u===void 0?0:u,f=r.items,m=r.children,v=r.direction,g=r.id,h=r.mode,p=h===void 0?"vertical":h,b=r.inlineCollapsed,y=r.disabled,C=r.disabledOverflow,$=r.subMenuOpenDelay,S=$===void 0?.1:$,x=r.subMenuCloseDelay,E=x===void 0?.1:x,O=r.forceSubMenuRender,w=r.defaultOpenKeys,I=r.openKeys,P=r.activeKey,M=r.defaultActiveFirst,R=r.selectable,N=R===void 0?!0:R,T=r.multiple,j=T===void 0?!1:T,z=r.defaultSelectedKeys,_=r.selectedKeys,B=r.onSelect,V=r.onDeselect,G=r.inlineIndent,q=G===void 0?24:G,H=r.motion,W=r.defaultMotions,K=r.triggerSubMenuAction,U=K===void 0?"hover":K,te=r.builtinPlacements,X=r.itemIcon,ae=r.expandIcon,le=r.overflowedIndicator,ee=le===void 0?"...":le,Y=r.overflowedIndicatorPopupClassName,re=r.getPopupContainer,ne=r.onClick,Z=r.onOpenChange,Q=r.onKeyDown;r.openAnimation,r.openTransitionName;var ie=r._internalRenderMenuItem,de=r._internalRenderSubMenuItem,he=r._internalComponents,ye=ft(r,D3),oe=i.useMemo(function(){return[Qv(m,f,ao,he,a),Qv(m,f,ao,{},a)]},[m,f,he]),ce=J(oe,2),ge=ce[0],se=ce[1],be=i.useState(!1),we=J(be,2),Me=we[0],Te=we[1],Se=i.useRef(),Fe=v3(g),Ce=v==="rtl",me=Lt(w,{value:I,postState:function(ut){return ut||ao}}),$e=J(me,2),Ee=$e[0],Ie=$e[1],fe=function(ut){var st=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;function _t(){Ie(ut),Z==null||Z(ut)}st?Pr.flushSync(_t):_t()},ve=i.useState(Ee),xe=J(ve,2),Re=xe[0],it=xe[1],dt=i.useRef(!1),Oe=i.useMemo(function(){return(p==="inline"||p==="vertical")&&b?["vertical",b]:[p,!1]},[p,b]),Le=J(Oe,2),Ue=Le[0],ke=Le[1],Je=Ue==="inline",Xe=i.useState(Ue),He=J(Xe,2),je=He[0],rt=He[1],et=i.useState(ke),Pe=J(et,2),qe=Pe[0],We=Pe[1];i.useEffect(function(){rt(Ue),We(ke),dt.current&&(Je?Ie(Re):fe(ao))},[Ue,ke]);var tt=i.useState(0),mt=J(tt,2),ct=mt[0],Ke=mt[1],Ye=ct>=ge.length-1||je!=="horizontal"||C;i.useEffect(function(){Je&&it(Ee)},[Ee]),i.useEffect(function(){return dt.current=!0,function(){dt.current=!1}},[]);var at=f3(),gt=at.registerPath,Ot=at.unregisterPath,Pt=at.refreshOverflowKeys,Rt=at.isSubPathKey,jt=at.getKeyPath,zt=at.getKeys,Dt=at.getSubPathKeys,De=i.useMemo(function(){return{registerPath:gt,unregisterPath:Ot}},[gt,Ot]),Ze=i.useMemo(function(){return{isSubPathKey:Rt}},[Rt]);i.useEffect(function(){Pt(Ye?ao:ge.slice(ct+1).map(function(At){return At.key}))},[ct,Ye]);var Ge=Lt(P||M&&((n=ge[0])===null||n===void 0?void 0:n.key),{value:P}),Be=J(Ge,2),ze=Be[0],_e=Be[1],lt=Da(function(At){_e(At)}),Ct=Da(function(){_e(void 0)});i.useImperativeHandle(t,function(){return{list:Se.current,focus:function(ut){var st,_t=zt(),Ht=Yu(_t,Fe),Vt=Ht.elements,Xt=Ht.key2element,vn=Ht.element2key,dn=cf(Se.current,Vt),gn=ze??(dn[0]?vn.get(dn[0]):(st=ge.find(function(St){return!St.props.disabled}))===null||st===void 0?void 0:st.key),pn=Xt.get(gn);if(gn&&pn){var Rn;pn==null||(Rn=pn.focus)===null||Rn===void 0||Rn.call(pn,ut)}}}});var Ae=Lt(z||[],{value:_,postState:function(ut){return Array.isArray(ut)?ut:ut==null?ao:[ut]}}),nt=J(Ae,2),ht=nt[0],Ft=nt[1],qt=function(ut){if(N){var st=ut.key,_t=ht.includes(st),Ht;j?_t?Ht=ht.filter(function(Xt){return Xt!==st}):Ht=[].concat(pe(ht),[st]):Ht=[st],Ft(Ht);var Vt=k(k({},ut),{},{selectedKeys:Ht});_t?V==null||V(Vt):B==null||B(Vt)}!j&&Ee.length&&je!=="inline"&&fe(ao)},Qt=Da(function(At){ne==null||ne(El(At)),qt(At)}),ln=Da(function(At,ut){var st=Ee.filter(function(Ht){return Ht!==At});if(ut)st.push(At);else if(je!=="inline"){var _t=Dt(At);st=st.filter(function(Ht){return!_t.has(Ht)})}hr(Ee,st,!0)||fe(st,!0)}),on=function(ut,st){var _t=st??!Ee.includes(ut);ln(ut,_t)},Tn=c3(je,ze,Ce,Fe,Se,zt,jt,_e,on,Q);i.useEffect(function(){Te(!0)},[]);var On=i.useMemo(function(){return{_internalRenderMenuItem:ie,_internalRenderSubMenuItem:de}},[ie,de]),In=je!=="horizontal"||C?ge:ge.map(function(At,ut){return i.createElement(ei,{key:At.key,overflowDisabled:ut>ct},At)}),An=i.createElement(Rr,ue({id:g,ref:Se,prefixCls:"".concat(a,"-overflow"),component:"ul",itemComponent:Ci,className:A(a,"".concat(a,"-root"),"".concat(a,"-").concat(je),c,D(D({},"".concat(a,"-inline-collapsed"),qe),"".concat(a,"-rtl"),Ce),l),dir:v,style:s,role:"menu",tabIndex:d,data:In,renderRawItem:function(ut){return ut},renderRawRest:function(ut){var st=ut.length,_t=st?ge.slice(-st):null;return i.createElement(Is,{eventKey:Qu,title:ee,disabled:Ye,internalPopupClose:st===0,popupClassName:Y},_t)},maxCount:je!=="horizontal"||C?Rr.INVALIDATE:Rr.RESPONSIVE,ssr:"full","data-menu-list":!0,onVisibleChange:function(ut){Ke(ut)},onKeyDown:Tn},ye));return i.createElement(sf.Provider,{value:On},i.createElement(ty.Provider,{value:Fe},i.createElement(ei,{prefixCls:a,rootClassName:l,mode:je,openKeys:Ee,rtl:Ce,disabled:y,motion:Me?H:null,defaultMotions:Me?W:null,activeKey:ze,onActive:lt,onInactive:Ct,selectedKeys:ht,inlineIndent:q,subMenuOpenDelay:S,subMenuCloseDelay:E,forceSubMenuRender:O,builtinPlacements:te,triggerSubMenuAction:U,getPopupContainer:re,itemIcon:X,expandIcon:ae,onItemClick:Qt,onOpenChange:ln},i.createElement(iy.Provider,{value:Ze},An),i.createElement("div",{style:{display:"none"},"aria-hidden":!0},i.createElement(oy.Provider,{value:De},se)))))}),pa=_3;pa.Item=Ci;pa.SubMenu=Is;pa.ItemGroup=vf;pa.Divider=mf;var B3={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M912 192H328c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h584c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8zm0 284H328c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h584c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8zm0 284H328c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h584c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8zM104 228a56 56 0 10112 0 56 56 0 10-112 0zm0 284a56 56 0 10112 0 56 56 0 10-112 0zm0 284a56 56 0 10112 0 56 56 0 10-112 0z"}}]},name:"bars",theme:"outlined"},L3=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:B3}))},H3=i.forwardRef(L3);const fy=i.createContext({siderHook:{addSider:()=>null,removeSider:()=>null}}),A3=e=>{const{antCls:t,componentCls:n,colorText:r,footerBg:o,headerHeight:a,headerPadding:l,headerColor:s,footerPadding:c,fontSize:u,bodyBg:d,headerBg:f}=e;return{[n]:{display:"flex",flex:"auto",flexDirection:"column",minHeight:0,background:d,"&, *":{boxSizing:"border-box"},[`&${n}-has-sider`]:{flexDirection:"row",[`> ${n}, > ${n}-content`]:{width:0}},[`${n}-header, &${n}-footer`]:{flex:"0 0 auto"},"&-rtl":{direction:"rtl"}},[`${n}-header`]:{height:a,padding:l,color:s,lineHeight:L(a),background:f,[`${t}-menu`]:{lineHeight:"inherit"}},[`${n}-footer`]:{padding:c,color:r,fontSize:u,background:o},[`${n}-content`]:{flex:"auto",color:r,minHeight:0}}},my=e=>{const{colorBgLayout:t,controlHeight:n,controlHeightLG:r,colorText:o,controlHeightSM:a,marginXXS:l,colorTextLightSolid:s,colorBgContainer:c}=e,u=r*1.25;return{colorBgHeader:"#001529",colorBgBody:t,colorBgTrigger:"#002140",bodyBg:t,headerBg:"#001529",headerHeight:n*2,headerPadding:`0 ${u}px`,headerColor:o,footerPadding:`${a}px ${u}px`,footerBg:t,siderBg:"#001529",triggerHeight:r+l*2,triggerBg:"#002140",triggerColor:s,zeroTriggerWidth:r,zeroTriggerHeight:r,lightSiderBg:c,lightTriggerBg:c,lightTriggerColor:o}},vy=[["colorBgBody","bodyBg"],["colorBgHeader","headerBg"],["colorBgTrigger","triggerBg"]],gy=It("Layout",A3,my,{deprecatedTokens:vy}),F3=e=>{const{componentCls:t,siderBg:n,motionDurationMid:r,motionDurationSlow:o,antCls:a,triggerHeight:l,triggerColor:s,triggerBg:c,headerHeight:u,zeroTriggerWidth:d,zeroTriggerHeight:f,borderRadiusLG:m,lightSiderBg:v,lightTriggerColor:g,lightTriggerBg:h,bodyBg:p}=e;return{[t]:{position:"relative",minWidth:0,background:n,transition:`all ${r}, background 0s`,"&-has-trigger":{paddingBottom:l},"&-right":{order:1},[`${t}-children`]:{height:"100%",marginTop:-.1,paddingTop:.1,[`${a}-menu${a}-menu-inline-collapsed`]:{width:"auto"}},[`&-zero-width ${t}-children`]:{overflow:"hidden"},[`${t}-trigger`]:{position:"fixed",bottom:0,zIndex:1,height:l,color:s,lineHeight:L(l),textAlign:"center",background:c,cursor:"pointer",transition:`all ${r}`},[`${t}-zero-width-trigger`]:{position:"absolute",top:u,insetInlineEnd:e.calc(d).mul(-1).equal(),zIndex:1,width:d,height:f,color:s,fontSize:e.fontSizeXL,display:"flex",alignItems:"center",justifyContent:"center",background:n,borderRadius:`0 ${L(m)} ${L(m)} 0`,cursor:"pointer",transition:`background ${o} ease`,"&::after":{position:"absolute",inset:0,background:"transparent",transition:`all ${o}`,content:'""'},"&:hover::after":{background:"rgba(255, 255, 255, 0.2)"},"&-right":{insetInlineStart:e.calc(d).mul(-1).equal(),borderRadius:`${L(m)} 0 0 ${L(m)}`}},"&-light":{background:v,[`${t}-trigger`]:{color:g,background:h},[`${t}-zero-width-trigger`]:{color:g,background:h,border:`1px solid ${p}`,borderInlineStart:0}}}}},k3=It(["Layout","Sider"],F3,my,{deprecatedTokens:vy});var V3=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Zv={xs:"479.98px",sm:"575.98px",md:"767.98px",lg:"991.98px",xl:"1199.98px",xxl:"1599.98px"},W3=e=>!Number.isNaN(Number.parseFloat(e))&&isFinite(e),Rs=i.createContext({}),K3=(()=>{let e=0;return(t="")=>(e+=1,`${t}${e}`)})(),py=i.forwardRef((e,t)=>{const{prefixCls:n,className:r,trigger:o,children:a,defaultCollapsed:l=!1,theme:s="dark",style:c={},collapsible:u=!1,reverseArrow:d=!1,width:f=200,collapsedWidth:m=80,zeroWidthTriggerStyle:v,breakpoint:g,onCollapse:h,onBreakpoint:p}=e,b=V3(e,["prefixCls","className","trigger","children","defaultCollapsed","theme","style","collapsible","reverseArrow","width","collapsedWidth","zeroWidthTriggerStyle","breakpoint","onCollapse","onBreakpoint"]),{siderHook:y}=i.useContext(fy),[C,$]=i.useState("collapsed"in e?e.collapsed:l),[S,x]=i.useState(!1);i.useEffect(()=>{"collapsed"in e&&$(e.collapsed)},[e.collapsed]);const E=(X,ae)=>{"collapsed"in e||$(X),h==null||h(X,ae)},{getPrefixCls:O,direction:w}=i.useContext(ot),I=O("layout-sider",n),[P,M,R]=k3(I),N=i.useRef(null);N.current=X=>{x(X.matches),p==null||p(X.matches),C!==X.matches&&E(X.matches,"responsive")},i.useEffect(()=>{function X(le){var ee;return(ee=N.current)===null||ee===void 0?void 0:ee.call(N,le)}let ae;return typeof(window==null?void 0:window.matchMedia)<"u"&&g&&g in Zv&&(ae=window.matchMedia(`screen and (max-width: ${Zv[g]})`),kb(ae,X),X(ae)),()=>{Vb(ae,X)}},[g]),i.useEffect(()=>{const X=K3("ant-sider-");return y.addSider(X),()=>y.removeSider(X)},[]);const T=()=>{E(!C,"clickTrigger")},j=Gt(b,["collapsed"]),z=C?m:f,_=W3(z)?`${z}px`:String(z),B=parseFloat(String(m||0))===0?i.createElement("span",{onClick:T,className:A(`${I}-zero-width-trigger`,`${I}-zero-width-trigger-${d?"right":"left"}`),style:v},o||i.createElement(H3,null)):null,V=w==="rtl"==!d,H={expanded:V?i.createElement(na,null):i.createElement(Ja,null),collapsed:V?i.createElement(Ja,null):i.createElement(na,null)}[C?"collapsed":"expanded"],W=o!==null?B||i.createElement("div",{className:`${I}-trigger`,onClick:T,style:{width:_}},o||H):null,K=Object.assign(Object.assign({},c),{flex:`0 0 ${_}`,maxWidth:_,minWidth:_,width:_}),U=A(I,`${I}-${s}`,{[`${I}-collapsed`]:!!C,[`${I}-has-trigger`]:u&&o!==null&&!B,[`${I}-below`]:!!S,[`${I}-zero-width`]:parseFloat(_)===0},r,M,R),te=i.useMemo(()=>({siderCollapsed:C}),[C]);return P(i.createElement(Rs.Provider,{value:te},i.createElement("aside",Object.assign({className:U},j,{style:K,ref:t}),i.createElement("div",{className:`${I}-children`},a),u||S&&B?W:null)))});var G3={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M176 511a56 56 0 10112 0 56 56 0 10-112 0zm280 0a56 56 0 10112 0 56 56 0 10-112 0zm280 0a56 56 0 10112 0 56 56 0 10-112 0z"}}]},name:"ellipsis",theme:"outlined"},q3=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:G3}))},gf=i.forwardRef(q3);const Ol=i.createContext({prefixCls:"",firstLevel:!0,inlineCollapsed:!1});var U3=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const hy=e=>{const{prefixCls:t,className:n,dashed:r}=e,o=U3(e,["prefixCls","className","dashed"]),{getPrefixCls:a}=i.useContext(ot),l=a("menu",t),s=A({[`${l}-item-divider-dashed`]:!!r},n);return i.createElement(mf,Object.assign({className:s},o))},by=e=>{var t;const{className:n,children:r,icon:o,title:a,danger:l,extra:s}=e,{prefixCls:c,firstLevel:u,direction:d,disableMenuItemTitleTooltip:f,inlineCollapsed:m}=i.useContext(Ol),v=C=>{const $=r==null?void 0:r[0],S=i.createElement("span",{className:A(`${c}-title-content`,{[`${c}-title-content-with-extra`]:!!s||s===0})},r);return(!o||i.isValidElement(r)&&r.type==="span")&&r&&C&&u&&typeof $=="string"?i.createElement("div",{className:`${c}-inline-collapsed-noicon`},$.charAt(0)):S},{siderCollapsed:g}=i.useContext(Rs);let h=a;typeof a>"u"?h=u?r:"":a===!1&&(h="");const p={title:h};!g&&!m&&(p.title=null,p.open=!1);const b=xn(r).length;let y=i.createElement(Ci,Object.assign({},Gt(e,["title","icon","danger"]),{className:A({[`${c}-item-danger`]:l,[`${c}-item-only-child`]:(o?b+1:b)===1},n),title:typeof a=="string"?a:void 0}),cn(o,{className:A(i.isValidElement(o)?(t=o.props)===null||t===void 0?void 0:t.className:void 0,`${c}-item-icon`)}),v(m));return f||(y=i.createElement($r,Object.assign({},p,{placement:d==="rtl"?"left":"right",classNames:{root:`${c}-inline-collapsed-tooltip`}}),y)),y};var X3=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Il=i.createContext(null),yy=i.forwardRef((e,t)=>{const{children:n}=e,r=X3(e,["children"]),o=i.useContext(Il),a=i.useMemo(()=>Object.assign(Object.assign({},o),r),[o,r.prefixCls,r.mode,r.selectable,r.rootClassName]),l=BS(n),s=zr(t,l?$o(n):null);return i.createElement(Il.Provider,{value:a},i.createElement(jr,{space:!0},l?i.cloneElement(n,{ref:s}):n))}),Y3=e=>{const{componentCls:t,motionDurationSlow:n,horizontalLineHeight:r,colorSplit:o,lineWidth:a,lineType:l,itemPaddingInline:s}=e;return{[`${t}-horizontal`]:{lineHeight:r,border:0,borderBottom:`${L(a)} ${l} ${o}`,boxShadow:"none","&::after":{display:"block",clear:"both",height:0,content:'"\\20"'},[`${t}-item, ${t}-submenu`]:{position:"relative",display:"inline-block",verticalAlign:"bottom",paddingInline:s},[`> ${t}-item:hover,
        > ${t}-item-active,
        > ${t}-submenu ${t}-submenu-title:hover`]:{backgroundColor:"transparent"},[`${t}-item, ${t}-submenu-title`]:{transition:[`border-color ${n}`,`background ${n}`].join(",")},[`${t}-submenu-arrow`]:{display:"none"}}}},Q3=({componentCls:e,menuArrowOffset:t,calc:n})=>({[`${e}-rtl`]:{direction:"rtl"},[`${e}-submenu-rtl`]:{transformOrigin:"100% 0"},[`${e}-rtl${e}-vertical,
    ${e}-submenu-rtl ${e}-vertical`]:{[`${e}-submenu-arrow`]:{"&::before":{transform:`rotate(-45deg) translateY(${L(n(t).mul(-1).equal())})`},"&::after":{transform:`rotate(45deg) translateY(${L(t)})`}}}}),Jv=e=>Cr(e),eg=(e,t)=>{const{componentCls:n,itemColor:r,itemSelectedColor:o,subMenuItemSelectedColor:a,groupTitleColor:l,itemBg:s,subMenuItemBg:c,itemSelectedBg:u,activeBarHeight:d,activeBarWidth:f,activeBarBorderWidth:m,motionDurationSlow:v,motionEaseInOut:g,motionEaseOut:h,itemPaddingInline:p,motionDurationMid:b,itemHoverColor:y,lineType:C,colorSplit:$,itemDisabledColor:S,dangerItemColor:x,dangerItemHoverColor:E,dangerItemSelectedColor:O,dangerItemActiveBg:w,dangerItemSelectedBg:I,popupBg:P,itemHoverBg:M,itemActiveBg:R,menuSubMenuBg:N,horizontalItemSelectedColor:T,horizontalItemSelectedBg:j,horizontalItemBorderRadius:z,horizontalItemHoverBg:_}=e;return{[`${n}-${t}, ${n}-${t} > ${n}`]:{color:r,background:s,[`&${n}-root:focus-visible`]:Object.assign({},Jv(e)),[`${n}-item`]:{"&-group-title, &-extra":{color:l}},[`${n}-submenu-selected > ${n}-submenu-title`]:{color:a},[`${n}-item, ${n}-submenu-title`]:{color:r,[`&:not(${n}-item-disabled):focus-visible`]:Object.assign({},Jv(e))},[`${n}-item-disabled, ${n}-submenu-disabled`]:{color:`${S} !important`},[`${n}-item:not(${n}-item-selected):not(${n}-submenu-selected)`]:{[`&:hover, > ${n}-submenu-title:hover`]:{color:y}},[`&:not(${n}-horizontal)`]:{[`${n}-item:not(${n}-item-selected)`]:{"&:hover":{backgroundColor:M},"&:active":{backgroundColor:R}},[`${n}-submenu-title`]:{"&:hover":{backgroundColor:M},"&:active":{backgroundColor:R}}},[`${n}-item-danger`]:{color:x,[`&${n}-item:hover`]:{[`&:not(${n}-item-selected):not(${n}-submenu-selected)`]:{color:E}},[`&${n}-item:active`]:{background:w}},[`${n}-item a`]:{"&, &:hover":{color:"inherit"}},[`${n}-item-selected`]:{color:o,[`&${n}-item-danger`]:{color:O},"a, a:hover":{color:"inherit"}},[`& ${n}-item-selected`]:{backgroundColor:u,[`&${n}-item-danger`]:{backgroundColor:I}},[`&${n}-submenu > ${n}`]:{backgroundColor:N},[`&${n}-popup > ${n}`]:{backgroundColor:P},[`&${n}-submenu-popup > ${n}`]:{backgroundColor:P},[`&${n}-horizontal`]:Object.assign(Object.assign({},t==="dark"?{borderBottom:0}:{}),{[`> ${n}-item, > ${n}-submenu`]:{top:m,marginTop:e.calc(m).mul(-1).equal(),marginBottom:0,borderRadius:z,"&::after":{position:"absolute",insetInline:p,bottom:0,borderBottom:`${L(d)} solid transparent`,transition:`border-color ${v} ${g}`,content:'""'},"&:hover, &-active, &-open":{background:_,"&::after":{borderBottomWidth:d,borderBottomColor:T}},"&-selected":{color:T,backgroundColor:j,"&:hover":{backgroundColor:j},"&::after":{borderBottomWidth:d,borderBottomColor:T}}}}),[`&${n}-root`]:{[`&${n}-inline, &${n}-vertical`]:{borderInlineEnd:`${L(m)} ${C} ${$}`}},[`&${n}-inline`]:{[`${n}-sub${n}-inline`]:{background:c},[`${n}-item`]:{position:"relative","&::after":{position:"absolute",insetBlock:0,insetInlineEnd:0,borderInlineEnd:`${L(f)} solid ${o}`,transform:"scaleY(0.0001)",opacity:0,transition:[`transform ${b} ${h}`,`opacity ${b} ${h}`].join(","),content:'""'},[`&${n}-item-danger`]:{"&::after":{borderInlineEndColor:O}}},[`${n}-selected, ${n}-item-selected`]:{"&::after":{transform:"scaleY(1)",opacity:1,transition:[`transform ${b} ${g}`,`opacity ${b} ${g}`].join(",")}}}}}},tg=e=>{const{componentCls:t,itemHeight:n,itemMarginInline:r,padding:o,menuArrowSize:a,marginXS:l,itemMarginBlock:s,itemWidth:c,itemPaddingInline:u}=e,d=e.calc(a).add(o).add(l).equal();return{[`${t}-item`]:{position:"relative",overflow:"hidden"},[`${t}-item, ${t}-submenu-title`]:{height:n,lineHeight:L(n),paddingInline:u,overflow:"hidden",textOverflow:"ellipsis",marginInline:r,marginBlock:s,width:c},[`> ${t}-item,
            > ${t}-submenu > ${t}-submenu-title`]:{height:n,lineHeight:L(n)},[`${t}-item-group-list ${t}-submenu-title,
            ${t}-submenu-title`]:{paddingInlineEnd:d}}},Z3=e=>{const{componentCls:t,iconCls:n,itemHeight:r,colorTextLightSolid:o,dropdownWidth:a,controlHeightLG:l,motionEaseOut:s,paddingXL:c,itemMarginInline:u,fontSizeLG:d,motionDurationFast:f,motionDurationSlow:m,paddingXS:v,boxShadowSecondary:g,collapsedWidth:h,collapsedIconSize:p}=e,b={height:r,lineHeight:L(r),listStylePosition:"inside",listStyleType:"disc"};return[{[t]:{"&-inline, &-vertical":Object.assign({[`&${t}-root`]:{boxShadow:"none"}},tg(e))},[`${t}-submenu-popup`]:{[`${t}-vertical`]:Object.assign(Object.assign({},tg(e)),{boxShadow:g})}},{[`${t}-submenu-popup ${t}-vertical${t}-sub`]:{minWidth:a,maxHeight:`calc(100vh - ${L(e.calc(l).mul(2.5).equal())})`,padding:"0",overflow:"hidden",borderInlineEnd:0,"&:not([class*='-active'])":{overflowX:"hidden",overflowY:"auto"}}},{[`${t}-inline`]:{width:"100%",[`&${t}-root`]:{[`${t}-item, ${t}-submenu-title`]:{display:"flex",alignItems:"center",transition:[`border-color ${m}`,`background ${m}`,`padding ${f} ${s}`].join(","),[`> ${t}-title-content`]:{flex:"auto",minWidth:0,overflow:"hidden",textOverflow:"ellipsis"},"> *":{flex:"none"}}},[`${t}-sub${t}-inline`]:{padding:0,border:0,borderRadius:0,boxShadow:"none",[`& > ${t}-submenu > ${t}-submenu-title`]:b,[`& ${t}-item-group-title`]:{paddingInlineStart:c}},[`${t}-item`]:b}},{[`${t}-inline-collapsed`]:{width:h,[`&${t}-root`]:{[`${t}-item, ${t}-submenu ${t}-submenu-title`]:{[`> ${t}-inline-collapsed-noicon`]:{fontSize:d,textAlign:"center"}}},[`> ${t}-item,
          > ${t}-item-group > ${t}-item-group-list > ${t}-item,
          > ${t}-item-group > ${t}-item-group-list > ${t}-submenu > ${t}-submenu-title,
          > ${t}-submenu > ${t}-submenu-title`]:{insetInlineStart:0,paddingInline:`calc(50% - ${L(e.calc(p).div(2).equal())} - ${L(u)})`,textOverflow:"clip",[`
            ${t}-submenu-arrow,
            ${t}-submenu-expand-icon
          `]:{opacity:0},[`${t}-item-icon, ${n}`]:{margin:0,fontSize:p,lineHeight:L(r),"+ span":{display:"inline-block",opacity:0}}},[`${t}-item-icon, ${n}`]:{display:"inline-block"},"&-tooltip":{pointerEvents:"none",[`${t}-item-icon, ${n}`]:{display:"none"},"a, a:hover":{color:o}},[`${t}-item-group-title`]:Object.assign(Object.assign({},sr),{paddingInline:v})}}]},ng=e=>{const{componentCls:t,motionDurationSlow:n,motionDurationMid:r,motionEaseInOut:o,motionEaseOut:a,iconCls:l,iconSize:s,iconMarginInlineEnd:c}=e;return{[`${t}-item, ${t}-submenu-title`]:{position:"relative",display:"block",margin:0,whiteSpace:"nowrap",cursor:"pointer",transition:[`border-color ${n}`,`background ${n}`,`padding calc(${n} + 0.1s) ${o}`].join(","),[`${t}-item-icon, ${l}`]:{minWidth:s,fontSize:s,transition:[`font-size ${r} ${a}`,`margin ${n} ${o}`,`color ${n}`].join(","),"+ span":{marginInlineStart:c,opacity:1,transition:[`opacity ${n} ${o}`,`margin ${n}`,`color ${n}`].join(",")}},[`${t}-item-icon`]:Object.assign({},xo()),[`&${t}-item-only-child`]:{[`> ${l}, > ${t}-item-icon`]:{marginInlineEnd:0}}},[`${t}-item-disabled, ${t}-submenu-disabled`]:{background:"none !important",cursor:"not-allowed","&::after":{borderColor:"transparent !important"},a:{color:"inherit !important",cursor:"not-allowed",pointerEvents:"none"},[`> ${t}-submenu-title`]:{color:"inherit !important",cursor:"not-allowed"}}}},rg=e=>{const{componentCls:t,motionDurationSlow:n,motionEaseInOut:r,borderRadius:o,menuArrowSize:a,menuArrowOffset:l}=e;return{[`${t}-submenu`]:{"&-expand-icon, &-arrow":{position:"absolute",top:"50%",insetInlineEnd:e.margin,width:a,color:"currentcolor",transform:"translateY(-50%)",transition:`transform ${n} ${r}, opacity ${n}`},"&-arrow":{"&::before, &::after":{position:"absolute",width:e.calc(a).mul(.6).equal(),height:e.calc(a).mul(.15).equal(),backgroundColor:"currentcolor",borderRadius:o,transition:[`background ${n} ${r}`,`transform ${n} ${r}`,`top ${n} ${r}`,`color ${n} ${r}`].join(","),content:'""'},"&::before":{transform:`rotate(45deg) translateY(${L(e.calc(l).mul(-1).equal())})`},"&::after":{transform:`rotate(-45deg) translateY(${L(l)})`}}}}},J3=e=>{const{antCls:t,componentCls:n,fontSize:r,motionDurationSlow:o,motionDurationMid:a,motionEaseInOut:l,paddingXS:s,padding:c,colorSplit:u,lineWidth:d,zIndexPopup:f,borderRadiusLG:m,subMenuItemBorderRadius:v,menuArrowSize:g,menuArrowOffset:h,lineType:p,groupTitleLineHeight:b,groupTitleFontSize:y}=e;return[{"":{[n]:Object.assign(Object.assign({},yr()),{"&-hidden":{display:"none"}})},[`${n}-submenu-hidden`]:{display:"none"}},{[n]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),yr()),{marginBottom:0,paddingInlineStart:0,fontSize:r,lineHeight:0,listStyle:"none",outline:"none",transition:`width ${o} cubic-bezier(0.2, 0, 0, 1) 0s`,"ul, ol":{margin:0,padding:0,listStyle:"none"},"&-overflow":{display:"flex",[`${n}-item`]:{flex:"none"}},[`${n}-item, ${n}-submenu, ${n}-submenu-title`]:{borderRadius:e.itemBorderRadius},[`${n}-item-group-title`]:{padding:`${L(s)} ${L(c)}`,fontSize:y,lineHeight:b,transition:`all ${o}`},[`&-horizontal ${n}-submenu`]:{transition:[`border-color ${o} ${l}`,`background ${o} ${l}`].join(",")},[`${n}-submenu, ${n}-submenu-inline`]:{transition:[`border-color ${o} ${l}`,`background ${o} ${l}`,`padding ${a} ${l}`].join(",")},[`${n}-submenu ${n}-sub`]:{cursor:"initial",transition:[`background ${o} ${l}`,`padding ${o} ${l}`].join(",")},[`${n}-title-content`]:{transition:`color ${o}`,"&-with-extra":{display:"inline-flex",alignItems:"center",width:"100%"},[`> ${t}-typography-ellipsis-single-line`]:{display:"inline",verticalAlign:"unset"},[`${n}-item-extra`]:{marginInlineStart:"auto",paddingInlineStart:e.padding}},[`${n}-item a`]:{"&::before":{position:"absolute",inset:0,backgroundColor:"transparent",content:'""'}},[`${n}-item-divider`]:{overflow:"hidden",lineHeight:0,borderColor:u,borderStyle:p,borderWidth:0,borderTopWidth:d,marginBlock:d,padding:0,"&-dashed":{borderStyle:"dashed"}}}),ng(e)),{[`${n}-item-group`]:{[`${n}-item-group-list`]:{margin:0,padding:0,[`${n}-item, ${n}-submenu-title`]:{paddingInline:`${L(e.calc(r).mul(2).equal())} ${L(c)}`}}},"&-submenu":{"&-popup":{position:"absolute",zIndex:f,borderRadius:m,boxShadow:"none",transformOrigin:"0 0",[`&${n}-submenu`]:{background:"transparent"},"&::before":{position:"absolute",inset:0,zIndex:-1,width:"100%",height:"100%",opacity:0,content:'""'},[`> ${n}`]:Object.assign(Object.assign(Object.assign({borderRadius:m},ng(e)),rg(e)),{[`${n}-item, ${n}-submenu > ${n}-submenu-title`]:{borderRadius:v},[`${n}-submenu-title::after`]:{transition:`transform ${o} ${l}`}})},"\n          &-placement-leftTop,\n          &-placement-bottomRight,\n          ":{transformOrigin:"100% 0"},"\n          &-placement-leftBottom,\n          &-placement-topRight,\n          ":{transformOrigin:"100% 100%"},"\n          &-placement-rightBottom,\n          &-placement-topLeft,\n          ":{transformOrigin:"0 100%"},"\n          &-placement-bottomLeft,\n          &-placement-rightTop,\n          ":{transformOrigin:"0 0"},"\n          &-placement-leftTop,\n          &-placement-leftBottom\n          ":{paddingInlineEnd:e.paddingXS},"\n          &-placement-rightTop,\n          &-placement-rightBottom\n          ":{paddingInlineStart:e.paddingXS},"\n          &-placement-topRight,\n          &-placement-topLeft\n          ":{paddingBottom:e.paddingXS},"\n          &-placement-bottomRight,\n          &-placement-bottomLeft\n          ":{paddingTop:e.paddingXS}}}),rg(e)),{[`&-inline-collapsed ${n}-submenu-arrow,
        &-inline ${n}-submenu-arrow`]:{"&::before":{transform:`rotate(-45deg) translateX(${L(h)})`},"&::after":{transform:`rotate(45deg) translateX(${L(e.calc(h).mul(-1).equal())})`}},[`${n}-submenu-open${n}-submenu-inline > ${n}-submenu-title > ${n}-submenu-arrow`]:{transform:`translateY(${L(e.calc(g).mul(.2).mul(-1).equal())})`,"&::after":{transform:`rotate(-45deg) translateX(${L(e.calc(h).mul(-1).equal())})`},"&::before":{transform:`rotate(45deg) translateX(${L(h)})`}}})},{[`${t}-layout-header`]:{[n]:{lineHeight:"inherit"}}}]},eM=e=>{var t,n,r;const{colorPrimary:o,colorError:a,colorTextDisabled:l,colorErrorBg:s,colorText:c,colorTextDescription:u,colorBgContainer:d,colorFillAlter:f,colorFillContent:m,lineWidth:v,lineWidthBold:g,controlItemBgActive:h,colorBgTextHover:p,controlHeightLG:b,lineHeight:y,colorBgElevated:C,marginXXS:$,padding:S,fontSize:x,controlHeightSM:E,fontSizeLG:O,colorTextLightSolid:w,colorErrorHover:I}=e,P=(t=e.activeBarWidth)!==null&&t!==void 0?t:0,M=(n=e.activeBarBorderWidth)!==null&&n!==void 0?n:v,R=(r=e.itemMarginInline)!==null&&r!==void 0?r:e.marginXXS,N=new Mt(w).setA(.65).toRgbString();return{dropdownWidth:160,zIndexPopup:e.zIndexPopupBase+50,radiusItem:e.borderRadiusLG,itemBorderRadius:e.borderRadiusLG,radiusSubMenuItem:e.borderRadiusSM,subMenuItemBorderRadius:e.borderRadiusSM,colorItemText:c,itemColor:c,colorItemTextHover:c,itemHoverColor:c,colorItemTextHoverHorizontal:o,horizontalItemHoverColor:o,colorGroupTitle:u,groupTitleColor:u,colorItemTextSelected:o,itemSelectedColor:o,subMenuItemSelectedColor:o,colorItemTextSelectedHorizontal:o,horizontalItemSelectedColor:o,colorItemBg:d,itemBg:d,colorItemBgHover:p,itemHoverBg:p,colorItemBgActive:m,itemActiveBg:h,colorSubItemBg:f,subMenuItemBg:f,colorItemBgSelected:h,itemSelectedBg:h,colorItemBgSelectedHorizontal:"transparent",horizontalItemSelectedBg:"transparent",colorActiveBarWidth:0,activeBarWidth:P,colorActiveBarHeight:g,activeBarHeight:g,colorActiveBarBorderSize:v,activeBarBorderWidth:M,colorItemTextDisabled:l,itemDisabledColor:l,colorDangerItemText:a,dangerItemColor:a,colorDangerItemTextHover:a,dangerItemHoverColor:a,colorDangerItemTextSelected:a,dangerItemSelectedColor:a,colorDangerItemBgActive:s,dangerItemActiveBg:s,colorDangerItemBgSelected:s,dangerItemSelectedBg:s,itemMarginInline:R,horizontalItemBorderRadius:0,horizontalItemHoverBg:"transparent",itemHeight:b,groupTitleLineHeight:y,collapsedWidth:b*2,popupBg:C,itemMarginBlock:$,itemPaddingInline:S,horizontalLineHeight:`${b*1.15}px`,iconSize:x,iconMarginInlineEnd:E-x,collapsedIconSize:O,groupTitleFontSize:x,darkItemDisabledColor:new Mt(w).setA(.25).toRgbString(),darkItemColor:N,darkDangerItemColor:a,darkItemBg:"#001529",darkPopupBg:"#001529",darkSubMenuItemBg:"#000c17",darkItemSelectedColor:w,darkItemSelectedBg:o,darkDangerItemSelectedBg:a,darkItemHoverBg:"transparent",darkGroupTitleColor:N,darkItemHoverColor:w,darkDangerItemHoverColor:I,darkDangerItemSelectedColor:w,darkDangerItemActiveBg:a,itemWidth:P?`calc(100% + ${M}px)`:`calc(100% - ${R*2}px)`}},tM=(e,t=e,n=!0)=>It("Menu",o=>{const{colorBgElevated:a,controlHeightLG:l,fontSize:s,darkItemColor:c,darkDangerItemColor:u,darkItemBg:d,darkSubMenuItemBg:f,darkItemSelectedColor:m,darkItemSelectedBg:v,darkDangerItemSelectedBg:g,darkItemHoverBg:h,darkGroupTitleColor:p,darkItemHoverColor:b,darkItemDisabledColor:y,darkDangerItemHoverColor:C,darkDangerItemSelectedColor:$,darkDangerItemActiveBg:S,popupBg:x,darkPopupBg:E}=o,O=o.calc(s).div(7).mul(5).equal(),w=yt(o,{menuArrowSize:O,menuHorizontalHeight:o.calc(l).mul(1.15).equal(),menuArrowOffset:o.calc(O).mul(.25).equal(),menuSubMenuBg:a,calc:o.calc,popupBg:x}),I=yt(w,{itemColor:c,itemHoverColor:b,groupTitleColor:p,itemSelectedColor:m,subMenuItemSelectedColor:m,itemBg:d,popupBg:E,subMenuItemBg:f,itemActiveBg:"transparent",itemSelectedBg:v,activeBarHeight:0,activeBarBorderWidth:0,itemHoverBg:h,itemDisabledColor:y,dangerItemColor:u,dangerItemHoverColor:C,dangerItemSelectedColor:$,dangerItemActiveBg:S,dangerItemSelectedBg:g,menuSubMenuBg:f,horizontalItemSelectedColor:m,horizontalItemSelectedBg:v});return[J3(w),Y3(w),Z3(w),eg(w,"light"),eg(I,"dark"),Q3(w),ss(w),eo(w,"slide-up"),eo(w,"slide-down"),ui(w,"zoom-big")]},eM,{deprecatedTokens:[["colorGroupTitle","groupTitleColor"],["radiusItem","itemBorderRadius"],["radiusSubMenuItem","subMenuItemBorderRadius"],["colorItemText","itemColor"],["colorItemTextHover","itemHoverColor"],["colorItemTextHoverHorizontal","horizontalItemHoverColor"],["colorItemTextSelected","itemSelectedColor"],["colorItemTextSelectedHorizontal","horizontalItemSelectedColor"],["colorItemTextDisabled","itemDisabledColor"],["colorDangerItemText","dangerItemColor"],["colorDangerItemTextHover","dangerItemHoverColor"],["colorDangerItemTextSelected","dangerItemSelectedColor"],["colorDangerItemBgActive","dangerItemActiveBg"],["colorDangerItemBgSelected","dangerItemSelectedBg"],["colorItemBg","itemBg"],["colorItemBgHover","itemHoverBg"],["colorSubItemBg","subMenuItemBg"],["colorItemBgActive","itemActiveBg"],["colorItemBgSelectedHorizontal","horizontalItemSelectedBg"],["colorActiveBarWidth","activeBarWidth"],["colorActiveBarHeight","activeBarHeight"],["colorActiveBarBorderSize","activeBarBorderWidth"],["colorItemBgSelected","itemSelectedBg"]],injectStyle:n,unitless:{groupTitleLineHeight:!0}})(e,t),Cy=e=>{var t;const{popupClassName:n,icon:r,title:o,theme:a}=e,l=i.useContext(Ol),{prefixCls:s,inlineCollapsed:c,theme:u}=l,d=ga();let f;if(!r)f=c&&!d.length&&o&&typeof o=="string"?i.createElement("div",{className:`${s}-inline-collapsed-noicon`},o.charAt(0)):i.createElement("span",{className:`${s}-title-content`},o);else{const g=i.isValidElement(o)&&o.type==="span";f=i.createElement(i.Fragment,null,cn(r,{className:A(i.isValidElement(r)?(t=r.props)===null||t===void 0?void 0:t.className:void 0,`${s}-item-icon`)}),g?o:i.createElement("span",{className:`${s}-title-content`},o))}const m=i.useMemo(()=>Object.assign(Object.assign({},l),{firstLevel:!1}),[l]),[v]=ma("Menu");return i.createElement(Ol.Provider,{value:m},i.createElement(Is,Object.assign({},Gt(e,["icon"]),{title:f,popupClassName:A(s,n,`${s}-${a||u}`),popupStyle:Object.assign({zIndex:v},e.popupStyle)})))};var nM=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function $c(e){return e===null||e===!1}const rM={item:by,submenu:Cy,divider:hy},oM=i.forwardRef((e,t)=>{var n;const r=i.useContext(Il),o=r||{},{getPrefixCls:a,getPopupContainer:l,direction:s,menu:c}=i.useContext(ot),u=a(),{prefixCls:d,className:f,style:m,theme:v="light",expandIcon:g,_internalDisableMenuItemTitleTooltip:h,inlineCollapsed:p,siderCollapsed:b,rootClassName:y,mode:C,selectable:$,onClick:S,overflowedIndicatorPopupClassName:x}=e,E=nM(e,["prefixCls","className","style","theme","expandIcon","_internalDisableMenuItemTitleTooltip","inlineCollapsed","siderCollapsed","rootClassName","mode","selectable","onClick","overflowedIndicatorPopupClassName"]),O=Gt(E,["collapsedWidth"]);(n=o.validator)===null||n===void 0||n.call(o,{mode:C});const w=Nt((...q)=>{var H;S==null||S.apply(void 0,q),(H=o.onClick)===null||H===void 0||H.call(o)}),I=o.mode||C,P=$??o.selectable,M=p??b,R={horizontal:{motionName:`${u}-slide-up`},inline:os(u),other:{motionName:`${u}-zoom-big`}},N=a("menu",d||o.prefixCls),T=Cn(N),[j,z,_]=tM(N,T,!r),B=A(`${N}-${v}`,c==null?void 0:c.className,f),V=i.useMemo(()=>{var q,H;if(typeof g=="function"||$c(g))return g||null;if(typeof o.expandIcon=="function"||$c(o.expandIcon))return o.expandIcon||null;if(typeof(c==null?void 0:c.expandIcon)=="function"||$c(c==null?void 0:c.expandIcon))return(c==null?void 0:c.expandIcon)||null;const W=(q=g??(o==null?void 0:o.expandIcon))!==null&&q!==void 0?q:c==null?void 0:c.expandIcon;return cn(W,{className:A(`${N}-submenu-expand-icon`,i.isValidElement(W)?(H=W.props)===null||H===void 0?void 0:H.className:void 0)})},[g,o==null?void 0:o.expandIcon,c==null?void 0:c.expandIcon,N]),G=i.useMemo(()=>({prefixCls:N,inlineCollapsed:M||!1,direction:s,firstLevel:!0,theme:v,mode:I,disableMenuItemTitleTooltip:h}),[N,M,s,h,v]);return j(i.createElement(Il.Provider,{value:null},i.createElement(Ol.Provider,{value:G},i.createElement(pa,Object.assign({getPopupContainer:l,overflowedIndicator:i.createElement(gf,null),overflowedIndicatorPopupClassName:A(N,`${N}-${v}`,x),mode:I,selectable:P,onClick:w},O,{inlineCollapsed:M,style:Object.assign(Object.assign({},c==null?void 0:c.style),m),className:B,prefixCls:N,direction:s,defaultMotions:R,expandIcon:V,ref:t,rootClassName:A(y,z,o.rootClassName,_,T),_internalComponents:rM})))))}),ha=i.forwardRef((e,t)=>{const n=i.useRef(null),r=i.useContext(Rs);return i.useImperativeHandle(t,()=>({menu:n.current,focus:o=>{var a;(a=n.current)===null||a===void 0||a.focus(o)}})),i.createElement(oM,Object.assign({ref:n},e,r))});ha.Item=by;ha.SubMenu=Cy;ha.Divider=hy;ha.ItemGroup=vf;const aM=e=>{const{componentCls:t,menuCls:n,colorError:r,colorTextLightSolid:o}=e,a=`${n}-item`;return{[`${t}, ${t}-menu-submenu`]:{[`${n} ${a}`]:{[`&${a}-danger:not(${a}-disabled)`]:{color:r,"&:hover":{color:o,backgroundColor:r}}}}}},iM=e=>{const{componentCls:t,menuCls:n,zIndexPopup:r,dropdownArrowDistance:o,sizePopupArrow:a,antCls:l,iconCls:s,motionDurationMid:c,paddingBlock:u,fontSize:d,dropdownEdgeChildPadding:f,colorTextDisabled:m,fontSizeIcon:v,controlPaddingHorizontal:g,colorBgElevated:h}=e;return[{[t]:{position:"absolute",top:-9999,left:{_skip_check_:!0,value:-9999},zIndex:r,display:"block","&::before":{position:"absolute",insetBlock:e.calc(a).div(2).sub(o).equal(),zIndex:-9999,opacity:1e-4,content:'""'},"&-menu-vertical":{maxHeight:"100vh",overflowY:"auto"},[`&-trigger${l}-btn`]:{[`& > ${s}-down, & > ${l}-btn-icon > ${s}-down`]:{fontSize:v}},[`${t}-wrap`]:{position:"relative",[`${l}-btn > ${s}-down`]:{fontSize:v},[`${s}-down::before`]:{transition:`transform ${c}`}},[`${t}-wrap-open`]:{[`${s}-down::before`]:{transform:"rotate(180deg)"}},"\n        &-hidden,\n        &-menu-hidden,\n        &-menu-submenu-hidden\n      ":{display:"none"},[`&${l}-slide-down-enter${l}-slide-down-enter-active${t}-placement-bottomLeft,
          &${l}-slide-down-appear${l}-slide-down-appear-active${t}-placement-bottomLeft,
          &${l}-slide-down-enter${l}-slide-down-enter-active${t}-placement-bottom,
          &${l}-slide-down-appear${l}-slide-down-appear-active${t}-placement-bottom,
          &${l}-slide-down-enter${l}-slide-down-enter-active${t}-placement-bottomRight,
          &${l}-slide-down-appear${l}-slide-down-appear-active${t}-placement-bottomRight`]:{animationName:Ld},[`&${l}-slide-up-enter${l}-slide-up-enter-active${t}-placement-topLeft,
          &${l}-slide-up-appear${l}-slide-up-appear-active${t}-placement-topLeft,
          &${l}-slide-up-enter${l}-slide-up-enter-active${t}-placement-top,
          &${l}-slide-up-appear${l}-slide-up-appear-active${t}-placement-top,
          &${l}-slide-up-enter${l}-slide-up-enter-active${t}-placement-topRight,
          &${l}-slide-up-appear${l}-slide-up-appear-active${t}-placement-topRight`]:{animationName:Ad},[`&${l}-slide-down-leave${l}-slide-down-leave-active${t}-placement-bottomLeft,
          &${l}-slide-down-leave${l}-slide-down-leave-active${t}-placement-bottom,
          &${l}-slide-down-leave${l}-slide-down-leave-active${t}-placement-bottomRight`]:{animationName:Hd},[`&${l}-slide-up-leave${l}-slide-up-leave-active${t}-placement-topLeft,
          &${l}-slide-up-leave${l}-slide-up-leave-active${t}-placement-top,
          &${l}-slide-up-leave${l}-slide-up-leave-active${t}-placement-topRight`]:{animationName:Fd}}},af(e,h,{arrowPlacement:{top:!0,bottom:!0}}),{[`${t} ${n}`]:{position:"relative",margin:0},[`${n}-submenu-popup`]:{position:"absolute",zIndex:r,background:"transparent",boxShadow:"none",transformOrigin:"0 0","ul, li":{listStyle:"none",margin:0}},[`${t}, ${t}-menu-submenu`]:Object.assign(Object.assign({},Tt(e)),{[n]:Object.assign(Object.assign({padding:f,listStyleType:"none",backgroundColor:h,backgroundClip:"padding-box",borderRadius:e.borderRadiusLG,outline:"none",boxShadow:e.boxShadowSecondary},Vn(e)),{"&:empty":{padding:0,boxShadow:"none"},[`${n}-item-group-title`]:{padding:`${L(u)} ${L(g)}`,color:e.colorTextDescription,transition:`all ${c}`},[`${n}-item`]:{position:"relative",display:"flex",alignItems:"center"},[`${n}-item-icon`]:{minWidth:d,marginInlineEnd:e.marginXS,fontSize:e.fontSizeSM},[`${n}-title-content`]:{flex:"auto","&-with-extra":{display:"inline-flex",alignItems:"center",width:"100%"},"> a":{color:"inherit",transition:`all ${c}`,"&:hover":{color:"inherit"},"&::after":{position:"absolute",inset:0,content:'""'}},[`${n}-item-extra`]:{paddingInlineStart:e.padding,marginInlineStart:"auto",fontSize:e.fontSizeSM,color:e.colorTextDescription}},[`${n}-item, ${n}-submenu-title`]:Object.assign(Object.assign({display:"flex",margin:0,padding:`${L(u)} ${L(g)}`,color:e.colorText,fontWeight:"normal",fontSize:d,lineHeight:e.lineHeight,cursor:"pointer",transition:`all ${c}`,borderRadius:e.borderRadiusSM,"&:hover, &-active":{backgroundColor:e.controlItemBgHover}},Vn(e)),{"&-selected":{color:e.colorPrimary,backgroundColor:e.controlItemBgActive,"&:hover, &-active":{backgroundColor:e.controlItemBgActiveHover}},"&-disabled":{color:m,cursor:"not-allowed","&:hover":{color:m,backgroundColor:h,cursor:"not-allowed"},a:{pointerEvents:"none"}},"&-divider":{height:1,margin:`${L(e.marginXXS)} 0`,overflow:"hidden",lineHeight:0,backgroundColor:e.colorSplit},[`${t}-menu-submenu-expand-icon`]:{position:"absolute",insetInlineEnd:e.paddingXS,[`${t}-menu-submenu-arrow-icon`]:{marginInlineEnd:"0 !important",color:e.colorIcon,fontSize:v,fontStyle:"normal"}}}),[`${n}-item-group-list`]:{margin:`0 ${L(e.marginXS)}`,padding:0,listStyle:"none"},[`${n}-submenu-title`]:{paddingInlineEnd:e.calc(g).add(e.fontSizeSM).equal()},[`${n}-submenu-vertical`]:{position:"relative"},[`${n}-submenu${n}-submenu-disabled ${t}-menu-submenu-title`]:{[`&, ${t}-menu-submenu-arrow-icon`]:{color:m,backgroundColor:h,cursor:"not-allowed"}},[`${n}-submenu-selected ${t}-menu-submenu-title`]:{color:e.colorPrimary}})})},[eo(e,"slide-up"),eo(e,"slide-down"),Sl(e,"move-up"),Sl(e,"move-down"),ui(e,"zoom-big")]]},lM=e=>Object.assign(Object.assign({zIndexPopup:e.zIndexPopupBase+50,paddingBlock:(e.controlHeight-e.fontSize*e.lineHeight)/2},ws({contentRadius:e.borderRadiusLG,limitVerticalRadius:!0})),of(e)),sM=It("Dropdown",e=>{const{marginXXS:t,sizePopupArrow:n,paddingXXS:r,componentCls:o}=e,a=yt(e,{menuCls:`${o}-menu`,dropdownArrowDistance:e.calc(n).div(2).add(t).equal(),dropdownEdgeChildPadding:r});return[iM(a),aM(a)]},lM,{resetStyle:!1}),Ps=e=>{var t;const{menu:n,arrow:r,prefixCls:o,children:a,trigger:l,disabled:s,dropdownRender:c,popupRender:u,getPopupContainer:d,overlayClassName:f,rootClassName:m,overlayStyle:v,open:g,onOpenChange:h,visible:p,onVisibleChange:b,mouseEnterDelay:y=.15,mouseLeaveDelay:C=.1,autoAdjustOverflow:$=!0,placement:S="",overlay:x,transitionName:E,destroyOnHidden:O,destroyPopupOnHide:w}=e,{getPopupContainer:I,getPrefixCls:P,direction:M,dropdown:R}=i.useContext(ot),N=u||c;no();const T=i.useMemo(()=>{const ie=P();return E!==void 0?E:S.includes("top")?`${ie}-slide-down`:`${ie}-slide-up`},[P,S,E]),j=i.useMemo(()=>S?S.includes("Center")?S.slice(0,S.indexOf("Center")):S:M==="rtl"?"bottomRight":"bottomLeft",[S,M]),z=P("dropdown",o),_=Cn(z),[B,V,G]=sM(z,_),[,q]=yn(),H=i.Children.only(t3(a)?i.createElement("span",null,a):a),W=cn(H,{className:A(`${z}-trigger`,{[`${z}-rtl`]:M==="rtl"},H.props.className),disabled:(t=H.props.disabled)!==null&&t!==void 0?t:s}),K=s?[]:l,U=!!(K!=null&&K.includes("contextMenu")),[te,X]=Lt(!1,{value:g??p}),ae=Nt(ie=>{h==null||h(ie,{source:"trigger"}),b==null||b(ie),X(ie)}),le=A(f,m,V,G,_,R==null?void 0:R.className,{[`${z}-rtl`]:M==="rtl"}),ee=Gb({arrowPointAtCenter:typeof r=="object"&&r.pointAtCenter,autoAdjustOverflow:$,offset:q.marginXXS,arrowWidth:r?q.sizePopupArrow:0,borderRadius:q.borderRadius}),Y=i.useCallback(()=>{n!=null&&n.selectable&&(n!=null&&n.multiple)||(h==null||h(!1,{source:"menu"}),X(!1))},[n==null?void 0:n.selectable,n==null?void 0:n.multiple]),re=()=>{let ie;return n!=null&&n.items?ie=i.createElement(ha,Object.assign({},n)):typeof x=="function"?ie=x():ie=x,N&&(ie=N(ie)),ie=i.Children.only(typeof ie=="string"?i.createElement("span",null,ie):ie),i.createElement(yy,{prefixCls:`${z}-menu`,rootClassName:A(G,_),expandIcon:i.createElement("span",{className:`${z}-menu-submenu-arrow`},M==="rtl"?i.createElement(Ja,{className:`${z}-menu-submenu-arrow-icon`}):i.createElement(na,{className:`${z}-menu-submenu-arrow-icon`})),mode:"vertical",selectable:!1,onClick:Y,validator:({mode:de})=>{}},ie)},[ne,Z]=ma("Dropdown",v==null?void 0:v.zIndex);let Q=i.createElement(ey,Object.assign({alignPoint:U},Gt(e,["rootClassName"]),{mouseEnterDelay:y,mouseLeaveDelay:C,visible:te,builtinPlacements:ee,arrow:!!r,overlayClassName:le,prefixCls:z,getPopupContainer:d||I,transitionName:T,trigger:K,overlay:re,placement:j,onVisibleChange:ae,overlayStyle:Object.assign(Object.assign(Object.assign({},R==null?void 0:R.style),v),{zIndex:ne}),autoDestroy:O??w}),W);return ne&&(Q=i.createElement(li.Provider,{value:Z},Q)),B(Q)},cM=Ud(Ps,"align",void 0,"dropdown",e=>e),uM=e=>i.createElement(cM,Object.assign({},e),i.createElement("span",null));Ps._InternalPanelDoNotUseOrYouWillBeFired=uM;const Sy=i.createContext(null),dM=Sy.Provider,$y=i.createContext(null),fM=$y.Provider;var mM=["prefixCls","className","style","checked","disabled","defaultChecked","type","title","onChange"],xy=i.forwardRef(function(e,t){var n=e.prefixCls,r=n===void 0?"rc-checkbox":n,o=e.className,a=e.style,l=e.checked,s=e.disabled,c=e.defaultChecked,u=c===void 0?!1:c,d=e.type,f=d===void 0?"checkbox":d,m=e.title,v=e.onChange,g=ft(e,mM),h=i.useRef(null),p=i.useRef(null),b=Lt(u,{value:l}),y=J(b,2),C=y[0],$=y[1];i.useImperativeHandle(t,function(){return{focus:function(O){var w;(w=h.current)===null||w===void 0||w.focus(O)},blur:function(){var O;(O=h.current)===null||O===void 0||O.blur()},input:h.current,nativeElement:p.current}});var S=A(r,o,D(D({},"".concat(r,"-checked"),C),"".concat(r,"-disabled"),s)),x=function(O){s||("checked"in e||$(O.target.checked),v==null||v({target:k(k({},e),{},{type:f,checked:O.target.checked}),stopPropagation:function(){O.stopPropagation()},preventDefault:function(){O.preventDefault()},nativeEvent:O.nativeEvent}))};return i.createElement("span",{className:S,title:m,style:a,ref:p},i.createElement("input",ue({},g,{className:"".concat(r,"-input"),ref:h,onChange:x,disabled:s,checked:!!C,type:f})),i.createElement("span",{className:"".concat(r,"-inner")}))});function wy(e){const t=F.useRef(null),n=()=>{Et.cancel(t.current),t.current=null};return[()=>{n(),t.current=Et(()=>{t.current=null})},a=>{t.current&&(a.stopPropagation(),n()),e==null||e(a)}]}const vM=e=>{const{componentCls:t,antCls:n}=e,r=`${t}-group`;return{[r]:Object.assign(Object.assign({},Tt(e)),{display:"inline-block",fontSize:0,[`&${r}-rtl`]:{direction:"rtl"},[`&${r}-block`]:{display:"flex"},[`${n}-badge ${n}-badge-count`]:{zIndex:1},[`> ${n}-badge:not(:first-child) > ${n}-button-wrapper`]:{borderInlineStart:"none"}})}},gM=e=>{const{componentCls:t,wrapperMarginInlineEnd:n,colorPrimary:r,radioSize:o,motionDurationSlow:a,motionDurationMid:l,motionEaseInOutCirc:s,colorBgContainer:c,colorBorder:u,lineWidth:d,colorBgContainerDisabled:f,colorTextDisabled:m,paddingXS:v,dotColorDisabled:g,lineType:h,radioColor:p,radioBgColor:b,calc:y}=e,C=`${t}-inner`,S=y(o).sub(y(4).mul(2)),x=y(1).mul(o).equal({unit:!0});return{[`${t}-wrapper`]:Object.assign(Object.assign({},Tt(e)),{display:"inline-flex",alignItems:"baseline",marginInlineStart:0,marginInlineEnd:n,cursor:"pointer","&:last-child":{marginInlineEnd:0},[`&${t}-wrapper-rtl`]:{direction:"rtl"},"&-disabled":{cursor:"not-allowed",color:e.colorTextDisabled},"&::after":{display:"inline-block",width:0,overflow:"hidden",content:'"\\a0"'},"&-block":{flex:1,justifyContent:"center"},[`${t}-checked::after`]:{position:"absolute",insetBlockStart:0,insetInlineStart:0,width:"100%",height:"100%",border:`${L(d)} ${h} ${r}`,borderRadius:"50%",visibility:"hidden",opacity:0,content:'""'},[t]:Object.assign(Object.assign({},Tt(e)),{position:"relative",display:"inline-block",outline:"none",cursor:"pointer",alignSelf:"center",borderRadius:"50%"}),[`${t}-wrapper:hover &,
        &:hover ${C}`]:{borderColor:r},[`${t}-input:focus-visible + ${C}`]:Cr(e),[`${t}:hover::after, ${t}-wrapper:hover &::after`]:{visibility:"visible"},[`${t}-inner`]:{"&::after":{boxSizing:"border-box",position:"absolute",insetBlockStart:"50%",insetInlineStart:"50%",display:"block",width:x,height:x,marginBlockStart:y(1).mul(o).div(-2).equal({unit:!0}),marginInlineStart:y(1).mul(o).div(-2).equal({unit:!0}),backgroundColor:p,borderBlockStart:0,borderInlineStart:0,borderRadius:x,transform:"scale(0)",opacity:0,transition:`all ${a} ${s}`,content:'""'},boxSizing:"border-box",position:"relative",insetBlockStart:0,insetInlineStart:0,display:"block",width:x,height:x,backgroundColor:c,borderColor:u,borderStyle:"solid",borderWidth:d,borderRadius:"50%",transition:`all ${l}`},[`${t}-input`]:{position:"absolute",inset:0,zIndex:1,cursor:"pointer",opacity:0},[`${t}-checked`]:{[C]:{borderColor:r,backgroundColor:b,"&::after":{transform:`scale(${e.calc(e.dotSize).div(o).equal()})`,opacity:1,transition:`all ${a} ${s}`}}},[`${t}-disabled`]:{cursor:"not-allowed",[C]:{backgroundColor:f,borderColor:u,cursor:"not-allowed","&::after":{backgroundColor:g}},[`${t}-input`]:{cursor:"not-allowed"},[`${t}-disabled + span`]:{color:m,cursor:"not-allowed"},[`&${t}-checked`]:{[C]:{"&::after":{transform:`scale(${y(S).div(o).equal()})`}}}},[`span${t} + *`]:{paddingInlineStart:v,paddingInlineEnd:v}})}},pM=e=>{const{buttonColor:t,controlHeight:n,componentCls:r,lineWidth:o,lineType:a,colorBorder:l,motionDurationSlow:s,motionDurationMid:c,buttonPaddingInline:u,fontSize:d,buttonBg:f,fontSizeLG:m,controlHeightLG:v,controlHeightSM:g,paddingXS:h,borderRadius:p,borderRadiusSM:b,borderRadiusLG:y,buttonCheckedBg:C,buttonSolidCheckedColor:$,colorTextDisabled:S,colorBgContainerDisabled:x,buttonCheckedBgDisabled:E,buttonCheckedColorDisabled:O,colorPrimary:w,colorPrimaryHover:I,colorPrimaryActive:P,buttonSolidCheckedBg:M,buttonSolidCheckedHoverBg:R,buttonSolidCheckedActiveBg:N,calc:T}=e;return{[`${r}-button-wrapper`]:{position:"relative",display:"inline-block",height:n,margin:0,paddingInline:u,paddingBlock:0,color:t,fontSize:d,lineHeight:L(T(n).sub(T(o).mul(2)).equal()),background:f,border:`${L(o)} ${a} ${l}`,borderBlockStartWidth:T(o).add(.02).equal(),borderInlineStartWidth:0,borderInlineEndWidth:o,cursor:"pointer",transition:[`color ${c}`,`background ${c}`,`box-shadow ${c}`].join(","),a:{color:t},[`> ${r}-button`]:{position:"absolute",insetBlockStart:0,insetInlineStart:0,zIndex:-1,width:"100%",height:"100%"},"&:not(:first-child)":{"&::before":{position:"absolute",insetBlockStart:T(o).mul(-1).equal(),insetInlineStart:T(o).mul(-1).equal(),display:"block",boxSizing:"content-box",width:1,height:"100%",paddingBlock:o,paddingInline:0,backgroundColor:l,transition:`background-color ${s}`,content:'""'}},"&:first-child":{borderInlineStart:`${L(o)} ${a} ${l}`,borderStartStartRadius:p,borderEndStartRadius:p},"&:last-child":{borderStartEndRadius:p,borderEndEndRadius:p},"&:first-child:last-child":{borderRadius:p},[`${r}-group-large &`]:{height:v,fontSize:m,lineHeight:L(T(v).sub(T(o).mul(2)).equal()),"&:first-child":{borderStartStartRadius:y,borderEndStartRadius:y},"&:last-child":{borderStartEndRadius:y,borderEndEndRadius:y}},[`${r}-group-small &`]:{height:g,paddingInline:T(h).sub(o).equal(),paddingBlock:0,lineHeight:L(T(g).sub(T(o).mul(2)).equal()),"&:first-child":{borderStartStartRadius:b,borderEndStartRadius:b},"&:last-child":{borderStartEndRadius:b,borderEndEndRadius:b}},"&:hover":{position:"relative",color:w},"&:has(:focus-visible)":Cr(e),[`${r}-inner, input[type='checkbox'], input[type='radio']`]:{width:0,height:0,opacity:0,pointerEvents:"none"},[`&-checked:not(${r}-button-wrapper-disabled)`]:{zIndex:1,color:w,background:C,borderColor:w,"&::before":{backgroundColor:w},"&:first-child":{borderColor:w},"&:hover":{color:I,borderColor:I,"&::before":{backgroundColor:I}},"&:active":{color:P,borderColor:P,"&::before":{backgroundColor:P}}},[`${r}-group-solid &-checked:not(${r}-button-wrapper-disabled)`]:{color:$,background:M,borderColor:M,"&:hover":{color:$,background:R,borderColor:R},"&:active":{color:$,background:N,borderColor:N}},"&-disabled":{color:S,backgroundColor:x,borderColor:l,cursor:"not-allowed","&:first-child, &:hover":{color:S,backgroundColor:x,borderColor:l}},[`&-disabled${r}-button-wrapper-checked`]:{color:O,backgroundColor:E,borderColor:l,boxShadow:"none"},"&-block":{flex:1,textAlign:"center"}}}},hM=e=>{const{wireframe:t,padding:n,marginXS:r,lineWidth:o,fontSizeLG:a,colorText:l,colorBgContainer:s,colorTextDisabled:c,controlItemBgActiveDisabled:u,colorTextLightSolid:d,colorPrimary:f,colorPrimaryHover:m,colorPrimaryActive:v,colorWhite:g}=e,h=4,p=a,b=t?p-h*2:p-(h+o)*2;return{radioSize:p,dotSize:b,dotColorDisabled:c,buttonSolidCheckedColor:d,buttonSolidCheckedBg:f,buttonSolidCheckedHoverBg:m,buttonSolidCheckedActiveBg:v,buttonBg:s,buttonCheckedBg:s,buttonColor:l,buttonCheckedBgDisabled:u,buttonCheckedColorDisabled:c,buttonPaddingInline:n-o,wrapperMarginInlineEnd:r,radioColor:t?f:g,radioBgColor:t?s:f}},Ey=It("Radio",e=>{const{controlOutline:t,controlOutlineWidth:n}=e,r=`0 0 0 ${L(n)} ${t}`,a=yt(e,{radioFocusShadow:r,radioButtonFocusShadow:r});return[vM(a),gM(a),pM(a)]},hM,{unitless:{radioSize:!0,dotSize:!0}});var bM=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const yM=(e,t)=>{var n,r;const o=i.useContext(Sy),a=i.useContext($y),{getPrefixCls:l,direction:s,radio:c}=i.useContext(ot),u=i.useRef(null),d=un(t,u),{isFormItemInput:f}=i.useContext(Wn),m=j=>{var z,_;(z=e.onChange)===null||z===void 0||z.call(e,j),(_=o==null?void 0:o.onChange)===null||_===void 0||_.call(o,j)},{prefixCls:v,className:g,rootClassName:h,children:p,style:b,title:y}=e,C=bM(e,["prefixCls","className","rootClassName","children","style","title"]),$=l("radio",v),S=((o==null?void 0:o.optionType)||a)==="button",x=S?`${$}-button`:$,E=Cn($),[O,w,I]=Ey($,E),P=Object.assign({},C),M=i.useContext(Ln);o&&(P.name=o.name,P.onChange=m,P.checked=e.value===o.value,P.disabled=(n=P.disabled)!==null&&n!==void 0?n:o.disabled),P.disabled=(r=P.disabled)!==null&&r!==void 0?r:M;const R=A(`${x}-wrapper`,{[`${x}-wrapper-checked`]:P.checked,[`${x}-wrapper-disabled`]:P.disabled,[`${x}-wrapper-rtl`]:s==="rtl",[`${x}-wrapper-in-form-item`]:f,[`${x}-wrapper-block`]:!!(o!=null&&o.block)},c==null?void 0:c.className,g,h,w,I,E),[N,T]=wy(P.onClick);return O(i.createElement(ci,{component:"Radio",disabled:P.disabled},i.createElement("label",{className:R,style:Object.assign(Object.assign({},c==null?void 0:c.style),b),onMouseEnter:e.onMouseEnter,onMouseLeave:e.onMouseLeave,title:y,onClick:N},i.createElement(xy,Object.assign({},P,{className:A(P.className,{[is]:!S}),type:"radio",prefixCls:x,ref:d,onClick:T})),p!==void 0?i.createElement("span",{className:`${x}-label`},p):null)))},Rl=i.forwardRef(yM);function CM(e){return e===void 0||e===!1?[]:Array.isArray(e)?e:[e]}function SM(e){return CM(e).join("_")}const $M=i.forwardRef((e,t)=>{const{getPrefixCls:n,direction:r}=i.useContext(ot),{name:o}=i.useContext(Wn),a=mi(SM(o)),{prefixCls:l,className:s,rootClassName:c,options:u,buttonStyle:d="outline",disabled:f,children:m,size:v,style:g,id:h,optionType:p,name:b=a,defaultValue:y,value:C,block:$=!1,onChange:S,onMouseEnter:x,onMouseLeave:E,onFocus:O,onBlur:w}=e,[I,P]=Lt(y,{value:C}),M=i.useCallback(H=>{const W=I,K=H.target.value;"value"in e||P(K),K!==W&&(S==null||S(H))},[I,P,S]),R=n("radio",l),N=`${R}-group`,T=Cn(R),[j,z,_]=Ey(R,T);let B=m;u&&u.length>0&&(B=u.map(H=>typeof H=="string"||typeof H=="number"?i.createElement(Rl,{key:H.toString(),prefixCls:R,disabled:f,value:H,checked:I===H},H):i.createElement(Rl,{key:`radio-group-value-options-${H.value}`,prefixCls:R,disabled:H.disabled||f,value:H.value,checked:I===H.value,title:H.title,style:H.style,className:H.className,id:H.id,required:H.required},H.label)));const V=Sn(v),G=A(N,`${N}-${d}`,{[`${N}-${V}`]:V,[`${N}-rtl`]:r==="rtl",[`${N}-block`]:$},s,c,z,_,T),q=i.useMemo(()=>({onChange:M,value:I,disabled:f,name:b,optionType:p,block:$}),[M,I,f,b,p,$]);return j(i.createElement("div",Object.assign({},rn(e,{aria:!0,data:!0}),{className:G,style:g,onMouseEnter:x,onMouseLeave:E,onFocus:O,onBlur:w,id:h,ref:t}),i.createElement(dM,{value:q},B)))}),xM=i.memo($M);var wM=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const EM=(e,t)=>{const{getPrefixCls:n}=i.useContext(ot),{prefixCls:r}=e,o=wM(e,["prefixCls"]),a=n("radio",r);return i.createElement(fM,{value:"button"},i.createElement(Rl,Object.assign({prefixCls:a},o,{type:"radio",ref:t})))},OM=i.forwardRef(EM),Si=Rl;Si.Button=OM;Si.Group=xM;Si.__ANT_RADIO=!0;function ba(e){return yt(e,{inputAffixPadding:e.paddingXXS})}const ya=e=>{const{controlHeight:t,fontSize:n,lineHeight:r,lineWidth:o,controlHeightSM:a,controlHeightLG:l,fontSizeLG:s,lineHeightLG:c,paddingSM:u,controlPaddingHorizontalSM:d,controlPaddingHorizontal:f,colorFillAlter:m,colorPrimaryHover:v,colorPrimary:g,controlOutlineWidth:h,controlOutline:p,colorErrorOutline:b,colorWarningOutline:y,colorBgContainer:C,inputFontSize:$,inputFontSizeLG:S,inputFontSizeSM:x}=e,E=$||n,O=x||E,w=S||s,I=Math.round((t-E*r)/2*10)/10-o,P=Math.round((a-O*r)/2*10)/10-o,M=Math.ceil((l-w*c)/2*10)/10-o;return{paddingBlock:Math.max(I,0),paddingBlockSM:Math.max(P,0),paddingBlockLG:Math.max(M,0),paddingInline:u-o,paddingInlineSM:d-o,paddingInlineLG:f-o,addonBg:m,activeBorderColor:g,hoverBorderColor:v,activeShadow:`0 0 0 ${h}px ${p}`,errorActiveShadow:`0 0 0 ${h}px ${b}`,warningActiveShadow:`0 0 0 ${h}px ${y}`,hoverBg:C,activeBg:C,inputFontSize:E,inputFontSizeLG:w,inputFontSizeSM:O}},IM=e=>({borderColor:e.hoverBorderColor,backgroundColor:e.hoverBg}),Ns=e=>({color:e.colorTextDisabled,backgroundColor:e.colorBgContainerDisabled,borderColor:e.colorBorder,boxShadow:"none",cursor:"not-allowed",opacity:1,"input[disabled], textarea[disabled]":{cursor:"not-allowed"},"&:hover:not([disabled])":Object.assign({},IM(yt(e,{hoverBorderColor:e.colorBorder,hoverBg:e.colorBgContainerDisabled})))}),pf=(e,t)=>({background:e.colorBgContainer,borderWidth:e.lineWidth,borderStyle:e.lineType,borderColor:t.borderColor,"&:hover":{borderColor:t.hoverBorderColor,backgroundColor:e.hoverBg},"&:focus, &:focus-within":{borderColor:t.activeBorderColor,boxShadow:t.activeShadow,outline:0,backgroundColor:e.activeBg}}),og=(e,t)=>({[`&${e.componentCls}-status-${t.status}:not(${e.componentCls}-disabled)`]:Object.assign(Object.assign({},pf(e,t)),{[`${e.componentCls}-prefix, ${e.componentCls}-suffix`]:{color:t.affixColor}}),[`&${e.componentCls}-status-${t.status}${e.componentCls}-disabled`]:{borderColor:t.borderColor}}),Oy=(e,t)=>({"&-outlined":Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},pf(e,{borderColor:e.colorBorder,hoverBorderColor:e.hoverBorderColor,activeBorderColor:e.activeBorderColor,activeShadow:e.activeShadow})),{[`&${e.componentCls}-disabled, &[disabled]`]:Object.assign({},Ns(e))}),og(e,{status:"error",borderColor:e.colorError,hoverBorderColor:e.colorErrorBorderHover,activeBorderColor:e.colorError,activeShadow:e.errorActiveShadow,affixColor:e.colorError})),og(e,{status:"warning",borderColor:e.colorWarning,hoverBorderColor:e.colorWarningBorderHover,activeBorderColor:e.colorWarning,activeShadow:e.warningActiveShadow,affixColor:e.colorWarning})),t)}),ag=(e,t)=>({[`&${e.componentCls}-group-wrapper-status-${t.status}`]:{[`${e.componentCls}-group-addon`]:{borderColor:t.addonBorderColor,color:t.addonColor}}}),Iy=e=>({"&-outlined":Object.assign(Object.assign(Object.assign({[`${e.componentCls}-group`]:{"&-addon":{background:e.addonBg,border:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`},"&-addon:first-child":{borderInlineEnd:0},"&-addon:last-child":{borderInlineStart:0}}},ag(e,{status:"error",addonBorderColor:e.colorError,addonColor:e.colorErrorText})),ag(e,{status:"warning",addonBorderColor:e.colorWarning,addonColor:e.colorWarningText})),{[`&${e.componentCls}-group-wrapper-disabled`]:{[`${e.componentCls}-group-addon`]:Object.assign({},Ns(e))}})}),Ry=(e,t)=>{const{componentCls:n}=e;return{"&-borderless":Object.assign({background:"transparent",border:"none","&:focus, &:focus-within":{outline:"none"},[`&${n}-disabled, &[disabled]`]:{color:e.colorTextDisabled,cursor:"not-allowed"},[`&${n}-status-error`]:{"&, & input, & textarea":{color:e.colorError}},[`&${n}-status-warning`]:{"&, & input, & textarea":{color:e.colorWarning}}},t)}},Py=(e,t)=>{var n;return{background:t.bg,borderWidth:e.lineWidth,borderStyle:e.lineType,borderColor:"transparent","input&, & input, textarea&, & textarea":{color:(n=t==null?void 0:t.inputColor)!==null&&n!==void 0?n:"unset"},"&:hover":{background:t.hoverBg},"&:focus, &:focus-within":{outline:0,borderColor:t.activeBorderColor,backgroundColor:e.activeBg}}},ig=(e,t)=>({[`&${e.componentCls}-status-${t.status}:not(${e.componentCls}-disabled)`]:Object.assign(Object.assign({},Py(e,t)),{[`${e.componentCls}-prefix, ${e.componentCls}-suffix`]:{color:t.affixColor}})}),Ny=(e,t)=>({"&-filled":Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},Py(e,{bg:e.colorFillTertiary,hoverBg:e.colorFillSecondary,activeBorderColor:e.activeBorderColor})),{[`&${e.componentCls}-disabled, &[disabled]`]:Object.assign({},Ns(e))}),ig(e,{status:"error",bg:e.colorErrorBg,hoverBg:e.colorErrorBgHover,activeBorderColor:e.colorError,inputColor:e.colorErrorText,affixColor:e.colorError})),ig(e,{status:"warning",bg:e.colorWarningBg,hoverBg:e.colorWarningBgHover,activeBorderColor:e.colorWarning,inputColor:e.colorWarningText,affixColor:e.colorWarning})),t)}),lg=(e,t)=>({[`&${e.componentCls}-group-wrapper-status-${t.status}`]:{[`${e.componentCls}-group-addon`]:{background:t.addonBg,color:t.addonColor}}}),My=e=>({"&-filled":Object.assign(Object.assign(Object.assign({[`${e.componentCls}-group-addon`]:{background:e.colorFillTertiary,"&:last-child":{position:"static"}}},lg(e,{status:"error",addonBg:e.colorErrorBg,addonColor:e.colorErrorText})),lg(e,{status:"warning",addonBg:e.colorWarningBg,addonColor:e.colorWarningText})),{[`&${e.componentCls}-group-wrapper-disabled`]:{[`${e.componentCls}-group`]:{"&-addon":{background:e.colorFillTertiary,color:e.colorTextDisabled},"&-addon:first-child":{borderInlineStart:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,borderTop:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,borderBottom:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`},"&-addon:last-child":{borderInlineEnd:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,borderTop:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,borderBottom:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`}}}})}),Ty=(e,t)=>({background:e.colorBgContainer,borderWidth:`${L(e.lineWidth)} 0`,borderStyle:`${e.lineType} none`,borderColor:`transparent transparent ${t.borderColor} transparent`,borderRadius:0,"&:hover":{borderColor:`transparent transparent ${t.borderColor} transparent`,backgroundColor:e.hoverBg},"&:focus, &:focus-within":{borderColor:`transparent transparent ${t.activeBorderColor} transparent`,outline:0,backgroundColor:e.activeBg}}),sg=(e,t)=>({[`&${e.componentCls}-status-${t.status}:not(${e.componentCls}-disabled)`]:Object.assign(Object.assign({},Ty(e,t)),{[`${e.componentCls}-prefix, ${e.componentCls}-suffix`]:{color:t.affixColor}}),[`&${e.componentCls}-status-${t.status}${e.componentCls}-disabled`]:{borderColor:`transparent transparent ${t.borderColor} transparent`}}),jy=(e,t)=>({"&-underlined":Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},Ty(e,{borderColor:e.colorBorder,hoverBorderColor:e.hoverBorderColor,activeBorderColor:e.activeBorderColor,activeShadow:e.activeShadow})),{[`&${e.componentCls}-disabled, &[disabled]`]:{color:e.colorTextDisabled,boxShadow:"none",cursor:"not-allowed","&:hover":{borderColor:`transparent transparent ${e.colorBorder} transparent`}},"input[disabled], textarea[disabled]":{cursor:"not-allowed"}}),sg(e,{status:"error",borderColor:e.colorError,hoverBorderColor:e.colorErrorBorderHover,activeBorderColor:e.colorError,activeShadow:e.errorActiveShadow,affixColor:e.colorError})),sg(e,{status:"warning",borderColor:e.colorWarning,hoverBorderColor:e.colorWarningBorderHover,activeBorderColor:e.colorWarning,activeShadow:e.warningActiveShadow,affixColor:e.colorWarning})),t)}),zy=e=>({"&::-moz-placeholder":{opacity:1},"&::placeholder":{color:e,userSelect:"none"},"&:placeholder-shown":{textOverflow:"ellipsis"}}),Dy=e=>{const{paddingBlockLG:t,lineHeightLG:n,borderRadiusLG:r,paddingInlineLG:o}=e;return{padding:`${L(t)} ${L(o)}`,fontSize:e.inputFontSizeLG,lineHeight:n,borderRadius:r}},hf=e=>({padding:`${L(e.paddingBlockSM)} ${L(e.paddingInlineSM)}`,fontSize:e.inputFontSizeSM,borderRadius:e.borderRadiusSM}),$i=e=>Object.assign(Object.assign({position:"relative",display:"inline-block",width:"100%",minWidth:0,padding:`${L(e.paddingBlock)} ${L(e.paddingInline)}`,color:e.colorText,fontSize:e.inputFontSize,lineHeight:e.lineHeight,borderRadius:e.borderRadius,transition:`all ${e.motionDurationMid}`},zy(e.colorTextPlaceholder)),{"&-lg":Object.assign({},Dy(e)),"&-sm":Object.assign({},hf(e)),"&-rtl, &-textarea-rtl":{direction:"rtl"}}),_y=e=>{const{componentCls:t,antCls:n}=e;return{position:"relative",display:"table",width:"100%",borderCollapse:"separate",borderSpacing:0,"&[class*='col-']":{paddingInlineEnd:e.paddingXS,"&:last-child":{paddingInlineEnd:0}},[`&-lg ${t}, &-lg > ${t}-group-addon`]:Object.assign({},Dy(e)),[`&-sm ${t}, &-sm > ${t}-group-addon`]:Object.assign({},hf(e)),[`&-lg ${n}-select-single ${n}-select-selector`]:{height:e.controlHeightLG},[`&-sm ${n}-select-single ${n}-select-selector`]:{height:e.controlHeightSM},[`> ${t}`]:{display:"table-cell","&:not(:first-child):not(:last-child)":{borderRadius:0}},[`${t}-group`]:{"&-addon, &-wrap":{display:"table-cell",width:1,whiteSpace:"nowrap",verticalAlign:"middle","&:not(:first-child):not(:last-child)":{borderRadius:0}},"&-wrap > *":{display:"block !important"},"&-addon":{position:"relative",padding:`0 ${L(e.paddingInline)}`,color:e.colorText,fontWeight:"normal",fontSize:e.inputFontSize,textAlign:"center",borderRadius:e.borderRadius,transition:`all ${e.motionDurationSlow}`,lineHeight:1,[`${n}-select`]:{margin:`${L(e.calc(e.paddingBlock).add(1).mul(-1).equal())} ${L(e.calc(e.paddingInline).mul(-1).equal())}`,[`&${n}-select-single:not(${n}-select-customize-input):not(${n}-pagination-size-changer)`]:{[`${n}-select-selector`]:{backgroundColor:"inherit",border:`${L(e.lineWidth)} ${e.lineType} transparent`,boxShadow:"none"}}},[`${n}-cascader-picker`]:{margin:`-9px ${L(e.calc(e.paddingInline).mul(-1).equal())}`,backgroundColor:"transparent",[`${n}-cascader-input`]:{textAlign:"start",border:0,boxShadow:"none"}}}},[t]:{width:"100%",marginBottom:0,textAlign:"inherit","&:focus":{zIndex:1,borderInlineEndWidth:1},"&:hover":{zIndex:1,borderInlineEndWidth:1,[`${t}-search-with-button &`]:{zIndex:0}}},[`> ${t}:first-child, ${t}-group-addon:first-child`]:{borderStartEndRadius:0,borderEndEndRadius:0,[`${n}-select ${n}-select-selector`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`> ${t}-affix-wrapper`]:{[`&:not(:first-child) ${t}`]:{borderStartStartRadius:0,borderEndStartRadius:0},[`&:not(:last-child) ${t}`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`> ${t}:last-child, ${t}-group-addon:last-child`]:{borderStartStartRadius:0,borderEndStartRadius:0,[`${n}-select ${n}-select-selector`]:{borderStartStartRadius:0,borderEndStartRadius:0}},[`${t}-affix-wrapper`]:{"&:not(:last-child)":{borderStartEndRadius:0,borderEndEndRadius:0,[`${t}-search &`]:{borderStartStartRadius:e.borderRadius,borderEndStartRadius:e.borderRadius}},[`&:not(:first-child), ${t}-search &:not(:first-child)`]:{borderStartStartRadius:0,borderEndStartRadius:0}},[`&${t}-group-compact`]:Object.assign(Object.assign({display:"block"},yr()),{[`${t}-group-addon, ${t}-group-wrap, > ${t}`]:{"&:not(:first-child):not(:last-child)":{borderInlineEndWidth:e.lineWidth,"&:hover, &:focus":{zIndex:1}}},"& > *":{display:"inline-flex",float:"none",verticalAlign:"top",borderRadius:0},[`
        & > ${t}-affix-wrapper,
        & > ${t}-number-affix-wrapper,
        & > ${n}-picker-range
      `]:{display:"inline-flex"},"& > *:not(:last-child)":{marginInlineEnd:e.calc(e.lineWidth).mul(-1).equal(),borderInlineEndWidth:e.lineWidth},[t]:{float:"none"},[`& > ${n}-select > ${n}-select-selector,
      & > ${n}-select-auto-complete ${t},
      & > ${n}-cascader-picker ${t},
      & > ${t}-group-wrapper ${t}`]:{borderInlineEndWidth:e.lineWidth,borderRadius:0,"&:hover, &:focus":{zIndex:1}},[`& > ${n}-select-focused`]:{zIndex:1},[`& > ${n}-select > ${n}-select-arrow`]:{zIndex:1},[`& > *:first-child,
      & > ${n}-select:first-child > ${n}-select-selector,
      & > ${n}-select-auto-complete:first-child ${t},
      & > ${n}-cascader-picker:first-child ${t}`]:{borderStartStartRadius:e.borderRadius,borderEndStartRadius:e.borderRadius},[`& > *:last-child,
      & > ${n}-select:last-child > ${n}-select-selector,
      & > ${n}-cascader-picker:last-child ${t},
      & > ${n}-cascader-picker-focused:last-child ${t}`]:{borderInlineEndWidth:e.lineWidth,borderStartEndRadius:e.borderRadius,borderEndEndRadius:e.borderRadius},[`& > ${n}-select-auto-complete ${t}`]:{verticalAlign:"top"},[`${t}-group-wrapper + ${t}-group-wrapper`]:{marginInlineStart:e.calc(e.lineWidth).mul(-1).equal(),[`${t}-affix-wrapper`]:{borderRadius:0}},[`${t}-group-wrapper:not(:last-child)`]:{[`&${t}-search > ${t}-group`]:{[`& > ${t}-group-addon > ${t}-search-button`]:{borderRadius:0},[`& > ${t}`]:{borderStartStartRadius:e.borderRadius,borderStartEndRadius:0,borderEndEndRadius:0,borderEndStartRadius:e.borderRadius}}}})}},RM=e=>{const{componentCls:t,controlHeightSM:n,lineWidth:r,calc:o}=e,l=o(n).sub(o(r).mul(2)).sub(16).div(2).equal();return{[t]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),$i(e)),Oy(e)),Ny(e)),Ry(e)),jy(e)),{'&[type="color"]':{height:e.controlHeight,[`&${t}-lg`]:{height:e.controlHeightLG},[`&${t}-sm`]:{height:n,paddingTop:l,paddingBottom:l}},'&[type="search"]::-webkit-search-cancel-button, &[type="search"]::-webkit-search-decoration':{appearance:"none"}})}},PM=e=>{const{componentCls:t}=e;return{[`${t}-clear-icon`]:{margin:0,padding:0,lineHeight:0,color:e.colorTextQuaternary,fontSize:e.fontSizeIcon,verticalAlign:-1,cursor:"pointer",transition:`color ${e.motionDurationSlow}`,border:"none",outline:"none",backgroundColor:"transparent","&:hover":{color:e.colorIcon},"&:active":{color:e.colorText},"&-hidden":{visibility:"hidden"},"&-has-suffix":{margin:`0 ${L(e.inputAffixPadding)}`}}}},NM=e=>{const{componentCls:t,inputAffixPadding:n,colorTextDescription:r,motionDurationSlow:o,colorIcon:a,colorIconHover:l,iconCls:s}=e,c=`${t}-affix-wrapper`,u=`${t}-affix-wrapper-disabled`;return{[c]:Object.assign(Object.assign(Object.assign(Object.assign({},$i(e)),{display:"inline-flex",[`&:not(${t}-disabled):hover`]:{zIndex:1,[`${t}-search-with-button &`]:{zIndex:0}},"&-focused, &:focus":{zIndex:1},[`> input${t}`]:{padding:0},[`> input${t}, > textarea${t}`]:{fontSize:"inherit",border:"none",borderRadius:0,outline:"none",background:"transparent",color:"inherit","&::-ms-reveal":{display:"none"},"&:focus":{boxShadow:"none !important"}},"&::before":{display:"inline-block",width:0,visibility:"hidden",content:'"\\a0"'},[t]:{"&-prefix, &-suffix":{display:"flex",flex:"none",alignItems:"center","> *:not(:last-child)":{marginInlineEnd:e.paddingXS}},"&-show-count-suffix":{color:r,direction:"ltr"},"&-show-count-has-suffix":{marginInlineEnd:e.paddingXXS},"&-prefix":{marginInlineEnd:n},"&-suffix":{marginInlineStart:n}}}),PM(e)),{[`${s}${t}-password-icon`]:{color:a,cursor:"pointer",transition:`all ${o}`,"&:hover":{color:l}}}),[`${t}-underlined`]:{borderRadius:0},[u]:{[`${s}${t}-password-icon`]:{color:a,cursor:"not-allowed","&:hover":{color:a}}}}},MM=e=>{const{componentCls:t,borderRadiusLG:n,borderRadiusSM:r}=e;return{[`${t}-group`]:Object.assign(Object.assign(Object.assign({},Tt(e)),_y(e)),{"&-rtl":{direction:"rtl"},"&-wrapper":Object.assign(Object.assign(Object.assign({display:"inline-block",width:"100%",textAlign:"start",verticalAlign:"top","&-rtl":{direction:"rtl"},"&-lg":{[`${t}-group-addon`]:{borderRadius:n,fontSize:e.inputFontSizeLG}},"&-sm":{[`${t}-group-addon`]:{borderRadius:r}}},Iy(e)),My(e)),{[`&:not(${t}-compact-first-item):not(${t}-compact-last-item)${t}-compact-item`]:{[`${t}, ${t}-group-addon`]:{borderRadius:0}},[`&:not(${t}-compact-last-item)${t}-compact-first-item`]:{[`${t}, ${t}-group-addon`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`&:not(${t}-compact-first-item)${t}-compact-last-item`]:{[`${t}, ${t}-group-addon`]:{borderStartStartRadius:0,borderEndStartRadius:0}},[`&:not(${t}-compact-last-item)${t}-compact-item`]:{[`${t}-affix-wrapper`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`&:not(${t}-compact-first-item)${t}-compact-item`]:{[`${t}-affix-wrapper`]:{borderStartStartRadius:0,borderEndStartRadius:0}}})})}},TM=e=>{const{componentCls:t,antCls:n}=e,r=`${t}-search`;return{[r]:{[t]:{"&:hover, &:focus":{[`+ ${t}-group-addon ${r}-button:not(${n}-btn-color-primary):not(${n}-btn-variant-text)`]:{borderInlineStartColor:e.colorPrimaryHover}}},[`${t}-affix-wrapper`]:{height:e.controlHeight,borderRadius:0},[`${t}-lg`]:{lineHeight:e.calc(e.lineHeightLG).sub(2e-4).equal()},[`> ${t}-group`]:{[`> ${t}-group-addon:last-child`]:{insetInlineStart:-1,padding:0,border:0,[`${r}-button`]:{marginInlineEnd:-1,borderStartStartRadius:0,borderEndStartRadius:0,boxShadow:"none"},[`${r}-button:not(${n}-btn-color-primary)`]:{color:e.colorTextDescription,"&:hover":{color:e.colorPrimaryHover},"&:active":{color:e.colorPrimaryActive},[`&${n}-btn-loading::before`]:{inset:0}}}},[`${r}-button`]:{height:e.controlHeight,"&:hover, &:focus":{zIndex:1}},"&-large":{[`${t}-affix-wrapper, ${r}-button`]:{height:e.controlHeightLG}},"&-small":{[`${t}-affix-wrapper, ${r}-button`]:{height:e.controlHeightSM}},"&-rtl":{direction:"rtl"},[`&${t}-compact-item`]:{[`&:not(${t}-compact-last-item)`]:{[`${t}-group-addon`]:{[`${t}-search-button`]:{marginInlineEnd:e.calc(e.lineWidth).mul(-1).equal(),borderRadius:0}}},[`&:not(${t}-compact-first-item)`]:{[`${t},${t}-affix-wrapper`]:{borderRadius:0}},[`> ${t}-group-addon ${t}-search-button,
        > ${t},
        ${t}-affix-wrapper`]:{"&:hover, &:focus, &:active":{zIndex:2}},[`> ${t}-affix-wrapper-focused`]:{zIndex:2}}}}},jM=e=>{const{componentCls:t}=e;return{[`${t}-out-of-range`]:{[`&, & input, & textarea, ${t}-show-count-suffix, ${t}-data-count`]:{color:e.colorError}}}},By=It(["Input","Shared"],e=>{const t=yt(e,ba(e));return[RM(t),NM(t)]},ya,{resetFont:!1}),Ly=It(["Input","Component"],e=>{const t=yt(e,ba(e));return[MM(t),TM(t),jM(t),di(t)]},ya,{resetFont:!1});var zM={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M482 152h60q8 0 8 8v704q0 8-8 8h-60q-8 0-8-8V160q0-8 8-8z"}},{tag:"path",attrs:{d:"M192 474h672q8 0 8 8v60q0 8-8 8H160q-8 0-8-8v-60q0-8 8-8z"}}]},name:"plus",theme:"outlined"},DM=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:zM}))},_M=i.forwardRef(DM);const Ms=i.createContext(null);var BM=function(t){var n=t.activeTabOffset,r=t.horizontal,o=t.rtl,a=t.indicator,l=a===void 0?{}:a,s=l.size,c=l.align,u=c===void 0?"center":c,d=i.useState(),f=J(d,2),m=f[0],v=f[1],g=i.useRef(),h=F.useCallback(function(b){return typeof s=="function"?s(b):typeof s=="number"?s:b},[s]);function p(){Et.cancel(g.current)}return i.useEffect(function(){var b={};if(n)if(r){b.width=h(n.width);var y=o?"right":"left";u==="start"&&(b[y]=n[y]),u==="center"&&(b[y]=n[y]+n.width/2,b.transform=o?"translateX(50%)":"translateX(-50%)"),u==="end"&&(b[y]=n[y]+n.width,b.transform="translateX(-100%)")}else b.height=h(n.height),u==="start"&&(b.top=n.top),u==="center"&&(b.top=n.top+n.height/2,b.transform="translateY(-50%)"),u==="end"&&(b.top=n.top+n.height,b.transform="translateY(-100%)");return p(),g.current=Et(function(){var C=m&&b&&Object.keys(b).every(function($){var S=b[$],x=m[$];return typeof S=="number"&&typeof x=="number"?Math.round(S)===Math.round(x):S===x});C||v(b)}),p},[JSON.stringify(n),r,o,u,h]),{style:m}},cg={width:0,height:0,left:0,top:0};function LM(e,t,n){return i.useMemo(function(){for(var r,o=new Map,a=t.get((r=e[0])===null||r===void 0?void 0:r.key)||cg,l=a.left+a.width,s=0;s<e.length;s+=1){var c=e[s].key,u=t.get(c);if(!u){var d;u=t.get((d=e[s-1])===null||d===void 0?void 0:d.key)||cg}var f=o.get(c)||k({},u);f.right=l-f.left-f.width,o.set(c,f)}return o},[e.map(function(r){return r.key}).join("_"),t,n])}function ug(e,t){var n=i.useRef(e),r=i.useState({}),o=J(r,2),a=o[1];function l(s){var c=typeof s=="function"?s(n.current):s;c!==n.current&&t(c,n.current),n.current=c,a({})}return[n.current,l]}var HM=.1,dg=.01,ll=20,fg=Math.pow(.995,ll);function AM(e,t){var n=i.useState(),r=J(n,2),o=r[0],a=r[1],l=i.useState(0),s=J(l,2),c=s[0],u=s[1],d=i.useState(0),f=J(d,2),m=f[0],v=f[1],g=i.useState(),h=J(g,2),p=h[0],b=h[1],y=i.useRef();function C(w){var I=w.touches[0],P=I.screenX,M=I.screenY;a({x:P,y:M}),window.clearInterval(y.current)}function $(w){if(o){var I=w.touches[0],P=I.screenX,M=I.screenY;a({x:P,y:M});var R=P-o.x,N=M-o.y;t(R,N);var T=Date.now();u(T),v(T-c),b({x:R,y:N})}}function S(){if(o&&(a(null),b(null),p)){var w=p.x/m,I=p.y/m,P=Math.abs(w),M=Math.abs(I);if(Math.max(P,M)<HM)return;var R=w,N=I;y.current=window.setInterval(function(){if(Math.abs(R)<dg&&Math.abs(N)<dg){window.clearInterval(y.current);return}R*=fg,N*=fg,t(R*ll,N*ll)},ll)}}var x=i.useRef();function E(w){var I=w.deltaX,P=w.deltaY,M=0,R=Math.abs(I),N=Math.abs(P);R===N?M=x.current==="x"?I:P:R>N?(M=I,x.current="x"):(M=P,x.current="y"),t(-M,-M)&&w.preventDefault()}var O=i.useRef(null);O.current={onTouchStart:C,onTouchMove:$,onTouchEnd:S,onWheel:E},i.useEffect(function(){function w(R){O.current.onTouchStart(R)}function I(R){O.current.onTouchMove(R)}function P(R){O.current.onTouchEnd(R)}function M(R){O.current.onWheel(R)}return document.addEventListener("touchmove",I,{passive:!1}),document.addEventListener("touchend",P,{passive:!0}),e.current.addEventListener("touchstart",w,{passive:!0}),e.current.addEventListener("wheel",M,{passive:!1}),function(){document.removeEventListener("touchmove",I),document.removeEventListener("touchend",P)}},[])}function Hy(e){var t=i.useState(0),n=J(t,2),r=n[0],o=n[1],a=i.useRef(0),l=i.useRef();return l.current=e,Fo(function(){var s;(s=l.current)===null||s===void 0||s.call(l)},[r]),function(){a.current===r&&(a.current+=1,o(a.current))}}function FM(e){var t=i.useRef([]),n=i.useState({}),r=J(n,2),o=r[1],a=i.useRef(typeof e=="function"?e():e),l=Hy(function(){var c=a.current;t.current.forEach(function(u){c=u(c)}),t.current=[],a.current=c,o({})});function s(c){t.current.push(c),l()}return[a.current,s]}var mg={width:0,height:0,left:0,top:0,right:0};function kM(e,t,n,r,o,a,l){var s=l.tabs,c=l.tabPosition,u=l.rtl,d,f,m;return["top","bottom"].includes(c)?(d="width",f=u?"right":"left",m=Math.abs(n)):(d="height",f="top",m=-n),i.useMemo(function(){if(!s.length)return[0,0];for(var v=s.length,g=v,h=0;h<v;h+=1){var p=e.get(s[h].key)||mg;if(Math.floor(p[f]+p[d])>Math.floor(m+t)){g=h-1;break}}for(var b=0,y=v-1;y>=0;y-=1){var C=e.get(s[y].key)||mg;if(C[f]<m){b=y+1;break}}return b>g?[0,-1]:[b,g]},[e,t,r,o,a,m,c,s.map(function(v){return v.key}).join("_"),u])}function vg(e){var t;return e instanceof Map?(t={},e.forEach(function(n,r){t[r]=n})):t=e,JSON.stringify(t)}var VM="TABS_DQ";function Ay(e){return String(e).replace(/"/g,VM)}function bf(e,t,n,r){return!(!n||r||e===!1||e===void 0&&(t===!1||t===null))}var Fy=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.editable,o=e.locale,a=e.style;return!r||r.showAdd===!1?null:i.createElement("button",{ref:t,type:"button",className:"".concat(n,"-nav-add"),style:a,"aria-label":(o==null?void 0:o.addAriaLabel)||"Add tab",onClick:function(s){r.onEdit("add",{event:s})}},r.addIcon||"+")}),gg=i.forwardRef(function(e,t){var n=e.position,r=e.prefixCls,o=e.extra;if(!o)return null;var a,l={};return Qe(o)==="object"&&!i.isValidElement(o)?l=o:l.right=o,n==="right"&&(a=l.right),n==="left"&&(a=l.left),a?i.createElement("div",{className:"".concat(r,"-extra-content"),ref:t},a):null}),WM=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.id,o=e.tabs,a=e.locale,l=e.mobile,s=e.more,c=s===void 0?{}:s,u=e.style,d=e.className,f=e.editable,m=e.tabBarGutter,v=e.rtl,g=e.removeAriaLabel,h=e.onTabClick,p=e.getPopupContainer,b=e.popupClassName,y=i.useState(!1),C=J(y,2),$=C[0],S=C[1],x=i.useState(null),E=J(x,2),O=E[0],w=E[1],I=c.icon,P=I===void 0?"More":I,M="".concat(r,"-more-popup"),R="".concat(n,"-dropdown"),N=O!==null?"".concat(M,"-").concat(O):null,T=a==null?void 0:a.dropdownAriaLabel;function j(H,W){H.preventDefault(),H.stopPropagation(),f.onEdit("remove",{key:W,event:H})}var z=i.createElement(pa,{onClick:function(W){var K=W.key,U=W.domEvent;h(K,U),S(!1)},prefixCls:"".concat(R,"-menu"),id:M,tabIndex:-1,role:"listbox","aria-activedescendant":N,selectedKeys:[O],"aria-label":T!==void 0?T:"expanded dropdown"},o.map(function(H){var W=H.closable,K=H.disabled,U=H.closeIcon,te=H.key,X=H.label,ae=bf(W,U,f,K);return i.createElement(Ci,{key:te,id:"".concat(M,"-").concat(te),role:"option","aria-controls":r&&"".concat(r,"-panel-").concat(te),disabled:K},i.createElement("span",null,X),ae&&i.createElement("button",{type:"button","aria-label":g||"remove",tabIndex:0,className:"".concat(R,"-menu-item-remove"),onClick:function(ee){ee.stopPropagation(),j(ee,te)}},U||f.removeIcon||"×"))}));function _(H){for(var W=o.filter(function(ae){return!ae.disabled}),K=W.findIndex(function(ae){return ae.key===O})||0,U=W.length,te=0;te<U;te+=1){K=(K+H+U)%U;var X=W[K];if(!X.disabled){w(X.key);return}}}function B(H){var W=H.which;if(!$){[Ne.DOWN,Ne.SPACE,Ne.ENTER].includes(W)&&(S(!0),H.preventDefault());return}switch(W){case Ne.UP:_(-1),H.preventDefault();break;case Ne.DOWN:_(1),H.preventDefault();break;case Ne.ESC:S(!1);break;case Ne.SPACE:case Ne.ENTER:O!==null&&h(O,H);break}}i.useEffect(function(){var H=document.getElementById(N);H&&H.scrollIntoView&&H.scrollIntoView(!1)},[O]),i.useEffect(function(){$||w(null)},[$]);var V=D({},v?"marginRight":"marginLeft",m);o.length||(V.visibility="hidden",V.order=1);var G=A(D({},"".concat(R,"-rtl"),v)),q=l?null:i.createElement(ey,ue({prefixCls:R,overlay:z,visible:o.length?$:!1,onVisibleChange:S,overlayClassName:A(G,b),mouseEnterDelay:.1,mouseLeaveDelay:.1,getPopupContainer:p},c),i.createElement("button",{type:"button",className:"".concat(n,"-nav-more"),style:V,"aria-haspopup":"listbox","aria-controls":M,id:"".concat(r,"-more"),"aria-expanded":$,onKeyDown:B},P));return i.createElement("div",{className:A("".concat(n,"-nav-operations"),d),style:u,ref:t},q,i.createElement(Fy,{prefixCls:n,locale:a,editable:f}))});const KM=i.memo(WM,function(e,t){return t.tabMoving});var GM=function(t){var n=t.prefixCls,r=t.id,o=t.active,a=t.focus,l=t.tab,s=l.key,c=l.label,u=l.disabled,d=l.closeIcon,f=l.icon,m=t.closable,v=t.renderWrapper,g=t.removeAriaLabel,h=t.editable,p=t.onClick,b=t.onFocus,y=t.onBlur,C=t.onKeyDown,$=t.onMouseDown,S=t.onMouseUp,x=t.style,E=t.tabCount,O=t.currentPosition,w="".concat(n,"-tab"),I=bf(m,d,h,u);function P(j){u||p(j)}function M(j){j.preventDefault(),j.stopPropagation(),h.onEdit("remove",{key:s,event:j})}var R=i.useMemo(function(){return f&&typeof c=="string"?i.createElement("span",null,c):c},[c,f]),N=i.useRef(null);i.useEffect(function(){a&&N.current&&N.current.focus()},[a]);var T=i.createElement("div",{key:s,"data-node-key":Ay(s),className:A(w,D(D(D(D({},"".concat(w,"-with-remove"),I),"".concat(w,"-active"),o),"".concat(w,"-disabled"),u),"".concat(w,"-focus"),a)),style:x,onClick:P},i.createElement("div",{ref:N,role:"tab","aria-selected":o,id:r&&"".concat(r,"-tab-").concat(s),className:"".concat(w,"-btn"),"aria-controls":r&&"".concat(r,"-panel-").concat(s),"aria-disabled":u,tabIndex:u?null:o?0:-1,onClick:function(z){z.stopPropagation(),P(z)},onKeyDown:C,onMouseDown:$,onMouseUp:S,onFocus:b,onBlur:y},a&&i.createElement("div",{"aria-live":"polite",style:{width:0,height:0,position:"absolute",overflow:"hidden",opacity:0}},"Tab ".concat(O," of ").concat(E)),f&&i.createElement("span",{className:"".concat(w,"-icon")},f),c&&R),I&&i.createElement("button",{type:"button",role:"tab","aria-label":g||"remove",tabIndex:o?0:-1,className:"".concat(w,"-remove"),onClick:function(z){z.stopPropagation(),M(z)}},d||h.removeIcon||"×"));return v?v(T):T},qM=function(t,n){var r=t.offsetWidth,o=t.offsetHeight,a=t.offsetTop,l=t.offsetLeft,s=t.getBoundingClientRect(),c=s.width,u=s.height,d=s.left,f=s.top;return Math.abs(c-r)<1?[c,u,d-n.left,f-n.top]:[r,o,l,a]},_o=function(t){var n=t.current||{},r=n.offsetWidth,o=r===void 0?0:r,a=n.offsetHeight,l=a===void 0?0:a;if(t.current){var s=t.current.getBoundingClientRect(),c=s.width,u=s.height;if(Math.abs(c-o)<1)return[c,u]}return[o,l]},Hi=function(t,n){return t[n?0:1]},pg=i.forwardRef(function(e,t){var n=e.className,r=e.style,o=e.id,a=e.animated,l=e.activeKey,s=e.rtl,c=e.extra,u=e.editable,d=e.locale,f=e.tabPosition,m=e.tabBarGutter,v=e.children,g=e.onTabClick,h=e.onTabScroll,p=e.indicator,b=i.useContext(Ms),y=b.prefixCls,C=b.tabs,$=i.useRef(null),S=i.useRef(null),x=i.useRef(null),E=i.useRef(null),O=i.useRef(null),w=i.useRef(null),I=i.useRef(null),P=f==="top"||f==="bottom",M=ug(0,function(ze,_e){P&&h&&h({direction:ze>_e?"left":"right"})}),R=J(M,2),N=R[0],T=R[1],j=ug(0,function(ze,_e){!P&&h&&h({direction:ze>_e?"top":"bottom"})}),z=J(j,2),_=z[0],B=z[1],V=i.useState([0,0]),G=J(V,2),q=G[0],H=G[1],W=i.useState([0,0]),K=J(W,2),U=K[0],te=K[1],X=i.useState([0,0]),ae=J(X,2),le=ae[0],ee=ae[1],Y=i.useState([0,0]),re=J(Y,2),ne=re[0],Z=re[1],Q=FM(new Map),ie=J(Q,2),de=ie[0],he=ie[1],ye=LM(C,de,U[0]),oe=Hi(q,P),ce=Hi(U,P),ge=Hi(le,P),se=Hi(ne,P),be=Math.floor(oe)<Math.floor(ce+ge),we=be?oe-se:oe-ge,Me="".concat(y,"-nav-operations-hidden"),Te=0,Se=0;P&&s?(Te=0,Se=Math.max(0,ce-we)):(Te=Math.min(0,we-ce),Se=0);function Fe(ze){return ze<Te?Te:ze>Se?Se:ze}var Ce=i.useRef(null),me=i.useState(),$e=J(me,2),Ee=$e[0],Ie=$e[1];function fe(){Ie(Date.now())}function ve(){Ce.current&&clearTimeout(Ce.current)}AM(E,function(ze,_e){function lt(Ct,Ae){Ct(function(nt){var ht=Fe(nt+Ae);return ht})}return be?(P?lt(T,ze):lt(B,_e),ve(),fe(),!0):!1}),i.useEffect(function(){return ve(),Ee&&(Ce.current=setTimeout(function(){Ie(0)},100)),ve},[Ee]);var xe=kM(ye,we,P?N:_,ce,ge,se,k(k({},e),{},{tabs:C})),Re=J(xe,2),it=Re[0],dt=Re[1],Oe=Nt(function(){var ze=arguments.length>0&&arguments[0]!==void 0?arguments[0]:l,_e=ye.get(ze)||{width:0,height:0,left:0,right:0,top:0};if(P){var lt=N;s?_e.right<N?lt=_e.right:_e.right+_e.width>N+we&&(lt=_e.right+_e.width-we):_e.left<-N?lt=-_e.left:_e.left+_e.width>-N+we&&(lt=-(_e.left+_e.width-we)),B(0),T(Fe(lt))}else{var Ct=_;_e.top<-_?Ct=-_e.top:_e.top+_e.height>-_+we&&(Ct=-(_e.top+_e.height-we)),T(0),B(Fe(Ct))}}),Le=i.useState(),Ue=J(Le,2),ke=Ue[0],Je=Ue[1],Xe=i.useState(!1),He=J(Xe,2),je=He[0],rt=He[1],et=C.filter(function(ze){return!ze.disabled}).map(function(ze){return ze.key}),Pe=function(_e){var lt=et.indexOf(ke||l),Ct=et.length,Ae=(lt+_e+Ct)%Ct,nt=et[Ae];Je(nt)},qe=function(_e,lt){var Ct=et.indexOf(_e),Ae=C.find(function(ht){return ht.key===_e}),nt=bf(Ae==null?void 0:Ae.closable,Ae==null?void 0:Ae.closeIcon,u,Ae==null?void 0:Ae.disabled);nt&&(lt.preventDefault(),lt.stopPropagation(),u.onEdit("remove",{key:_e,event:lt}),Ct===et.length-1?Pe(-1):Pe(1))},We=function(_e,lt){rt(!0),lt.button===1&&qe(_e,lt)},tt=function(_e){var lt=_e.code,Ct=s&&P,Ae=et[0],nt=et[et.length-1];switch(lt){case"ArrowLeft":{P&&Pe(Ct?1:-1);break}case"ArrowRight":{P&&Pe(Ct?-1:1);break}case"ArrowUp":{_e.preventDefault(),P||Pe(-1);break}case"ArrowDown":{_e.preventDefault(),P||Pe(1);break}case"Home":{_e.preventDefault(),Je(Ae);break}case"End":{_e.preventDefault(),Je(nt);break}case"Enter":case"Space":{_e.preventDefault(),g(ke??l,_e);break}case"Backspace":case"Delete":{qe(ke,_e);break}}},mt={};P?mt[s?"marginRight":"marginLeft"]=m:mt.marginTop=m;var ct=C.map(function(ze,_e){var lt=ze.key;return i.createElement(GM,{id:o,prefixCls:y,key:lt,tab:ze,style:_e===0?void 0:mt,closable:ze.closable,editable:u,active:lt===l,focus:lt===ke,renderWrapper:v,removeAriaLabel:d==null?void 0:d.removeAriaLabel,tabCount:et.length,currentPosition:_e+1,onClick:function(Ae){g(lt,Ae)},onKeyDown:tt,onFocus:function(){je||Je(lt),Oe(lt),fe(),E.current&&(s||(E.current.scrollLeft=0),E.current.scrollTop=0)},onBlur:function(){Je(void 0)},onMouseDown:function(Ae){return We(lt,Ae)},onMouseUp:function(){rt(!1)}})}),Ke=function(){return he(function(){var _e,lt=new Map,Ct=(_e=O.current)===null||_e===void 0?void 0:_e.getBoundingClientRect();return C.forEach(function(Ae){var nt,ht=Ae.key,Ft=(nt=O.current)===null||nt===void 0?void 0:nt.querySelector('[data-node-key="'.concat(Ay(ht),'"]'));if(Ft){var qt=qM(Ft,Ct),Qt=J(qt,4),ln=Qt[0],on=Qt[1],Tn=Qt[2],On=Qt[3];lt.set(ht,{width:ln,height:on,left:Tn,top:On})}}),lt})};i.useEffect(function(){Ke()},[C.map(function(ze){return ze.key}).join("_")]);var Ye=Hy(function(){var ze=_o($),_e=_o(S),lt=_o(x);H([ze[0]-_e[0]-lt[0],ze[1]-_e[1]-lt[1]]);var Ct=_o(I);ee(Ct);var Ae=_o(w);Z(Ae);var nt=_o(O);te([nt[0]-Ct[0],nt[1]-Ct[1]]),Ke()}),at=C.slice(0,it),gt=C.slice(dt+1),Ot=[].concat(pe(at),pe(gt)),Pt=ye.get(l),Rt=BM({activeTabOffset:Pt,horizontal:P,indicator:p,rtl:s}),jt=Rt.style;i.useEffect(function(){Oe()},[l,Te,Se,vg(Pt),vg(ye),P]),i.useEffect(function(){Ye()},[s]);var zt=!!Ot.length,Dt="".concat(y,"-nav-wrap"),De,Ze,Ge,Be;return P?s?(Ze=N>0,De=N!==Se):(De=N<0,Ze=N!==Te):(Ge=_<0,Be=_!==Te),i.createElement(Bn,{onResize:Ye},i.createElement("div",{ref:zr(t,$),role:"tablist","aria-orientation":P?"horizontal":"vertical",className:A("".concat(y,"-nav"),n),style:r,onKeyDown:function(){fe()}},i.createElement(gg,{ref:S,position:"left",extra:c,prefixCls:y}),i.createElement(Bn,{onResize:Ye},i.createElement("div",{className:A(Dt,D(D(D(D({},"".concat(Dt,"-ping-left"),De),"".concat(Dt,"-ping-right"),Ze),"".concat(Dt,"-ping-top"),Ge),"".concat(Dt,"-ping-bottom"),Be)),ref:E},i.createElement(Bn,{onResize:Ye},i.createElement("div",{ref:O,className:"".concat(y,"-nav-list"),style:{transform:"translate(".concat(N,"px, ").concat(_,"px)"),transition:Ee?"none":void 0}},ct,i.createElement(Fy,{ref:I,prefixCls:y,locale:d,editable:u,style:k(k({},ct.length===0?void 0:mt),{},{visibility:zt?"hidden":null})}),i.createElement("div",{className:A("".concat(y,"-ink-bar"),D({},"".concat(y,"-ink-bar-animated"),a.inkBar)),style:jt}))))),i.createElement(KM,ue({},e,{removeAriaLabel:d==null?void 0:d.removeAriaLabel,ref:w,prefixCls:y,tabs:Ot,className:!zt&&Me,tabMoving:!!Ee})),i.createElement(gg,{ref:x,position:"right",extra:c,prefixCls:y})))}),ky=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.className,o=e.style,a=e.id,l=e.active,s=e.tabKey,c=e.children;return i.createElement("div",{id:a&&"".concat(a,"-panel-").concat(s),role:"tabpanel",tabIndex:l?0:-1,"aria-labelledby":a&&"".concat(a,"-tab-").concat(s),"aria-hidden":!l,style:o,className:A(n,l&&"".concat(n,"-active"),r),ref:t},c)}),UM=["renderTabBar"],XM=["label","key"],YM=function(t){var n=t.renderTabBar,r=ft(t,UM),o=i.useContext(Ms),a=o.tabs;if(n){var l=k(k({},r),{},{panes:a.map(function(s){var c=s.label,u=s.key,d=ft(s,XM);return i.createElement(ky,ue({tab:c,key:u,tabKey:u},d))})});return n(l,pg)}return i.createElement(pg,r)},QM=["key","forceRender","style","className","destroyInactiveTabPane"],ZM=function(t){var n=t.id,r=t.activeKey,o=t.animated,a=t.tabPosition,l=t.destroyInactiveTabPane,s=i.useContext(Ms),c=s.prefixCls,u=s.tabs,d=o.tabPane,f="".concat(c,"-tabpane");return i.createElement("div",{className:A("".concat(c,"-content-holder"))},i.createElement("div",{className:A("".concat(c,"-content"),"".concat(c,"-content-").concat(a),D({},"".concat(c,"-content-animated"),d))},u.map(function(m){var v=m.key,g=m.forceRender,h=m.style,p=m.className,b=m.destroyInactiveTabPane,y=ft(m,QM),C=v===r;return i.createElement(En,ue({key:v,visible:C,forceRender:g,removeOnLeave:!!(l||b),leavedClassName:"".concat(f,"-hidden")},o.tabPaneMotion),function($,S){var x=$.style,E=$.className;return i.createElement(ky,ue({},y,{prefixCls:f,id:n,tabKey:v,animated:d,active:C,style:k(k({},h),x),className:A(p,E),ref:S}))})})))};function JM(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{inkBar:!0,tabPane:!1},t;return e===!1?t={inkBar:!1,tabPane:!1}:e===!0?t={inkBar:!0,tabPane:!1}:t=k({inkBar:!0},Qe(e)==="object"?e:{}),t.tabPaneMotion&&t.tabPane===void 0&&(t.tabPane=!0),!t.tabPaneMotion&&t.tabPane&&(t.tabPane=!1),t}var e6=["id","prefixCls","className","items","direction","activeKey","defaultActiveKey","editable","animated","tabPosition","tabBarGutter","tabBarStyle","tabBarExtraContent","locale","more","destroyInactiveTabPane","renderTabBar","onChange","onTabClick","onTabScroll","getPopupContainer","popupClassName","indicator"],hg=0,t6=i.forwardRef(function(e,t){var n=e.id,r=e.prefixCls,o=r===void 0?"rc-tabs":r,a=e.className,l=e.items,s=e.direction,c=e.activeKey,u=e.defaultActiveKey,d=e.editable,f=e.animated,m=e.tabPosition,v=m===void 0?"top":m,g=e.tabBarGutter,h=e.tabBarStyle,p=e.tabBarExtraContent,b=e.locale,y=e.more,C=e.destroyInactiveTabPane,$=e.renderTabBar,S=e.onChange,x=e.onTabClick,E=e.onTabScroll,O=e.getPopupContainer,w=e.popupClassName,I=e.indicator,P=ft(e,e6),M=i.useMemo(function(){return(l||[]).filter(function(ne){return ne&&Qe(ne)==="object"&&"key"in ne})},[l]),R=s==="rtl",N=JM(f),T=i.useState(!1),j=J(T,2),z=j[0],_=j[1];i.useEffect(function(){_(ys())},[]);var B=Lt(function(){var ne;return(ne=M[0])===null||ne===void 0?void 0:ne.key},{value:c,defaultValue:u}),V=J(B,2),G=V[0],q=V[1],H=i.useState(function(){return M.findIndex(function(ne){return ne.key===G})}),W=J(H,2),K=W[0],U=W[1];i.useEffect(function(){var ne=M.findIndex(function(Q){return Q.key===G});if(ne===-1){var Z;ne=Math.max(0,Math.min(K,M.length-1)),q((Z=M[ne])===null||Z===void 0?void 0:Z.key)}U(ne)},[M.map(function(ne){return ne.key}).join("_"),G,K]);var te=Lt(null,{value:n}),X=J(te,2),ae=X[0],le=X[1];i.useEffect(function(){n||(le("rc-tabs-".concat(hg)),hg+=1)},[]);function ee(ne,Z){x==null||x(ne,Z);var Q=ne!==G;q(ne),Q&&(S==null||S(ne))}var Y={id:ae,activeKey:G,animated:N,tabPosition:v,rtl:R,mobile:z},re=k(k({},Y),{},{editable:d,locale:b,more:y,tabBarGutter:g,onTabClick:ee,onTabScroll:E,extra:p,style:h,panes:null,getPopupContainer:O,popupClassName:w,indicator:I});return i.createElement(Ms.Provider,{value:{tabs:M,prefixCls:o}},i.createElement("div",ue({ref:t,id:n,className:A(o,"".concat(o,"-").concat(v),D(D(D({},"".concat(o,"-mobile"),z),"".concat(o,"-editable"),d),"".concat(o,"-rtl"),R),a)},P),i.createElement(YM,ue({},re,{renderTabBar:$})),i.createElement(ZM,ue({destroyInactiveTabPane:C},Y,{animated:N}))))});const n6={motionAppear:!1,motionEnter:!0,motionLeave:!0};function r6(e,t={inkBar:!0,tabPane:!1}){let n;return t===!1?n={inkBar:!1,tabPane:!1}:t===!0?n={inkBar:!0,tabPane:!0}:n=Object.assign({inkBar:!0},typeof t=="object"?t:{}),n.tabPane&&(n.tabPaneMotion=Object.assign(Object.assign({},n6),{motionName:Mr(e,"switch")})),n}var o6=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function a6(e){return e.filter(t=>t)}function i6(e,t){if(e)return e.map(r=>{var o;const a=(o=r.destroyOnHidden)!==null&&o!==void 0?o:r.destroyInactiveTabPane;return Object.assign(Object.assign({},r),{destroyInactiveTabPane:a})});const n=xn(t).map(r=>{if(i.isValidElement(r)){const{key:o,props:a}=r,l=a||{},{tab:s}=l,c=o6(l,["tab"]);return Object.assign(Object.assign({key:String(o)},c),{label:s})}return null});return a6(n)}const l6=e=>{const{componentCls:t,motionDurationSlow:n}=e;return[{[t]:{[`${t}-switch`]:{"&-appear, &-enter":{transition:"none","&-start":{opacity:0},"&-active":{opacity:1,transition:`opacity ${n}`}},"&-leave":{position:"absolute",transition:"none",inset:0,"&-start":{opacity:1},"&-active":{opacity:0,transition:`opacity ${n}`}}}}},[eo(e,"slide-up"),eo(e,"slide-down")]]},s6=e=>{const{componentCls:t,tabsCardPadding:n,cardBg:r,cardGutter:o,colorBorderSecondary:a,itemSelectedColor:l}=e;return{[`${t}-card`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-tab`]:{margin:0,padding:n,background:r,border:`${L(e.lineWidth)} ${e.lineType} ${a}`,transition:`all ${e.motionDurationSlow} ${e.motionEaseInOut}`},[`${t}-tab-active`]:{color:l,background:e.colorBgContainer},[`${t}-tab-focus:has(${t}-tab-btn:focus-visible)`]:Cr(e,-3),[`& ${t}-tab${t}-tab-focus ${t}-tab-btn:focus-visible`]:{outline:"none"},[`${t}-ink-bar`]:{visibility:"hidden"}},[`&${t}-top, &${t}-bottom`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-tab + ${t}-tab`]:{marginLeft:{_skip_check_:!0,value:L(o)}}}},[`&${t}-top`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-tab`]:{borderRadius:`${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)} 0 0`},[`${t}-tab-active`]:{borderBottomColor:e.colorBgContainer}}},[`&${t}-bottom`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-tab`]:{borderRadius:`0 0 ${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)}`},[`${t}-tab-active`]:{borderTopColor:e.colorBgContainer}}},[`&${t}-left, &${t}-right`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-tab + ${t}-tab`]:{marginTop:L(o)}}},[`&${t}-left`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-tab`]:{borderRadius:{_skip_check_:!0,value:`${L(e.borderRadiusLG)} 0 0 ${L(e.borderRadiusLG)}`}},[`${t}-tab-active`]:{borderRightColor:{_skip_check_:!0,value:e.colorBgContainer}}}},[`&${t}-right`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-tab`]:{borderRadius:{_skip_check_:!0,value:`0 ${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)} 0`}},[`${t}-tab-active`]:{borderLeftColor:{_skip_check_:!0,value:e.colorBgContainer}}}}}}},c6=e=>{const{componentCls:t,itemHoverColor:n,dropdownEdgeChildVerticalPadding:r}=e;return{[`${t}-dropdown`]:Object.assign(Object.assign({},Tt(e)),{position:"absolute",top:-9999,left:{_skip_check_:!0,value:-9999},zIndex:e.zIndexPopup,display:"block","&-hidden":{display:"none"},[`${t}-dropdown-menu`]:{maxHeight:e.tabsDropdownHeight,margin:0,padding:`${L(r)} 0`,overflowX:"hidden",overflowY:"auto",textAlign:{_skip_check_:!0,value:"left"},listStyleType:"none",backgroundColor:e.colorBgContainer,backgroundClip:"padding-box",borderRadius:e.borderRadiusLG,outline:"none",boxShadow:e.boxShadowSecondary,"&-item":Object.assign(Object.assign({},sr),{display:"flex",alignItems:"center",minWidth:e.tabsDropdownWidth,margin:0,padding:`${L(e.paddingXXS)} ${L(e.paddingSM)}`,color:e.colorText,fontWeight:"normal",fontSize:e.fontSize,lineHeight:e.lineHeight,cursor:"pointer",transition:`all ${e.motionDurationSlow}`,"> span":{flex:1,whiteSpace:"nowrap"},"&-remove":{flex:"none",marginLeft:{_skip_check_:!0,value:e.marginSM},color:e.colorIcon,fontSize:e.fontSizeSM,background:"transparent",border:0,cursor:"pointer","&:hover":{color:n}},"&:hover":{background:e.controlItemBgHover},"&-disabled":{"&, &:hover":{color:e.colorTextDisabled,background:"transparent",cursor:"not-allowed"}}})}})}},u6=e=>{const{componentCls:t,margin:n,colorBorderSecondary:r,horizontalMargin:o,verticalItemPadding:a,verticalItemMargin:l,calc:s}=e;return{[`${t}-top, ${t}-bottom`]:{flexDirection:"column",[`> ${t}-nav, > div > ${t}-nav`]:{margin:o,"&::before":{position:"absolute",right:{_skip_check_:!0,value:0},left:{_skip_check_:!0,value:0},borderBottom:`${L(e.lineWidth)} ${e.lineType} ${r}`,content:"''"},[`${t}-ink-bar`]:{height:e.lineWidthBold,"&-animated":{transition:`width ${e.motionDurationSlow}, left ${e.motionDurationSlow},
            right ${e.motionDurationSlow}`}},[`${t}-nav-wrap`]:{"&::before, &::after":{top:0,bottom:0,width:e.controlHeight},"&::before":{left:{_skip_check_:!0,value:0},boxShadow:e.boxShadowTabsOverflowLeft},"&::after":{right:{_skip_check_:!0,value:0},boxShadow:e.boxShadowTabsOverflowRight},[`&${t}-nav-wrap-ping-left::before`]:{opacity:1},[`&${t}-nav-wrap-ping-right::after`]:{opacity:1}}}},[`${t}-top`]:{[`> ${t}-nav,
        > div > ${t}-nav`]:{"&::before":{bottom:0},[`${t}-ink-bar`]:{bottom:0}}},[`${t}-bottom`]:{[`> ${t}-nav, > div > ${t}-nav`]:{order:1,marginTop:n,marginBottom:0,"&::before":{top:0},[`${t}-ink-bar`]:{top:0}},[`> ${t}-content-holder, > div > ${t}-content-holder`]:{order:0}},[`${t}-left, ${t}-right`]:{[`> ${t}-nav, > div > ${t}-nav`]:{flexDirection:"column",minWidth:s(e.controlHeight).mul(1.25).equal(),[`${t}-tab`]:{padding:a,textAlign:"center"},[`${t}-tab + ${t}-tab`]:{margin:l},[`${t}-nav-wrap`]:{flexDirection:"column","&::before, &::after":{right:{_skip_check_:!0,value:0},left:{_skip_check_:!0,value:0},height:e.controlHeight},"&::before":{top:0,boxShadow:e.boxShadowTabsOverflowTop},"&::after":{bottom:0,boxShadow:e.boxShadowTabsOverflowBottom},[`&${t}-nav-wrap-ping-top::before`]:{opacity:1},[`&${t}-nav-wrap-ping-bottom::after`]:{opacity:1}},[`${t}-ink-bar`]:{width:e.lineWidthBold,"&-animated":{transition:`height ${e.motionDurationSlow}, top ${e.motionDurationSlow}`}},[`${t}-nav-list, ${t}-nav-operations`]:{flex:"1 0 auto",flexDirection:"column"}}},[`${t}-left`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-ink-bar`]:{right:{_skip_check_:!0,value:0}}},[`> ${t}-content-holder, > div > ${t}-content-holder`]:{marginLeft:{_skip_check_:!0,value:L(s(e.lineWidth).mul(-1).equal())},borderLeft:{_skip_check_:!0,value:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`},[`> ${t}-content > ${t}-tabpane`]:{paddingLeft:{_skip_check_:!0,value:e.paddingLG}}}},[`${t}-right`]:{[`> ${t}-nav, > div > ${t}-nav`]:{order:1,[`${t}-ink-bar`]:{left:{_skip_check_:!0,value:0}}},[`> ${t}-content-holder, > div > ${t}-content-holder`]:{order:0,marginRight:{_skip_check_:!0,value:s(e.lineWidth).mul(-1).equal()},borderRight:{_skip_check_:!0,value:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`},[`> ${t}-content > ${t}-tabpane`]:{paddingRight:{_skip_check_:!0,value:e.paddingLG}}}}}},d6=e=>{const{componentCls:t,cardPaddingSM:n,cardPaddingLG:r,cardHeightSM:o,cardHeightLG:a,horizontalItemPaddingSM:l,horizontalItemPaddingLG:s}=e;return{[t]:{"&-small":{[`> ${t}-nav`]:{[`${t}-tab`]:{padding:l,fontSize:e.titleFontSizeSM}}},"&-large":{[`> ${t}-nav`]:{[`${t}-tab`]:{padding:s,fontSize:e.titleFontSizeLG,lineHeight:e.lineHeightLG}}}},[`${t}-card`]:{[`&${t}-small`]:{[`> ${t}-nav`]:{[`${t}-tab`]:{padding:n},[`${t}-nav-add`]:{minWidth:o,minHeight:o}},[`&${t}-bottom`]:{[`> ${t}-nav ${t}-tab`]:{borderRadius:`0 0 ${L(e.borderRadius)} ${L(e.borderRadius)}`}},[`&${t}-top`]:{[`> ${t}-nav ${t}-tab`]:{borderRadius:`${L(e.borderRadius)} ${L(e.borderRadius)} 0 0`}},[`&${t}-right`]:{[`> ${t}-nav ${t}-tab`]:{borderRadius:{_skip_check_:!0,value:`0 ${L(e.borderRadius)} ${L(e.borderRadius)} 0`}}},[`&${t}-left`]:{[`> ${t}-nav ${t}-tab`]:{borderRadius:{_skip_check_:!0,value:`${L(e.borderRadius)} 0 0 ${L(e.borderRadius)}`}}}},[`&${t}-large`]:{[`> ${t}-nav`]:{[`${t}-tab`]:{padding:r},[`${t}-nav-add`]:{minWidth:a,minHeight:a}}}}}},f6=e=>{const{componentCls:t,itemActiveColor:n,itemHoverColor:r,iconCls:o,tabsHorizontalItemMargin:a,horizontalItemPadding:l,itemSelectedColor:s,itemColor:c}=e,u=`${t}-tab`;return{[u]:{position:"relative",WebkitTouchCallout:"none",WebkitTapHighlightColor:"transparent",display:"inline-flex",alignItems:"center",padding:l,fontSize:e.titleFontSize,background:"transparent",border:0,outline:"none",cursor:"pointer",color:c,"&-btn, &-remove":{"&:focus:not(:focus-visible), &:active":{color:n}},"&-btn":{outline:"none",transition:`all ${e.motionDurationSlow}`,[`${u}-icon:not(:last-child)`]:{marginInlineEnd:e.marginSM}},"&-remove":Object.assign({flex:"none",marginRight:{_skip_check_:!0,value:e.calc(e.marginXXS).mul(-1).equal()},marginLeft:{_skip_check_:!0,value:e.marginXS},color:e.colorIcon,fontSize:e.fontSizeSM,background:"transparent",border:"none",outline:"none",cursor:"pointer",transition:`all ${e.motionDurationSlow}`,"&:hover":{color:e.colorTextHeading}},Vn(e)),"&:hover":{color:r},[`&${u}-active ${u}-btn`]:{color:s,textShadow:e.tabsActiveTextShadow},[`&${u}-focus ${u}-btn:focus-visible`]:Cr(e),[`&${u}-disabled`]:{color:e.colorTextDisabled,cursor:"not-allowed"},[`&${u}-disabled ${u}-btn, &${u}-disabled ${t}-remove`]:{"&:focus, &:active":{color:e.colorTextDisabled}},[`& ${u}-remove ${o}`]:{margin:0},[`${o}:not(:last-child)`]:{marginRight:{_skip_check_:!0,value:e.marginSM}}},[`${u} + ${u}`]:{margin:{_skip_check_:!0,value:a}}}},m6=e=>{const{componentCls:t,tabsHorizontalItemMarginRTL:n,iconCls:r,cardGutter:o,calc:a}=e;return{[`${t}-rtl`]:{direction:"rtl",[`${t}-nav`]:{[`${t}-tab`]:{margin:{_skip_check_:!0,value:n},[`${t}-tab:last-of-type`]:{marginLeft:{_skip_check_:!0,value:0}},[r]:{marginRight:{_skip_check_:!0,value:0},marginLeft:{_skip_check_:!0,value:L(e.marginSM)}},[`${t}-tab-remove`]:{marginRight:{_skip_check_:!0,value:L(e.marginXS)},marginLeft:{_skip_check_:!0,value:L(a(e.marginXXS).mul(-1).equal())},[r]:{margin:0}}}},[`&${t}-left`]:{[`> ${t}-nav`]:{order:1},[`> ${t}-content-holder`]:{order:0}},[`&${t}-right`]:{[`> ${t}-nav`]:{order:0},[`> ${t}-content-holder`]:{order:1}},[`&${t}-card${t}-top, &${t}-card${t}-bottom`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-tab + ${t}-tab`]:{marginRight:{_skip_check_:!0,value:o},marginLeft:{_skip_check_:!0,value:0}}}}},[`${t}-dropdown-rtl`]:{direction:"rtl"},[`${t}-menu-item`]:{[`${t}-dropdown-rtl`]:{textAlign:{_skip_check_:!0,value:"right"}}}}},v6=e=>{const{componentCls:t,tabsCardPadding:n,cardHeight:r,cardGutter:o,itemHoverColor:a,itemActiveColor:l,colorBorderSecondary:s}=e;return{[t]:Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),{display:"flex",[`> ${t}-nav, > div > ${t}-nav`]:{position:"relative",display:"flex",flex:"none",alignItems:"center",[`${t}-nav-wrap`]:{position:"relative",display:"flex",flex:"auto",alignSelf:"stretch",overflow:"hidden",whiteSpace:"nowrap",transform:"translate(0)","&::before, &::after":{position:"absolute",zIndex:1,opacity:0,transition:`opacity ${e.motionDurationSlow}`,content:"''",pointerEvents:"none"}},[`${t}-nav-list`]:{position:"relative",display:"flex",transition:`opacity ${e.motionDurationSlow}`},[`${t}-nav-operations`]:{display:"flex",alignSelf:"stretch"},[`${t}-nav-operations-hidden`]:{position:"absolute",visibility:"hidden",pointerEvents:"none"},[`${t}-nav-more`]:{position:"relative",padding:n,background:"transparent",border:0,color:e.colorText,"&::after":{position:"absolute",right:{_skip_check_:!0,value:0},bottom:0,left:{_skip_check_:!0,value:0},height:e.calc(e.controlHeightLG).div(8).equal(),transform:"translateY(100%)",content:"''"}},[`${t}-nav-add`]:Object.assign({minWidth:r,minHeight:r,marginLeft:{_skip_check_:!0,value:o},background:"transparent",border:`${L(e.lineWidth)} ${e.lineType} ${s}`,borderRadius:`${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)} 0 0`,outline:"none",cursor:"pointer",color:e.colorText,transition:`all ${e.motionDurationSlow} ${e.motionEaseInOut}`,"&:hover":{color:a},"&:active, &:focus:not(:focus-visible)":{color:l}},Vn(e,-3))},[`${t}-extra-content`]:{flex:"none"},[`${t}-ink-bar`]:{position:"absolute",background:e.inkBarColor,pointerEvents:"none"}}),f6(e)),{[`${t}-content`]:{position:"relative",width:"100%"},[`${t}-content-holder`]:{flex:"auto",minWidth:0,minHeight:0},[`${t}-tabpane`]:Object.assign(Object.assign({},Vn(e)),{"&-hidden":{display:"none"}})}),[`${t}-centered`]:{[`> ${t}-nav, > div > ${t}-nav`]:{[`${t}-nav-wrap`]:{[`&:not([class*='${t}-nav-wrap-ping']) > ${t}-nav-list`]:{margin:"auto"}}}}}},g6=e=>{const{cardHeight:t,cardHeightSM:n,cardHeightLG:r,controlHeight:o,controlHeightLG:a}=e,l=t||a,s=n||o,c=r||a+8;return{zIndexPopup:e.zIndexPopupBase+50,cardBg:e.colorFillAlter,cardHeight:l,cardHeightSM:s,cardHeightLG:c,cardPadding:`${(l-e.fontHeight)/2-e.lineWidth}px ${e.padding}px`,cardPaddingSM:`${(s-e.fontHeight)/2-e.lineWidth}px ${e.paddingXS}px`,cardPaddingLG:`${(c-e.fontHeightLG)/2-e.lineWidth}px ${e.padding}px`,titleFontSize:e.fontSize,titleFontSizeLG:e.fontSizeLG,titleFontSizeSM:e.fontSize,inkBarColor:e.colorPrimary,horizontalMargin:`0 0 ${e.margin}px 0`,horizontalItemGutter:32,horizontalItemMargin:"",horizontalItemMarginRTL:"",horizontalItemPadding:`${e.paddingSM}px 0`,horizontalItemPaddingSM:`${e.paddingXS}px 0`,horizontalItemPaddingLG:`${e.padding}px 0`,verticalItemPadding:`${e.paddingXS}px ${e.paddingLG}px`,verticalItemMargin:`${e.margin}px 0 0 0`,itemColor:e.colorText,itemSelectedColor:e.colorPrimary,itemHoverColor:e.colorPrimaryHover,itemActiveColor:e.colorPrimaryActive,cardGutter:e.marginXXS/2}},p6=It("Tabs",e=>{const t=yt(e,{tabsCardPadding:e.cardPadding,dropdownEdgeChildVerticalPadding:e.paddingXXS,tabsActiveTextShadow:"0 0 0.25px currentcolor",tabsDropdownHeight:200,tabsDropdownWidth:120,tabsHorizontalItemMargin:`0 0 0 ${L(e.horizontalItemGutter)}`,tabsHorizontalItemMarginRTL:`0 0 0 ${L(e.horizontalItemGutter)}`});return[d6(t),m6(t),u6(t),c6(t),s6(t),v6(t),l6(t)]},g6),h6=()=>null;var b6=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const y6=i.forwardRef((e,t)=>{var n,r,o,a,l,s,c,u,d,f,m;const{type:v,className:g,rootClassName:h,size:p,onEdit:b,hideAdd:y,centered:C,addIcon:$,removeIcon:S,moreIcon:x,more:E,popupClassName:O,children:w,items:I,animated:P,style:M,indicatorSize:R,indicator:N,destroyInactiveTabPane:T,destroyOnHidden:j}=e,z=b6(e,["type","className","rootClassName","size","onEdit","hideAdd","centered","addIcon","removeIcon","moreIcon","more","popupClassName","children","items","animated","style","indicatorSize","indicator","destroyInactiveTabPane","destroyOnHidden"]),{prefixCls:_}=z,{direction:B,tabs:V,getPrefixCls:G,getPopupContainer:q}=i.useContext(ot),H=G("tabs",_),W=Cn(H),[K,U,te]=p6(H,W),X=i.useRef(null);i.useImperativeHandle(t,()=>({nativeElement:X.current}));let ae;v==="editable-card"&&(ae={onEdit:(Q,{key:ie,event:de})=>{b==null||b(Q==="add"?de:ie,Q)},removeIcon:(n=S??(V==null?void 0:V.removeIcon))!==null&&n!==void 0?n:i.createElement(Fr,null),addIcon:($??(V==null?void 0:V.addIcon))||i.createElement(_M,null),showAdd:y!==!0});const le=G(),ee=Sn(p),Y=i6(I,w),re=r6(H,P),ne=Object.assign(Object.assign({},V==null?void 0:V.style),M),Z={align:(r=N==null?void 0:N.align)!==null&&r!==void 0?r:(o=V==null?void 0:V.indicator)===null||o===void 0?void 0:o.align,size:(c=(l=(a=N==null?void 0:N.size)!==null&&a!==void 0?a:R)!==null&&l!==void 0?l:(s=V==null?void 0:V.indicator)===null||s===void 0?void 0:s.size)!==null&&c!==void 0?c:V==null?void 0:V.indicatorSize};return K(i.createElement(t6,Object.assign({ref:X,direction:B,getPopupContainer:q},z,{items:Y,className:A({[`${H}-${ee}`]:ee,[`${H}-card`]:["card","editable-card"].includes(v),[`${H}-editable-card`]:v==="editable-card",[`${H}-centered`]:C},V==null?void 0:V.className,g,h,U,te,W),popupClassName:A(O,U,te,W),style:ne,editable:ae,more:Object.assign({icon:(m=(f=(d=(u=V==null?void 0:V.more)===null||u===void 0?void 0:u.icon)!==null&&d!==void 0?d:V==null?void 0:V.moreIcon)!==null&&f!==void 0?f:x)!==null&&m!==void 0?m:i.createElement(gf,null),transitionName:`${le}-slide-up`},E),prefixCls:H,animated:re,indicator:Z,destroyInactiveTabPane:j??T})))}),Vy=y6;Vy.TabPane=h6;var C6=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Wy=e=>{var{prefixCls:t,className:n,hoverable:r=!0}=e,o=C6(e,["prefixCls","className","hoverable"]);const{getPrefixCls:a}=i.useContext(ot),l=a("card",t),s=A(`${l}-grid`,n,{[`${l}-grid-hoverable`]:r});return i.createElement("div",Object.assign({},o,{className:s}))},S6=e=>{const{antCls:t,componentCls:n,headerHeight:r,headerPadding:o,tabsMarginBottom:a}=e;return Object.assign(Object.assign({display:"flex",justifyContent:"center",flexDirection:"column",minHeight:r,marginBottom:-1,padding:`0 ${L(o)}`,color:e.colorTextHeading,fontWeight:e.fontWeightStrong,fontSize:e.headerFontSize,background:e.headerBg,borderBottom:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorderSecondary}`,borderRadius:`${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)} 0 0`},yr()),{"&-wrapper":{width:"100%",display:"flex",alignItems:"center"},"&-title":Object.assign(Object.assign({display:"inline-block",flex:1},sr),{[`
          > ${n}-typography,
          > ${n}-typography-edit-content
        `]:{insetInlineStart:0,marginTop:0,marginBottom:0}}),[`${t}-tabs-top`]:{clear:"both",marginBottom:a,color:e.colorText,fontWeight:"normal",fontSize:e.fontSize,"&-bar":{borderBottom:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorderSecondary}`}}})},$6=e=>{const{cardPaddingBase:t,colorBorderSecondary:n,cardShadow:r,lineWidth:o}=e;return{width:"33.33%",padding:t,border:0,borderRadius:0,boxShadow:`
      ${L(o)} 0 0 0 ${n},
      0 ${L(o)} 0 0 ${n},
      ${L(o)} ${L(o)} 0 0 ${n},
      ${L(o)} 0 0 0 ${n} inset,
      0 ${L(o)} 0 0 ${n} inset;
    `,transition:`all ${e.motionDurationMid}`,"&-hoverable:hover":{position:"relative",zIndex:1,boxShadow:r}}},x6=e=>{const{componentCls:t,iconCls:n,actionsLiMargin:r,cardActionsIconSize:o,colorBorderSecondary:a,actionsBg:l}=e;return Object.assign(Object.assign({margin:0,padding:0,listStyle:"none",background:l,borderTop:`${L(e.lineWidth)} ${e.lineType} ${a}`,display:"flex",borderRadius:`0 0 ${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)}`},yr()),{"& > li":{margin:r,color:e.colorTextDescription,textAlign:"center","> span":{position:"relative",display:"block",minWidth:e.calc(e.cardActionsIconSize).mul(2).equal(),fontSize:e.fontSize,lineHeight:e.lineHeight,cursor:"pointer","&:hover":{color:e.colorPrimary,transition:`color ${e.motionDurationMid}`},[`a:not(${t}-btn), > ${n}`]:{display:"inline-block",width:"100%",color:e.colorIcon,lineHeight:L(e.fontHeight),transition:`color ${e.motionDurationMid}`,"&:hover":{color:e.colorPrimary}},[`> ${n}`]:{fontSize:o,lineHeight:L(e.calc(o).mul(e.lineHeight).equal())}},"&:not(:last-child)":{borderInlineEnd:`${L(e.lineWidth)} ${e.lineType} ${a}`}}})},w6=e=>Object.assign(Object.assign({margin:`${L(e.calc(e.marginXXS).mul(-1).equal())} 0`,display:"flex"},yr()),{"&-avatar":{paddingInlineEnd:e.padding},"&-detail":{overflow:"hidden",flex:1,"> div:not(:last-child)":{marginBottom:e.marginXS}},"&-title":Object.assign({color:e.colorTextHeading,fontWeight:e.fontWeightStrong,fontSize:e.fontSizeLG},sr),"&-description":{color:e.colorTextDescription}}),E6=e=>{const{componentCls:t,colorFillAlter:n,headerPadding:r,bodyPadding:o}=e;return{[`${t}-head`]:{padding:`0 ${L(r)}`,background:n,"&-title":{fontSize:e.fontSize}},[`${t}-body`]:{padding:`${L(e.padding)} ${L(o)}`}}},O6=e=>{const{componentCls:t}=e;return{overflow:"hidden",[`${t}-body`]:{userSelect:"none"}}},I6=e=>{const{componentCls:t,cardShadow:n,cardHeadPadding:r,colorBorderSecondary:o,boxShadowTertiary:a,bodyPadding:l,extraColor:s}=e;return{[t]:Object.assign(Object.assign({},Tt(e)),{position:"relative",background:e.colorBgContainer,borderRadius:e.borderRadiusLG,[`&:not(${t}-bordered)`]:{boxShadow:a},[`${t}-head`]:S6(e),[`${t}-extra`]:{marginInlineStart:"auto",color:s,fontWeight:"normal",fontSize:e.fontSize},[`${t}-body`]:Object.assign({padding:l,borderRadius:`0 0 ${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)}`},yr()),[`${t}-grid`]:$6(e),[`${t}-cover`]:{"> *":{display:"block",width:"100%",borderRadius:`${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)} 0 0`}},[`${t}-actions`]:x6(e),[`${t}-meta`]:w6(e)}),[`${t}-bordered`]:{border:`${L(e.lineWidth)} ${e.lineType} ${o}`,[`${t}-cover`]:{marginTop:-1,marginInlineStart:-1,marginInlineEnd:-1}},[`${t}-hoverable`]:{cursor:"pointer",transition:`box-shadow ${e.motionDurationMid}, border-color ${e.motionDurationMid}`,"&:hover":{borderColor:"transparent",boxShadow:n}},[`${t}-contain-grid`]:{borderRadius:`${L(e.borderRadiusLG)} ${L(e.borderRadiusLG)} 0 0 `,[`${t}-body`]:{display:"flex",flexWrap:"wrap"},[`&:not(${t}-loading) ${t}-body`]:{marginBlockStart:e.calc(e.lineWidth).mul(-1).equal(),marginInlineStart:e.calc(e.lineWidth).mul(-1).equal(),padding:0}},[`${t}-contain-tabs`]:{[`> div${t}-head`]:{minHeight:0,[`${t}-head-title, ${t}-extra`]:{paddingTop:r}}},[`${t}-type-inner`]:E6(e),[`${t}-loading`]:O6(e),[`${t}-rtl`]:{direction:"rtl"}}},R6=e=>{const{componentCls:t,bodyPaddingSM:n,headerPaddingSM:r,headerHeightSM:o,headerFontSizeSM:a}=e;return{[`${t}-small`]:{[`> ${t}-head`]:{minHeight:o,padding:`0 ${L(r)}`,fontSize:a,[`> ${t}-head-wrapper`]:{[`> ${t}-extra`]:{fontSize:e.fontSize}}},[`> ${t}-body`]:{padding:n}},[`${t}-small${t}-contain-tabs`]:{[`> ${t}-head`]:{[`${t}-head-title, ${t}-extra`]:{paddingTop:0,display:"flex",alignItems:"center"}}}}},P6=e=>{var t,n;return{headerBg:"transparent",headerFontSize:e.fontSizeLG,headerFontSizeSM:e.fontSize,headerHeight:e.fontSizeLG*e.lineHeightLG+e.padding*2,headerHeightSM:e.fontSize*e.lineHeight+e.paddingXS*2,actionsBg:e.colorBgContainer,actionsLiMargin:`${e.paddingSM}px 0`,tabsMarginBottom:-e.padding-e.lineWidth,extraColor:e.colorText,bodyPaddingSM:12,headerPaddingSM:12,bodyPadding:(t=e.bodyPadding)!==null&&t!==void 0?t:e.paddingLG,headerPadding:(n=e.headerPadding)!==null&&n!==void 0?n:e.paddingLG}},N6=It("Card",e=>{const t=yt(e,{cardShadow:e.boxShadowCard,cardHeadPadding:e.padding,cardPaddingBase:e.paddingLG,cardActionsIconSize:e.fontSize});return[I6(t),R6(t)]},P6);var bg=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const M6=e=>{const{actionClasses:t,actions:n=[],actionStyle:r}=e;return i.createElement("ul",{className:t,style:r},n.map((o,a)=>{const l=`action-${a}`;return i.createElement("li",{style:{width:`${100/n.length}%`},key:l},i.createElement("span",null,o))}))},T6=i.forwardRef((e,t)=>{const{prefixCls:n,className:r,rootClassName:o,style:a,extra:l,headStyle:s={},bodyStyle:c={},title:u,loading:d,bordered:f,variant:m,size:v,type:g,cover:h,actions:p,tabList:b,children:y,activeTabKey:C,defaultActiveTabKey:$,tabBarExtraContent:S,hoverable:x,tabProps:E={},classNames:O,styles:w}=e,I=bg(e,["prefixCls","className","rootClassName","style","extra","headStyle","bodyStyle","title","loading","bordered","variant","size","type","cover","actions","tabList","children","activeTabKey","defaultActiveTabKey","tabBarExtraContent","hoverable","tabProps","classNames","styles"]),{getPrefixCls:P,direction:M,card:R}=i.useContext(ot),[N]=yi("card",m,f),T=ye=>{var oe;(oe=e.onTabChange)===null||oe===void 0||oe.call(e,ye)},j=ye=>{var oe;return A((oe=R==null?void 0:R.classNames)===null||oe===void 0?void 0:oe[ye],O==null?void 0:O[ye])},z=ye=>{var oe;return Object.assign(Object.assign({},(oe=R==null?void 0:R.styles)===null||oe===void 0?void 0:oe[ye]),w==null?void 0:w[ye])},_=i.useMemo(()=>{let ye=!1;return i.Children.forEach(y,oe=>{(oe==null?void 0:oe.type)===Wy&&(ye=!0)}),ye},[y]),B=P("card",n),[V,G,q]=N6(B),H=i.createElement(kr,{loading:!0,active:!0,paragraph:{rows:4},title:!1},y),W=C!==void 0,K=Object.assign(Object.assign({},E),{[W?"activeKey":"defaultActiveKey"]:W?C:$,tabBarExtraContent:S});let U;const te=Sn(v),X=!te||te==="default"?"large":te,ae=b?i.createElement(Vy,Object.assign({size:X},K,{className:`${B}-head-tabs`,onChange:T,items:b.map(ye=>{var{tab:oe}=ye,ce=bg(ye,["tab"]);return Object.assign({label:oe},ce)})})):null;if(u||l||ae){const ye=A(`${B}-head`,j("header")),oe=A(`${B}-head-title`,j("title")),ce=A(`${B}-extra`,j("extra")),ge=Object.assign(Object.assign({},s),z("header"));U=i.createElement("div",{className:ye,style:ge},i.createElement("div",{className:`${B}-head-wrapper`},u&&i.createElement("div",{className:oe,style:z("title")},u),l&&i.createElement("div",{className:ce,style:z("extra")},l)),ae)}const le=A(`${B}-cover`,j("cover")),ee=h?i.createElement("div",{className:le,style:z("cover")},h):null,Y=A(`${B}-body`,j("body")),re=Object.assign(Object.assign({},c),z("body")),ne=i.createElement("div",{className:Y,style:re},d?H:y),Z=A(`${B}-actions`,j("actions")),Q=p!=null&&p.length?i.createElement(M6,{actionClasses:Z,actionStyle:z("actions"),actions:p}):null,ie=Gt(I,["onTabChange"]),de=A(B,R==null?void 0:R.className,{[`${B}-loading`]:d,[`${B}-bordered`]:N!=="borderless",[`${B}-hoverable`]:x,[`${B}-contain-grid`]:_,[`${B}-contain-tabs`]:b==null?void 0:b.length,[`${B}-${te}`]:te,[`${B}-type-${g}`]:!!g,[`${B}-rtl`]:M==="rtl"},r,o,G,q),he=Object.assign(Object.assign({},R==null?void 0:R.style),a);return V(i.createElement("div",Object.assign({ref:t},ie,{className:de,style:he}),U,ee,ne,Q))});var j6=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const z6=e=>{const{prefixCls:t,className:n,avatar:r,title:o,description:a}=e,l=j6(e,["prefixCls","className","avatar","title","description"]),{getPrefixCls:s}=i.useContext(ot),c=s("card",t),u=A(`${c}-meta`,n),d=r?i.createElement("div",{className:`${c}-meta-avatar`},r):null,f=o?i.createElement("div",{className:`${c}-meta-title`},o):null,m=a?i.createElement("div",{className:`${c}-meta-description`},a):null,v=f||m?i.createElement("div",{className:`${c}-meta-detail`},f,m):null;return i.createElement("div",Object.assign({},l,{className:u}),d,v)},Ky=T6;Ky.Grid=Wy;Ky.Meta=z6;function D6(e,t,n){var r=n||{},o=r.noTrailing,a=o===void 0?!1:o,l=r.noLeading,s=l===void 0?!1:l,c=r.debounceMode,u=c===void 0?void 0:c,d,f=!1,m=0;function v(){d&&clearTimeout(d)}function g(p){var b=p||{},y=b.upcomingOnly,C=y===void 0?!1:y;v(),f=!C}function h(){for(var p=arguments.length,b=new Array(p),y=0;y<p;y++)b[y]=arguments[y];var C=this,$=Date.now()-m;if(f)return;function S(){m=Date.now(),t.apply(C,b)}function x(){d=void 0}!s&&u&&!d&&S(),v(),u===void 0&&$>e?s?(m=Date.now(),a||(d=setTimeout(u?x:S,e))):S():a!==!0&&(d=setTimeout(u?x:S,u===void 0?e-$:e))}return h.cancel=g,h}function _6(e,t,n){var r={},o=r.atBegin,a=o===void 0?!1:o;return D6(e,t,{debounceMode:a!==!1})}function kn(e,t){return e[t]}var B6=["children"];function Gy(e,t){return"".concat(e,"-").concat(t)}function L6(e){return e&&e.type&&e.type.isTreeNode}function xi(e,t){return e??t}function la(e){var t=e||{},n=t.title,r=t._title,o=t.key,a=t.children,l=n||"title";return{title:l,_title:r||[l],key:o||"key",children:a||"children"}}function qy(e){function t(n){var r=xn(n);return r.map(function(o){if(!L6(o))return Kt(!o,"Tree/TreeNode can only accept TreeNode as children."),null;var a=o.key,l=o.props,s=l.children,c=ft(l,B6),u=k({key:a},c),d=t(s);return d.length&&(u.children=d),u}).filter(function(o){return o})}return t(e)}function xc(e,t,n){var r=la(n),o=r._title,a=r.key,l=r.children,s=new Set(t===!0?[]:t),c=[];function u(d){var f=arguments.length>1&&arguments[1]!==void 0?arguments[1]:null;return d.map(function(m,v){for(var g=Gy(f?f.pos:"0",v),h=xi(m[a],g),p,b=0;b<o.length;b+=1){var y=o[b];if(m[y]!==void 0){p=m[y];break}}var C=Object.assign(Gt(m,[].concat(pe(o),[a,l])),{title:p,key:h,parent:f,pos:g,children:null,data:m,isStart:[].concat(pe(f?f.isStart:[]),[v===0]),isEnd:[].concat(pe(f?f.isEnd:[]),[v===d.length-1])});return c.push(C),t===!0||s.has(h)?C.children=u(m[l]||[],C):C.children=[],C})}return u(e),c}function H6(e,t,n){var r={};Qe(n)==="object"?r=n:r={externalGetKey:n},r=r||{};var o=r,a=o.childrenPropName,l=o.externalGetKey,s=o.fieldNames,c=la(s),u=c.key,d=c.children,f=a||d,m;l?typeof l=="string"?m=function(h){return h[l]}:typeof l=="function"&&(m=function(h){return l(h)}):m=function(h,p){return xi(h[u],p)};function v(g,h,p,b){var y=g?g[f]:e,C=g?Gy(p.pos,h):"0",$=g?[].concat(pe(b),[g]):[];if(g){var S=m(g,C),x={node:g,index:h,pos:C,key:S,parentPos:p.node?p.pos:null,level:p.level+1,nodes:$};t(x)}y&&y.forEach(function(E,O){v(E,O,{node:g,pos:C,level:p?p.level+1:-1},$)})}v(null)}function yf(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=t.initWrapper,r=t.processEntity,o=t.onProcessFinished,a=t.externalGetKey,l=t.childrenPropName,s=t.fieldNames,c=arguments.length>2?arguments[2]:void 0,u=a||c,d={},f={},m={posEntities:d,keyEntities:f};return n&&(m=n(m)||m),H6(e,function(v){var g=v.node,h=v.index,p=v.pos,b=v.key,y=v.parentPos,C=v.level,$=v.nodes,S={node:g,nodes:$,index:h,key:b,pos:p,level:C},x=xi(b,p);d[p]=S,f[x]=S,S.parent=d[y],S.parent&&(S.parent.children=S.parent.children||[],S.parent.children.push(S)),r&&r(S,m)},{externalGetKey:u,childrenPropName:l,fieldNames:s}),o&&o(m),m}function ka(e,t){var n=t.expandedKeys,r=t.selectedKeys,o=t.loadedKeys,a=t.loadingKeys,l=t.checkedKeys,s=t.halfCheckedKeys,c=t.dragOverNodeKey,u=t.dropPosition,d=t.keyEntities,f=kn(d,e),m={eventKey:e,expanded:n.indexOf(e)!==-1,selected:r.indexOf(e)!==-1,loaded:o.indexOf(e)!==-1,loading:a.indexOf(e)!==-1,checked:l.indexOf(e)!==-1,halfChecked:s.indexOf(e)!==-1,pos:String(f?f.pos:""),dragOver:c===e&&u===0,dragOverGapTop:c===e&&u===-1,dragOverGapBottom:c===e&&u===1};return m}function fn(e){var t=e.data,n=e.expanded,r=e.selected,o=e.checked,a=e.loaded,l=e.loading,s=e.halfChecked,c=e.dragOver,u=e.dragOverGapTop,d=e.dragOverGapBottom,f=e.pos,m=e.active,v=e.eventKey,g=k(k({},t),{},{expanded:n,selected:r,checked:o,loaded:a,loading:l,halfChecked:s,dragOver:c,dragOverGapTop:u,dragOverGapBottom:d,pos:f,active:m,key:v});return"props"in g||Object.defineProperty(g,"props",{get:function(){return Kt(!1,"Second param return from event is node data instead of TreeNode instance. Please read value directly instead of reading from `props`."),e}}),g}function Uy(e,t){var n=new Set;return e.forEach(function(r){t.has(r)||n.add(r)}),n}function A6(e){var t=e||{},n=t.disabled,r=t.disableCheckbox,o=t.checkable;return!!(n||r)||o===!1}function F6(e,t,n,r){for(var o=new Set(e),a=new Set,l=0;l<=n;l+=1){var s=t.get(l)||new Set;s.forEach(function(f){var m=f.key,v=f.node,g=f.children,h=g===void 0?[]:g;o.has(m)&&!r(v)&&h.filter(function(p){return!r(p.node)}).forEach(function(p){o.add(p.key)})})}for(var c=new Set,u=n;u>=0;u-=1){var d=t.get(u)||new Set;d.forEach(function(f){var m=f.parent,v=f.node;if(!(r(v)||!f.parent||c.has(f.parent.key))){if(r(f.parent.node)){c.add(m.key);return}var g=!0,h=!1;(m.children||[]).filter(function(p){return!r(p.node)}).forEach(function(p){var b=p.key,y=o.has(b);g&&!y&&(g=!1),!h&&(y||a.has(b))&&(h=!0)}),g&&o.add(m.key),h&&a.add(m.key),c.add(m.key)}})}return{checkedKeys:Array.from(o),halfCheckedKeys:Array.from(Uy(a,o))}}function k6(e,t,n,r,o){for(var a=new Set(e),l=new Set(t),s=0;s<=r;s+=1){var c=n.get(s)||new Set;c.forEach(function(m){var v=m.key,g=m.node,h=m.children,p=h===void 0?[]:h;!a.has(v)&&!l.has(v)&&!o(g)&&p.filter(function(b){return!o(b.node)}).forEach(function(b){a.delete(b.key)})})}l=new Set;for(var u=new Set,d=r;d>=0;d-=1){var f=n.get(d)||new Set;f.forEach(function(m){var v=m.parent,g=m.node;if(!(o(g)||!m.parent||u.has(m.parent.key))){if(o(m.parent.node)){u.add(v.key);return}var h=!0,p=!1;(v.children||[]).filter(function(b){return!o(b.node)}).forEach(function(b){var y=b.key,C=a.has(y);h&&!C&&(h=!1),!p&&(C||l.has(y))&&(p=!0)}),h||a.delete(v.key),p&&l.add(v.key),u.add(v.key)}})}return{checkedKeys:Array.from(a),halfCheckedKeys:Array.from(Uy(l,a))}}function qo(e,t,n,r){var o=[],a;r?a=r:a=A6;var l=new Set(e.filter(function(d){var f=!!kn(n,d);return f||o.push(d),f})),s=new Map,c=0;Object.keys(n).forEach(function(d){var f=n[d],m=f.level,v=s.get(m);v||(v=new Set,s.set(m,v)),v.add(f),c=Math.max(c,m)}),Kt(!o.length,"Tree missing follow keys: ".concat(o.slice(0,100).map(function(d){return"'".concat(d,"'")}).join(", ")));var u;return t===!0?u=F6(l,s,c,a):u=k6(l,t.halfCheckedKeys,s,c,a),u}const V6=e=>{const{checkboxCls:t}=e,n=`${t}-wrapper`;return[{[`${t}-group`]:Object.assign(Object.assign({},Tt(e)),{display:"inline-flex",flexWrap:"wrap",columnGap:e.marginXS,[`> ${e.antCls}-row`]:{flex:1}}),[n]:Object.assign(Object.assign({},Tt(e)),{display:"inline-flex",alignItems:"baseline",cursor:"pointer","&:after":{display:"inline-block",width:0,overflow:"hidden",content:"'\\a0'"},[`& + ${n}`]:{marginInlineStart:0},[`&${n}-in-form-item`]:{'input[type="checkbox"]':{width:14,height:14}}}),[t]:Object.assign(Object.assign({},Tt(e)),{position:"relative",whiteSpace:"nowrap",lineHeight:1,cursor:"pointer",borderRadius:e.borderRadiusSM,alignSelf:"center",[`${t}-input`]:{position:"absolute",inset:0,zIndex:1,cursor:"pointer",opacity:0,margin:0,[`&:focus-visible + ${t}-inner`]:Cr(e)},[`${t}-inner`]:{boxSizing:"border-box",display:"block",width:e.checkboxSize,height:e.checkboxSize,direction:"ltr",backgroundColor:e.colorBgContainer,border:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,borderRadius:e.borderRadiusSM,borderCollapse:"separate",transition:`all ${e.motionDurationSlow}`,"&:after":{boxSizing:"border-box",position:"absolute",top:"50%",insetInlineStart:"25%",display:"table",width:e.calc(e.checkboxSize).div(14).mul(5).equal(),height:e.calc(e.checkboxSize).div(14).mul(8).equal(),border:`${L(e.lineWidthBold)} solid ${e.colorWhite}`,borderTop:0,borderInlineStart:0,transform:"rotate(45deg) scale(0) translate(-50%,-50%)",opacity:0,content:'""',transition:`all ${e.motionDurationFast} ${e.motionEaseInBack}, opacity ${e.motionDurationFast}`}},"& + span":{paddingInlineStart:e.paddingXS,paddingInlineEnd:e.paddingXS}})},{[`
        ${n}:not(${n}-disabled),
        ${t}:not(${t}-disabled)
      `]:{[`&:hover ${t}-inner`]:{borderColor:e.colorPrimary}},[`${n}:not(${n}-disabled)`]:{[`&:hover ${t}-checked:not(${t}-disabled) ${t}-inner`]:{backgroundColor:e.colorPrimaryHover,borderColor:"transparent"},[`&:hover ${t}-checked:not(${t}-disabled):after`]:{borderColor:e.colorPrimaryHover}}},{[`${t}-checked`]:{[`${t}-inner`]:{backgroundColor:e.colorPrimary,borderColor:e.colorPrimary,"&:after":{opacity:1,transform:"rotate(45deg) scale(1) translate(-50%,-50%)",transition:`all ${e.motionDurationMid} ${e.motionEaseOutBack} ${e.motionDurationFast}`}}},[`
        ${n}-checked:not(${n}-disabled),
        ${t}-checked:not(${t}-disabled)
      `]:{[`&:hover ${t}-inner`]:{backgroundColor:e.colorPrimaryHover,borderColor:"transparent"}}},{[t]:{"&-indeterminate":{"&":{[`${t}-inner`]:{backgroundColor:`${e.colorBgContainer}`,borderColor:`${e.colorBorder}`,"&:after":{top:"50%",insetInlineStart:"50%",width:e.calc(e.fontSizeLG).div(2).equal(),height:e.calc(e.fontSizeLG).div(2).equal(),backgroundColor:e.colorPrimary,border:0,transform:"translate(-50%, -50%) scale(1)",opacity:1,content:'""'}},[`&:hover ${t}-inner`]:{backgroundColor:`${e.colorBgContainer}`,borderColor:`${e.colorPrimary}`}}}}},{[`${n}-disabled`]:{cursor:"not-allowed"},[`${t}-disabled`]:{[`&, ${t}-input`]:{cursor:"not-allowed",pointerEvents:"none"},[`${t}-inner`]:{background:e.colorBgContainerDisabled,borderColor:e.colorBorder,"&:after":{borderColor:e.colorTextDisabled}},"&:after":{display:"none"},"& + span":{color:e.colorTextDisabled},[`&${t}-indeterminate ${t}-inner::after`]:{background:e.colorTextDisabled}}}]};function Xy(e,t){const n=yt(t,{checkboxCls:`.${e}`,checkboxSize:t.controlInteractiveSize});return V6(n)}const Yy=It("Checkbox",(e,{prefixCls:t})=>[Xy(t,e)]),Qy=F.createContext(null);var W6=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const K6=(e,t)=>{var n;const{prefixCls:r,className:o,rootClassName:a,children:l,indeterminate:s=!1,style:c,onMouseEnter:u,onMouseLeave:d,skipGroup:f=!1,disabled:m}=e,v=W6(e,["prefixCls","className","rootClassName","children","indeterminate","style","onMouseEnter","onMouseLeave","skipGroup","disabled"]),{getPrefixCls:g,direction:h,checkbox:p}=i.useContext(ot),b=i.useContext(Qy),{isFormItemInput:y}=i.useContext(Wn),C=i.useContext(Ln),$=(n=(b==null?void 0:b.disabled)||m)!==null&&n!==void 0?n:C,S=i.useRef(v.value),x=i.useRef(null),E=un(t,x);i.useEffect(()=>{b==null||b.registerValue(v.value)},[]),i.useEffect(()=>{if(!f)return v.value!==S.current&&(b==null||b.cancelValue(S.current),b==null||b.registerValue(v.value),S.current=v.value),()=>b==null?void 0:b.cancelValue(v.value)},[v.value]),i.useEffect(()=>{var _;!((_=x.current)===null||_===void 0)&&_.input&&(x.current.input.indeterminate=s)},[s]);const O=g("checkbox",r),w=Cn(O),[I,P,M]=Yy(O,w),R=Object.assign({},v);b&&!f&&(R.onChange=(..._)=>{v.onChange&&v.onChange.apply(v,_),b.toggleOption&&b.toggleOption({label:l,value:v.value})},R.name=b.name,R.checked=b.value.includes(v.value));const N=A(`${O}-wrapper`,{[`${O}-rtl`]:h==="rtl",[`${O}-wrapper-checked`]:R.checked,[`${O}-wrapper-disabled`]:$,[`${O}-wrapper-in-form-item`]:y},p==null?void 0:p.className,o,a,M,w,P),T=A({[`${O}-indeterminate`]:s},is,P),[j,z]=wy(R.onClick);return I(i.createElement(ci,{component:"Checkbox",disabled:$},i.createElement("label",{className:N,style:Object.assign(Object.assign({},p==null?void 0:p.style),c),onMouseEnter:u,onMouseLeave:d,onClick:j},i.createElement(xy,Object.assign({},R,{onClick:z,prefixCls:O,className:T,disabled:$,ref:E})),l!=null&&i.createElement("span",{className:`${O}-label`},l))))},Zy=i.forwardRef(K6);var G6=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const q6=i.forwardRef((e,t)=>{const{defaultValue:n,children:r,options:o=[],prefixCls:a,className:l,rootClassName:s,style:c,onChange:u}=e,d=G6(e,["defaultValue","children","options","prefixCls","className","rootClassName","style","onChange"]),{getPrefixCls:f,direction:m}=i.useContext(ot),[v,g]=i.useState(d.value||n||[]),[h,p]=i.useState([]);i.useEffect(()=>{"value"in d&&g(d.value||[])},[d.value]);const b=i.useMemo(()=>o.map(T=>typeof T=="string"||typeof T=="number"?{label:T,value:T}:T),[o]),y=T=>{p(j=>j.filter(z=>z!==T))},C=T=>{p(j=>[].concat(pe(j),[T]))},$=T=>{const j=v.indexOf(T.value),z=pe(v);j===-1?z.push(T.value):z.splice(j,1),"value"in d||g(z),u==null||u(z.filter(_=>h.includes(_)).sort((_,B)=>{const V=b.findIndex(q=>q.value===_),G=b.findIndex(q=>q.value===B);return V-G}))},S=f("checkbox",a),x=`${S}-group`,E=Cn(S),[O,w,I]=Yy(S,E),P=Gt(d,["value","disabled"]),M=o.length?b.map(T=>i.createElement(Zy,{prefixCls:S,key:T.value.toString(),disabled:"disabled"in T?T.disabled:d.disabled,value:T.value,checked:v.includes(T.value),onChange:T.onChange,className:A(`${x}-item`,T.className),style:T.style,title:T.title,id:T.id,required:T.required},T.label)):r,R=i.useMemo(()=>({toggleOption:$,value:v,disabled:d.disabled,name:d.name,registerValue:C,cancelValue:y}),[$,v,d.disabled,d.name,C,y]),N=A(x,{[`${x}-rtl`]:m==="rtl"},l,s,I,E,w);return O(i.createElement("div",Object.assign({className:N,style:c},P,{ref:t}),i.createElement(Qy.Provider,{value:R},M)))}),sa=Zy;sa.Group=q6;sa.__ANT_CHECKBOX=!0;const Jy=i.createContext({});var U6=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function yg(e){return typeof e=="number"?`${e} ${e} auto`:/^\d+(\.\d+)?(px|em|rem|%)$/.test(e)?`0 0 ${e}`:e}const X6=["xs","sm","md","lg","xl","xxl"],dA=i.forwardRef((e,t)=>{const{getPrefixCls:n,direction:r}=i.useContext(ot),{gutter:o,wrap:a}=i.useContext(Jy),{prefixCls:l,span:s,order:c,offset:u,push:d,pull:f,className:m,children:v,flex:g,style:h}=e,p=U6(e,["prefixCls","span","order","offset","push","pull","className","children","flex","style"]),b=n("col",l),[y,C,$]=tR(b),S={};let x={};X6.forEach(w=>{let I={};const P=e[w];typeof P=="number"?I.span=P:typeof P=="object"&&(I=P||{}),delete p[w],x=Object.assign(Object.assign({},x),{[`${b}-${w}-${I.span}`]:I.span!==void 0,[`${b}-${w}-order-${I.order}`]:I.order||I.order===0,[`${b}-${w}-offset-${I.offset}`]:I.offset||I.offset===0,[`${b}-${w}-push-${I.push}`]:I.push||I.push===0,[`${b}-${w}-pull-${I.pull}`]:I.pull||I.pull===0,[`${b}-rtl`]:r==="rtl"}),I.flex&&(x[`${b}-${w}-flex`]=!0,S[`--${b}-${w}-flex`]=yg(I.flex))});const E=A(b,{[`${b}-${s}`]:s!==void 0,[`${b}-order-${c}`]:c,[`${b}-offset-${u}`]:u,[`${b}-push-${d}`]:d,[`${b}-pull-${f}`]:f},m,x,C,$),O={};if(o&&o[0]>0){const w=o[0]/2;O.paddingLeft=w,O.paddingRight=w}return g&&(O.flex=yg(g),a===!1&&!O.minWidth&&(O.minWidth=0)),y(i.createElement("div",Object.assign({},p,{style:Object.assign(Object.assign(Object.assign({},O),h),S),className:E,ref:t}),v))});function Y6(e,t){const n=[void 0,void 0],r=Array.isArray(e)?e:[e,void 0],o=t||{xs:!0,sm:!0,md:!0,lg:!0,xl:!0,xxl:!0};return r.forEach((a,l)=>{if(typeof a=="object"&&a!==null)for(let s=0;s<aa.length;s++){const c=aa[s];if(o[c]&&a[c]!==void 0){n[l]=a[c];break}}else n[l]=a}),n}var Q6=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function Cg(e,t){const[n,r]=i.useState(typeof e=="string"?e:""),o=()=>{if(typeof e=="string"&&r(e),typeof e=="object")for(let a=0;a<aa.length;a++){const l=aa[a];if(!t||!t[l])continue;const s=e[l];if(s!==void 0){r(s);return}}};return i.useEffect(()=>{o()},[JSON.stringify(e),t]),n}const fA=i.forwardRef((e,t)=>{const{prefixCls:n,justify:r,align:o,className:a,style:l,children:s,gutter:c=0,wrap:u}=e,d=Q6(e,["prefixCls","justify","align","className","style","children","gutter","wrap"]),{getPrefixCls:f,direction:m}=i.useContext(ot),v=xs(!0,null),g=Cg(o,v),h=Cg(r,v),p=f("row",n),[b,y,C]=eR(p),$=Y6(c,v),S=A(p,{[`${p}-no-wrap`]:u===!1,[`${p}-${h}`]:h,[`${p}-${g}`]:g,[`${p}-rtl`]:m==="rtl"},a,y,C),x={},E=$[0]!=null&&$[0]>0?$[0]/-2:void 0;E&&(x.marginLeft=E,x.marginRight=E);const[O,w]=$;x.rowGap=w;const I=i.useMemo(()=>({gutter:[O,w],wrap:u}),[O,w,u]);return b(i.createElement(Jy.Provider,{value:I},i.createElement("div",Object.assign({},d,{className:S,style:Object.assign(Object.assign({},x),l),ref:t}),s)))}),Z6=e=>{const{componentCls:t}=e;return{[t]:{"&-horizontal":{[`&${t}`]:{"&-sm":{marginBlock:e.marginXS},"&-md":{marginBlock:e.margin}}}}}},J6=e=>{const{componentCls:t,sizePaddingEdgeHorizontal:n,colorSplit:r,lineWidth:o,textPaddingInline:a,orientationMargin:l,verticalMarginInline:s}=e;return{[t]:Object.assign(Object.assign({},Tt(e)),{borderBlockStart:`${L(o)} solid ${r}`,"&-vertical":{position:"relative",top:"-0.06em",display:"inline-block",height:"0.9em",marginInline:s,marginBlock:0,verticalAlign:"middle",borderTop:0,borderInlineStart:`${L(o)} solid ${r}`},"&-horizontal":{display:"flex",clear:"both",width:"100%",minWidth:"100%",margin:`${L(e.marginLG)} 0`},[`&-horizontal${t}-with-text`]:{display:"flex",alignItems:"center",margin:`${L(e.dividerHorizontalWithTextGutterMargin)} 0`,color:e.colorTextHeading,fontWeight:500,fontSize:e.fontSizeLG,whiteSpace:"nowrap",textAlign:"center",borderBlockStart:`0 ${r}`,"&::before, &::after":{position:"relative",width:"50%",borderBlockStart:`${L(o)} solid transparent`,borderBlockStartColor:"inherit",borderBlockEnd:0,transform:"translateY(50%)",content:"''"}},[`&-horizontal${t}-with-text-start`]:{"&::before":{width:`calc(${l} * 100%)`},"&::after":{width:`calc(100% - ${l} * 100%)`}},[`&-horizontal${t}-with-text-end`]:{"&::before":{width:`calc(100% - ${l} * 100%)`},"&::after":{width:`calc(${l} * 100%)`}},[`${t}-inner-text`]:{display:"inline-block",paddingBlock:0,paddingInline:a},"&-dashed":{background:"none",borderColor:r,borderStyle:"dashed",borderWidth:`${L(o)} 0 0`},[`&-horizontal${t}-with-text${t}-dashed`]:{"&::before, &::after":{borderStyle:"dashed none none"}},[`&-vertical${t}-dashed`]:{borderInlineStartWidth:o,borderInlineEnd:0,borderBlockStart:0,borderBlockEnd:0},"&-dotted":{background:"none",borderColor:r,borderStyle:"dotted",borderWidth:`${L(o)} 0 0`},[`&-horizontal${t}-with-text${t}-dotted`]:{"&::before, &::after":{borderStyle:"dotted none none"}},[`&-vertical${t}-dotted`]:{borderInlineStartWidth:o,borderInlineEnd:0,borderBlockStart:0,borderBlockEnd:0},[`&-plain${t}-with-text`]:{color:e.colorText,fontWeight:"normal",fontSize:e.fontSize},[`&-horizontal${t}-with-text-start${t}-no-default-orientation-margin-start`]:{"&::before":{width:0},"&::after":{width:"100%"},[`${t}-inner-text`]:{paddingInlineStart:n}},[`&-horizontal${t}-with-text-end${t}-no-default-orientation-margin-end`]:{"&::before":{width:"100%"},"&::after":{width:0},[`${t}-inner-text`]:{paddingInlineEnd:n}}})}},eT=e=>({textPaddingInline:"1em",orientationMargin:.05,verticalMarginInline:e.marginXS}),tT=It("Divider",e=>{const t=yt(e,{dividerHorizontalWithTextGutterMargin:e.margin,sizePaddingEdgeHorizontal:0});return[J6(t),Z6(t)]},eT,{unitless:{orientationMargin:!0}});var nT=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const rT={small:"sm",middle:"md"},oT=e=>{const{getPrefixCls:t,direction:n,className:r,style:o}=tn("divider"),{prefixCls:a,type:l="horizontal",orientation:s="center",orientationMargin:c,className:u,rootClassName:d,children:f,dashed:m,variant:v="solid",plain:g,style:h,size:p}=e,b=nT(e,["prefixCls","type","orientation","orientationMargin","className","rootClassName","children","dashed","variant","plain","style","size"]),y=t("divider",a),[C,$,S]=tT(y),x=Sn(p),E=rT[x],O=!!f,w=i.useMemo(()=>s==="left"?n==="rtl"?"end":"start":s==="right"?n==="rtl"?"start":"end":s,[n,s]),I=w==="start"&&c!=null,P=w==="end"&&c!=null,M=A(y,r,$,S,`${y}-${l}`,{[`${y}-with-text`]:O,[`${y}-with-text-${w}`]:O,[`${y}-dashed`]:!!m,[`${y}-${v}`]:v!=="solid",[`${y}-plain`]:!!g,[`${y}-rtl`]:n==="rtl",[`${y}-no-default-orientation-margin-start`]:I,[`${y}-no-default-orientation-margin-end`]:P,[`${y}-${E}`]:!!E},u,d),R=i.useMemo(()=>typeof c=="number"?c:/^\d+$/.test(c)?Number(c):c,[c]),N={marginInlineStart:I?R:void 0,marginInlineEnd:P?R:void 0};return C(i.createElement("div",Object.assign({className:M,style:Object.assign(Object.assign({},o),h)},b,{role:"separator"}),f&&l!=="vertical"&&i.createElement("span",{className:`${y}-inner-text`,style:N},f)))};var Sg=function(t,n){if(!t)return null;var r={left:t.offsetLeft,right:t.parentElement.clientWidth-t.clientWidth-t.offsetLeft,width:t.clientWidth,top:t.offsetTop,bottom:t.parentElement.clientHeight-t.clientHeight-t.offsetTop,height:t.clientHeight};return n?{left:0,right:0,width:0,top:r.top,bottom:r.bottom,height:r.height}:{left:r.left,right:r.right,width:r.width,top:0,bottom:0,height:0}},Er=function(t){return t!==void 0?"".concat(t,"px"):void 0};function aT(e){var t=e.prefixCls,n=e.containerRef,r=e.value,o=e.getValueIndex,a=e.motionName,l=e.onMotionStart,s=e.onMotionEnd,c=e.direction,u=e.vertical,d=u===void 0?!1:u,f=i.useRef(null),m=i.useState(r),v=J(m,2),g=v[0],h=v[1],p=function(T){var j,z=o(T),_=(j=n.current)===null||j===void 0?void 0:j.querySelectorAll(".".concat(t,"-item"))[z];return(_==null?void 0:_.offsetParent)&&_},b=i.useState(null),y=J(b,2),C=y[0],$=y[1],S=i.useState(null),x=J(S,2),E=x[0],O=x[1];wt(function(){if(g!==r){var N=p(g),T=p(r),j=Sg(N,d),z=Sg(T,d);h(r),$(j),O(z),N&&T?l():s()}},[r]);var w=i.useMemo(function(){if(d){var N;return Er((N=C==null?void 0:C.top)!==null&&N!==void 0?N:0)}return Er(c==="rtl"?-(C==null?void 0:C.right):C==null?void 0:C.left)},[d,c,C]),I=i.useMemo(function(){if(d){var N;return Er((N=E==null?void 0:E.top)!==null&&N!==void 0?N:0)}return Er(c==="rtl"?-(E==null?void 0:E.right):E==null?void 0:E.left)},[d,c,E]),P=function(){return d?{transform:"translateY(var(--thumb-start-top))",height:"var(--thumb-start-height)"}:{transform:"translateX(var(--thumb-start-left))",width:"var(--thumb-start-width)"}},M=function(){return d?{transform:"translateY(var(--thumb-active-top))",height:"var(--thumb-active-height)"}:{transform:"translateX(var(--thumb-active-left))",width:"var(--thumb-active-width)"}},R=function(){$(null),O(null),s()};return!C||!E?null:i.createElement(En,{visible:!0,motionName:a,motionAppear:!0,onAppearStart:P,onAppearActive:M,onVisibleChanged:R},function(N,T){var j=N.className,z=N.style,_=k(k({},z),{},{"--thumb-start-left":w,"--thumb-start-width":Er(C==null?void 0:C.width),"--thumb-active-left":I,"--thumb-active-width":Er(E==null?void 0:E.width),"--thumb-start-top":w,"--thumb-start-height":Er(C==null?void 0:C.height),"--thumb-active-top":I,"--thumb-active-height":Er(E==null?void 0:E.height)}),B={ref:un(f,T),style:_,className:A("".concat(t,"-thumb"),j)};return i.createElement("div",B)})}var iT=["prefixCls","direction","vertical","options","disabled","defaultValue","value","name","onChange","className","motionName"];function lT(e){if(typeof e.title<"u")return e.title;if(Qe(e.label)!=="object"){var t;return(t=e.label)===null||t===void 0?void 0:t.toString()}}function sT(e){return e.map(function(t){if(Qe(t)==="object"&&t!==null){var n=lT(t);return k(k({},t),{},{title:n})}return{label:t==null?void 0:t.toString(),title:t==null?void 0:t.toString(),value:t}})}var cT=function(t){var n=t.prefixCls,r=t.className,o=t.disabled,a=t.checked,l=t.label,s=t.title,c=t.value,u=t.name,d=t.onChange,f=t.onFocus,m=t.onBlur,v=t.onKeyDown,g=t.onKeyUp,h=t.onMouseDown,p=function(y){o||d(y,c)};return i.createElement("label",{className:A(r,D({},"".concat(n,"-item-disabled"),o)),onMouseDown:h},i.createElement("input",{name:u,className:"".concat(n,"-item-input"),type:"radio",disabled:o,checked:a,onChange:p,onFocus:f,onBlur:m,onKeyDown:v,onKeyUp:g}),i.createElement("div",{className:"".concat(n,"-item-label"),title:s,"aria-selected":a},l))},uT=i.forwardRef(function(e,t){var n,r,o=e.prefixCls,a=o===void 0?"rc-segmented":o,l=e.direction,s=e.vertical,c=e.options,u=c===void 0?[]:c,d=e.disabled,f=e.defaultValue,m=e.value,v=e.name,g=e.onChange,h=e.className,p=h===void 0?"":h,b=e.motionName,y=b===void 0?"thumb-motion":b,C=ft(e,iT),$=i.useRef(null),S=i.useMemo(function(){return un($,t)},[$,t]),x=i.useMemo(function(){return sT(u)},[u]),E=Lt((n=x[0])===null||n===void 0?void 0:n.value,{value:m,defaultValue:f}),O=J(E,2),w=O[0],I=O[1],P=i.useState(!1),M=J(P,2),R=M[0],N=M[1],T=function(Y,re){I(re),g==null||g(re)},j=Gt(C,["children"]),z=i.useState(!1),_=J(z,2),B=_[0],V=_[1],G=i.useState(!1),q=J(G,2),H=q[0],W=q[1],K=function(){W(!0)},U=function(){W(!1)},te=function(){V(!1)},X=function(Y){Y.key==="Tab"&&V(!0)},ae=function(Y){var re=x.findIndex(function(ie){return ie.value===w}),ne=x.length,Z=(re+Y+ne)%ne,Q=x[Z];Q&&(I(Q.value),g==null||g(Q.value))},le=function(Y){switch(Y.key){case"ArrowLeft":case"ArrowUp":ae(-1);break;case"ArrowRight":case"ArrowDown":ae(1);break}};return i.createElement("div",ue({role:"radiogroup","aria-label":"segmented control",tabIndex:d?void 0:0},j,{className:A(a,(r={},D(r,"".concat(a,"-rtl"),l==="rtl"),D(r,"".concat(a,"-disabled"),d),D(r,"".concat(a,"-vertical"),s),r),p),ref:S}),i.createElement("div",{className:"".concat(a,"-group")},i.createElement(aT,{vertical:s,prefixCls:a,value:w,containerRef:$,motionName:"".concat(a,"-").concat(y),direction:l,getValueIndex:function(Y){return x.findIndex(function(re){return re.value===Y})},onMotionStart:function(){N(!0)},onMotionEnd:function(){N(!1)}}),x.map(function(ee){var Y;return i.createElement(cT,ue({},ee,{name:v,key:ee.value,prefixCls:a,className:A(ee.className,"".concat(a,"-item"),(Y={},D(Y,"".concat(a,"-item-selected"),ee.value===w&&!R),D(Y,"".concat(a,"-item-focused"),H&&B&&ee.value===w),Y)),checked:ee.value===w,onChange:T,onFocus:K,onBlur:U,onKeyDown:le,onKeyUp:X,onMouseDown:te,disabled:!!d||!!ee.disabled}))})))}),dT=uT;function $g(e,t){return{[`${e}, ${e}:hover, ${e}:focus`]:{color:t.colorTextDisabled,cursor:"not-allowed"}}}function xg(e){return{backgroundColor:e.itemSelectedBg,boxShadow:e.boxShadowTertiary}}const fT=Object.assign({overflow:"hidden"},sr),mT=e=>{const{componentCls:t}=e,n=e.calc(e.controlHeight).sub(e.calc(e.trackPadding).mul(2)).equal(),r=e.calc(e.controlHeightLG).sub(e.calc(e.trackPadding).mul(2)).equal(),o=e.calc(e.controlHeightSM).sub(e.calc(e.trackPadding).mul(2)).equal();return{[t]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),{display:"inline-block",padding:e.trackPadding,color:e.itemColor,background:e.trackBg,borderRadius:e.borderRadius,transition:`all ${e.motionDurationMid} ${e.motionEaseInOut}`}),Vn(e)),{[`${t}-group`]:{position:"relative",display:"flex",alignItems:"stretch",justifyItems:"flex-start",flexDirection:"row",width:"100%"},[`&${t}-rtl`]:{direction:"rtl"},[`&${t}-vertical`]:{[`${t}-group`]:{flexDirection:"column"},[`${t}-thumb`]:{width:"100%",height:0,padding:`0 ${L(e.paddingXXS)}`}},[`&${t}-block`]:{display:"flex"},[`&${t}-block ${t}-item`]:{flex:1,minWidth:0},[`${t}-item`]:{position:"relative",textAlign:"center",cursor:"pointer",transition:`color ${e.motionDurationMid} ${e.motionEaseInOut}`,borderRadius:e.borderRadiusSM,transform:"translateZ(0)","&-selected":Object.assign(Object.assign({},xg(e)),{color:e.itemSelectedColor}),"&-focused":Cr(e),"&::after":{content:'""',position:"absolute",zIndex:-1,width:"100%",height:"100%",top:0,insetInlineStart:0,borderRadius:"inherit",opacity:0,transition:`opacity ${e.motionDurationMid}`,pointerEvents:"none"},[`&:hover:not(${t}-item-selected):not(${t}-item-disabled)`]:{color:e.itemHoverColor,"&::after":{opacity:1,backgroundColor:e.itemHoverBg}},[`&:active:not(${t}-item-selected):not(${t}-item-disabled)`]:{color:e.itemHoverColor,"&::after":{opacity:1,backgroundColor:e.itemActiveBg}},"&-label":Object.assign({minHeight:n,lineHeight:L(n),padding:`0 ${L(e.segmentedPaddingHorizontal)}`},fT),"&-icon + *":{marginInlineStart:e.calc(e.marginSM).div(2).equal()},"&-input":{position:"absolute",insetBlockStart:0,insetInlineStart:0,width:0,height:0,opacity:0,pointerEvents:"none"}},[`${t}-thumb`]:Object.assign(Object.assign({},xg(e)),{position:"absolute",insetBlockStart:0,insetInlineStart:0,width:0,height:"100%",padding:`${L(e.paddingXXS)} 0`,borderRadius:e.borderRadiusSM,transition:`transform ${e.motionDurationSlow} ${e.motionEaseInOut}, height ${e.motionDurationSlow} ${e.motionEaseInOut}`,[`& ~ ${t}-item:not(${t}-item-selected):not(${t}-item-disabled)::after`]:{backgroundColor:"transparent"}}),[`&${t}-lg`]:{borderRadius:e.borderRadiusLG,[`${t}-item-label`]:{minHeight:r,lineHeight:L(r),padding:`0 ${L(e.segmentedPaddingHorizontal)}`,fontSize:e.fontSizeLG},[`${t}-item, ${t}-thumb`]:{borderRadius:e.borderRadius}},[`&${t}-sm`]:{borderRadius:e.borderRadiusSM,[`${t}-item-label`]:{minHeight:o,lineHeight:L(o),padding:`0 ${L(e.segmentedPaddingHorizontalSM)}`},[`${t}-item, ${t}-thumb`]:{borderRadius:e.borderRadiusXS}}}),$g(`&-disabled ${t}-item`,e)),$g(`${t}-item-disabled`,e)),{[`${t}-thumb-motion-appear-active`]:{transition:`transform ${e.motionDurationSlow} ${e.motionEaseInOut}, width ${e.motionDurationSlow} ${e.motionEaseInOut}`,willChange:"transform, width"},[`&${t}-shape-round`]:{borderRadius:9999,[`${t}-item, ${t}-thumb`]:{borderRadius:9999}}})}},vT=e=>{const{colorTextLabel:t,colorText:n,colorFillSecondary:r,colorBgElevated:o,colorFill:a,lineWidthBold:l,colorBgLayout:s}=e;return{trackPadding:l,trackBg:s,itemColor:t,itemHoverColor:n,itemHoverBg:r,itemSelectedBg:o,itemActiveBg:a,itemSelectedColor:n}},gT=It("Segmented",e=>{const{lineWidth:t,calc:n}=e,r=yt(e,{segmentedPaddingHorizontal:n(e.controlPaddingHorizontal).sub(t).equal(),segmentedPaddingHorizontalSM:n(e.controlPaddingHorizontalSM).sub(t).equal()});return mT(r)},vT);var wg=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function pT(e){return typeof e=="object"&&!!(e!=null&&e.icon)}const hT=i.forwardRef((e,t)=>{const n=mi(),{prefixCls:r,className:o,rootClassName:a,block:l,options:s=[],size:c="middle",style:u,vertical:d,shape:f="default",name:m=n}=e,v=wg(e,["prefixCls","className","rootClassName","block","options","size","style","vertical","shape","name"]),{getPrefixCls:g,direction:h,className:p,style:b}=tn("segmented"),y=g("segmented",r),[C,$,S]=gT(y),x=Sn(c),E=i.useMemo(()=>s.map(I=>{if(pT(I)){const{icon:P,label:M}=I,R=wg(I,["icon","label"]);return Object.assign(Object.assign({},R),{label:i.createElement(i.Fragment,null,i.createElement("span",{className:`${y}-item-icon`},P),M&&i.createElement("span",null,M))})}return I}),[s,y]),O=A(o,a,p,{[`${y}-block`]:l,[`${y}-sm`]:x==="small",[`${y}-lg`]:x==="large",[`${y}-vertical`]:d,[`${y}-shape-${f}`]:f==="round"},$,S),w=Object.assign(Object.assign({},b),u);return C(i.createElement(dT,Object.assign({},v,{name:m,className:O,style:w,options:E,ref:t,prefixCls:y,direction:h,vertical:d})))}),bT=hT,eC=F.createContext({}),tC=F.createContext({}),nC=({prefixCls:e,value:t,onChange:n})=>{const r=()=>{if(n&&t&&!t.cleared){const o=t.toHsb();o.a=0;const a=Nn(o);a.cleared=!0,n(a)}};return F.createElement("div",{className:`${e}-clear`,onClick:r})},rC="hex",oC="rgb",aC="hsb";var yT={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M890.5 755.3L537.9 269.2c-12.8-17.6-39-17.6-51.7 0L133.5 755.3A8 8 0 00140 768h75c5.1 0 9.9-2.5 12.9-6.6L512 369.8l284.1 391.6c3 4.1 7.8 6.6 12.9 6.6h75c6.5 0 10.3-7.4 6.5-12.7z"}}]},name:"up",theme:"outlined"},CT=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:yT}))},ST=i.forwardRef(CT);function Ju(){return typeof BigInt=="function"}function iC(e){return!e&&e!==0&&!Number.isNaN(e)||!String(e).trim()}function go(e){var t=e.trim(),n=t.startsWith("-");n&&(t=t.slice(1)),t=t.replace(/(\.\d*[^0])0*$/,"$1").replace(/\.0*$/,"").replace(/^0+/,""),t.startsWith(".")&&(t="0".concat(t));var r=t||"0",o=r.split("."),a=o[0]||"0",l=o[1]||"0";a==="0"&&l==="0"&&(n=!1);var s=n?"-":"";return{negative:n,negativeStr:s,trimStr:r,integerStr:a,decimalStr:l,fullStr:"".concat(s).concat(r)}}function Cf(e){var t=String(e);return!Number.isNaN(Number(t))&&t.includes("e")}function fo(e){var t=String(e);if(Cf(e)){var n=Number(t.slice(t.indexOf("e-")+2)),r=t.match(/\.(\d+)/);return r!=null&&r[1]&&(n+=r[1].length),n}return t.includes(".")&&Sf(t)?t.length-t.indexOf(".")-1:0}function Ts(e){var t=String(e);if(Cf(e)){if(e>Number.MAX_SAFE_INTEGER)return String(Ju()?BigInt(e).toString():Number.MAX_SAFE_INTEGER);if(e<Number.MIN_SAFE_INTEGER)return String(Ju()?BigInt(e).toString():Number.MIN_SAFE_INTEGER);t=e.toFixed(fo(t))}return go(t).fullStr}function Sf(e){return typeof e=="number"?!Number.isNaN(e):e?/^\s*-?\d+(\.\d+)?\s*$/.test(e)||/^\s*-?\d+\.\s*$/.test(e)||/^\s*-?\.\d+\s*$/.test(e):!1}var $T=function(){function e(t){if(Zt(this,e),D(this,"origin",""),D(this,"negative",void 0),D(this,"integer",void 0),D(this,"decimal",void 0),D(this,"decimalLen",void 0),D(this,"empty",void 0),D(this,"nan",void 0),iC(t)){this.empty=!0;return}if(this.origin=String(t),t==="-"||Number.isNaN(t)){this.nan=!0;return}var n=t;if(Cf(n)&&(n=Number(n)),n=typeof n=="string"?n:Ts(n),Sf(n)){var r=go(n);this.negative=r.negative;var o=r.trimStr.split(".");this.integer=BigInt(o[0]);var a=o[1]||"0";this.decimal=BigInt(a),this.decimalLen=a.length}else this.nan=!0}return Jt(e,[{key:"getMark",value:function(){return this.negative?"-":""}},{key:"getIntegerStr",value:function(){return this.integer.toString()}},{key:"getDecimalStr",value:function(){return this.decimal.toString().padStart(this.decimalLen,"0")}},{key:"alignDecimal",value:function(n){var r="".concat(this.getMark()).concat(this.getIntegerStr()).concat(this.getDecimalStr().padEnd(n,"0"));return BigInt(r)}},{key:"negate",value:function(){var n=new e(this.toString());return n.negative=!n.negative,n}},{key:"cal",value:function(n,r,o){var a=Math.max(this.getDecimalStr().length,n.getDecimalStr().length),l=this.alignDecimal(a),s=n.alignDecimal(a),c=r(l,s).toString(),u=o(a),d=go(c),f=d.negativeStr,m=d.trimStr,v="".concat(f).concat(m.padStart(u+1,"0"));return new e("".concat(v.slice(0,-u),".").concat(v.slice(-u)))}},{key:"add",value:function(n){if(this.isInvalidate())return new e(n);var r=new e(n);return r.isInvalidate()?this:this.cal(r,function(o,a){return o+a},function(o){return o})}},{key:"multi",value:function(n){var r=new e(n);return this.isInvalidate()||r.isInvalidate()?new e(NaN):this.cal(r,function(o,a){return o*a},function(o){return o*2})}},{key:"isEmpty",value:function(){return this.empty}},{key:"isNaN",value:function(){return this.nan}},{key:"isInvalidate",value:function(){return this.isEmpty()||this.isNaN()}},{key:"equals",value:function(n){return this.toString()===(n==null?void 0:n.toString())}},{key:"lessEquals",value:function(n){return this.add(n.negate().toString()).toNumber()<=0}},{key:"toNumber",value:function(){return this.isNaN()?NaN:Number(this.toString())}},{key:"toString",value:function(){var n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!0;return n?this.isInvalidate()?"":go("".concat(this.getMark()).concat(this.getIntegerStr(),".").concat(this.getDecimalStr())).fullStr:this.origin}}]),e}(),xT=function(){function e(t){if(Zt(this,e),D(this,"origin",""),D(this,"number",void 0),D(this,"empty",void 0),iC(t)){this.empty=!0;return}this.origin=String(t),this.number=Number(t)}return Jt(e,[{key:"negate",value:function(){return new e(-this.toNumber())}},{key:"add",value:function(n){if(this.isInvalidate())return new e(n);var r=Number(n);if(Number.isNaN(r))return this;var o=this.number+r;if(o>Number.MAX_SAFE_INTEGER)return new e(Number.MAX_SAFE_INTEGER);if(o<Number.MIN_SAFE_INTEGER)return new e(Number.MIN_SAFE_INTEGER);var a=Math.max(fo(this.number),fo(r));return new e(o.toFixed(a))}},{key:"multi",value:function(n){var r=Number(n);if(this.isInvalidate()||Number.isNaN(r))return new e(NaN);var o=this.number*r;if(o>Number.MAX_SAFE_INTEGER)return new e(Number.MAX_SAFE_INTEGER);if(o<Number.MIN_SAFE_INTEGER)return new e(Number.MIN_SAFE_INTEGER);var a=Math.max(fo(this.number),fo(r));return new e(o.toFixed(a))}},{key:"isEmpty",value:function(){return this.empty}},{key:"isNaN",value:function(){return Number.isNaN(this.number)}},{key:"isInvalidate",value:function(){return this.isEmpty()||this.isNaN()}},{key:"equals",value:function(n){return this.toNumber()===(n==null?void 0:n.toNumber())}},{key:"lessEquals",value:function(n){return this.add(n.negate().toString()).toNumber()<=0}},{key:"toNumber",value:function(){return this.number}},{key:"toString",value:function(){var n=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!0;return n?this.isInvalidate()?"":Ts(this.number):this.origin}}]),e}();function dr(e){return Ju()?new $T(e):new xT(e)}function sl(e,t,n){var r=arguments.length>3&&arguments[3]!==void 0?arguments[3]:!1;if(e==="")return"";var o=go(e),a=o.negativeStr,l=o.integerStr,s=o.decimalStr,c="".concat(t).concat(s),u="".concat(a).concat(l);if(n>=0){var d=Number(s[n]);if(d>=5&&!r){var f=dr(e).add("".concat(a,"0.").concat("0".repeat(n)).concat(10-d));return sl(f.toString(),t,n,r)}return n===0?u:"".concat(u).concat(t).concat(s.padEnd(n,"0").slice(0,n))}return c===".0"?u:"".concat(u).concat(c)}function wT(e){return!!(e.addonBefore||e.addonAfter)}function ET(e){return!!(e.prefix||e.suffix||e.allowClear)}function Eg(e,t,n){var r=t.cloneNode(!0),o=Object.create(e,{target:{value:r},currentTarget:{value:r}});return r.value=n,typeof t.selectionStart=="number"&&typeof t.selectionEnd=="number"&&(r.selectionStart=t.selectionStart,r.selectionEnd=t.selectionEnd),r.setSelectionRange=function(){t.setSelectionRange.apply(t,arguments)},o}function Pl(e,t,n,r){if(n){var o=t;if(t.type==="click"){o=Eg(t,e,""),n(o);return}if(e.type!=="file"&&r!==void 0){o=Eg(t,e,r),n(o);return}n(o)}}function $f(e,t){if(e){e.focus(t);var n=t||{},r=n.cursor;if(r){var o=e.value.length;switch(r){case"start":e.setSelectionRange(0,0);break;case"end":e.setSelectionRange(o,o);break;default:e.setSelectionRange(0,o)}}}}var xf=F.forwardRef(function(e,t){var n,r,o,a=e.inputElement,l=e.children,s=e.prefixCls,c=e.prefix,u=e.suffix,d=e.addonBefore,f=e.addonAfter,m=e.className,v=e.style,g=e.disabled,h=e.readOnly,p=e.focused,b=e.triggerFocus,y=e.allowClear,C=e.value,$=e.handleReset,S=e.hidden,x=e.classes,E=e.classNames,O=e.dataAttrs,w=e.styles,I=e.components,P=e.onClear,M=l??a,R=(I==null?void 0:I.affixWrapper)||"span",N=(I==null?void 0:I.groupWrapper)||"span",T=(I==null?void 0:I.wrapper)||"span",j=(I==null?void 0:I.groupAddon)||"span",z=i.useRef(null),_=function(Z){var Q;(Q=z.current)!==null&&Q!==void 0&&Q.contains(Z.target)&&(b==null||b())},B=ET(e),V=i.cloneElement(M,{value:C,className:A((n=M.props)===null||n===void 0?void 0:n.className,!B&&(E==null?void 0:E.variant))||null}),G=i.useRef(null);if(F.useImperativeHandle(t,function(){return{nativeElement:G.current||z.current}}),B){var q=null;if(y){var H=!g&&!h&&C,W="".concat(s,"-clear-icon"),K=Qe(y)==="object"&&y!==null&&y!==void 0&&y.clearIcon?y.clearIcon:"✖";q=F.createElement("button",{type:"button",tabIndex:-1,onClick:function(Z){$==null||$(Z),P==null||P()},onMouseDown:function(Z){return Z.preventDefault()},className:A(W,D(D({},"".concat(W,"-hidden"),!H),"".concat(W,"-has-suffix"),!!u))},K)}var U="".concat(s,"-affix-wrapper"),te=A(U,D(D(D(D(D({},"".concat(s,"-disabled"),g),"".concat(U,"-disabled"),g),"".concat(U,"-focused"),p),"".concat(U,"-readonly"),h),"".concat(U,"-input-with-clear-btn"),u&&y&&C),x==null?void 0:x.affixWrapper,E==null?void 0:E.affixWrapper,E==null?void 0:E.variant),X=(u||y)&&F.createElement("span",{className:A("".concat(s,"-suffix"),E==null?void 0:E.suffix),style:w==null?void 0:w.suffix},q,u);V=F.createElement(R,ue({className:te,style:w==null?void 0:w.affixWrapper,onClick:_},O==null?void 0:O.affixWrapper,{ref:z}),c&&F.createElement("span",{className:A("".concat(s,"-prefix"),E==null?void 0:E.prefix),style:w==null?void 0:w.prefix},c),V,X)}if(wT(e)){var ae="".concat(s,"-group"),le="".concat(ae,"-addon"),ee="".concat(ae,"-wrapper"),Y=A("".concat(s,"-wrapper"),ae,x==null?void 0:x.wrapper,E==null?void 0:E.wrapper),re=A(ee,D({},"".concat(ee,"-disabled"),g),x==null?void 0:x.group,E==null?void 0:E.groupWrapper);V=F.createElement(N,{className:re,ref:G},F.createElement(T,{className:Y},d&&F.createElement(j,{className:le},d),V,f&&F.createElement(j,{className:le},f)))}return F.cloneElement(V,{className:A((r=V.props)===null||r===void 0?void 0:r.className,m)||null,style:k(k({},(o=V.props)===null||o===void 0?void 0:o.style),v),hidden:S})}),OT=["show"];function lC(e,t){return i.useMemo(function(){var n={};t&&(n.show=Qe(t)==="object"&&t.formatter?t.formatter:!!t),n=k(k({},n),e);var r=n,o=r.show,a=ft(r,OT);return k(k({},a),{},{show:!!o,showFormatter:typeof o=="function"?o:void 0,strategy:a.strategy||function(l){return l.length}})},[e,t])}var IT=["autoComplete","onChange","onFocus","onBlur","onPressEnter","onKeyDown","onKeyUp","prefixCls","disabled","htmlSize","className","maxLength","suffix","showCount","count","type","classes","classNames","styles","onCompositionStart","onCompositionEnd"],RT=i.forwardRef(function(e,t){var n=e.autoComplete,r=e.onChange,o=e.onFocus,a=e.onBlur,l=e.onPressEnter,s=e.onKeyDown,c=e.onKeyUp,u=e.prefixCls,d=u===void 0?"rc-input":u,f=e.disabled,m=e.htmlSize,v=e.className,g=e.maxLength,h=e.suffix,p=e.showCount,b=e.count,y=e.type,C=y===void 0?"text":y,$=e.classes,S=e.classNames,x=e.styles,E=e.onCompositionStart,O=e.onCompositionEnd,w=ft(e,IT),I=i.useState(!1),P=J(I,2),M=P[0],R=P[1],N=i.useRef(!1),T=i.useRef(!1),j=i.useRef(null),z=i.useRef(null),_=function(se){j.current&&$f(j.current,se)},B=Lt(e.defaultValue,{value:e.value}),V=J(B,2),G=V[0],q=V[1],H=G==null?"":String(G),W=i.useState(null),K=J(W,2),U=K[0],te=K[1],X=lC(b,p),ae=X.max||g,le=X.strategy(H),ee=!!ae&&le>ae;i.useImperativeHandle(t,function(){var ge;return{focus:_,blur:function(){var be;(be=j.current)===null||be===void 0||be.blur()},setSelectionRange:function(be,we,Me){var Te;(Te=j.current)===null||Te===void 0||Te.setSelectionRange(be,we,Me)},select:function(){var be;(be=j.current)===null||be===void 0||be.select()},input:j.current,nativeElement:((ge=z.current)===null||ge===void 0?void 0:ge.nativeElement)||j.current}}),i.useEffect(function(){T.current&&(T.current=!1),R(function(ge){return ge&&f?!1:ge})},[f]);var Y=function(se,be,we){var Me=be;if(!N.current&&X.exceedFormatter&&X.max&&X.strategy(be)>X.max){if(Me=X.exceedFormatter(be,{max:X.max}),be!==Me){var Te,Se;te([((Te=j.current)===null||Te===void 0?void 0:Te.selectionStart)||0,((Se=j.current)===null||Se===void 0?void 0:Se.selectionEnd)||0])}}else if(we.source==="compositionEnd")return;q(Me),j.current&&Pl(j.current,se,r,Me)};i.useEffect(function(){if(U){var ge;(ge=j.current)===null||ge===void 0||ge.setSelectionRange.apply(ge,pe(U))}},[U]);var re=function(se){Y(se,se.target.value,{source:"change"})},ne=function(se){N.current=!1,Y(se,se.currentTarget.value,{source:"compositionEnd"}),O==null||O(se)},Z=function(se){l&&se.key==="Enter"&&!T.current&&(T.current=!0,l(se)),s==null||s(se)},Q=function(se){se.key==="Enter"&&(T.current=!1),c==null||c(se)},ie=function(se){R(!0),o==null||o(se)},de=function(se){T.current&&(T.current=!1),R(!1),a==null||a(se)},he=function(se){q(""),_(),j.current&&Pl(j.current,se,r)},ye=ee&&"".concat(d,"-out-of-range"),oe=function(){var se=Gt(e,["prefixCls","onPressEnter","addonBefore","addonAfter","prefix","suffix","allowClear","defaultValue","showCount","count","classes","htmlSize","styles","classNames","onClear"]);return F.createElement("input",ue({autoComplete:n},se,{onChange:re,onFocus:ie,onBlur:de,onKeyDown:Z,onKeyUp:Q,className:A(d,D({},"".concat(d,"-disabled"),f),S==null?void 0:S.input),style:x==null?void 0:x.input,ref:j,size:m,type:C,onCompositionStart:function(we){N.current=!0,E==null||E(we)},onCompositionEnd:ne}))},ce=function(){var se=Number(ae)>0;if(h||X.show){var be=X.showFormatter?X.showFormatter({value:H,count:le,maxLength:ae}):"".concat(le).concat(se?" / ".concat(ae):"");return F.createElement(F.Fragment,null,X.show&&F.createElement("span",{className:A("".concat(d,"-show-count-suffix"),D({},"".concat(d,"-show-count-has-suffix"),!!h),S==null?void 0:S.count),style:k({},x==null?void 0:x.count)},be),h)}return null};return F.createElement(xf,ue({},w,{prefixCls:d,className:A(v,ye),handleReset:he,value:H,focused:M,triggerFocus:_,suffix:ce(),disabled:f,classes:$,classNames:S,styles:x,ref:z}),oe())});function PT(e,t){return typeof Proxy<"u"&&e?new Proxy(e,{get:function(r,o){if(t[o])return t[o];var a=r[o];return typeof a=="function"?a.bind(r):a}}):e}function NT(e,t){var n=i.useRef(null);function r(){try{var a=e.selectionStart,l=e.selectionEnd,s=e.value,c=s.substring(0,a),u=s.substring(l);n.current={start:a,end:l,value:s,beforeTxt:c,afterTxt:u}}catch{}}function o(){if(e&&n.current&&t)try{var a=e.value,l=n.current,s=l.beforeTxt,c=l.afterTxt,u=l.start,d=a.length;if(a.startsWith(s))d=s.length;else if(a.endsWith(c))d=a.length-n.current.afterTxt.length;else{var f=s[u-1],m=a.indexOf(f,u-1);m!==-1&&(d=m+1)}e.setSelectionRange(d,d)}catch(v){Kt(!1,"Something warning of cursor restore. Please fire issue about this: ".concat(v.message))}}return[r,o]}var MT=function(){var t=i.useState(!1),n=J(t,2),r=n[0],o=n[1];return wt(function(){o(ys())},[]),r},TT=200,jT=600;function zT(e){var t=e.prefixCls,n=e.upNode,r=e.downNode,o=e.upDisabled,a=e.downDisabled,l=e.onStep,s=i.useRef(),c=i.useRef([]),u=i.useRef();u.current=l;var d=function(){clearTimeout(s.current)},f=function(C,$){C.preventDefault(),d(),u.current($);function S(){u.current($),s.current=setTimeout(S,TT)}s.current=setTimeout(S,jT)};i.useEffect(function(){return function(){d(),c.current.forEach(function(y){return Et.cancel(y)})}},[]);var m=MT();if(m)return null;var v="".concat(t,"-handler"),g=A(v,"".concat(v,"-up"),D({},"".concat(v,"-up-disabled"),o)),h=A(v,"".concat(v,"-down"),D({},"".concat(v,"-down-disabled"),a)),p=function(){return c.current.push(Et(d))},b={unselectable:"on",role:"button",onMouseUp:p,onMouseLeave:p};return i.createElement("div",{className:"".concat(v,"-wrap")},i.createElement("span",ue({},b,{onMouseDown:function(C){f(C,!0)},"aria-label":"Increase Value","aria-disabled":o,className:g}),n||i.createElement("span",{unselectable:"on",className:"".concat(t,"-handler-up-inner")})),i.createElement("span",ue({},b,{onMouseDown:function(C){f(C,!1)},"aria-label":"Decrease Value","aria-disabled":a,className:h}),r||i.createElement("span",{unselectable:"on",className:"".concat(t,"-handler-down-inner")})))}function Og(e){var t=typeof e=="number"?Ts(e):go(e).fullStr,n=t.includes(".");return n?go(t.replace(/(\d)\.(\d)/g,"$1$2.")).fullStr:e+"0"}const DT=function(){var e=i.useRef(0),t=function(){Et.cancel(e.current)};return i.useEffect(function(){return t},[]),function(n){t(),e.current=Et(function(){n()})}};var _T=["prefixCls","className","style","min","max","step","defaultValue","value","disabled","readOnly","upHandler","downHandler","keyboard","changeOnWheel","controls","classNames","stringMode","parser","formatter","precision","decimalSeparator","onChange","onInput","onPressEnter","onStep","changeOnBlur","domRef"],BT=["disabled","style","prefixCls","value","prefix","suffix","addonBefore","addonAfter","className","classNames"],Ig=function(t,n){return t||n.isEmpty()?n.toString():n.toNumber()},Rg=function(t){var n=dr(t);return n.isInvalidate()?null:n},LT=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.className,o=e.style,a=e.min,l=e.max,s=e.step,c=s===void 0?1:s,u=e.defaultValue,d=e.value,f=e.disabled,m=e.readOnly,v=e.upHandler,g=e.downHandler,h=e.keyboard,p=e.changeOnWheel,b=p===void 0?!1:p,y=e.controls,C=y===void 0?!0:y;e.classNames;var $=e.stringMode,S=e.parser,x=e.formatter,E=e.precision,O=e.decimalSeparator,w=e.onChange,I=e.onInput,P=e.onPressEnter,M=e.onStep,R=e.changeOnBlur,N=R===void 0?!0:R,T=e.domRef,j=ft(e,_T),z="".concat(n,"-input"),_=i.useRef(null),B=i.useState(!1),V=J(B,2),G=V[0],q=V[1],H=i.useRef(!1),W=i.useRef(!1),K=i.useRef(!1),U=i.useState(function(){return dr(d??u)}),te=J(U,2),X=te[0],ae=te[1];function le(Oe){d===void 0&&ae(Oe)}var ee=i.useCallback(function(Oe,Le){if(!Le)return E>=0?E:Math.max(fo(Oe),fo(c))},[E,c]),Y=i.useCallback(function(Oe){var Le=String(Oe);if(S)return S(Le);var Ue=Le;return O&&(Ue=Ue.replace(O,".")),Ue.replace(/[^\w.-]+/g,"")},[S,O]),re=i.useRef(""),ne=i.useCallback(function(Oe,Le){if(x)return x(Oe,{userTyping:Le,input:String(re.current)});var Ue=typeof Oe=="number"?Ts(Oe):Oe;if(!Le){var ke=ee(Ue,Le);if(Sf(Ue)&&(O||ke>=0)){var Je=O||".";Ue=sl(Ue,Je,ke)}}return Ue},[x,ee,O]),Z=i.useState(function(){var Oe=u??d;return X.isInvalidate()&&["string","number"].includes(Qe(Oe))?Number.isNaN(Oe)?"":Oe:ne(X.toString(),!1)}),Q=J(Z,2),ie=Q[0],de=Q[1];re.current=ie;function he(Oe,Le){de(ne(Oe.isInvalidate()?Oe.toString(!1):Oe.toString(!Le),Le))}var ye=i.useMemo(function(){return Rg(l)},[l,E]),oe=i.useMemo(function(){return Rg(a)},[a,E]),ce=i.useMemo(function(){return!ye||!X||X.isInvalidate()?!1:ye.lessEquals(X)},[ye,X]),ge=i.useMemo(function(){return!oe||!X||X.isInvalidate()?!1:X.lessEquals(oe)},[oe,X]),se=NT(_.current,G),be=J(se,2),we=be[0],Me=be[1],Te=function(Le){return ye&&!Le.lessEquals(ye)?ye:oe&&!oe.lessEquals(Le)?oe:null},Se=function(Le){return!Te(Le)},Fe=function(Le,Ue){var ke=Le,Je=Se(ke)||ke.isEmpty();if(!ke.isEmpty()&&!Ue&&(ke=Te(ke)||ke,Je=!0),!m&&!f&&Je){var Xe=ke.toString(),He=ee(Xe,Ue);return He>=0&&(ke=dr(sl(Xe,".",He)),Se(ke)||(ke=dr(sl(Xe,".",He,!0)))),ke.equals(X)||(le(ke),w==null||w(ke.isEmpty()?null:Ig($,ke)),d===void 0&&he(ke,Ue)),ke}return X},Ce=DT(),me=function Oe(Le){if(we(),re.current=Le,de(Le),!W.current){var Ue=Y(Le),ke=dr(Ue);ke.isNaN()||Fe(ke,!0)}I==null||I(Le),Ce(function(){var Je=Le;S||(Je=Le.replace(/。/g,".")),Je!==Le&&Oe(Je)})},$e=function(){W.current=!0},Ee=function(){W.current=!1,me(_.current.value)},Ie=function(Le){me(Le.target.value)},fe=function(Le){var Ue;if(!(Le&&ce||!Le&&ge)){H.current=!1;var ke=dr(K.current?Og(c):c);Le||(ke=ke.negate());var Je=(X||dr(0)).add(ke.toString()),Xe=Fe(Je,!1);M==null||M(Ig($,Xe),{offset:K.current?Og(c):c,type:Le?"up":"down"}),(Ue=_.current)===null||Ue===void 0||Ue.focus()}},ve=function(Le){var Ue=dr(Y(ie)),ke;Ue.isNaN()?ke=Fe(X,Le):ke=Fe(Ue,Le),d!==void 0?he(X,!1):ke.isNaN()||he(ke,!1)},xe=function(){H.current=!0},Re=function(Le){var Ue=Le.key,ke=Le.shiftKey;H.current=!0,K.current=ke,Ue==="Enter"&&(W.current||(H.current=!1),ve(!1),P==null||P(Le)),h!==!1&&!W.current&&["Up","ArrowUp","Down","ArrowDown"].includes(Ue)&&(fe(Ue==="Up"||Ue==="ArrowUp"),Le.preventDefault())},it=function(){H.current=!1,K.current=!1};i.useEffect(function(){if(b&&G){var Oe=function(ke){fe(ke.deltaY<0),ke.preventDefault()},Le=_.current;if(Le)return Le.addEventListener("wheel",Oe,{passive:!1}),function(){return Le.removeEventListener("wheel",Oe)}}});var dt=function(){N&&ve(!1),q(!1),H.current=!1};return Fo(function(){X.isInvalidate()||he(X,!1)},[E,x]),Fo(function(){var Oe=dr(d);ae(Oe);var Le=dr(Y(ie));(!Oe.equals(Le)||!H.current||x)&&he(Oe,H.current)},[d]),Fo(function(){x&&Me()},[ie]),i.createElement("div",{ref:T,className:A(n,r,D(D(D(D(D({},"".concat(n,"-focused"),G),"".concat(n,"-disabled"),f),"".concat(n,"-readonly"),m),"".concat(n,"-not-a-number"),X.isNaN()),"".concat(n,"-out-of-range"),!X.isInvalidate()&&!Se(X))),style:o,onFocus:function(){q(!0)},onBlur:dt,onKeyDown:Re,onKeyUp:it,onCompositionStart:$e,onCompositionEnd:Ee,onBeforeInput:xe},C&&i.createElement(zT,{prefixCls:n,upNode:v,downNode:g,upDisabled:ce,downDisabled:ge,onStep:fe}),i.createElement("div",{className:"".concat(z,"-wrap")},i.createElement("input",ue({autoComplete:"off",role:"spinbutton","aria-valuemin":a,"aria-valuemax":l,"aria-valuenow":X.isInvalidate()?null:X.toString(),step:c},j,{ref:un(_,t),className:z,value:ie,onChange:Ie,disabled:f,readOnly:m}))))}),HT=i.forwardRef(function(e,t){var n=e.disabled,r=e.style,o=e.prefixCls,a=o===void 0?"rc-input-number":o,l=e.value,s=e.prefix,c=e.suffix,u=e.addonBefore,d=e.addonAfter,f=e.className,m=e.classNames,v=ft(e,BT),g=i.useRef(null),h=i.useRef(null),p=i.useRef(null),b=function(C){p.current&&$f(p.current,C)};return i.useImperativeHandle(t,function(){return PT(p.current,{focus:b,nativeElement:g.current.nativeElement||h.current})}),i.createElement(xf,{className:f,triggerFocus:b,prefixCls:a,value:l,disabled:n,style:r,prefix:s,suffix:c,addonAfter:d,addonBefore:u,classNames:m,components:{affixWrapper:"div",groupWrapper:"div",wrapper:"div",groupAddon:"div"},ref:g},i.createElement(LT,ue({prefixCls:a,disabled:n,ref:p,domRef:h,className:m==null?void 0:m.input},v)))});const AT=e=>{var t;const n=(t=e.handleVisible)!==null&&t!==void 0?t:"auto",r=e.controlHeightSM-e.lineWidth*2;return Object.assign(Object.assign({},ya(e)),{controlWidth:90,handleWidth:r,handleFontSize:e.fontSize/2,handleVisible:n,handleActiveBg:e.colorFillAlter,handleBg:e.colorBgContainer,filledHandleBg:new Mt(e.colorFillSecondary).onBackground(e.colorBgContainer).toHexString(),handleHoverColor:e.colorPrimary,handleBorderColor:e.colorBorder,handleOpacity:n===!0?1:0,handleVisibleWidth:n===!0?r:0})},Pg=({componentCls:e,borderRadiusSM:t,borderRadiusLG:n},r)=>{const o=r==="lg"?n:t;return{[`&-${r}`]:{[`${e}-handler-wrap`]:{borderStartEndRadius:o,borderEndEndRadius:o},[`${e}-handler-up`]:{borderStartEndRadius:o},[`${e}-handler-down`]:{borderEndEndRadius:o}}}},FT=e=>{const{componentCls:t,lineWidth:n,lineType:r,borderRadius:o,inputFontSizeSM:a,inputFontSizeLG:l,controlHeightLG:s,controlHeightSM:c,colorError:u,paddingInlineSM:d,paddingBlockSM:f,paddingBlockLG:m,paddingInlineLG:v,colorIcon:g,motionDurationMid:h,handleHoverColor:p,handleOpacity:b,paddingInline:y,paddingBlock:C,handleBg:$,handleActiveBg:S,colorTextDisabled:x,borderRadiusSM:E,borderRadiusLG:O,controlWidth:w,handleBorderColor:I,filledHandleBg:P,lineHeightLG:M,calc:R}=e;return[{[t]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),$i(e)),{display:"inline-block",width:w,margin:0,padding:0,borderRadius:o}),Oy(e,{[`${t}-handler-wrap`]:{background:$,[`${t}-handler-down`]:{borderBlockStart:`${L(n)} ${r} ${I}`}}})),Ny(e,{[`${t}-handler-wrap`]:{background:P,[`${t}-handler-down`]:{borderBlockStart:`${L(n)} ${r} ${I}`}},"&:focus-within":{[`${t}-handler-wrap`]:{background:$}}})),jy(e,{[`${t}-handler-wrap`]:{background:$,[`${t}-handler-down`]:{borderBlockStart:`${L(n)} ${r} ${I}`}}})),Ry(e)),{"&-rtl":{direction:"rtl",[`${t}-input`]:{direction:"rtl"}},"&-lg":{padding:0,fontSize:l,lineHeight:M,borderRadius:O,[`input${t}-input`]:{height:R(s).sub(R(n).mul(2)).equal(),padding:`${L(m)} ${L(v)}`}},"&-sm":{padding:0,fontSize:a,borderRadius:E,[`input${t}-input`]:{height:R(c).sub(R(n).mul(2)).equal(),padding:`${L(f)} ${L(d)}`}},"&-out-of-range":{[`${t}-input-wrap`]:{input:{color:u}}},"&-group":Object.assign(Object.assign(Object.assign({},Tt(e)),_y(e)),{"&-wrapper":Object.assign(Object.assign(Object.assign({display:"inline-block",textAlign:"start",verticalAlign:"top",[`${t}-affix-wrapper`]:{width:"100%"},"&-lg":{[`${t}-group-addon`]:{borderRadius:O,fontSize:e.fontSizeLG}},"&-sm":{[`${t}-group-addon`]:{borderRadius:E}}},Iy(e)),My(e)),{[`&:not(${t}-compact-first-item):not(${t}-compact-last-item)${t}-compact-item`]:{[`${t}, ${t}-group-addon`]:{borderRadius:0}},[`&:not(${t}-compact-last-item)${t}-compact-first-item`]:{[`${t}, ${t}-group-addon`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`&:not(${t}-compact-first-item)${t}-compact-last-item`]:{[`${t}, ${t}-group-addon`]:{borderStartStartRadius:0,borderEndStartRadius:0}}})}),[`&-disabled ${t}-input`]:{cursor:"not-allowed"},[t]:{"&-input":Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),{width:"100%",padding:`${L(C)} ${L(y)}`,textAlign:"start",backgroundColor:"transparent",border:0,borderRadius:o,outline:0,transition:`all ${h} linear`,appearance:"textfield",fontSize:"inherit"}),zy(e.colorTextPlaceholder)),{'&[type="number"]::-webkit-inner-spin-button, &[type="number"]::-webkit-outer-spin-button':{margin:0,appearance:"none"}})},[`&:hover ${t}-handler-wrap, &-focused ${t}-handler-wrap`]:{width:e.handleWidth,opacity:1}})},{[t]:Object.assign(Object.assign(Object.assign({[`${t}-handler-wrap`]:{position:"absolute",insetBlockStart:0,insetInlineEnd:0,width:e.handleVisibleWidth,opacity:b,height:"100%",borderStartStartRadius:0,borderStartEndRadius:o,borderEndEndRadius:o,borderEndStartRadius:0,display:"flex",flexDirection:"column",alignItems:"stretch",transition:`all ${h}`,overflow:"hidden",[`${t}-handler`]:{display:"flex",alignItems:"center",justifyContent:"center",flex:"auto",height:"40%",[`
              ${t}-handler-up-inner,
              ${t}-handler-down-inner
            `]:{marginInlineEnd:0,fontSize:e.handleFontSize}}},[`${t}-handler`]:{height:"50%",overflow:"hidden",color:g,fontWeight:"bold",lineHeight:0,textAlign:"center",cursor:"pointer",borderInlineStart:`${L(n)} ${r} ${I}`,transition:`all ${h} linear`,"&:active":{background:S},"&:hover":{height:"60%",[`
              ${t}-handler-up-inner,
              ${t}-handler-down-inner
            `]:{color:p}},"&-up-inner, &-down-inner":Object.assign(Object.assign({},xo()),{color:g,transition:`all ${h} linear`,userSelect:"none"})},[`${t}-handler-up`]:{borderStartEndRadius:o},[`${t}-handler-down`]:{borderEndEndRadius:o}},Pg(e,"lg")),Pg(e,"sm")),{"&-disabled, &-readonly":{[`${t}-handler-wrap`]:{display:"none"},[`${t}-input`]:{color:"inherit"}},[`
          ${t}-handler-up-disabled,
          ${t}-handler-down-disabled
        `]:{cursor:"not-allowed"},[`
          ${t}-handler-up-disabled:hover &-handler-up-inner,
          ${t}-handler-down-disabled:hover &-handler-down-inner
        `]:{color:x}})}]},kT=e=>{const{componentCls:t,paddingBlock:n,paddingInline:r,inputAffixPadding:o,controlWidth:a,borderRadiusLG:l,borderRadiusSM:s,paddingInlineLG:c,paddingInlineSM:u,paddingBlockLG:d,paddingBlockSM:f,motionDurationMid:m}=e;return{[`${t}-affix-wrapper`]:Object.assign(Object.assign({[`input${t}-input`]:{padding:`${L(n)} 0`}},$i(e)),{position:"relative",display:"inline-flex",alignItems:"center",width:a,padding:0,paddingInlineStart:r,"&-lg":{borderRadius:l,paddingInlineStart:c,[`input${t}-input`]:{padding:`${L(d)} 0`}},"&-sm":{borderRadius:s,paddingInlineStart:u,[`input${t}-input`]:{padding:`${L(f)} 0`}},[`&:not(${t}-disabled):hover`]:{zIndex:1},"&-focused, &:focus":{zIndex:1},[`&-disabled > ${t}-disabled`]:{background:"transparent"},[`> div${t}`]:{width:"100%",border:"none",outline:"none",[`&${t}-focused`]:{boxShadow:"none !important"}},"&::before":{display:"inline-block",width:0,visibility:"hidden",content:'"\\a0"'},[`${t}-handler-wrap`]:{zIndex:2},[t]:{position:"static",color:"inherit","&-prefix, &-suffix":{display:"flex",flex:"none",alignItems:"center",pointerEvents:"none"},"&-prefix":{marginInlineEnd:o},"&-suffix":{insetBlockStart:0,insetInlineEnd:0,height:"100%",marginInlineEnd:r,marginInlineStart:o,transition:`margin ${m}`}},[`&:hover ${t}-handler-wrap, &-focused ${t}-handler-wrap`]:{width:e.handleWidth,opacity:1},[`&:not(${t}-affix-wrapper-without-controls):hover ${t}-suffix`]:{marginInlineEnd:e.calc(e.handleWidth).add(r).equal()}}),[`${t}-underlined`]:{borderRadius:0}}},VT=It("InputNumber",e=>{const t=yt(e,ba(e));return[FT(t),kT(t),di(t)]},AT,{unitless:{handleOpacity:!0},resetFont:!1});var WT=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const sC=i.forwardRef((e,t)=>{const{getPrefixCls:n,direction:r}=i.useContext(ot),o=i.useRef(null);i.useImperativeHandle(t,()=>o.current);const{className:a,rootClassName:l,size:s,disabled:c,prefixCls:u,addonBefore:d,addonAfter:f,prefix:m,suffix:v,bordered:g,readOnly:h,status:p,controls:b,variant:y}=e,C=WT(e,["className","rootClassName","size","disabled","prefixCls","addonBefore","addonAfter","prefix","suffix","bordered","readOnly","status","controls","variant"]),$=n("input-number",u),S=Cn($),[x,E,O]=VT($,S),{compactSize:w,compactItemClassnames:I}=ro($,r);let P=i.createElement(ST,{className:`${$}-handler-up-inner`}),M=i.createElement(ef,{className:`${$}-handler-down-inner`});const R=typeof b=="boolean"?b:void 0;typeof b=="object"&&(P=typeof b.upIcon>"u"?P:i.createElement("span",{className:`${$}-handler-up-inner`},b.upIcon),M=typeof b.downIcon>"u"?M:i.createElement("span",{className:`${$}-handler-down-inner`},b.downIcon));const{hasFeedback:N,status:T,isFormItemInput:j,feedbackIcon:z}=i.useContext(Wn),_=bi(T,p),B=Sn(X=>{var ae;return(ae=s??w)!==null&&ae!==void 0?ae:X}),V=i.useContext(Ln),G=c??V,[q,H]=yi("inputNumber",y,g),W=N&&i.createElement(i.Fragment,null,z),K=A({[`${$}-lg`]:B==="large",[`${$}-sm`]:B==="small",[`${$}-rtl`]:r==="rtl",[`${$}-in-form-item`]:j},E),U=`${$}-group`,te=i.createElement(HT,Object.assign({ref:o,disabled:G,className:A(O,S,a,l,I),upHandler:P,downHandler:M,prefixCls:$,readOnly:h,controls:R,prefix:m,suffix:W||v,addonBefore:d&&i.createElement(jr,{form:!0,space:!0},d),addonAfter:f&&i.createElement(jr,{form:!0,space:!0},f),classNames:{input:K,variant:A({[`${$}-${q}`]:H},yo($,_,N)),affixWrapper:A({[`${$}-affix-wrapper-sm`]:B==="small",[`${$}-affix-wrapper-lg`]:B==="large",[`${$}-affix-wrapper-rtl`]:r==="rtl",[`${$}-affix-wrapper-without-controls`]:b===!1||G||h},E),wrapper:A({[`${U}-rtl`]:r==="rtl"},E),groupWrapper:A({[`${$}-group-wrapper-sm`]:B==="small",[`${$}-group-wrapper-lg`]:B==="large",[`${$}-group-wrapper-rtl`]:r==="rtl",[`${$}-group-wrapper-${q}`]:H},yo(`${$}-group-wrapper`,_,N),E)}},C));return x(te)}),cC=sC,KT=e=>i.createElement(wr,{theme:{components:{InputNumber:{handleVisible:!0}}}},i.createElement(sC,Object.assign({},e)));cC._InternalPanelDoNotUseOrYouWillBeFired=KT;const po=({prefixCls:e,min:t=0,max:n=100,value:r,onChange:o,className:a,formatter:l})=>{const s=`${e}-steppers`,[c,u]=i.useState(0),d=Number.isNaN(r)?c:r;return F.createElement(cC,{className:A(s,a),min:t,max:n,value:d,formatter:l,size:"small",onChange:f=>{u(f||0),o==null||o(f)}})},GT=({prefixCls:e,value:t,onChange:n})=>{const r=`${e}-alpha-input`,[o,a]=i.useState(()=>Nn(t||"#000")),l=t||o,s=c=>{const u=l.toHsb();u.a=(c||0)/100;const d=Nn(u);a(d),n==null||n(d)};return F.createElement(po,{value:kd(l),prefixCls:e,formatter:c=>`${c}%`,className:r,onChange:s})},uC=e=>{let t;return typeof e=="object"&&(e!=null&&e.clearIcon)?t=e:e&&(t={clearIcon:F.createElement(wo,null)}),t};function dC(e,t){const n=i.useRef([]),r=()=>{n.current.push(setTimeout(()=>{var o,a,l,s;!((o=e.current)===null||o===void 0)&&o.input&&((a=e.current)===null||a===void 0?void 0:a.input.getAttribute("type"))==="password"&&(!((l=e.current)===null||l===void 0)&&l.input.hasAttribute("value"))&&((s=e.current)===null||s===void 0||s.input.removeAttribute("value"))}))};return i.useEffect(()=>(t&&r(),()=>n.current.forEach(o=>{o&&clearTimeout(o)})),[]),r}function qT(e){return!!(e.prefix||e.suffix||e.allowClear||e.showCount)}var UT=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Ca=i.forwardRef((e,t)=>{const{prefixCls:n,bordered:r=!0,status:o,size:a,disabled:l,onBlur:s,onFocus:c,suffix:u,allowClear:d,addonAfter:f,addonBefore:m,className:v,style:g,styles:h,rootClassName:p,onChange:b,classNames:y,variant:C}=e,$=UT(e,["prefixCls","bordered","status","size","disabled","onBlur","onFocus","suffix","allowClear","addonAfter","addonBefore","className","style","styles","rootClassName","onChange","classNames","variant"]),{getPrefixCls:S,direction:x,allowClear:E,autoComplete:O,className:w,style:I,classNames:P,styles:M}=tn("input"),R=S("input",n),N=i.useRef(null),T=Cn(R),[j,z,_]=By(R,p),[B]=Ly(R,T),{compactSize:V,compactItemClassnames:G}=ro(R,x),q=Sn(de=>{var he;return(he=a??V)!==null&&he!==void 0?he:de}),H=F.useContext(Ln),W=l??H,{status:K,hasFeedback:U,feedbackIcon:te}=i.useContext(Wn),X=bi(K,o),ae=qT(e)||!!U;i.useRef(ae);const le=dC(N,!0),ee=de=>{le(),s==null||s(de)},Y=de=>{le(),c==null||c(de)},re=de=>{le(),b==null||b(de)},ne=(U||u)&&F.createElement(F.Fragment,null,u,U&&te),Z=uC(d??E),[Q,ie]=yi("input",C,r);return j(B(F.createElement(RT,Object.assign({ref:un(t,N),prefixCls:R,autoComplete:O},$,{disabled:W,onBlur:ee,onFocus:Y,style:Object.assign(Object.assign({},I),g),styles:Object.assign(Object.assign({},M),h),suffix:ne,allowClear:Z,className:A(v,p,_,T,G,w),onChange:re,addonBefore:m&&F.createElement(jr,{form:!0,space:!0},m),addonAfter:f&&F.createElement(jr,{form:!0,space:!0},f),classNames:Object.assign(Object.assign(Object.assign({},y),P),{input:A({[`${R}-sm`]:q==="small",[`${R}-lg`]:q==="large",[`${R}-rtl`]:x==="rtl"},y==null?void 0:y.input,P.input,z),variant:A({[`${R}-${Q}`]:ie},yo(R,X)),affixWrapper:A({[`${R}-affix-wrapper-sm`]:q==="small",[`${R}-affix-wrapper-lg`]:q==="large",[`${R}-affix-wrapper-rtl`]:x==="rtl"},z),wrapper:A({[`${R}-group-rtl`]:x==="rtl"},z),groupWrapper:A({[`${R}-group-wrapper-sm`]:q==="small",[`${R}-group-wrapper-lg`]:q==="large",[`${R}-group-wrapper-rtl`]:x==="rtl",[`${R}-group-wrapper-${Q}`]:ie},yo(`${R}-group-wrapper`,X,U),z)})}))))}),XT=/(^#[\da-f]{6}$)|(^#[\da-f]{8}$)/i,YT=e=>XT.test(`#${e}`),QT=({prefixCls:e,value:t,onChange:n})=>{const r=`${e}-hex-input`,[o,a]=i.useState(()=>t?ja(t.toHexString()):void 0);i.useEffect(()=>{t&&a(ja(t.toHexString()))},[t]);const l=s=>{const c=s.target.value;a(ja(c)),YT(ja(c,!0))&&(n==null||n(Nn(c)))};return F.createElement(Ca,{className:r,value:o,prefix:"#",onChange:l,size:"small"})},ZT=({prefixCls:e,value:t,onChange:n})=>{const r=`${e}-hsb-input`,[o,a]=i.useState(()=>Nn(t||"#000")),l=t||o,s=(c,u)=>{const d=l.toHsb();d[u]=u==="h"?c:(c||0)/100;const f=Nn(d);a(f),n==null||n(f)};return F.createElement("div",{className:r},F.createElement(po,{max:360,min:0,value:Number(l.toHsb().h),prefixCls:e,className:r,formatter:c=>rl(c||0).toString(),onChange:c=>s(Number(c),"h")}),F.createElement(po,{max:100,min:0,value:Number(l.toHsb().s)*100,prefixCls:e,className:r,formatter:c=>`${rl(c||0)}%`,onChange:c=>s(Number(c),"s")}),F.createElement(po,{max:100,min:0,value:Number(l.toHsb().b)*100,prefixCls:e,className:r,formatter:c=>`${rl(c||0)}%`,onChange:c=>s(Number(c),"b")}))},JT=({prefixCls:e,value:t,onChange:n})=>{const r=`${e}-rgb-input`,[o,a]=i.useState(()=>Nn(t||"#000")),l=t||o,s=(c,u)=>{const d=l.toRgb();d[u]=c||0;const f=Nn(d);a(f),n==null||n(f)};return F.createElement("div",{className:r},F.createElement(po,{max:255,min:0,value:Number(l.toRgb().r),prefixCls:e,className:r,onChange:c=>s(Number(c),"r")}),F.createElement(po,{max:255,min:0,value:Number(l.toRgb().g),prefixCls:e,className:r,onChange:c=>s(Number(c),"g")}),F.createElement(po,{max:255,min:0,value:Number(l.toRgb().b),prefixCls:e,className:r,onChange:c=>s(Number(c),"b")}))},e5=[rC,aC,oC].map(e=>({value:e,label:e.toUpperCase()})),t5=e=>{const{prefixCls:t,format:n,value:r,disabledAlpha:o,onFormatChange:a,onChange:l,disabledFormat:s}=e,[c,u]=Lt(rC,{value:n,onChange:a}),d=`${t}-input`,f=v=>{u(v)},m=i.useMemo(()=>{const v={value:r,prefixCls:t,onChange:l};switch(c){case aC:return F.createElement(ZT,Object.assign({},v));case oC:return F.createElement(JT,Object.assign({},v));default:return F.createElement(QT,Object.assign({},v))}},[c,t,r,l]);return F.createElement("div",{className:`${d}-container`},!s&&F.createElement(Eo,{value:c,variant:"borderless",getPopupContainer:v=>v,popupMatchSelectWidth:68,placement:"bottomRight",onChange:f,className:`${t}-format-select`,size:"small",options:e5}),F.createElement("div",{className:d},m),!o&&F.createElement(GT,{prefixCls:t,value:r,onChange:l}))};function ed(e,t,n){return(e-t)/(n-t)}function wf(e,t,n,r){var o=ed(t,n,r),a={};switch(e){case"rtl":a.right="".concat(o*100,"%"),a.transform="translateX(50%)";break;case"btt":a.bottom="".concat(o*100,"%"),a.transform="translateY(50%)";break;case"ttb":a.top="".concat(o*100,"%"),a.transform="translateY(-50%)";break;default:a.left="".concat(o*100,"%"),a.transform="translateX(-50%)";break}return a}function so(e,t){return Array.isArray(e)?e[t]:e}var Oo=i.createContext({min:0,max:0,direction:"ltr",step:1,includedStart:0,includedEnd:0,tabIndex:0,keyboard:!0,styles:{},classNames:{}}),fC=i.createContext({}),n5=["prefixCls","value","valueIndex","onStartMove","onDelete","style","render","dragging","draggingDelete","onOffsetChange","onChangeComplete","onFocus","onMouseEnter"],Ng=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.value,o=e.valueIndex,a=e.onStartMove,l=e.onDelete,s=e.style,c=e.render,u=e.dragging,d=e.draggingDelete,f=e.onOffsetChange,m=e.onChangeComplete,v=e.onFocus,g=e.onMouseEnter,h=ft(e,n5),p=i.useContext(Oo),b=p.min,y=p.max,C=p.direction,$=p.disabled,S=p.keyboard,x=p.range,E=p.tabIndex,O=p.ariaLabelForHandle,w=p.ariaLabelledByForHandle,I=p.ariaRequired,P=p.ariaValueTextFormatterForHandle,M=p.styles,R=p.classNames,N="".concat(n,"-handle"),T=function(K){$||a(K,o)},j=function(K){v==null||v(K,o)},z=function(K){g(K,o)},_=function(K){if(!$&&S){var U=null;switch(K.which||K.keyCode){case Ne.LEFT:U=C==="ltr"||C==="btt"?-1:1;break;case Ne.RIGHT:U=C==="ltr"||C==="btt"?1:-1;break;case Ne.UP:U=C!=="ttb"?1:-1;break;case Ne.DOWN:U=C!=="ttb"?-1:1;break;case Ne.HOME:U="min";break;case Ne.END:U="max";break;case Ne.PAGE_UP:U=2;break;case Ne.PAGE_DOWN:U=-2;break;case Ne.BACKSPACE:case Ne.DELETE:l(o);break}U!==null&&(K.preventDefault(),f(U,o))}},B=function(K){switch(K.which||K.keyCode){case Ne.LEFT:case Ne.RIGHT:case Ne.UP:case Ne.DOWN:case Ne.HOME:case Ne.END:case Ne.PAGE_UP:case Ne.PAGE_DOWN:m==null||m();break}},V=wf(C,r,b,y),G={};if(o!==null){var q;G={tabIndex:$?null:so(E,o),role:"slider","aria-valuemin":b,"aria-valuemax":y,"aria-valuenow":r,"aria-disabled":$,"aria-label":so(O,o),"aria-labelledby":so(w,o),"aria-required":so(I,o),"aria-valuetext":(q=so(P,o))===null||q===void 0?void 0:q(r),"aria-orientation":C==="ltr"||C==="rtl"?"horizontal":"vertical",onMouseDown:T,onTouchStart:T,onFocus:j,onMouseEnter:z,onKeyDown:_,onKeyUp:B}}var H=i.createElement("div",ue({ref:t,className:A(N,D(D(D({},"".concat(N,"-").concat(o+1),o!==null&&x),"".concat(N,"-dragging"),u),"".concat(N,"-dragging-delete"),d),R.handle),style:k(k(k({},V),s),M.handle)},G,h));return c&&(H=c(H,{index:o,prefixCls:n,value:r,dragging:u,draggingDelete:d})),H}),r5=["prefixCls","style","onStartMove","onOffsetChange","values","handleRender","activeHandleRender","draggingIndex","draggingDelete","onFocus"],o5=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.style,o=e.onStartMove,a=e.onOffsetChange,l=e.values,s=e.handleRender,c=e.activeHandleRender,u=e.draggingIndex,d=e.draggingDelete,f=e.onFocus,m=ft(e,r5),v=i.useRef({}),g=i.useState(!1),h=J(g,2),p=h[0],b=h[1],y=i.useState(-1),C=J(y,2),$=C[0],S=C[1],x=function(P){S(P),b(!0)},E=function(P,M){x(M),f==null||f(P)},O=function(P,M){x(M)};i.useImperativeHandle(t,function(){return{focus:function(P){var M;(M=v.current[P])===null||M===void 0||M.focus()},hideHelp:function(){Pr.flushSync(function(){b(!1)})}}});var w=k({prefixCls:n,onStartMove:o,onOffsetChange:a,render:s,onFocus:E,onMouseEnter:O},m);return i.createElement(i.Fragment,null,l.map(function(I,P){var M=u===P;return i.createElement(Ng,ue({ref:function(N){N?v.current[P]=N:delete v.current[P]},dragging:M,draggingDelete:M&&d,style:so(r,P),key:P,value:I,valueIndex:P},w))}),c&&p&&i.createElement(Ng,ue({key:"a11y"},w,{value:l[$],valueIndex:null,dragging:u!==-1,draggingDelete:d,render:c,style:{pointerEvents:"none"},tabIndex:null,"aria-hidden":!0})))}),a5=function(t){var n=t.prefixCls,r=t.style,o=t.children,a=t.value,l=t.onClick,s=i.useContext(Oo),c=s.min,u=s.max,d=s.direction,f=s.includedStart,m=s.includedEnd,v=s.included,g="".concat(n,"-text"),h=wf(d,a,c,u);return i.createElement("span",{className:A(g,D({},"".concat(g,"-active"),v&&f<=a&&a<=m)),style:k(k({},h),r),onMouseDown:function(b){b.stopPropagation()},onClick:function(){l(a)}},o)},i5=function(t){var n=t.prefixCls,r=t.marks,o=t.onClick,a="".concat(n,"-mark");return r.length?i.createElement("div",{className:a},r.map(function(l){var s=l.value,c=l.style,u=l.label;return i.createElement(a5,{key:s,prefixCls:a,style:c,value:s,onClick:o},u)})):null},l5=function(t){var n=t.prefixCls,r=t.value,o=t.style,a=t.activeStyle,l=i.useContext(Oo),s=l.min,c=l.max,u=l.direction,d=l.included,f=l.includedStart,m=l.includedEnd,v="".concat(n,"-dot"),g=d&&f<=r&&r<=m,h=k(k({},wf(u,r,s,c)),typeof o=="function"?o(r):o);return g&&(h=k(k({},h),typeof a=="function"?a(r):a)),i.createElement("span",{className:A(v,D({},"".concat(v,"-active"),g)),style:h})},s5=function(t){var n=t.prefixCls,r=t.marks,o=t.dots,a=t.style,l=t.activeStyle,s=i.useContext(Oo),c=s.min,u=s.max,d=s.step,f=i.useMemo(function(){var m=new Set;if(r.forEach(function(g){m.add(g.value)}),o&&d!==null)for(var v=c;v<=u;)m.add(v),v+=d;return Array.from(m)},[c,u,d,o,r]);return i.createElement("div",{className:"".concat(n,"-step")},f.map(function(m){return i.createElement(l5,{prefixCls:n,key:m,value:m,style:a,activeStyle:l})}))},Mg=function(t){var n=t.prefixCls,r=t.style,o=t.start,a=t.end,l=t.index,s=t.onStartMove,c=t.replaceCls,u=i.useContext(Oo),d=u.direction,f=u.min,m=u.max,v=u.disabled,g=u.range,h=u.classNames,p="".concat(n,"-track"),b=ed(o,f,m),y=ed(a,f,m),C=function(E){!v&&s&&s(E,-1)},$={};switch(d){case"rtl":$.right="".concat(b*100,"%"),$.width="".concat(y*100-b*100,"%");break;case"btt":$.bottom="".concat(b*100,"%"),$.height="".concat(y*100-b*100,"%");break;case"ttb":$.top="".concat(b*100,"%"),$.height="".concat(y*100-b*100,"%");break;default:$.left="".concat(b*100,"%"),$.width="".concat(y*100-b*100,"%")}var S=c||A(p,D(D({},"".concat(p,"-").concat(l+1),l!==null&&g),"".concat(n,"-track-draggable"),s),h.track);return i.createElement("div",{className:S,style:k(k({},$),r),onMouseDown:C,onTouchStart:C})},c5=function(t){var n=t.prefixCls,r=t.style,o=t.values,a=t.startPoint,l=t.onStartMove,s=i.useContext(Oo),c=s.included,u=s.range,d=s.min,f=s.styles,m=s.classNames,v=i.useMemo(function(){if(!u){if(o.length===0)return[];var h=a??d,p=o[0];return[{start:Math.min(h,p),end:Math.max(h,p)}]}for(var b=[],y=0;y<o.length-1;y+=1)b.push({start:o[y],end:o[y+1]});return b},[o,u,a,d]);if(!c)return null;var g=v!=null&&v.length&&(m.tracks||f.tracks)?i.createElement(Mg,{index:null,prefixCls:n,start:v[0].start,end:v[v.length-1].end,replaceCls:A(m.tracks,"".concat(n,"-tracks")),style:f.tracks}):null;return i.createElement(i.Fragment,null,g,v.map(function(h,p){var b=h.start,y=h.end;return i.createElement(Mg,{index:p,prefixCls:n,style:k(k({},so(r,p)),f.track),start:b,end:y,key:p,onStartMove:l})}))},u5=130;function Tg(e){var t="targetTouches"in e?e.targetTouches[0]:e;return{pageX:t.pageX,pageY:t.pageY}}function d5(e,t,n,r,o,a,l,s,c,u,d){var f=i.useState(null),m=J(f,2),v=m[0],g=m[1],h=i.useState(-1),p=J(h,2),b=p[0],y=p[1],C=i.useState(!1),$=J(C,2),S=$[0],x=$[1],E=i.useState(n),O=J(E,2),w=O[0],I=O[1],P=i.useState(n),M=J(P,2),R=M[0],N=M[1],T=i.useRef(null),j=i.useRef(null),z=i.useRef(null),_=i.useContext(fC),B=_.onDragStart,V=_.onDragChange;wt(function(){b===-1&&I(n)},[n,b]),i.useEffect(function(){return function(){document.removeEventListener("mousemove",T.current),document.removeEventListener("mouseup",j.current),z.current&&(z.current.removeEventListener("touchmove",T.current),z.current.removeEventListener("touchend",j.current))}},[]);var G=function(U,te,X){te!==void 0&&g(te),I(U);var ae=U;X&&(ae=U.filter(function(le,ee){return ee!==b})),l(ae),V&&V({rawValues:U,deleteIndex:X?b:-1,draggingIndex:b,draggingValue:te})},q=Nt(function(K,U,te){if(K===-1){var X=R[0],ae=R[R.length-1],le=r-X,ee=o-ae,Y=U*(o-r);Y=Math.max(Y,le),Y=Math.min(Y,ee);var re=a(X+Y);Y=re-X;var ne=R.map(function(de){return de+Y});G(ne)}else{var Z=(o-r)*U,Q=pe(w);Q[K]=R[K];var ie=c(Q,Z,K,"dist");G(ie.values,ie.value,te)}}),H=function(U,te,X){U.stopPropagation();var ae=X||n,le=ae[te];y(te),g(le),N(ae),I(ae),x(!1);var ee=Tg(U),Y=ee.pageX,re=ee.pageY,ne=!1;B&&B({rawValues:ae,draggingIndex:te,draggingValue:le});var Z=function(de){de.preventDefault();var he=Tg(de),ye=he.pageX,oe=he.pageY,ce=ye-Y,ge=oe-re,se=e.current.getBoundingClientRect(),be=se.width,we=se.height,Me,Te;switch(t){case"btt":Me=-ge/we,Te=ce;break;case"ttb":Me=ge/we,Te=ce;break;case"rtl":Me=-ce/be,Te=ge;break;default:Me=ce/be,Te=ge}ne=u?Math.abs(Te)>u5&&d<w.length:!1,x(ne),q(te,Me,ne)},Q=function ie(de){de.preventDefault(),document.removeEventListener("mouseup",ie),document.removeEventListener("mousemove",Z),z.current&&(z.current.removeEventListener("touchmove",T.current),z.current.removeEventListener("touchend",j.current)),T.current=null,j.current=null,z.current=null,s(ne),y(-1),x(!1)};document.addEventListener("mouseup",Q),document.addEventListener("mousemove",Z),U.currentTarget.addEventListener("touchend",Q),U.currentTarget.addEventListener("touchmove",Z),T.current=Z,j.current=Q,z.current=U.currentTarget},W=i.useMemo(function(){var K=pe(n).sort(function(le,ee){return le-ee}),U=pe(w).sort(function(le,ee){return le-ee}),te={};U.forEach(function(le){te[le]=(te[le]||0)+1}),K.forEach(function(le){te[le]=(te[le]||0)-1});var X=u?1:0,ae=Object.values(te).reduce(function(le,ee){return le+Math.abs(ee)},0);return ae<=X?w:n},[n,w,u]);return[b,v,S,W,H]}function f5(e,t,n,r,o,a){var l=i.useCallback(function(v){return Math.max(e,Math.min(t,v))},[e,t]),s=i.useCallback(function(v){if(n!==null){var g=e+Math.round((l(v)-e)/n)*n,h=function(C){return(String(C).split(".")[1]||"").length},p=Math.max(h(n),h(t),h(e)),b=Number(g.toFixed(p));return e<=b&&b<=t?b:null}return null},[n,e,t,l]),c=i.useCallback(function(v){var g=l(v),h=r.map(function(y){return y.value});n!==null&&h.push(s(v)),h.push(e,t);var p=h[0],b=t-e;return h.forEach(function(y){var C=Math.abs(g-y);C<=b&&(p=y,b=C)}),p},[e,t,r,n,l,s]),u=function v(g,h,p){var b=arguments.length>3&&arguments[3]!==void 0?arguments[3]:"unit";if(typeof h=="number"){var y,C=g[p],$=C+h,S=[];r.forEach(function(I){S.push(I.value)}),S.push(e,t),S.push(s(C));var x=h>0?1:-1;b==="unit"?S.push(s(C+x*n)):S.push(s($)),S=S.filter(function(I){return I!==null}).filter(function(I){return h<0?I<=C:I>=C}),b==="unit"&&(S=S.filter(function(I){return I!==C}));var E=b==="unit"?C:$;y=S[0];var O=Math.abs(y-E);if(S.forEach(function(I){var P=Math.abs(I-E);P<O&&(y=I,O=P)}),y===void 0)return h<0?e:t;if(b==="dist")return y;if(Math.abs(h)>1){var w=pe(g);return w[p]=y,v(w,h-x,p,b)}return y}else{if(h==="min")return e;if(h==="max")return t}},d=function(g,h,p){var b=arguments.length>3&&arguments[3]!==void 0?arguments[3]:"unit",y=g[p],C=u(g,h,p,b);return{value:C,changed:C!==y}},f=function(g){return a===null&&g===0||typeof a=="number"&&g<a},m=function(g,h,p){var b=arguments.length>3&&arguments[3]!==void 0?arguments[3]:"unit",y=g.map(c),C=y[p],$=u(y,h,p,b);if(y[p]=$,o===!1){var S=a||0;p>0&&y[p-1]!==C&&(y[p]=Math.max(y[p],y[p-1]+S)),p<y.length-1&&y[p+1]!==C&&(y[p]=Math.min(y[p],y[p+1]-S))}else if(typeof a=="number"||a===null){for(var x=p+1;x<y.length;x+=1)for(var E=!0;f(y[x]-y[x-1])&&E;){var O=d(y,1,x);y[x]=O.value,E=O.changed}for(var w=p;w>0;w-=1)for(var I=!0;f(y[w]-y[w-1])&&I;){var P=d(y,-1,w-1);y[w-1]=P.value,I=P.changed}for(var M=y.length-1;M>0;M-=1)for(var R=!0;f(y[M]-y[M-1])&&R;){var N=d(y,-1,M-1);y[M-1]=N.value,R=N.changed}for(var T=0;T<y.length-1;T+=1)for(var j=!0;f(y[T+1]-y[T])&&j;){var z=d(y,1,T+1);y[T+1]=z.value,j=z.changed}}return{value:y[p],values:y}};return[c,m]}function m5(e){return i.useMemo(function(){if(e===!0||!e)return[!!e,!1,!1,0];var t=e.editable,n=e.draggableTrack,r=e.minCount,o=e.maxCount;return[!0,t,!t&&n,r||0,o]},[e])}var v5=i.forwardRef(function(e,t){var n=e.prefixCls,r=n===void 0?"rc-slider":n,o=e.className,a=e.style,l=e.classNames,s=e.styles,c=e.id,u=e.disabled,d=u===void 0?!1:u,f=e.keyboard,m=f===void 0?!0:f,v=e.autoFocus,g=e.onFocus,h=e.onBlur,p=e.min,b=p===void 0?0:p,y=e.max,C=y===void 0?100:y,$=e.step,S=$===void 0?1:$,x=e.value,E=e.defaultValue,O=e.range,w=e.count,I=e.onChange,P=e.onBeforeChange,M=e.onAfterChange,R=e.onChangeComplete,N=e.allowCross,T=N===void 0?!0:N,j=e.pushable,z=j===void 0?!1:j,_=e.reverse,B=e.vertical,V=e.included,G=V===void 0?!0:V,q=e.startPoint,H=e.trackStyle,W=e.handleStyle,K=e.railStyle,U=e.dotStyle,te=e.activeDotStyle,X=e.marks,ae=e.dots,le=e.handleRender,ee=e.activeHandleRender,Y=e.track,re=e.tabIndex,ne=re===void 0?0:re,Z=e.ariaLabelForHandle,Q=e.ariaLabelledByForHandle,ie=e.ariaRequired,de=e.ariaValueTextFormatterForHandle,he=i.useRef(null),ye=i.useRef(null),oe=i.useMemo(function(){return B?_?"ttb":"btt":_?"rtl":"ltr"},[_,B]),ce=m5(O),ge=J(ce,5),se=ge[0],be=ge[1],we=ge[2],Me=ge[3],Te=ge[4],Se=i.useMemo(function(){return isFinite(b)?b:0},[b]),Fe=i.useMemo(function(){return isFinite(C)?C:100},[C]),Ce=i.useMemo(function(){return S!==null&&S<=0?1:S},[S]),me=i.useMemo(function(){return typeof z=="boolean"?z?Ce:!1:z>=0?z:!1},[z,Ce]),$e=i.useMemo(function(){return Object.keys(X||{}).map(function(Ge){var Be=X[Ge],ze={value:Number(Ge)};return Be&&Qe(Be)==="object"&&!i.isValidElement(Be)&&("label"in Be||"style"in Be)?(ze.style=Be.style,ze.label=Be.label):ze.label=Be,ze}).filter(function(Ge){var Be=Ge.label;return Be||typeof Be=="number"}).sort(function(Ge,Be){return Ge.value-Be.value})},[X]),Ee=f5(Se,Fe,Ce,$e,T,me),Ie=J(Ee,2),fe=Ie[0],ve=Ie[1],xe=Lt(E,{value:x}),Re=J(xe,2),it=Re[0],dt=Re[1],Oe=i.useMemo(function(){var Ge=it==null?[]:Array.isArray(it)?it:[it],Be=J(Ge,1),ze=Be[0],_e=ze===void 0?Se:ze,lt=it===null?[]:[_e];if(se){if(lt=pe(Ge),w||it===void 0){var Ct=w>=0?w+1:2;for(lt=lt.slice(0,Ct);lt.length<Ct;){var Ae;lt.push((Ae=lt[lt.length-1])!==null&&Ae!==void 0?Ae:Se)}}lt.sort(function(nt,ht){return nt-ht})}return lt.forEach(function(nt,ht){lt[ht]=fe(nt)}),lt},[it,se,Se,w,fe]),Le=function(Be){return se?Be:Be[0]},Ue=Nt(function(Ge){var Be=pe(Ge).sort(function(ze,_e){return ze-_e});I&&!hr(Be,Oe,!0)&&I(Le(Be)),dt(Be)}),ke=Nt(function(Ge){Ge&&he.current.hideHelp();var Be=Le(Oe);M==null||M(Be),Kt(!M,"[rc-slider] `onAfterChange` is deprecated. Please use `onChangeComplete` instead."),R==null||R(Be)}),Je=function(Be){if(!(d||!be||Oe.length<=Me)){var ze=pe(Oe);ze.splice(Be,1),P==null||P(Le(ze)),Ue(ze);var _e=Math.max(0,Be-1);he.current.hideHelp(),he.current.focus(_e)}},Xe=d5(ye,oe,Oe,Se,Fe,fe,Ue,ke,ve,be,Me),He=J(Xe,5),je=He[0],rt=He[1],et=He[2],Pe=He[3],qe=He[4],We=function(Be,ze){if(!d){var _e=pe(Oe),lt=0,Ct=0,Ae=Fe-Se;Oe.forEach(function(Qt,ln){var on=Math.abs(Be-Qt);on<=Ae&&(Ae=on,lt=ln),Qt<Be&&(Ct=ln)});var nt=lt;be&&Ae!==0&&(!Te||Oe.length<Te)?(_e.splice(Ct+1,0,Be),nt=Ct+1):_e[lt]=Be,se&&!Oe.length&&w===void 0&&_e.push(Be);var ht=Le(_e);if(P==null||P(ht),Ue(_e),ze){var Ft,qt;(Ft=document.activeElement)===null||Ft===void 0||(qt=Ft.blur)===null||qt===void 0||qt.call(Ft),he.current.focus(nt),qe(ze,nt,_e)}else M==null||M(ht),Kt(!M,"[rc-slider] `onAfterChange` is deprecated. Please use `onChangeComplete` instead."),R==null||R(ht)}},tt=function(Be){Be.preventDefault();var ze=ye.current.getBoundingClientRect(),_e=ze.width,lt=ze.height,Ct=ze.left,Ae=ze.top,nt=ze.bottom,ht=ze.right,Ft=Be.clientX,qt=Be.clientY,Qt;switch(oe){case"btt":Qt=(nt-qt)/lt;break;case"ttb":Qt=(qt-Ae)/lt;break;case"rtl":Qt=(ht-Ft)/_e;break;default:Qt=(Ft-Ct)/_e}var ln=Se+Qt*(Fe-Se);We(fe(ln),Be)},mt=i.useState(null),ct=J(mt,2),Ke=ct[0],Ye=ct[1],at=function(Be,ze){if(!d){var _e=ve(Oe,Be,ze);P==null||P(Le(Oe)),Ue(_e.values),Ye(_e.value)}};i.useEffect(function(){if(Ke!==null){var Ge=Oe.indexOf(Ke);Ge>=0&&he.current.focus(Ge)}Ye(null)},[Ke]);var gt=i.useMemo(function(){return we&&Ce===null?!1:we},[we,Ce]),Ot=Nt(function(Ge,Be){qe(Ge,Be),P==null||P(Le(Oe))}),Pt=je!==-1;i.useEffect(function(){if(!Pt){var Ge=Oe.lastIndexOf(rt);he.current.focus(Ge)}},[Pt]);var Rt=i.useMemo(function(){return pe(Pe).sort(function(Ge,Be){return Ge-Be})},[Pe]),jt=i.useMemo(function(){return se?[Rt[0],Rt[Rt.length-1]]:[Se,Rt[0]]},[Rt,se,Se]),zt=J(jt,2),Dt=zt[0],De=zt[1];i.useImperativeHandle(t,function(){return{focus:function(){he.current.focus(0)},blur:function(){var Be,ze=document,_e=ze.activeElement;(Be=ye.current)!==null&&Be!==void 0&&Be.contains(_e)&&(_e==null||_e.blur())}}}),i.useEffect(function(){v&&he.current.focus(0)},[]);var Ze=i.useMemo(function(){return{min:Se,max:Fe,direction:oe,disabled:d,keyboard:m,step:Ce,included:G,includedStart:Dt,includedEnd:De,range:se,tabIndex:ne,ariaLabelForHandle:Z,ariaLabelledByForHandle:Q,ariaRequired:ie,ariaValueTextFormatterForHandle:de,styles:s||{},classNames:l||{}}},[Se,Fe,oe,d,m,Ce,G,Dt,De,se,ne,Z,Q,ie,de,s,l]);return i.createElement(Oo.Provider,{value:Ze},i.createElement("div",{ref:ye,className:A(r,o,D(D(D(D({},"".concat(r,"-disabled"),d),"".concat(r,"-vertical"),B),"".concat(r,"-horizontal"),!B),"".concat(r,"-with-marks"),$e.length)),style:a,onMouseDown:tt,id:c},i.createElement("div",{className:A("".concat(r,"-rail"),l==null?void 0:l.rail),style:k(k({},K),s==null?void 0:s.rail)}),Y!==!1&&i.createElement(c5,{prefixCls:r,style:H,values:Oe,startPoint:q,onStartMove:gt?Ot:void 0}),i.createElement(s5,{prefixCls:r,marks:$e,dots:ae,style:U,activeStyle:te}),i.createElement(o5,{ref:he,prefixCls:r,style:W,values:Pe,draggingIndex:je,draggingDelete:et,onStartMove:Ot,onOffsetChange:at,onFocus:g,onBlur:h,handleRender:le,activeHandleRender:ee,onChangeComplete:ke,onDelete:be?Je:void 0}),i.createElement(i5,{prefixCls:r,marks:$e,onClick:We})))});const mC=i.createContext({}),jg=i.forwardRef((e,t)=>{const{open:n,draggingDelete:r,value:o}=e,a=i.useRef(null),l=n&&!r,s=i.useRef(null);function c(){Et.cancel(s.current),s.current=null}function u(){s.current=Et(()=>{var d;(d=a.current)===null||d===void 0||d.forceAlign(),s.current=null})}return i.useEffect(()=>(l?u():c(),c),[l,e.title,o]),i.createElement($r,Object.assign({ref:un(a,t)},e,{open:l}))}),g5=e=>{const{componentCls:t,antCls:n,controlSize:r,dotSize:o,marginFull:a,marginPart:l,colorFillContentHover:s,handleColorDisabled:c,calc:u,handleSize:d,handleSizeHover:f,handleActiveColor:m,handleActiveOutlineColor:v,handleLineWidth:g,handleLineWidthHover:h,motionDurationMid:p}=e;return{[t]:Object.assign(Object.assign({},Tt(e)),{position:"relative",height:r,margin:`${L(l)} ${L(a)}`,padding:0,cursor:"pointer",touchAction:"none","&-vertical":{margin:`${L(a)} ${L(l)}`},[`${t}-rail`]:{position:"absolute",backgroundColor:e.railBg,borderRadius:e.borderRadiusXS,transition:`background-color ${p}`},[`${t}-track,${t}-tracks`]:{position:"absolute",transition:`background-color ${p}`},[`${t}-track`]:{backgroundColor:e.trackBg,borderRadius:e.borderRadiusXS},[`${t}-track-draggable`]:{boxSizing:"content-box",backgroundClip:"content-box",border:"solid rgba(0,0,0,0)"},"&:hover":{[`${t}-rail`]:{backgroundColor:e.railHoverBg},[`${t}-track`]:{backgroundColor:e.trackHoverBg},[`${t}-dot`]:{borderColor:s},[`${t}-handle::after`]:{boxShadow:`0 0 0 ${L(g)} ${e.colorPrimaryBorderHover}`},[`${t}-dot-active`]:{borderColor:e.dotActiveBorderColor}},[`${t}-handle`]:{position:"absolute",width:d,height:d,outline:"none",userSelect:"none","&-dragging-delete":{opacity:0},"&::before":{content:'""',position:"absolute",insetInlineStart:u(g).mul(-1).equal(),insetBlockStart:u(g).mul(-1).equal(),width:u(d).add(u(g).mul(2)).equal(),height:u(d).add(u(g).mul(2)).equal(),backgroundColor:"transparent"},"&::after":{content:'""',position:"absolute",insetBlockStart:0,insetInlineStart:0,width:d,height:d,backgroundColor:e.colorBgElevated,boxShadow:`0 0 0 ${L(g)} ${e.handleColor}`,outline:"0px solid transparent",borderRadius:"50%",cursor:"pointer",transition:`
            inset-inline-start ${p},
            inset-block-start ${p},
            width ${p},
            height ${p},
            box-shadow ${p},
            outline ${p}
          `},"&:hover, &:active, &:focus":{"&::before":{insetInlineStart:u(f).sub(d).div(2).add(h).mul(-1).equal(),insetBlockStart:u(f).sub(d).div(2).add(h).mul(-1).equal(),width:u(f).add(u(h).mul(2)).equal(),height:u(f).add(u(h).mul(2)).equal()},"&::after":{boxShadow:`0 0 0 ${L(h)} ${m}`,outline:`6px solid ${v}`,width:f,height:f,insetInlineStart:e.calc(d).sub(f).div(2).equal(),insetBlockStart:e.calc(d).sub(f).div(2).equal()}}},[`&-lock ${t}-handle`]:{"&::before, &::after":{transition:"none"}},[`${t}-mark`]:{position:"absolute",fontSize:e.fontSize},[`${t}-mark-text`]:{position:"absolute",display:"inline-block",color:e.colorTextDescription,textAlign:"center",wordBreak:"keep-all",cursor:"pointer",userSelect:"none","&-active":{color:e.colorText}},[`${t}-step`]:{position:"absolute",background:"transparent",pointerEvents:"none"},[`${t}-dot`]:{position:"absolute",width:o,height:o,backgroundColor:e.colorBgElevated,border:`${L(g)} solid ${e.dotBorderColor}`,borderRadius:"50%",cursor:"pointer",transition:`border-color ${e.motionDurationSlow}`,pointerEvents:"auto","&-active":{borderColor:e.dotActiveBorderColor}},[`&${t}-disabled`]:{cursor:"not-allowed",[`${t}-rail`]:{backgroundColor:`${e.railBg} !important`},[`${t}-track`]:{backgroundColor:`${e.trackBgDisabled} !important`},[`
          ${t}-dot
        `]:{backgroundColor:e.colorBgElevated,borderColor:e.trackBgDisabled,boxShadow:"none",cursor:"not-allowed"},[`${t}-handle::after`]:{backgroundColor:e.colorBgElevated,cursor:"not-allowed",width:d,height:d,boxShadow:`0 0 0 ${L(g)} ${c}`,insetInlineStart:0,insetBlockStart:0},[`
          ${t}-mark-text,
          ${t}-dot
        `]:{cursor:"not-allowed !important"}},[`&-tooltip ${n}-tooltip-inner`]:{minWidth:"unset"}})}},vC=(e,t)=>{const{componentCls:n,railSize:r,handleSize:o,dotSize:a,marginFull:l,calc:s}=e,c=t?"paddingBlock":"paddingInline",u=t?"width":"height",d=t?"height":"width",f=t?"insetBlockStart":"insetInlineStart",m=t?"top":"insetInlineStart",v=s(r).mul(3).sub(o).div(2).equal(),g=s(o).sub(r).div(2).equal(),h=t?{borderWidth:`${L(g)} 0`,transform:`translateY(${L(s(g).mul(-1).equal())})`}:{borderWidth:`0 ${L(g)}`,transform:`translateX(${L(e.calc(g).mul(-1).equal())})`};return{[c]:r,[d]:s(r).mul(3).equal(),[`${n}-rail`]:{[u]:"100%",[d]:r},[`${n}-track,${n}-tracks`]:{[d]:r},[`${n}-track-draggable`]:Object.assign({},h),[`${n}-handle`]:{[f]:v},[`${n}-mark`]:{insetInlineStart:0,top:0,[m]:s(r).mul(3).add(t?0:l).equal(),[u]:"100%"},[`${n}-step`]:{insetInlineStart:0,top:0,[m]:r,[u]:"100%",[d]:r},[`${n}-dot`]:{position:"absolute",[f]:s(r).sub(a).div(2).equal()}}},p5=e=>{const{componentCls:t,marginPartWithMark:n}=e;return{[`${t}-horizontal`]:Object.assign(Object.assign({},vC(e,!0)),{[`&${t}-with-marks`]:{marginBottom:n}})}},h5=e=>{const{componentCls:t}=e;return{[`${t}-vertical`]:Object.assign(Object.assign({},vC(e,!1)),{height:"100%"})}},b5=e=>{const n=e.controlHeightLG/4,r=e.controlHeightSM/2,o=e.lineWidth+1,a=e.lineWidth+1*1.5,l=e.colorPrimary,s=new Mt(l).setA(.2).toRgbString();return{controlSize:n,railSize:4,handleSize:n,handleSizeHover:r,dotSize:8,handleLineWidth:o,handleLineWidthHover:a,railBg:e.colorFillTertiary,railHoverBg:e.colorFillSecondary,trackBg:e.colorPrimaryBorder,trackHoverBg:e.colorPrimaryBorderHover,handleColor:e.colorPrimaryBorder,handleActiveColor:l,handleActiveOutlineColor:s,handleColorDisabled:new Mt(e.colorTextDisabled).onBackground(e.colorBgContainer).toHexString(),dotBorderColor:e.colorBorderSecondary,dotActiveBorderColor:e.colorPrimaryBorder,trackBgDisabled:e.colorBgContainerDisabled}},y5=It("Slider",e=>{const t=yt(e,{marginPart:e.calc(e.controlHeight).sub(e.controlSize).div(2).equal(),marginFull:e.calc(e.controlSize).div(2).equal(),marginPartWithMark:e.calc(e.controlHeightLG).sub(e.controlSize).equal()});return[g5(t),p5(t),h5(t)]},b5);function wc(){const[e,t]=i.useState(!1),n=i.useRef(null),r=()=>{Et.cancel(n.current)},o=a=>{r(),a?t(a):n.current=Et(()=>{t(a)})};return i.useEffect(()=>r,[]),[e,o]}var C5=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function S5(e,t){return e||e===null?e:t||t===null?t:n=>typeof n=="number"?n.toString():""}const $5=F.forwardRef((e,t)=>{const{prefixCls:n,range:r,className:o,rootClassName:a,style:l,disabled:s,tooltipPrefixCls:c,tipFormatter:u,tooltipVisible:d,getTooltipPopupContainer:f,tooltipPlacement:m,tooltip:v={},onChangeComplete:g,classNames:h,styles:p}=e,b=C5(e,["prefixCls","range","className","rootClassName","style","disabled","tooltipPrefixCls","tipFormatter","tooltipVisible","getTooltipPopupContainer","tooltipPlacement","tooltip","onChangeComplete","classNames","styles"]),{vertical:y}=e,{getPrefixCls:C,direction:$,className:S,style:x,classNames:E,styles:O,getPopupContainer:w}=tn("slider"),I=F.useContext(Ln),P=s??I,{handleRender:M,direction:R}=F.useContext(mC),T=(R||$)==="rtl",[j,z]=wc(),[_,B]=wc(),V=Object.assign({},v),{open:G,placement:q,getPopupContainer:H,prefixCls:W,formatter:K}=V,U=G??d,te=(j||_)&&U!==!1,X=S5(K,u),[ae,le]=wc(),ee=se=>{g==null||g(se),le(!1)},Y=(se,be)=>se||(be?T?"left":"right":"top"),re=C("slider",n),[ne,Z,Q]=y5(re),ie=A(o,S,E.root,h==null?void 0:h.root,a,{[`${re}-rtl`]:T,[`${re}-lock`]:ae},Z,Q);T&&!b.vertical&&(b.reverse=!b.reverse),F.useEffect(()=>{const se=()=>{Et(()=>{B(!1)},1)};return document.addEventListener("mouseup",se),()=>{document.removeEventListener("mouseup",se)}},[]);const de=r&&!U,he=M||((se,be)=>{const{index:we}=be,Me=se.props;function Te(me,$e,Ee){var Ie,fe,ve,xe;Ee&&((fe=(Ie=b)[me])===null||fe===void 0||fe.call(Ie,$e)),(xe=(ve=Me)[me])===null||xe===void 0||xe.call(ve,$e)}const Se=Object.assign(Object.assign({},Me),{onMouseEnter:me=>{z(!0),Te("onMouseEnter",me)},onMouseLeave:me=>{z(!1),Te("onMouseLeave",me)},onMouseDown:me=>{B(!0),le(!0),Te("onMouseDown",me)},onFocus:me=>{var $e;B(!0),($e=b.onFocus)===null||$e===void 0||$e.call(b,me),Te("onFocus",me,!0)},onBlur:me=>{var $e;B(!1),($e=b.onBlur)===null||$e===void 0||$e.call(b,me),Te("onBlur",me,!0)}}),Fe=F.cloneElement(se,Se),Ce=(!!U||te)&&X!==null;return de?Fe:F.createElement(jg,Object.assign({},V,{prefixCls:C("tooltip",W??c),title:X?X(be.value):"",value:be.value,open:Ce,placement:Y(q??m,y),key:we,classNames:{root:`${re}-tooltip`},getPopupContainer:H||f||w}),Fe)}),ye=de?(se,be)=>{const we=F.cloneElement(se,{style:Object.assign(Object.assign({},se.props.style),{visibility:"hidden"})});return F.createElement(jg,Object.assign({},V,{prefixCls:C("tooltip",W??c),title:X?X(be.value):"",open:X!==null&&te,placement:Y(q??m,y),key:"tooltip",classNames:{root:`${re}-tooltip`},getPopupContainer:H||f||w,draggingDelete:be.draggingDelete}),we)}:void 0,oe=Object.assign(Object.assign(Object.assign(Object.assign({},O.root),x),p==null?void 0:p.root),l),ce=Object.assign(Object.assign({},O.tracks),p==null?void 0:p.tracks),ge=A(E.tracks,h==null?void 0:h.tracks);return ne(F.createElement(v5,Object.assign({},b,{classNames:Object.assign({handle:A(E.handle,h==null?void 0:h.handle),rail:A(E.rail,h==null?void 0:h.rail),track:A(E.track,h==null?void 0:h.track)},ge?{tracks:ge}:{}),styles:Object.assign({handle:Object.assign(Object.assign({},O.handle),p==null?void 0:p.handle),rail:Object.assign(Object.assign({},O.rail),p==null?void 0:p.rail),track:Object.assign(Object.assign({},O.track),p==null?void 0:p.track)},Object.keys(ce).length?{tracks:ce}:{}),step:b.step,range:r,className:ie,style:oe,disabled:P,ref:t,prefixCls:re,handleRender:he,activeHandleRender:ye,onChangeComplete:ee})))});var x5=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const gC=e=>{const{prefixCls:t,colors:n,type:r,color:o,range:a=!1,className:l,activeIndex:s,onActive:c,onDragStart:u,onDragChange:d,onKeyDelete:f}=e,m=x5(e,["prefixCls","colors","type","color","range","className","activeIndex","onActive","onDragStart","onDragChange","onKeyDelete"]),v=Object.assign(Object.assign({},m),{track:!1}),g=i.useMemo(()=>`linear-gradient(90deg, ${n.map(x=>`${x.color} ${x.percent}%`).join(", ")})`,[n]),h=i.useMemo(()=>!o||!r?null:r==="alpha"?o.toRgbString():`hsl(${o.toHsb().h}, 100%, 50%)`,[o,r]),p=Nt(u),b=Nt(d),y=i.useMemo(()=>({onDragStart:p,onDragChange:b}),[]),C=Nt((S,x)=>{const{onFocus:E,style:O,className:w,onKeyDown:I}=S.props,P=Object.assign({},O);return r==="gradient"&&(P.background=j0(n,x.value)),i.cloneElement(S,{onFocus:M=>{c==null||c(x.index),E==null||E(M)},style:P,className:A(w,{[`${t}-slider-handle-active`]:s===x.index}),onKeyDown:M=>{(M.key==="Delete"||M.key==="Backspace")&&f&&f(x.index),I==null||I(M)}})}),$=i.useMemo(()=>({direction:"ltr",handleRender:C}),[]);return i.createElement(mC.Provider,{value:$},i.createElement(fC.Provider,{value:y},i.createElement($5,Object.assign({},v,{className:A(l,`${t}-slider`),tooltip:{open:!1},range:{editable:a,minCount:2},styles:{rail:{background:g},handle:h?{background:h}:{}},classNames:{rail:`${t}-slider-rail`,handle:`${t}-slider-handle`}}))))},w5=e=>{const{value:t,onChange:n,onChangeComplete:r}=e,o=l=>n(l[0]),a=l=>r(l[0]);return i.createElement(gC,Object.assign({},e,{value:[t],onChange:o,onChangeComplete:a}))};function zg(e){return pe(e).sort((t,n)=>t.percent-n.percent)}const E5=e=>{const{prefixCls:t,mode:n,onChange:r,onChangeComplete:o,onActive:a,activeIndex:l,onGradientDragging:s,colors:c}=e,u=n==="gradient",d=i.useMemo(()=>c.map(b=>({percent:b.percent,color:b.color.toRgbString()})),[c]),f=i.useMemo(()=>d.map(b=>b.percent),[d]),m=i.useRef(d),v=({rawValues:b,draggingIndex:y,draggingValue:C})=>{if(b.length>d.length){const $=j0(d,C),S=pe(d);S.splice(y,0,{percent:C,color:$}),m.current=S}else m.current=d;s(!0),r(new Zn(zg(m.current)),!0)},g=({deleteIndex:b,draggingIndex:y,draggingValue:C})=>{let $=pe(m.current);b!==-1?$.splice(b,1):($[y]=Object.assign(Object.assign({},$[y]),{percent:C}),$=zg($)),r(new Zn($),!0)},h=b=>{const y=pe(d);y.splice(b,1);const C=new Zn(y);r(C),o(C)},p=b=>{o(new Zn(d)),l>=b.length&&a(b.length-1),s(!1)};return u?i.createElement(gC,{min:0,max:100,prefixCls:t,className:`${t}-gradient-slider`,colors:d,color:null,value:f,range:!0,onChangeComplete:p,disabled:!1,type:"gradient",activeIndex:l,onActive:a,onDragStart:v,onDragChange:g,onKeyDelete:h}):null},O5=i.memo(E5);var I5=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const R5={slider:w5},Dg=()=>{const e=i.useContext(eC),{mode:t,onModeChange:n,modeOptions:r,prefixCls:o,allowClear:a,value:l,disabledAlpha:s,onChange:c,onClear:u,onChangeComplete:d,activeIndex:f,gradientDragging:m}=e,v=I5(e,["mode","onModeChange","modeOptions","prefixCls","allowClear","value","disabledAlpha","onChange","onClear","onChangeComplete","activeIndex","gradientDragging"]),g=F.useMemo(()=>l.cleared?[{percent:0,color:new Zn("")},{percent:100,color:new Zn("")}]:l.getColors(),[l]),h=!l.isGradient(),[p,b]=F.useState(l);wt(()=>{var N;h||b((N=g[f])===null||N===void 0?void 0:N.color)},[m,f]);const y=F.useMemo(()=>{var N;return h?l:m?p:(N=g[f])===null||N===void 0?void 0:N.color},[l,f,h,p,m]),[C,$]=F.useState(y),[S,x]=F.useState(0),E=C!=null&&C.equals(y)?y:C;wt(()=>{$(y)},[S,y==null?void 0:y.toHexString()]);const O=(N,T)=>{let j=Nn(N);if(l.cleared){const _=j.toRgb();if(!_.r&&!_.g&&!_.b&&T){const{type:B,value:V=0}=T;j=new Zn({h:B==="hue"?V:0,s:1,b:1,a:B==="alpha"?V/100:1})}else j=ol(j)}if(t==="single")return j;const z=pe(g);return z[f]=Object.assign(Object.assign({},z[f]),{color:j}),new Zn(z)},w=(N,T,j)=>{const z=O(N,j);$(z.isGradient()?z.getColors()[f].color:z),c(z,T)},I=(N,T)=>{d(O(N,T)),x(j=>j+1)},P=N=>{c(O(N))};let M=null;const R=r.length>1;return(a||R)&&(M=F.createElement("div",{className:`${o}-operation`},R&&F.createElement(bT,{size:"small",options:r,value:t,onChange:n}),F.createElement(nC,Object.assign({prefixCls:o,value:l,onChange:N=>{c(N),u==null||u()}},v)))),F.createElement(F.Fragment,null,M,F.createElement(O5,Object.assign({},e,{colors:g})),F.createElement(WE,{prefixCls:o,value:E==null?void 0:E.toHsb(),disabledAlpha:s,onChange:(N,T)=>{w(N,!0,T)},onChangeComplete:(N,T)=>{I(N,T)},components:R5}),F.createElement(t5,Object.assign({value:y,onChange:P,prefixCls:o,disabledAlpha:s},v)))},_g=()=>{const{prefixCls:e,value:t,presets:n,onChange:r}=i.useContext(tC);return Array.isArray(n)?F.createElement(H2,{value:t,presets:n,prefixCls:e,onChange:r}):null},P5=e=>{const{prefixCls:t,presets:n,panelRender:r,value:o,onChange:a,onClear:l,allowClear:s,disabledAlpha:c,mode:u,onModeChange:d,modeOptions:f,onChangeComplete:m,activeIndex:v,onActive:g,format:h,onFormatChange:p,gradientDragging:b,onGradientDragging:y,disabledFormat:C}=e,$=`${t}-inner`,S=F.useMemo(()=>({prefixCls:t,value:o,onChange:a,onClear:l,allowClear:s,disabledAlpha:c,mode:u,onModeChange:d,modeOptions:f,onChangeComplete:m,activeIndex:v,onActive:g,format:h,onFormatChange:p,gradientDragging:b,onGradientDragging:y,disabledFormat:C}),[t,o,a,l,s,c,u,d,f,m,v,g,h,p,b,y,C]),x=F.useMemo(()=>({prefixCls:t,value:o,presets:n,onChange:a}),[t,o,n,a]),E=F.createElement("div",{className:`${$}-content`},F.createElement(Dg,null),Array.isArray(n)&&F.createElement(oT,null),F.createElement(_g,null));return F.createElement(eC.Provider,{value:S},F.createElement(tC.Provider,{value:x},F.createElement("div",{className:$},typeof r=="function"?r(E,{components:{Picker:Dg,Presets:_g}}):E)))};var N5=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const M5=i.forwardRef((e,t)=>{const{color:n,prefixCls:r,open:o,disabled:a,format:l,className:s,showText:c,activeIndex:u}=e,d=N5(e,["color","prefixCls","open","disabled","format","className","showText","activeIndex"]),f=`${r}-trigger`,m=`${f}-text`,v=`${m}-cell`,[g]=Kn("ColorPicker"),h=F.useMemo(()=>{if(!c)return"";if(typeof c=="function")return c(n);if(n.cleared)return g.transparent;if(n.isGradient())return n.getColors().map((C,$)=>{const S=u!==-1&&u!==$;return F.createElement("span",{key:$,className:A(v,S&&`${v}-inactive`)},C.color.toRgbString()," ",C.percent,"%")});const b=n.toHexString().toUpperCase(),y=kd(n);switch(l){case"rgb":return n.toRgbString();case"hsb":return n.toHsbString();default:return y<100?`${b.slice(0,7)},${y}%`:b}},[n,l,c,u]),p=i.useMemo(()=>n.cleared?F.createElement(nC,{prefixCls:r}):F.createElement(_d,{prefixCls:r,color:n.toCssString()}),[n,r]);return F.createElement("div",Object.assign({ref:t,className:A(f,s,{[`${f}-active`]:o,[`${f}-disabled`]:a})},rn(d)),p,c&&F.createElement("div",{className:m},h))});function T5(e,t,n){const[r]=Kn("ColorPicker"),[o,a]=Lt(e,{value:t}),[l,s]=i.useState("single"),[c,u]=i.useMemo(()=>{const h=(Array.isArray(n)?n:[n]).filter(C=>C);h.length||h.push("single");const p=new Set(h),b=[],y=(C,$)=>{p.has(C)&&b.push({label:$,value:C})};return y("single",r.singleColor),y("gradient",r.gradientColor),[b,p]},[n]),[d,f]=i.useState(null),m=Nt(h=>{f(h),a(h)}),v=i.useMemo(()=>{const h=Nn(o||"");return h.equals(d)?d:h},[o,d]),g=i.useMemo(()=>{var h;return u.has(l)?l:(h=c[0])===null||h===void 0?void 0:h.value},[u,l,c]);return i.useEffect(()=>{s(v.isGradient()?"gradient":"single")},[v]),[v,m,g,s,c]}const pC=(e,t)=>({backgroundImage:`conic-gradient(${t} 25%, transparent 25% 50%, ${t} 50% 75%, transparent 75% 100%)`,backgroundSize:`${e} ${e}`}),Bg=(e,t)=>{const{componentCls:n,borderRadiusSM:r,colorPickerInsetShadow:o,lineWidth:a,colorFillSecondary:l}=e;return{[`${n}-color-block`]:Object.assign(Object.assign({position:"relative",borderRadius:r,width:t,height:t,boxShadow:o,flex:"none"},pC("50%",e.colorFillSecondary)),{[`${n}-color-block-inner`]:{width:"100%",height:"100%",boxShadow:`inset 0 0 0 ${L(a)} ${l}`,borderRadius:"inherit"}})}},j5=e=>{const{componentCls:t,antCls:n,fontSizeSM:r,lineHeightSM:o,colorPickerAlphaInputWidth:a,marginXXS:l,paddingXXS:s,controlHeightSM:c,marginXS:u,fontSizeIcon:d,paddingXS:f,colorTextPlaceholder:m,colorPickerInputNumberHandleWidth:v,lineWidth:g}=e;return{[`${t}-input-container`]:{display:"flex",[`${t}-steppers${n}-input-number`]:{fontSize:r,lineHeight:o,[`${n}-input-number-input`]:{paddingInlineStart:s,paddingInlineEnd:0},[`${n}-input-number-handler-wrap`]:{width:v}},[`${t}-steppers${t}-alpha-input`]:{flex:`0 0 ${L(a)}`,marginInlineStart:l},[`${t}-format-select${n}-select`]:{marginInlineEnd:u,width:"auto","&-single":{[`${n}-select-selector`]:{padding:0,border:0},[`${n}-select-arrow`]:{insetInlineEnd:0},[`${n}-select-selection-item`]:{paddingInlineEnd:e.calc(d).add(l).equal(),fontSize:r,lineHeight:L(c)},[`${n}-select-item-option-content`]:{fontSize:r,lineHeight:o},[`${n}-select-dropdown`]:{[`${n}-select-item`]:{minHeight:"auto"}}}},[`${t}-input`]:{gap:l,alignItems:"center",flex:1,width:0,[`${t}-hsb-input,${t}-rgb-input`]:{display:"flex",gap:l,alignItems:"center"},[`${t}-steppers`]:{flex:1},[`${t}-hex-input${n}-input-affix-wrapper`]:{flex:1,padding:`0 ${L(f)}`,[`${n}-input`]:{fontSize:r,textTransform:"uppercase",lineHeight:L(e.calc(c).sub(e.calc(g).mul(2)).equal())},[`${n}-input-prefix`]:{color:m}}}}}},z5=e=>{const{componentCls:t,controlHeightLG:n,borderRadiusSM:r,colorPickerInsetShadow:o,marginSM:a,colorBgElevated:l,colorFillSecondary:s,lineWidthBold:c,colorPickerHandlerSize:u}=e;return{userSelect:"none",[`${t}-select`]:{[`${t}-palette`]:{minHeight:e.calc(n).mul(4).equal(),overflow:"hidden",borderRadius:r},[`${t}-saturation`]:{position:"absolute",borderRadius:"inherit",boxShadow:o,inset:0},marginBottom:a},[`${t}-handler`]:{width:u,height:u,border:`${L(c)} solid ${l}`,position:"relative",borderRadius:"50%",cursor:"pointer",boxShadow:`${o}, 0 0 0 1px ${s}`}}},D5=e=>{const{componentCls:t,antCls:n,colorTextQuaternary:r,paddingXXS:o,colorPickerPresetColorSize:a,fontSizeSM:l,colorText:s,lineHeightSM:c,lineWidth:u,borderRadius:d,colorFill:f,colorWhite:m,marginXXS:v,paddingXS:g,fontHeightSM:h}=e;return{[`${t}-presets`]:{[`${n}-collapse-item > ${n}-collapse-header`]:{padding:0,[`${n}-collapse-expand-icon`]:{height:h,color:r,paddingInlineEnd:o}},[`${n}-collapse`]:{display:"flex",flexDirection:"column",gap:v},[`${n}-collapse-item > ${n}-collapse-content > ${n}-collapse-content-box`]:{padding:`${L(g)} 0`},"&-label":{fontSize:l,color:s,lineHeight:c},"&-items":{display:"flex",flexWrap:"wrap",gap:e.calc(v).mul(1.5).equal(),[`${t}-presets-color`]:{position:"relative",cursor:"pointer",width:a,height:a,"&::before":{content:'""',pointerEvents:"none",width:e.calc(a).add(e.calc(u).mul(4)).equal(),height:e.calc(a).add(e.calc(u).mul(4)).equal(),position:"absolute",top:e.calc(u).mul(-2).equal(),insetInlineStart:e.calc(u).mul(-2).equal(),borderRadius:d,border:`${L(u)} solid transparent`,transition:`border-color ${e.motionDurationMid} ${e.motionEaseInBack}`},"&:hover::before":{borderColor:f},"&::after":{boxSizing:"border-box",position:"absolute",top:"50%",insetInlineStart:"21.5%",display:"table",width:e.calc(a).div(13).mul(5).equal(),height:e.calc(a).div(13).mul(8).equal(),border:`${L(e.lineWidthBold)} solid ${e.colorWhite}`,borderTop:0,borderInlineStart:0,transform:"rotate(45deg) scale(0) translate(-50%,-50%)",opacity:0,content:'""',transition:`all ${e.motionDurationFast} ${e.motionEaseInBack}, opacity ${e.motionDurationFast}`},[`&${t}-presets-color-checked`]:{"&::after":{opacity:1,borderColor:m,transform:"rotate(45deg) scale(1) translate(-50%,-50%)",transition:`transform ${e.motionDurationMid} ${e.motionEaseOutBack} ${e.motionDurationFast}`},[`&${t}-presets-color-bright`]:{"&::after":{borderColor:"rgba(0, 0, 0, 0.45)"}}}}},"&-empty":{fontSize:l,color:r}}}},_5=e=>{const{componentCls:t,colorPickerInsetShadow:n,colorBgElevated:r,colorFillSecondary:o,lineWidthBold:a,colorPickerHandlerSizeSM:l,colorPickerSliderHeight:s,marginSM:c,marginXS:u}=e,d=e.calc(l).sub(e.calc(a).mul(2).equal()).equal(),f=e.calc(l).add(e.calc(a).mul(2).equal()).equal(),m={"&:after":{transform:"scale(1)",boxShadow:`${n}, 0 0 0 1px ${e.colorPrimaryActive}`}};return{[`${t}-slider`]:[pC(L(s),e.colorFillSecondary),{margin:0,padding:0,height:s,borderRadius:e.calc(s).div(2).equal(),"&-rail":{height:s,borderRadius:e.calc(s).div(2).equal(),boxShadow:n},[`& ${t}-slider-handle`]:{width:d,height:d,top:0,borderRadius:"100%","&:before":{display:"block",position:"absolute",background:"transparent",left:{_skip_check_:!0,value:"50%"},top:"50%",transform:"translate(-50%, -50%)",width:f,height:f,borderRadius:"100%"},"&:after":{width:l,height:l,border:`${L(a)} solid ${r}`,boxShadow:`${n}, 0 0 0 1px ${o}`,outline:"none",insetInlineStart:e.calc(a).mul(-1).equal(),top:e.calc(a).mul(-1).equal(),background:"transparent",transition:"none"},"&:focus":m}}],[`${t}-slider-container`]:{display:"flex",gap:c,marginBottom:c,[`${t}-slider-group`]:{flex:1,flexDirection:"column",justifyContent:"space-between",display:"flex","&-disabled-alpha":{justifyContent:"center"}}},[`${t}-gradient-slider`]:{marginBottom:u,[`& ${t}-slider-handle`]:{"&:after":{transform:"scale(0.8)"},"&-active, &:focus":m}}}},td=(e,t,n)=>({borderInlineEndWidth:e.lineWidth,borderColor:t,boxShadow:`0 0 0 ${L(e.controlOutlineWidth)} ${n}`,outline:0}),B5=e=>{const{componentCls:t}=e;return{"&-rtl":{[`${t}-presets-color`]:{"&::after":{direction:"ltr"}},[`${t}-clear`]:{"&::after":{direction:"ltr"}}}}},Lg=(e,t,n)=>{const{componentCls:r,borderRadiusSM:o,lineWidth:a,colorSplit:l,colorBorder:s,red6:c}=e;return{[`${r}-clear`]:Object.assign(Object.assign({width:t,height:t,borderRadius:o,border:`${L(a)} solid ${l}`,position:"relative",overflow:"hidden",cursor:"inherit",transition:`all ${e.motionDurationFast}`},n),{"&::after":{content:'""',position:"absolute",insetInlineEnd:e.calc(a).mul(-1).equal(),top:e.calc(a).mul(-1).equal(),display:"block",width:40,height:2,transformOrigin:"calc(100% - 1px) 1px",transform:"rotate(-45deg)",backgroundColor:c},"&:hover":{borderColor:s}})}},L5=e=>{const{componentCls:t,colorError:n,colorWarning:r,colorErrorHover:o,colorWarningHover:a,colorErrorOutline:l,colorWarningOutline:s}=e;return{[`&${t}-status-error`]:{borderColor:n,"&:hover":{borderColor:o},[`&${t}-trigger-active`]:Object.assign({},td(e,n,l))},[`&${t}-status-warning`]:{borderColor:r,"&:hover":{borderColor:a},[`&${t}-trigger-active`]:Object.assign({},td(e,r,s))}}},H5=e=>{const{componentCls:t,controlHeightLG:n,controlHeightSM:r,controlHeight:o,controlHeightXS:a,borderRadius:l,borderRadiusSM:s,borderRadiusXS:c,borderRadiusLG:u,fontSizeLG:d}=e;return{[`&${t}-lg`]:{minWidth:n,minHeight:n,borderRadius:u,[`${t}-color-block, ${t}-clear`]:{width:o,height:o,borderRadius:l},[`${t}-trigger-text`]:{fontSize:d}},[`&${t}-sm`]:{minWidth:r,minHeight:r,borderRadius:s,[`${t}-color-block, ${t}-clear`]:{width:a,height:a,borderRadius:c},[`${t}-trigger-text`]:{lineHeight:L(a)}}}},A5=e=>{const{antCls:t,componentCls:n,colorPickerWidth:r,colorPrimary:o,motionDurationMid:a,colorBgElevated:l,colorTextDisabled:s,colorText:c,colorBgContainerDisabled:u,borderRadius:d,marginXS:f,marginSM:m,controlHeight:v,controlHeightSM:g,colorBgTextActive:h,colorPickerPresetColorSize:p,colorPickerPreviewSize:b,lineWidth:y,colorBorder:C,paddingXXS:$,fontSize:S,colorPrimaryHover:x,controlOutline:E}=e;return[{[n]:Object.assign({[`${n}-inner`]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({"&-content":{display:"flex",flexDirection:"column",width:r,[`& > ${t}-divider`]:{margin:`${L(m)} 0 ${L(f)}`}},[`${n}-panel`]:Object.assign({},z5(e))},_5(e)),Bg(e,b)),j5(e)),D5(e)),Lg(e,p,{marginInlineStart:"auto"})),{[`${n}-operation`]:{display:"flex",justifyContent:"space-between",marginBottom:f}}),"&-trigger":Object.assign(Object.assign(Object.assign(Object.assign({minWidth:v,minHeight:v,borderRadius:d,border:`${L(y)} solid ${C}`,cursor:"pointer",display:"inline-flex",alignItems:"flex-start",justifyContent:"center",transition:`all ${a}`,background:l,padding:e.calc($).sub(y).equal(),[`${n}-trigger-text`]:{marginInlineStart:f,marginInlineEnd:e.calc(f).sub(e.calc($).sub(y)).equal(),fontSize:S,color:c,alignSelf:"center","&-cell":{"&:not(:last-child):after":{content:'", "'},"&-inactive":{color:s}}},"&:hover":{borderColor:x},[`&${n}-trigger-active`]:Object.assign({},td(e,o,E)),"&-disabled":{color:s,background:u,cursor:"not-allowed","&:hover":{borderColor:h},[`${n}-trigger-text`]:{color:s}}},Lg(e,g)),Bg(e,g)),L5(e)),H5(e))},B5(e))},di(e,{focusElCls:`${n}-trigger-active`})]},F5=It("ColorPicker",e=>{const{colorTextQuaternary:t,marginSM:n}=e,r=8,o=yt(e,{colorPickerWidth:234,colorPickerHandlerSize:16,colorPickerHandlerSizeSM:12,colorPickerAlphaInputWidth:44,colorPickerInputNumberHandleWidth:16,colorPickerPresetColorSize:24,colorPickerInsetShadow:`inset 0 0 1px 0 ${t}`,colorPickerSliderHeight:r,colorPickerPreviewSize:e.calc(r).mul(2).add(n).equal()});return A5(o)});var k5=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const hC=e=>{const{mode:t,value:n,defaultValue:r,format:o,defaultFormat:a,allowClear:l=!1,presets:s,children:c,trigger:u="click",open:d,disabled:f,placement:m="bottomLeft",arrow:v=!0,panelRender:g,showText:h,style:p,className:b,size:y,rootClassName:C,prefixCls:$,styles:S,disabledAlpha:x=!1,onFormatChange:E,onChange:O,onClear:w,onOpenChange:I,onChangeComplete:P,getPopupContainer:M,autoAdjustOverflow:R=!0,destroyTooltipOnHide:N,destroyOnHidden:T,disabledFormat:j}=e,z=k5(e,["mode","value","defaultValue","format","defaultFormat","allowClear","presets","children","trigger","open","disabled","placement","arrow","panelRender","showText","style","className","size","rootClassName","prefixCls","styles","disabledAlpha","onFormatChange","onChange","onClear","onOpenChange","onChangeComplete","getPopupContainer","autoAdjustOverflow","destroyTooltipOnHide","destroyOnHidden","disabledFormat"]),{getPrefixCls:_,direction:B,colorPicker:V}=i.useContext(ot),G=i.useContext(Ln),q=f??G,[H,W]=Lt(!1,{value:d,postState:ve=>!q&&ve,onChange:I}),[K,U]=Lt(o,{value:o,defaultValue:a,onChange:E}),te=_("color-picker",$),[X,ae,le,ee,Y]=T5(r,n,t),re=i.useMemo(()=>kd(X)<100,[X]),[ne,Z]=F.useState(null),Q=ve=>{if(P){let xe=Nn(ve);x&&re&&(xe=ol(ve)),P(xe)}},ie=(ve,xe)=>{let Re=Nn(ve);x&&re&&(Re=ol(Re)),ae(Re),Z(null),O&&O(Re,Re.toCssString()),xe||Q(Re)},[de,he]=F.useState(0),[ye,oe]=F.useState(!1),ce=ve=>{if(ee(ve),ve==="single"&&X.isGradient())he(0),ie(new Zn(X.getColors()[0].color)),Z(X);else if(ve==="gradient"&&!X.isGradient()){const xe=re?ol(X):X;ie(new Zn(ne||[{percent:0,color:xe},{percent:100,color:xe}]))}},{status:ge}=F.useContext(Wn),{compactSize:se,compactItemClassnames:be}=ro(te,B),we=Sn(ve=>{var xe;return(xe=y??se)!==null&&xe!==void 0?xe:ve}),Me=Cn(te),[Te,Se,Fe]=F5(te,Me),Ce={[`${te}-rtl`]:B},me=A(C,Fe,Me,Ce),$e=A(yo(te,ge),{[`${te}-sm`]:we==="small",[`${te}-lg`]:we==="large"},be,V==null?void 0:V.className,me,b,Se),Ee=A(te,me),Ie={open:H,trigger:u,placement:m,arrow:v,rootClassName:C,getPopupContainer:M,autoAdjustOverflow:R,destroyOnHidden:T??!!N},fe=Object.assign(Object.assign({},V==null?void 0:V.style),p);return Te(F.createElement(lf,Object.assign({style:S==null?void 0:S.popup,styles:{body:S==null?void 0:S.popupOverlayInner},onOpenChange:ve=>{(!ve||!q)&&W(ve)},content:F.createElement(jr,{form:!0},F.createElement(P5,{mode:le,onModeChange:ce,modeOptions:Y,prefixCls:te,value:X,allowClear:l,disabled:q,disabledAlpha:x,presets:s,panelRender:g,format:K,onFormatChange:U,onChange:ie,onChangeComplete:Q,onClear:w,activeIndex:de,onActive:he,gradientDragging:ye,onGradientDragging:oe,disabledFormat:j})),classNames:{root:Ee}},Ie),c||F.createElement(M5,Object.assign({activeIndex:H?de:-1,open:H,className:$e,style:fe,prefixCls:te,disabled:q,showText:h,format:K},z,{color:X}))))},V5=Ud(hC,void 0,e=>Object.assign(Object.assign({},e),{placement:"bottom",autoAdjustOverflow:!1}),"color-picker",e=>e);hC._InternalPanelDoNotUseOrYouWillBeFired=V5;var W5={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372s166.6-372 372-372 372 166.6 372 372-166.6 372-372 372z"}},{tag:"path",attrs:{d:"M686.7 638.6L544.1 535.5V288c0-4.4-3.6-8-8-8H488c-4.4 0-8 3.6-8 8v275.4c0 2.6 1.2 5 3.3 6.5l165.4 120.6c3.6 2.6 8.6 1.8 11.2-1.7l28.6-39c2.6-3.7 1.8-8.7-1.8-11.2z"}}]},name:"clock-circle",theme:"outlined"},K5=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:W5}))},mA=i.forwardRef(K5);const G5={xxl:3,xl:3,lg:3,md:3,sm:2,xs:1},Ef=F.createContext({});var q5=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const U5=e=>xn(e).map(t=>Object.assign(Object.assign({},t==null?void 0:t.props),{key:t.key}));function X5(e,t,n){const r=i.useMemo(()=>t||U5(n),[t,n]);return i.useMemo(()=>r.map(a=>{var{span:l}=a,s=q5(a,["span"]);return l==="filled"?Object.assign(Object.assign({},s),{filled:!0}):Object.assign(Object.assign({},s),{span:typeof l=="number"?l:Wb(e,l)})}),[r,e])}var Y5=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function Q5(e,t){let n=[],r=[],o=!1,a=0;return e.filter(l=>l).forEach(l=>{const{filled:s}=l,c=Y5(l,["filled"]);if(s){r.push(c),n.push(r),r=[],a=0;return}const u=t-a;a+=l.span||1,a>=t?(a>t?(o=!0,r.push(Object.assign(Object.assign({},c),{span:u}))):r.push(c),n.push(r),r=[],a=0):r.push(c)}),r.length>0&&n.push(r),n=n.map(l=>{const s=l.reduce((c,u)=>c+(u.span||1),0);if(s<t){const c=l[l.length-1];return c.span=t-(s-(c.span||1)),l}return l}),[n,o]}const Z5=(e,t)=>{const[n,r]=i.useMemo(()=>Q5(t,e),[t,e]);return n},J5=({children:e})=>e;function Hg(e){return e!=null}const Ec=e=>{const{itemPrefixCls:t,component:n,span:r,className:o,style:a,labelStyle:l,contentStyle:s,bordered:c,label:u,content:d,colon:f,type:m,styles:v}=e,g=n,h=i.useContext(Ef),{classNames:p}=h;return c?i.createElement(g,{className:A({[`${t}-item-label`]:m==="label",[`${t}-item-content`]:m==="content",[`${p==null?void 0:p.label}`]:m==="label",[`${p==null?void 0:p.content}`]:m==="content"},o),style:a,colSpan:r},Hg(u)&&i.createElement("span",{style:Object.assign(Object.assign({},l),v==null?void 0:v.label)},u),Hg(d)&&i.createElement("span",{style:Object.assign(Object.assign({},l),v==null?void 0:v.content)},d)):i.createElement(g,{className:A(`${t}-item`,o),style:a,colSpan:r},i.createElement("div",{className:`${t}-item-container`},(u||u===0)&&i.createElement("span",{className:A(`${t}-item-label`,p==null?void 0:p.label,{[`${t}-item-no-colon`]:!f}),style:Object.assign(Object.assign({},l),v==null?void 0:v.label)},u),(d||d===0)&&i.createElement("span",{className:A(`${t}-item-content`,p==null?void 0:p.content),style:Object.assign(Object.assign({},s),v==null?void 0:v.content)},d)))};function Oc(e,{colon:t,prefixCls:n,bordered:r},{component:o,type:a,showLabel:l,showContent:s,labelStyle:c,contentStyle:u,styles:d}){return e.map(({label:f,children:m,prefixCls:v=n,className:g,style:h,labelStyle:p,contentStyle:b,span:y=1,key:C,styles:$},S)=>typeof o=="string"?i.createElement(Ec,{key:`${a}-${C||S}`,className:g,style:h,styles:{label:Object.assign(Object.assign(Object.assign(Object.assign({},c),d==null?void 0:d.label),p),$==null?void 0:$.label),content:Object.assign(Object.assign(Object.assign(Object.assign({},u),d==null?void 0:d.content),b),$==null?void 0:$.content)},span:y,colon:t,component:o,itemPrefixCls:v,bordered:r,label:l?f:null,content:s?m:null,type:a}):[i.createElement(Ec,{key:`label-${C||S}`,className:g,style:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},c),d==null?void 0:d.label),h),p),$==null?void 0:$.label),span:1,colon:t,component:o[0],itemPrefixCls:v,bordered:r,label:f,type:"label"}),i.createElement(Ec,{key:`content-${C||S}`,className:g,style:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},u),d==null?void 0:d.content),h),b),$==null?void 0:$.content),span:y*2-1,component:o[1],itemPrefixCls:v,bordered:r,content:m,type:"content"})])}const e8=e=>{const t=i.useContext(Ef),{prefixCls:n,vertical:r,row:o,index:a,bordered:l}=e;return r?i.createElement(i.Fragment,null,i.createElement("tr",{key:`label-${a}`,className:`${n}-row`},Oc(o,e,Object.assign({component:"th",type:"label",showLabel:!0},t))),i.createElement("tr",{key:`content-${a}`,className:`${n}-row`},Oc(o,e,Object.assign({component:"td",type:"content",showContent:!0},t)))):i.createElement("tr",{key:a,className:`${n}-row`},Oc(o,e,Object.assign({component:l?["th","td"]:"td",type:"item",showLabel:!0,showContent:!0},t)))},t8=e=>{const{componentCls:t,labelBg:n}=e;return{[`&${t}-bordered`]:{[`> ${t}-view`]:{border:`${L(e.lineWidth)} ${e.lineType} ${e.colorSplit}`,"> table":{tableLayout:"auto"},[`${t}-row`]:{borderBottom:`${L(e.lineWidth)} ${e.lineType} ${e.colorSplit}`,"&:first-child":{"> th:first-child, > td:first-child":{borderStartStartRadius:e.borderRadiusLG}},"&:last-child":{borderBottom:"none","> th:first-child, > td:first-child":{borderEndStartRadius:e.borderRadiusLG}},[`> ${t}-item-label, > ${t}-item-content`]:{padding:`${L(e.padding)} ${L(e.paddingLG)}`,borderInlineEnd:`${L(e.lineWidth)} ${e.lineType} ${e.colorSplit}`,"&:last-child":{borderInlineEnd:"none"}},[`> ${t}-item-label`]:{color:e.colorTextSecondary,backgroundColor:n,"&::after":{display:"none"}}}},[`&${t}-middle`]:{[`${t}-row`]:{[`> ${t}-item-label, > ${t}-item-content`]:{padding:`${L(e.paddingSM)} ${L(e.paddingLG)}`}}},[`&${t}-small`]:{[`${t}-row`]:{[`> ${t}-item-label, > ${t}-item-content`]:{padding:`${L(e.paddingXS)} ${L(e.padding)}`}}}}}},n8=e=>{const{componentCls:t,extraColor:n,itemPaddingBottom:r,itemPaddingEnd:o,colonMarginRight:a,colonMarginLeft:l,titleMarginBottom:s}=e;return{[t]:Object.assign(Object.assign(Object.assign({},Tt(e)),t8(e)),{"&-rtl":{direction:"rtl"},[`${t}-header`]:{display:"flex",alignItems:"center",marginBottom:s},[`${t}-title`]:Object.assign(Object.assign({},sr),{flex:"auto",color:e.titleColor,fontWeight:e.fontWeightStrong,fontSize:e.fontSizeLG,lineHeight:e.lineHeightLG}),[`${t}-extra`]:{marginInlineStart:"auto",color:n,fontSize:e.fontSize},[`${t}-view`]:{width:"100%",borderRadius:e.borderRadiusLG,table:{width:"100%",tableLayout:"fixed",borderCollapse:"collapse"}},[`${t}-row`]:{"> th, > td":{paddingBottom:r,paddingInlineEnd:o},"> th:last-child, > td:last-child":{paddingInlineEnd:0},"&:last-child":{borderBottom:"none","> th, > td":{paddingBottom:0}}},[`${t}-item-label`]:{color:e.labelColor,fontWeight:"normal",fontSize:e.fontSize,lineHeight:e.lineHeight,textAlign:"start","&::after":{content:'":"',position:"relative",top:-.5,marginInline:`${L(l)} ${L(a)}`},[`&${t}-item-no-colon::after`]:{content:'""'}},[`${t}-item-no-label`]:{"&::after":{margin:0,content:'""'}},[`${t}-item-content`]:{display:"table-cell",flex:1,color:e.contentColor,fontSize:e.fontSize,lineHeight:e.lineHeight,wordBreak:"break-word",overflowWrap:"break-word"},[`${t}-item`]:{paddingBottom:0,verticalAlign:"top","&-container":{display:"flex",[`${t}-item-label`]:{display:"inline-flex",alignItems:"baseline"},[`${t}-item-content`]:{display:"inline-flex",alignItems:"baseline",minWidth:"1em"}}},"&-middle":{[`${t}-row`]:{"> th, > td":{paddingBottom:e.paddingSM}}},"&-small":{[`${t}-row`]:{"> th, > td":{paddingBottom:e.paddingXS}}}})}},r8=e=>({labelBg:e.colorFillAlter,labelColor:e.colorTextTertiary,titleColor:e.colorText,titleMarginBottom:e.fontSizeSM*e.lineHeightSM,itemPaddingBottom:e.padding,itemPaddingEnd:e.padding,colonMarginRight:e.marginXS,colonMarginLeft:e.marginXXS/2,contentColor:e.colorText,extraColor:e.colorText}),o8=It("Descriptions",e=>{const t=yt(e,{});return n8(t)},r8);var a8=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const i8=e=>{const{prefixCls:t,title:n,extra:r,column:o,colon:a=!0,bordered:l,layout:s,children:c,className:u,rootClassName:d,style:f,size:m,labelStyle:v,contentStyle:g,styles:h,items:p,classNames:b}=e,y=a8(e,["prefixCls","title","extra","column","colon","bordered","layout","children","className","rootClassName","style","size","labelStyle","contentStyle","styles","items","classNames"]),{getPrefixCls:C,direction:$,className:S,style:x,classNames:E,styles:O}=tn("descriptions"),w=C("descriptions",t),I=xs(),P=i.useMemo(()=>{var B;return typeof o=="number"?o:(B=Wb(I,Object.assign(Object.assign({},G5),o)))!==null&&B!==void 0?B:3},[I,o]),M=X5(I,p,c),R=Sn(m),N=Z5(P,M),[T,j,z]=o8(w),_=i.useMemo(()=>({labelStyle:v,contentStyle:g,styles:{content:Object.assign(Object.assign({},O.content),h==null?void 0:h.content),label:Object.assign(Object.assign({},O.label),h==null?void 0:h.label)},classNames:{label:A(E.label,b==null?void 0:b.label),content:A(E.content,b==null?void 0:b.content)}}),[v,g,h,b,E,O]);return T(i.createElement(Ef.Provider,{value:_},i.createElement("div",Object.assign({className:A(w,S,E.root,b==null?void 0:b.root,{[`${w}-${R}`]:R&&R!=="default",[`${w}-bordered`]:!!l,[`${w}-rtl`]:$==="rtl"},u,d,j,z),style:Object.assign(Object.assign(Object.assign(Object.assign({},x),O.root),h==null?void 0:h.root),f)},y),(n||r)&&i.createElement("div",{className:A(`${w}-header`,E.header,b==null?void 0:b.header),style:Object.assign(Object.assign({},O.header),h==null?void 0:h.header)},n&&i.createElement("div",{className:A(`${w}-title`,E.title,b==null?void 0:b.title),style:Object.assign(Object.assign({},O.title),h==null?void 0:h.title)},n),r&&i.createElement("div",{className:A(`${w}-extra`,E.extra,b==null?void 0:b.extra),style:Object.assign(Object.assign({},O.extra),h==null?void 0:h.extra)},r)),i.createElement("div",{className:`${w}-view`},i.createElement("table",null,i.createElement("tbody",null,N.map((B,V)=>i.createElement(e8,{key:V,index:V,colon:a,prefixCls:w,vertical:s==="vertical",bordered:l,row:B}))))))))};i8.Item=J5;var Ag=i.createContext(null),bC=i.createContext({}),l8=["prefixCls","className","containerRef"],s8=function(t){var n=t.prefixCls,r=t.className,o=t.containerRef,a=ft(t,l8),l=i.useContext(bC),s=l.panel,c=zr(s,o);return i.createElement("div",ue({className:A("".concat(n,"-content"),r),role:"dialog",ref:c},rn(t,{aria:!0}),{"aria-modal":"true"},a))};function Fg(e){return typeof e=="string"&&String(Number(e))===e?(Kt(!1,"Invalid value type of `width` or `height` which should be number type instead."),Number(e)):e}var kg={width:0,height:0,overflow:"hidden",outline:"none",position:"absolute"};function c8(e,t){var n,r,o,a=e.prefixCls,l=e.open,s=e.placement,c=e.inline,u=e.push,d=e.forceRender,f=e.autoFocus,m=e.keyboard,v=e.classNames,g=e.rootClassName,h=e.rootStyle,p=e.zIndex,b=e.className,y=e.id,C=e.style,$=e.motion,S=e.width,x=e.height,E=e.children,O=e.mask,w=e.maskClosable,I=e.maskMotion,P=e.maskClassName,M=e.maskStyle,R=e.afterOpenChange,N=e.onClose,T=e.onMouseEnter,j=e.onMouseOver,z=e.onMouseLeave,_=e.onClick,B=e.onKeyDown,V=e.onKeyUp,G=e.styles,q=e.drawerRender,H=i.useRef(),W=i.useRef(),K=i.useRef();i.useImperativeHandle(t,function(){return H.current});var U=function(ce){var ge=ce.keyCode,se=ce.shiftKey;switch(ge){case Ne.TAB:{if(ge===Ne.TAB){if(!se&&document.activeElement===K.current){var be;(be=W.current)===null||be===void 0||be.focus({preventScroll:!0})}else if(se&&document.activeElement===W.current){var we;(we=K.current)===null||we===void 0||we.focus({preventScroll:!0})}}break}case Ne.ESC:{N&&m&&(ce.stopPropagation(),N(ce));break}}};i.useEffect(function(){if(l&&f){var oe;(oe=H.current)===null||oe===void 0||oe.focus({preventScroll:!0})}},[l]);var te=i.useState(!1),X=J(te,2),ae=X[0],le=X[1],ee=i.useContext(Ag),Y;typeof u=="boolean"?Y=u?{}:{distance:0}:Y=u||{};var re=(n=(r=(o=Y)===null||o===void 0?void 0:o.distance)!==null&&r!==void 0?r:ee==null?void 0:ee.pushDistance)!==null&&n!==void 0?n:180,ne=i.useMemo(function(){return{pushDistance:re,push:function(){le(!0)},pull:function(){le(!1)}}},[re]);i.useEffect(function(){if(l){var oe;ee==null||(oe=ee.push)===null||oe===void 0||oe.call(ee)}else{var ce;ee==null||(ce=ee.pull)===null||ce===void 0||ce.call(ee)}},[l]),i.useEffect(function(){return function(){var oe;ee==null||(oe=ee.pull)===null||oe===void 0||oe.call(ee)}},[]);var Z=i.createElement(En,ue({key:"mask"},I,{visible:O&&l}),function(oe,ce){var ge=oe.className,se=oe.style;return i.createElement("div",{className:A("".concat(a,"-mask"),ge,v==null?void 0:v.mask,P),style:k(k(k({},se),M),G==null?void 0:G.mask),onClick:w&&l?N:void 0,ref:ce})}),Q=typeof $=="function"?$(s):$,ie={};if(ae&&re)switch(s){case"top":ie.transform="translateY(".concat(re,"px)");break;case"bottom":ie.transform="translateY(".concat(-re,"px)");break;case"left":ie.transform="translateX(".concat(re,"px)");break;default:ie.transform="translateX(".concat(-re,"px)");break}s==="left"||s==="right"?ie.width=Fg(S):ie.height=Fg(x);var de={onMouseEnter:T,onMouseOver:j,onMouseLeave:z,onClick:_,onKeyDown:B,onKeyUp:V},he=i.createElement(En,ue({key:"panel"},Q,{visible:l,forceRender:d,onVisibleChanged:function(ce){R==null||R(ce)},removeOnLeave:!1,leavedClassName:"".concat(a,"-content-wrapper-hidden")}),function(oe,ce){var ge=oe.className,se=oe.style,be=i.createElement(s8,ue({id:y,containerRef:ce,prefixCls:a,className:A(b,v==null?void 0:v.content),style:k(k({},C),G==null?void 0:G.content)},rn(e,{aria:!0}),de),E);return i.createElement("div",ue({className:A("".concat(a,"-content-wrapper"),v==null?void 0:v.wrapper,ge),style:k(k(k({},ie),se),G==null?void 0:G.wrapper)},rn(e,{data:!0})),q?q(be):be)}),ye=k({},h);return p&&(ye.zIndex=p),i.createElement(Ag.Provider,{value:ne},i.createElement("div",{className:A(a,"".concat(a,"-").concat(s),g,D(D({},"".concat(a,"-open"),l),"".concat(a,"-inline"),c)),style:ye,tabIndex:-1,ref:H,onKeyDown:U},Z,i.createElement("div",{tabIndex:0,ref:W,style:kg,"aria-hidden":"true","data-sentinel":"start"}),he,i.createElement("div",{tabIndex:0,ref:K,style:kg,"aria-hidden":"true","data-sentinel":"end"})))}var u8=i.forwardRef(c8),d8=function(t){var n=t.open,r=n===void 0?!1:n,o=t.prefixCls,a=o===void 0?"rc-drawer":o,l=t.placement,s=l===void 0?"right":l,c=t.autoFocus,u=c===void 0?!0:c,d=t.keyboard,f=d===void 0?!0:d,m=t.width,v=m===void 0?378:m,g=t.mask,h=g===void 0?!0:g,p=t.maskClosable,b=p===void 0?!0:p,y=t.getContainer,C=t.forceRender,$=t.afterOpenChange,S=t.destroyOnClose,x=t.onMouseEnter,E=t.onMouseOver,O=t.onMouseLeave,w=t.onClick,I=t.onKeyDown,P=t.onKeyUp,M=t.panelRef,R=i.useState(!1),N=J(R,2),T=N[0],j=N[1],z=i.useState(!1),_=J(z,2),B=_[0],V=_[1];wt(function(){V(!0)},[]);var G=B?r:!1,q=i.useRef(),H=i.useRef();wt(function(){G&&(H.current=document.activeElement)},[G]);var W=function(ae){var le;if(j(ae),$==null||$(ae),!ae&&H.current&&!((le=q.current)!==null&&le!==void 0&&le.contains(H.current))){var ee;(ee=H.current)===null||ee===void 0||ee.focus({preventScroll:!0})}},K=i.useMemo(function(){return{panel:M}},[M]);if(!C&&!T&&!G&&S)return null;var U={onMouseEnter:x,onMouseOver:E,onMouseLeave:O,onClick:w,onKeyDown:I,onKeyUp:P},te=k(k({},t),{},{open:G,prefixCls:a,placement:s,autoFocus:u,keyboard:f,width:v,mask:h,maskClosable:b,inline:y===!1,afterOpenChange:W,ref:q},U);return i.createElement(bC.Provider,{value:K},i.createElement(ps,{open:G||C||T,autoDestroy:!1,getContainer:y,autoLock:h&&(G||T)},i.createElement(u8,te)))};const yC=e=>{var t,n;const{prefixCls:r,title:o,footer:a,extra:l,loading:s,onClose:c,headerStyle:u,bodyStyle:d,footerStyle:f,children:m,classNames:v,styles:g}=e,h=tn("drawer"),p=i.useCallback(S=>i.createElement("button",{type:"button",onClick:c,className:`${r}-close`},S),[c]),[b,y]=Gd(oa(e),oa(h),{closable:!0,closeIconRender:p}),C=i.useMemo(()=>{var S,x;return!o&&!b?null:i.createElement("div",{style:Object.assign(Object.assign(Object.assign({},(S=h.styles)===null||S===void 0?void 0:S.header),u),g==null?void 0:g.header),className:A(`${r}-header`,{[`${r}-header-close-only`]:b&&!o&&!l},(x=h.classNames)===null||x===void 0?void 0:x.header,v==null?void 0:v.header)},i.createElement("div",{className:`${r}-header-title`},y,o&&i.createElement("div",{className:`${r}-title`},o)),l&&i.createElement("div",{className:`${r}-extra`},l))},[b,y,l,u,r,o]),$=i.useMemo(()=>{var S,x;if(!a)return null;const E=`${r}-footer`;return i.createElement("div",{className:A(E,(S=h.classNames)===null||S===void 0?void 0:S.footer,v==null?void 0:v.footer),style:Object.assign(Object.assign(Object.assign({},(x=h.styles)===null||x===void 0?void 0:x.footer),f),g==null?void 0:g.footer)},a)},[a,f,r]);return i.createElement(i.Fragment,null,C,i.createElement("div",{className:A(`${r}-body`,v==null?void 0:v.body,(t=h.classNames)===null||t===void 0?void 0:t.body),style:Object.assign(Object.assign(Object.assign({},(n=h.styles)===null||n===void 0?void 0:n.body),d),g==null?void 0:g.body)},s?i.createElement(kr,{active:!0,title:!1,paragraph:{rows:5},className:`${r}-body-skeleton`}):m),$)},f8=e=>{const t="100%";return{left:`translateX(-${t})`,right:`translateX(${t})`,top:`translateY(-${t})`,bottom:`translateY(${t})`}[e]},CC=(e,t)=>({"&-enter, &-appear":Object.assign(Object.assign({},e),{"&-active":t}),"&-leave":Object.assign(Object.assign({},t),{"&-active":e})}),SC=(e,t)=>Object.assign({"&-enter, &-appear, &-leave":{"&-start":{transition:"none"},"&-active":{transition:`all ${t}`}}},CC({opacity:e},{opacity:1})),m8=(e,t)=>[SC(.7,t),CC({transform:f8(e)},{transform:"none"})],v8=e=>{const{componentCls:t,motionDurationSlow:n}=e;return{[t]:{[`${t}-mask-motion`]:SC(0,n),[`${t}-panel-motion`]:["left","right","top","bottom"].reduce((r,o)=>Object.assign(Object.assign({},r),{[`&-${o}`]:m8(o,n)}),{})}}},g8=e=>{const{borderRadiusSM:t,componentCls:n,zIndexPopup:r,colorBgMask:o,colorBgElevated:a,motionDurationSlow:l,motionDurationMid:s,paddingXS:c,padding:u,paddingLG:d,fontSizeLG:f,lineHeightLG:m,lineWidth:v,lineType:g,colorSplit:h,marginXS:p,colorIcon:b,colorIconHover:y,colorBgTextHover:C,colorBgTextActive:$,colorText:S,fontWeightStrong:x,footerPaddingBlock:E,footerPaddingInline:O,calc:w}=e,I=`${n}-content-wrapper`;return{[n]:{position:"fixed",inset:0,zIndex:r,pointerEvents:"none",color:S,"&-pure":{position:"relative",background:a,display:"flex",flexDirection:"column",[`&${n}-left`]:{boxShadow:e.boxShadowDrawerLeft},[`&${n}-right`]:{boxShadow:e.boxShadowDrawerRight},[`&${n}-top`]:{boxShadow:e.boxShadowDrawerUp},[`&${n}-bottom`]:{boxShadow:e.boxShadowDrawerDown}},"&-inline":{position:"absolute"},[`${n}-mask`]:{position:"absolute",inset:0,zIndex:r,background:o,pointerEvents:"auto"},[I]:{position:"absolute",zIndex:r,maxWidth:"100vw",transition:`all ${l}`,"&-hidden":{display:"none"}},[`&-left > ${I}`]:{top:0,bottom:0,left:{_skip_check_:!0,value:0},boxShadow:e.boxShadowDrawerLeft},[`&-right > ${I}`]:{top:0,right:{_skip_check_:!0,value:0},bottom:0,boxShadow:e.boxShadowDrawerRight},[`&-top > ${I}`]:{top:0,insetInline:0,boxShadow:e.boxShadowDrawerUp},[`&-bottom > ${I}`]:{bottom:0,insetInline:0,boxShadow:e.boxShadowDrawerDown},[`${n}-content`]:{display:"flex",flexDirection:"column",width:"100%",height:"100%",overflow:"auto",background:a,pointerEvents:"auto"},[`${n}-header`]:{display:"flex",flex:0,alignItems:"center",padding:`${L(u)} ${L(d)}`,fontSize:f,lineHeight:m,borderBottom:`${L(v)} ${g} ${h}`,"&-title":{display:"flex",flex:1,alignItems:"center",minWidth:0,minHeight:0}},[`${n}-extra`]:{flex:"none"},[`${n}-close`]:Object.assign({display:"inline-flex",width:w(f).add(c).equal(),height:w(f).add(c).equal(),borderRadius:t,justifyContent:"center",alignItems:"center",marginInlineEnd:p,color:b,fontWeight:x,fontSize:f,fontStyle:"normal",lineHeight:1,textAlign:"center",textTransform:"none",textDecoration:"none",background:"transparent",border:0,cursor:"pointer",transition:`all ${s}`,textRendering:"auto","&:hover":{color:y,backgroundColor:C,textDecoration:"none"},"&:active":{backgroundColor:$}},Vn(e)),[`${n}-title`]:{flex:1,margin:0,fontWeight:e.fontWeightStrong,fontSize:f,lineHeight:m},[`${n}-body`]:{flex:1,minWidth:0,minHeight:0,padding:d,overflow:"auto",[`${n}-body-skeleton`]:{width:"100%",height:"100%",display:"flex",justifyContent:"center"}},[`${n}-footer`]:{flexShrink:0,padding:`${L(E)} ${L(O)}`,borderTop:`${L(v)} ${g} ${h}`},"&-rtl":{direction:"rtl"}}}},p8=e=>({zIndexPopup:e.zIndexPopupBase,footerPaddingBlock:e.paddingXS,footerPaddingInline:e.padding}),$C=It("Drawer",e=>{const t=yt(e,{});return[g8(t),v8(t)]},p8);var xC=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const h8={distance:180},b8=e=>{const{rootClassName:t,width:n,height:r,size:o="default",mask:a=!0,push:l=h8,open:s,afterOpenChange:c,onClose:u,prefixCls:d,getContainer:f,panelRef:m=null,style:v,className:g,visible:h,afterVisibleChange:p,maskStyle:b,drawerStyle:y,contentWrapperStyle:C,destroyOnClose:$,destroyOnHidden:S}=e,x=xC(e,["rootClassName","width","height","size","mask","push","open","afterOpenChange","onClose","prefixCls","getContainer","panelRef","style","className","visible","afterVisibleChange","maskStyle","drawerStyle","contentWrapperStyle","destroyOnClose","destroyOnHidden"]),{getPopupContainer:E,getPrefixCls:O,direction:w,className:I,style:P,classNames:M,styles:R}=tn("drawer"),N=O("drawer",d),[T,j,z]=$C(N),_=f===void 0&&E?()=>E(document.body):f,B=A({"no-mask":!a,[`${N}-rtl`]:w==="rtl"},t,j,z),V=i.useMemo(()=>n??(o==="large"?736:378),[n,o]),G=i.useMemo(()=>r??(o==="large"?736:378),[r,o]),q={motionName:Mr(N,"mask-motion"),motionAppear:!0,motionEnter:!0,motionLeave:!0,motionDeadline:500},H=le=>({motionName:Mr(N,`panel-motion-${le}`),motionAppear:!0,motionEnter:!0,motionLeave:!0,motionDeadline:500}),W=Z0(),K=un(m,W),[U,te]=ma("Drawer",x.zIndex),{classNames:X={},styles:ae={}}=x;return T(i.createElement(jr,{form:!0,space:!0},i.createElement(li.Provider,{value:te},i.createElement(d8,Object.assign({prefixCls:N,onClose:u,maskMotion:q,motion:H},x,{classNames:{mask:A(X.mask,M.mask),content:A(X.content,M.content),wrapper:A(X.wrapper,M.wrapper)},styles:{mask:Object.assign(Object.assign(Object.assign({},ae.mask),b),R.mask),content:Object.assign(Object.assign(Object.assign({},ae.content),y),R.content),wrapper:Object.assign(Object.assign(Object.assign({},ae.wrapper),C),R.wrapper)},open:s??h,mask:a,push:l,width:V,height:G,style:Object.assign(Object.assign({},P),v),className:A(I,g),rootClassName:B,getContainer:_,afterOpenChange:c??p,panelRef:K,zIndex:U,destroyOnClose:S??$}),i.createElement(yC,Object.assign({prefixCls:N},x,{onClose:u}))))))},y8=e=>{const{prefixCls:t,style:n,className:r,placement:o="right"}=e,a=xC(e,["prefixCls","style","className","placement"]),{getPrefixCls:l}=i.useContext(ot),s=l("drawer",t),[c,u,d]=$C(s),f=A(s,`${s}-pure`,`${s}-${o}`,u,d,r);return c(i.createElement("div",{className:f,style:n},i.createElement(yC,Object.assign({prefixCls:s},a))))};b8._InternalPanelDoNotUseOrYouWillBeFired=y8;function Vg(e){return["small","middle","large"].includes(e)}function Wg(e){return e?typeof e=="number"&&!Number.isNaN(e):!1}const wC=F.createContext({latestIndex:0}),C8=wC.Provider,S8=({className:e,index:t,children:n,split:r,style:o})=>{const{latestIndex:a}=i.useContext(wC);return n==null?null:i.createElement(i.Fragment,null,i.createElement("div",{className:e,style:o},n),t<a&&r&&i.createElement("span",{className:`${e}-split`},r))};var $8=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const x8=i.forwardRef((e,t)=>{var n;const{getPrefixCls:r,direction:o,size:a,className:l,style:s,classNames:c,styles:u}=tn("space"),{size:d=a??"small",align:f,className:m,rootClassName:v,children:g,direction:h="horizontal",prefixCls:p,split:b,style:y,wrap:C=!1,classNames:$,styles:S}=e,x=$8(e,["size","align","className","rootClassName","children","direction","prefixCls","split","style","wrap","classNames","styles"]),[E,O]=Array.isArray(d)?d:[d,d],w=Vg(O),I=Vg(E),P=Wg(O),M=Wg(E),R=xn(g,{keepEmpty:!0}),N=f===void 0&&h==="horizontal"?"center":f,T=r("space",p),[j,z,_]=S0(T),B=A(T,l,z,`${T}-${h}`,{[`${T}-rtl`]:o==="rtl",[`${T}-align-${N}`]:N,[`${T}-gap-row-${O}`]:w,[`${T}-gap-col-${E}`]:I},m,v,_),V=A(`${T}-item`,(n=$==null?void 0:$.item)!==null&&n!==void 0?n:c.item);let G=0;const q=R.map((K,U)=>{var te;K!=null&&(G=U);const X=(K==null?void 0:K.key)||`${V}-${U}`;return i.createElement(S8,{className:V,key:X,index:U,split:b,style:(te=S==null?void 0:S.item)!==null&&te!==void 0?te:u.item},K)}),H=i.useMemo(()=>({latestIndex:G}),[G]);if(R.length===0)return null;const W={};return C&&(W.flexWrap="wrap"),!I&&M&&(W.columnGap=E),!w&&P&&(W.rowGap=O),j(i.createElement("div",Object.assign({ref:t,className:B,style:Object.assign(Object.assign(Object.assign({},W),s),y)},x),i.createElement(C8,{value:H},q)))}),EC=x8;EC.Compact=EE;var w8=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const OC=e=>{const{getPopupContainer:t,getPrefixCls:n,direction:r}=i.useContext(ot),{prefixCls:o,type:a="default",danger:l,disabled:s,loading:c,onClick:u,htmlType:d,children:f,className:m,menu:v,arrow:g,autoFocus:h,overlay:p,trigger:b,align:y,open:C,onOpenChange:$,placement:S,getPopupContainer:x,href:E,icon:O=i.createElement(gf,null),title:w,buttonsRender:I=ee=>ee,mouseEnterDelay:P,mouseLeaveDelay:M,overlayClassName:R,overlayStyle:N,destroyOnHidden:T,destroyPopupOnHide:j,dropdownRender:z,popupRender:_}=e,B=w8(e,["prefixCls","type","danger","disabled","loading","onClick","htmlType","children","className","menu","arrow","autoFocus","overlay","trigger","align","open","onOpenChange","placement","getPopupContainer","href","icon","title","buttonsRender","mouseEnterDelay","mouseLeaveDelay","overlayClassName","overlayStyle","destroyOnHidden","destroyPopupOnHide","dropdownRender","popupRender"]),V=n("dropdown",o),G=`${V}-button`,H={menu:v,arrow:g,autoFocus:h,align:y,disabled:s,trigger:s?[]:b,onOpenChange:$,getPopupContainer:x||t,mouseEnterDelay:P,mouseLeaveDelay:M,overlayClassName:R,overlayStyle:N,destroyOnHidden:T,popupRender:_||z},{compactSize:W,compactItemClassnames:K}=ro(V,r),U=A(G,K,m);"destroyPopupOnHide"in e&&(H.destroyPopupOnHide=j),"overlay"in e&&(H.overlay=p),"open"in e&&(H.open=C),"placement"in e?H.placement=S:H.placement=r==="rtl"?"bottomLeft":"bottomRight";const te=i.createElement(er,{type:a,danger:l,disabled:s,loading:c,onClick:u,htmlType:d,href:E,title:w},f),X=i.createElement(er,{type:a,danger:l,icon:O}),[ae,le]=I([te,X]);return i.createElement(EC.Compact,Object.assign({className:U,size:W,block:!0},B),ae,i.createElement(Ps,Object.assign({},H),le))};OC.__ANT_BUTTON=!0;const Of=Ps;Of.Button=OC;var E8={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M854.6 288.6L639.4 73.4c-6-6-14.1-9.4-22.6-9.4H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V311.3c0-8.5-3.4-16.7-9.4-22.7zM790.2 326H602V137.8L790.2 326zm1.8 562H232V136h302v216a42 42 0 0042 42h216v494zM504 618H320c-4.4 0-8 3.6-8 8v48c0 4.4 3.6 8 8 8h184c4.4 0 8-3.6 8-8v-48c0-4.4-3.6-8-8-8zM312 490v48c0 4.4 3.6 8 8 8h384c4.4 0 8-3.6 8-8v-48c0-4.4-3.6-8-8-8H320c-4.4 0-8 3.6-8 8z"}}]},name:"file-text",theme:"outlined"},O8=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:E8}))},vA=i.forwardRef(O8),I8={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M942.2 486.2C847.4 286.5 704.1 186 512 186c-192.2 0-335.4 100.5-430.2 300.3a60.3 60.3 0 000 51.5C176.6 737.5 319.9 838 512 838c192.2 0 335.4-100.5 430.2-300.3 7.7-16.2 7.7-35 0-51.5zM512 766c-161.3 0-279.4-81.8-362.7-254C232.6 339.8 350.7 258 512 258c161.3 0 279.4 81.8 362.7 254C791.5 684.2 673.4 766 512 766zm-4-430c-97.2 0-176 78.8-176 176s78.8 176 176 176 176-78.8 176-176-78.8-176-176-176zm0 288c-61.9 0-112-50.1-112-112s50.1-112 112-112 112 50.1 112 112-50.1 112-112 112z"}}]},name:"eye",theme:"outlined"},R8=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:I8}))},IC=i.forwardRef(R8);function Kg(e,t,n,r){var o=dl.unstable_batchedUpdates?function(l){dl.unstable_batchedUpdates(n,l)}:n;return e!=null&&e.addEventListener&&e.addEventListener(t,o,r),{remove:function(){e!=null&&e.removeEventListener&&e.removeEventListener(t,o,r)}}}const P8=e=>{const{getPrefixCls:t,direction:n}=i.useContext(ot),{prefixCls:r,className:o}=e,a=t("input-group",r),l=t("input"),[s,c,u]=Ly(l),d=A(a,u,{[`${a}-lg`]:e.size==="large",[`${a}-sm`]:e.size==="small",[`${a}-compact`]:e.compact,[`${a}-rtl`]:n==="rtl"},c,o),f=i.useContext(Wn),m=i.useMemo(()=>Object.assign(Object.assign({},f),{isFormItemInput:!1}),[f]);return s(i.createElement("span",{className:d,style:e.style,onMouseEnter:e.onMouseEnter,onMouseLeave:e.onMouseLeave,onFocus:e.onFocus,onBlur:e.onBlur},i.createElement(Wn.Provider,{value:m},e.children)))},N8=e=>{const{componentCls:t,paddingXS:n}=e;return{[t]:{display:"inline-flex",alignItems:"center",flexWrap:"nowrap",columnGap:n,[`${t}-input-wrapper`]:{position:"relative",[`${t}-mask-icon`]:{position:"absolute",zIndex:"1",top:"50%",right:"50%",transform:"translate(50%, -50%)",pointerEvents:"none"},[`${t}-mask-input`]:{color:"transparent",caretColor:e.colorText},[`${t}-mask-input[type=number]::-webkit-inner-spin-button`]:{"-webkit-appearance":"none",margin:0},[`${t}-mask-input[type=number]`]:{"-moz-appearance":"textfield"}},"&-rtl":{direction:"rtl"},[`${t}-input`]:{textAlign:"center",paddingInline:e.paddingXXS},[`&${t}-sm ${t}-input`]:{paddingInline:e.calc(e.paddingXXS).div(2).equal()},[`&${t}-lg ${t}-input`]:{paddingInline:e.paddingXS}}}},M8=It(["Input","OTP"],e=>{const t=yt(e,ba(e));return N8(t)},ya);var T8=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const j8=i.forwardRef((e,t)=>{const{className:n,value:r,onChange:o,onActiveChange:a,index:l,mask:s}=e,c=T8(e,["className","value","onChange","onActiveChange","index","mask"]),{getPrefixCls:u}=i.useContext(ot),d=u("otp"),f=typeof s=="string"?s:r,m=i.useRef(null);i.useImperativeHandle(t,()=>m.current);const v=b=>{o(l,b.target.value)},g=()=>{Et(()=>{var b;const y=(b=m.current)===null||b===void 0?void 0:b.input;document.activeElement===y&&y&&y.select()})},h=b=>{const{key:y,ctrlKey:C,metaKey:$}=b;y==="ArrowLeft"?a(l-1):y==="ArrowRight"?a(l+1):y==="z"&&(C||$)&&b.preventDefault(),g()},p=b=>{b.key==="Backspace"&&!r&&a(l-1),g()};return i.createElement("span",{className:`${d}-input-wrapper`,role:"presentation"},s&&r!==""&&r!==void 0&&i.createElement("span",{className:`${d}-mask-icon`,"aria-hidden":"true"},f),i.createElement(Ca,Object.assign({"aria-label":`OTP Input ${l+1}`,type:s===!0?"password":"text"},c,{ref:m,value:r,onInput:v,onFocus:g,onKeyDown:h,onKeyUp:p,onMouseDown:g,onMouseUp:g,className:A(n,{[`${d}-mask-input`]:s})})))});var z8=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function Ai(e){return(e||"").split("")}const D8=e=>{const{index:t,prefixCls:n,separator:r}=e,o=typeof r=="function"?r(t):r;return o?i.createElement("span",{className:`${n}-separator`},o):null},_8=i.forwardRef((e,t)=>{const{prefixCls:n,length:r=6,size:o,defaultValue:a,value:l,onChange:s,formatter:c,separator:u,variant:d,disabled:f,status:m,autoFocus:v,mask:g,type:h,onInput:p,inputMode:b}=e,y=z8(e,["prefixCls","length","size","defaultValue","value","onChange","formatter","separator","variant","disabled","status","autoFocus","mask","type","onInput","inputMode"]),{getPrefixCls:C,direction:$}=i.useContext(ot),S=C("otp",n),x=rn(y,{aria:!0,data:!0,attr:!0}),[E,O,w]=M8(S),I=Sn(W=>o??W),P=i.useContext(Wn),M=bi(P.status,m),R=i.useMemo(()=>Object.assign(Object.assign({},P),{status:M,hasFeedback:!1,feedbackIcon:null}),[P,M]),N=i.useRef(null),T=i.useRef({});i.useImperativeHandle(t,()=>({focus:()=>{var W;(W=T.current[0])===null||W===void 0||W.focus()},blur:()=>{var W;for(let K=0;K<r;K+=1)(W=T.current[K])===null||W===void 0||W.blur()},nativeElement:N.current}));const j=W=>c?c(W):W,[z,_]=i.useState(()=>Ai(j(a||"")));i.useEffect(()=>{l!==void 0&&_(Ai(l))},[l]);const B=Nt(W=>{_(W),p&&p(W),s&&W.length===r&&W.every(K=>K)&&W.some((K,U)=>z[U]!==K)&&s(W.join(""))}),V=Nt((W,K)=>{let U=pe(z);for(let X=0;X<W;X+=1)U[X]||(U[X]="");K.length<=1?U[W]=K:U=U.slice(0,W).concat(Ai(K)),U=U.slice(0,r);for(let X=U.length-1;X>=0&&!U[X];X-=1)U.pop();const te=j(U.map(X=>X||" ").join(""));return U=Ai(te).map((X,ae)=>X===" "&&!U[ae]?U[ae]:X),U}),G=(W,K)=>{var U;const te=V(W,K),X=Math.min(W+K.length,r-1);X!==W&&te[W]!==void 0&&((U=T.current[X])===null||U===void 0||U.focus()),B(te)},q=W=>{var K;(K=T.current[W])===null||K===void 0||K.focus()},H={variant:d,disabled:f,status:M,mask:g,type:h,inputMode:b};return E(i.createElement("div",Object.assign({},x,{ref:N,className:A(S,{[`${S}-sm`]:I==="small",[`${S}-lg`]:I==="large",[`${S}-rtl`]:$==="rtl"},w,O),role:"group"}),i.createElement(Wn.Provider,{value:R},Array.from({length:r}).map((W,K)=>{const U=`otp-${K}`,te=z[K]||"";return i.createElement(i.Fragment,{key:U},i.createElement(j8,Object.assign({ref:X=>{T.current[K]=X},index:K,size:I,htmlSize:1,className:`${S}-input`,onChange:G,value:te,onActiveChange:q,autoFocus:K===0&&v},H)),K<r-1&&i.createElement(D8,{separator:u,index:K,prefixCls:S}))}))))});var B8={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M942.2 486.2Q889.47 375.11 816.7 305l-50.88 50.88C807.31 395.53 843.45 447.4 874.7 512 791.5 684.2 673.4 766 512 766q-72.67 0-133.87-22.38L323 798.75Q408 838 512 838q288.3 0 430.2-300.3a60.29 60.29 0 000-51.5zm-63.57-320.64L836 122.88a8 8 0 00-11.32 0L715.31 232.2Q624.86 186 512 186q-288.3 0-430.2 300.3a60.3 60.3 0 000 51.5q56.69 119.4 136.5 191.41L112.48 835a8 8 0 000 11.31L155.17 889a8 8 0 0011.31 0l712.15-712.12a8 8 0 000-11.32zM149.3 512C232.6 339.8 350.7 258 512 258c54.54 0 104.13 9.36 149.12 28.39l-70.3 70.3a176 176 0 00-238.13 238.13l-83.42 83.42C223.1 637.49 183.3 582.28 149.3 512zm246.7 0a112.11 112.11 0 01146.2-106.69L401.31 546.2A112 112 0 01396 512z"}},{tag:"path",attrs:{d:"M508 624c-3.46 0-6.87-.16-10.25-.47l-52.82 52.82a176.09 176.09 0 00227.42-227.42l-52.82 52.82c.31 3.38.47 6.79.47 10.25a111.94 111.94 0 01-112 112z"}}]},name:"eye-invisible",theme:"outlined"},L8=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:B8}))},H8=i.forwardRef(L8),A8=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const F8=e=>e?i.createElement(IC,null):i.createElement(H8,null),k8={click:"onClick",hover:"onMouseOver"},V8=i.forwardRef((e,t)=>{const{disabled:n,action:r="click",visibilityToggle:o=!0,iconRender:a=F8,suffix:l}=e,s=i.useContext(Ln),c=n??s,u=typeof o=="object"&&o.visible!==void 0,[d,f]=i.useState(()=>u?o.visible:!1),m=i.useRef(null);i.useEffect(()=>{u&&f(o.visible)},[u,o]);const v=dC(m),g=()=>{var P;if(c)return;d&&v();const M=!d;f(M),typeof o=="object"&&((P=o.onVisibleChange)===null||P===void 0||P.call(o,M))},h=P=>{const M=k8[r]||"",R=a(d),N={[M]:g,className:`${P}-icon`,key:"passwordIcon",onMouseDown:T=>{T.preventDefault()},onMouseUp:T=>{T.preventDefault()}};return i.cloneElement(i.isValidElement(R)?R:i.createElement("span",null,R),N)},{className:p,prefixCls:b,inputPrefixCls:y,size:C}=e,$=A8(e,["className","prefixCls","inputPrefixCls","size"]),{getPrefixCls:S}=i.useContext(ot),x=S("input",y),E=S("input-password",b),O=o&&h(E),w=A(E,p,{[`${E}-${C}`]:!!C}),I=Object.assign(Object.assign({},Gt($,["suffix","iconRender","visibilityToggle"])),{type:d?"text":"password",className:w,prefixCls:x,suffix:i.createElement(i.Fragment,null,O,l)});return C&&(I.size=C),i.createElement(Ca,Object.assign({ref:un(t,m)},I))});var W8=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const K8=i.forwardRef((e,t)=>{const{prefixCls:n,inputPrefixCls:r,className:o,size:a,suffix:l,enterButton:s=!1,addonAfter:c,loading:u,disabled:d,onSearch:f,onChange:m,onCompositionStart:v,onCompositionEnd:g,variant:h,onPressEnter:p}=e,b=W8(e,["prefixCls","inputPrefixCls","className","size","suffix","enterButton","addonAfter","loading","disabled","onSearch","onChange","onCompositionStart","onCompositionEnd","variant","onPressEnter"]),{getPrefixCls:y,direction:C}=i.useContext(ot),$=i.useRef(!1),S=y("input-search",n),x=y("input",r),{compactSize:E}=ro(S,C),O=Sn(H=>{var W;return(W=a??E)!==null&&W!==void 0?W:H}),w=i.useRef(null),I=H=>{H!=null&&H.target&&H.type==="click"&&f&&f(H.target.value,H,{source:"clear"}),m==null||m(H)},P=H=>{var W;document.activeElement===((W=w.current)===null||W===void 0?void 0:W.input)&&H.preventDefault()},M=H=>{var W,K;f&&f((K=(W=w.current)===null||W===void 0?void 0:W.input)===null||K===void 0?void 0:K.value,H,{source:"input"})},R=H=>{$.current||u||(p==null||p(H),M(H))},N=typeof s=="boolean"?i.createElement(tf,null):null,T=`${S}-button`;let j;const z=s||{},_=z.type&&z.type.__ANT_BUTTON===!0;_||z.type==="button"?j=cn(z,Object.assign({onMouseDown:P,onClick:H=>{var W,K;(K=(W=z==null?void 0:z.props)===null||W===void 0?void 0:W.onClick)===null||K===void 0||K.call(W,H),M(H)},key:"enterButton"},_?{className:T,size:O}:{})):j=i.createElement(er,{className:T,color:s?"primary":"default",size:O,disabled:d,key:"enterButton",onMouseDown:P,onClick:M,loading:u,icon:N,variant:h==="borderless"||h==="filled"||h==="underlined"?"text":s?"solid":void 0},s),c&&(j=[j,cn(c,{key:"addonAfter"})]);const B=A(S,{[`${S}-rtl`]:C==="rtl",[`${S}-${O}`]:!!O,[`${S}-with-button`]:!!s},o),V=H=>{$.current=!0,v==null||v(H)},G=H=>{$.current=!1,g==null||g(H)},q=Object.assign(Object.assign({},b),{className:B,prefixCls:x,type:"search",size:O,variant:h,onPressEnter:R,onCompositionStart:V,onCompositionEnd:G,addonAfter:j,suffix:l,onChange:I,disabled:d});return i.createElement(Ca,Object.assign({ref:un(w,t)},q))});var G8=`
  min-height:0 !important;
  max-height:none !important;
  height:0 !important;
  visibility:hidden !important;
  overflow:hidden !important;
  position:absolute !important;
  z-index:-1000 !important;
  top:0 !important;
  right:0 !important;
  pointer-events: none !important;
`,q8=["letter-spacing","line-height","padding-top","padding-bottom","font-family","font-weight","font-size","font-variant","text-rendering","text-transform","width","text-indent","padding-left","padding-right","border-width","box-sizing","word-break","white-space"],Ic={},Yn;function U8(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,n=e.getAttribute("id")||e.getAttribute("data-reactid")||e.getAttribute("name");if(t&&Ic[n])return Ic[n];var r=window.getComputedStyle(e),o=r.getPropertyValue("box-sizing")||r.getPropertyValue("-moz-box-sizing")||r.getPropertyValue("-webkit-box-sizing"),a=parseFloat(r.getPropertyValue("padding-bottom"))+parseFloat(r.getPropertyValue("padding-top")),l=parseFloat(r.getPropertyValue("border-bottom-width"))+parseFloat(r.getPropertyValue("border-top-width")),s=q8.map(function(u){return"".concat(u,":").concat(r.getPropertyValue(u))}).join(";"),c={sizingStyle:s,paddingSize:a,borderSize:l,boxSizing:o};return t&&n&&(Ic[n]=c),c}function X8(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:null,r=arguments.length>3&&arguments[3]!==void 0?arguments[3]:null;Yn||(Yn=document.createElement("textarea"),Yn.setAttribute("tab-index","-1"),Yn.setAttribute("aria-hidden","true"),Yn.setAttribute("name","hiddenTextarea"),document.body.appendChild(Yn)),e.getAttribute("wrap")?Yn.setAttribute("wrap",e.getAttribute("wrap")):Yn.removeAttribute("wrap");var o=U8(e,t),a=o.paddingSize,l=o.borderSize,s=o.boxSizing,c=o.sizingStyle;Yn.setAttribute("style","".concat(c,";").concat(G8)),Yn.value=e.value||e.placeholder||"";var u=void 0,d=void 0,f,m=Yn.scrollHeight;if(s==="border-box"?m+=l:s==="content-box"&&(m-=a),n!==null||r!==null){Yn.value=" ";var v=Yn.scrollHeight-a;n!==null&&(u=v*n,s==="border-box"&&(u=u+a+l),m=Math.max(u,m)),r!==null&&(d=v*r,s==="border-box"&&(d=d+a+l),f=m>d?"":"hidden",m=Math.min(d,m))}var g={height:m,overflowY:f,resize:"none"};return u&&(g.minHeight=u),d&&(g.maxHeight=d),g}var Y8=["prefixCls","defaultValue","value","autoSize","onResize","className","style","disabled","onChange","onInternalAutoSize"],Rc=0,Pc=1,Nc=2,Q8=i.forwardRef(function(e,t){var n=e,r=n.prefixCls,o=n.defaultValue,a=n.value,l=n.autoSize,s=n.onResize,c=n.className,u=n.style,d=n.disabled,f=n.onChange;n.onInternalAutoSize;var m=ft(n,Y8),v=Lt(o,{value:a,postState:function(H){return H??""}}),g=J(v,2),h=g[0],p=g[1],b=function(H){p(H.target.value),f==null||f(H)},y=i.useRef();i.useImperativeHandle(t,function(){return{textArea:y.current}});var C=i.useMemo(function(){return l&&Qe(l)==="object"?[l.minRows,l.maxRows]:[]},[l]),$=J(C,2),S=$[0],x=$[1],E=!!l,O=i.useState(Nc),w=J(O,2),I=w[0],P=w[1],M=i.useState(),R=J(M,2),N=R[0],T=R[1],j=function(){P(Rc)};wt(function(){E&&j()},[a,S,x,E]),wt(function(){if(I===Rc)P(Pc);else if(I===Pc){var q=X8(y.current,!1,S,x);P(Nc),T(q)}},[I]);var z=i.useRef(),_=function(){Et.cancel(z.current)},B=function(H){I===Nc&&(s==null||s(H),l&&(_(),z.current=Et(function(){j()})))};i.useEffect(function(){return _},[]);var V=E?N:null,G=k(k({},u),V);return(I===Rc||I===Pc)&&(G.overflowY="hidden",G.overflowX="hidden"),i.createElement(Bn,{onResize:B,disabled:!(l||s)},i.createElement("textarea",ue({},m,{ref:y,style:G,className:A(r,c,D({},"".concat(r,"-disabled"),d)),disabled:d,value:h,onChange:b})))}),Z8=["defaultValue","value","onFocus","onBlur","onChange","allowClear","maxLength","onCompositionStart","onCompositionEnd","suffix","prefixCls","showCount","count","className","style","disabled","hidden","classNames","styles","onResize","onClear","onPressEnter","readOnly","autoSize","onKeyDown"],J8=F.forwardRef(function(e,t){var n,r=e.defaultValue,o=e.value,a=e.onFocus,l=e.onBlur,s=e.onChange,c=e.allowClear,u=e.maxLength,d=e.onCompositionStart,f=e.onCompositionEnd,m=e.suffix,v=e.prefixCls,g=v===void 0?"rc-textarea":v,h=e.showCount,p=e.count,b=e.className,y=e.style,C=e.disabled,$=e.hidden,S=e.classNames,x=e.styles,E=e.onResize,O=e.onClear,w=e.onPressEnter,I=e.readOnly,P=e.autoSize,M=e.onKeyDown,R=ft(e,Z8),N=Lt(r,{value:o,defaultValue:r}),T=J(N,2),j=T[0],z=T[1],_=j==null?"":String(j),B=F.useState(!1),V=J(B,2),G=V[0],q=V[1],H=F.useRef(!1),W=F.useState(null),K=J(W,2),U=K[0],te=K[1],X=i.useRef(null),ae=i.useRef(null),le=function(){var Ee;return(Ee=ae.current)===null||Ee===void 0?void 0:Ee.textArea},ee=function(){le().focus()};i.useImperativeHandle(t,function(){var $e;return{resizableTextArea:ae.current,focus:ee,blur:function(){le().blur()},nativeElement:(($e=X.current)===null||$e===void 0?void 0:$e.nativeElement)||le()}}),i.useEffect(function(){q(function($e){return!C&&$e})},[C]);var Y=F.useState(null),re=J(Y,2),ne=re[0],Z=re[1];F.useEffect(function(){if(ne){var $e;($e=le()).setSelectionRange.apply($e,pe(ne))}},[ne]);var Q=lC(p,h),ie=(n=Q.max)!==null&&n!==void 0?n:u,de=Number(ie)>0,he=Q.strategy(_),ye=!!ie&&he>ie,oe=function(Ee,Ie){var fe=Ie;!H.current&&Q.exceedFormatter&&Q.max&&Q.strategy(Ie)>Q.max&&(fe=Q.exceedFormatter(Ie,{max:Q.max}),Ie!==fe&&Z([le().selectionStart||0,le().selectionEnd||0])),z(fe),Pl(Ee.currentTarget,Ee,s,fe)},ce=function(Ee){H.current=!0,d==null||d(Ee)},ge=function(Ee){H.current=!1,oe(Ee,Ee.currentTarget.value),f==null||f(Ee)},se=function(Ee){oe(Ee,Ee.target.value)},be=function(Ee){Ee.key==="Enter"&&w&&w(Ee),M==null||M(Ee)},we=function(Ee){q(!0),a==null||a(Ee)},Me=function(Ee){q(!1),l==null||l(Ee)},Te=function(Ee){z(""),ee(),Pl(le(),Ee,s)},Se=m,Fe;Q.show&&(Q.showFormatter?Fe=Q.showFormatter({value:_,count:he,maxLength:ie}):Fe="".concat(he).concat(de?" / ".concat(ie):""),Se=F.createElement(F.Fragment,null,Se,F.createElement("span",{className:A("".concat(g,"-data-count"),S==null?void 0:S.count),style:x==null?void 0:x.count},Fe)));var Ce=function(Ee){var Ie;E==null||E(Ee),(Ie=le())!==null&&Ie!==void 0&&Ie.style.height&&te(!0)},me=!P&&!h&&!c;return F.createElement(xf,{ref:X,value:_,allowClear:c,handleReset:Te,suffix:Se,prefixCls:g,classNames:k(k({},S),{},{affixWrapper:A(S==null?void 0:S.affixWrapper,D(D({},"".concat(g,"-show-count"),h),"".concat(g,"-textarea-allow-clear"),c))}),disabled:C,focused:G,className:A(b,ye&&"".concat(g,"-out-of-range")),style:k(k({},y),U&&!me?{height:"auto"}:{}),dataAttrs:{affixWrapper:{"data-count":typeof Fe=="string"?Fe:void 0}},hidden:$,readOnly:I,onClear:O},F.createElement(Q8,ue({},R,{autoSize:P,maxLength:u,onKeyDown:be,onChange:se,onFocus:we,onBlur:Me,onCompositionStart:ce,onCompositionEnd:ge,className:A(S==null?void 0:S.textarea),style:k(k({},x==null?void 0:x.textarea),{},{resize:y==null?void 0:y.resize}),disabled:C,prefixCls:g,onResize:Ce,ref:ae,readOnly:I})))});const ej=e=>{const{componentCls:t,paddingLG:n}=e,r=`${t}-textarea`;return{[`textarea${t}`]:{maxWidth:"100%",height:"auto",minHeight:e.controlHeight,lineHeight:e.lineHeight,verticalAlign:"bottom",transition:`all ${e.motionDurationSlow}`,resize:"vertical",[`&${t}-mouse-active`]:{transition:`all ${e.motionDurationSlow}, height 0s, width 0s`}},[`${t}-textarea-affix-wrapper-resize-dirty`]:{width:"auto"},[r]:{position:"relative","&-show-count":{[`${t}-data-count`]:{position:"absolute",bottom:e.calc(e.fontSize).mul(e.lineHeight).mul(-1).equal(),insetInlineEnd:0,color:e.colorTextDescription,whiteSpace:"nowrap",pointerEvents:"none"}},[`
        &-allow-clear > ${t},
        &-affix-wrapper${r}-has-feedback ${t}
      `]:{paddingInlineEnd:n},[`&-affix-wrapper${t}-affix-wrapper`]:{padding:0,[`> textarea${t}`]:{fontSize:"inherit",border:"none",outline:"none",background:"transparent",minHeight:e.calc(e.controlHeight).sub(e.calc(e.lineWidth).mul(2)).equal(),"&:focus":{boxShadow:"none !important"}},[`${t}-suffix`]:{margin:0,"> *:not(:last-child)":{marginInline:0},[`${t}-clear-icon`]:{position:"absolute",insetInlineEnd:e.paddingInline,insetBlockStart:e.paddingXS},[`${r}-suffix`]:{position:"absolute",top:0,insetInlineEnd:e.paddingInline,bottom:0,zIndex:1,display:"inline-flex",alignItems:"center",margin:"auto",pointerEvents:"none"}}},[`&-affix-wrapper${t}-affix-wrapper-rtl`]:{[`${t}-suffix`]:{[`${t}-data-count`]:{direction:"ltr",insetInlineStart:0}}},[`&-affix-wrapper${t}-affix-wrapper-sm`]:{[`${t}-suffix`]:{[`${t}-clear-icon`]:{insetInlineEnd:e.paddingInlineSM}}}}}},tj=It(["Input","TextArea"],e=>{const t=yt(e,ba(e));return ej(t)},ya,{resetFont:!1});var nj=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const RC=i.forwardRef((e,t)=>{var n;const{prefixCls:r,bordered:o=!0,size:a,disabled:l,status:s,allowClear:c,classNames:u,rootClassName:d,className:f,style:m,styles:v,variant:g,showCount:h,onMouseDown:p,onResize:b}=e,y=nj(e,["prefixCls","bordered","size","disabled","status","allowClear","classNames","rootClassName","className","style","styles","variant","showCount","onMouseDown","onResize"]),{getPrefixCls:C,direction:$,allowClear:S,autoComplete:x,className:E,style:O,classNames:w,styles:I}=tn("textArea"),P=i.useContext(Ln),M=l??P,{status:R,hasFeedback:N,feedbackIcon:T}=i.useContext(Wn),j=bi(R,s),z=i.useRef(null);i.useImperativeHandle(t,()=>{var Q;return{resizableTextArea:(Q=z.current)===null||Q===void 0?void 0:Q.resizableTextArea,focus:ie=>{var de,he;$f((he=(de=z.current)===null||de===void 0?void 0:de.resizableTextArea)===null||he===void 0?void 0:he.textArea,ie)},blur:()=>{var ie;return(ie=z.current)===null||ie===void 0?void 0:ie.blur()}}});const _=C("input",r),B=Cn(_),[V,G,q]=By(_,d),[H]=tj(_,B),{compactSize:W,compactItemClassnames:K}=ro(_,$),U=Sn(Q=>{var ie;return(ie=a??W)!==null&&ie!==void 0?ie:Q}),[te,X]=yi("textArea",g,o),ae=uC(c??S),[le,ee]=i.useState(!1),[Y,re]=i.useState(!1),ne=Q=>{ee(!0),p==null||p(Q);const ie=()=>{ee(!1),document.removeEventListener("mouseup",ie)};document.addEventListener("mouseup",ie)},Z=Q=>{var ie,de;if(b==null||b(Q),le&&typeof getComputedStyle=="function"){const he=(de=(ie=z.current)===null||ie===void 0?void 0:ie.nativeElement)===null||de===void 0?void 0:de.querySelector("textarea");he&&getComputedStyle(he).resize==="both"&&re(!0)}};return V(H(i.createElement(J8,Object.assign({autoComplete:x},y,{style:Object.assign(Object.assign({},O),m),styles:Object.assign(Object.assign({},I),v),disabled:M,allowClear:ae,className:A(q,B,f,d,K,E,Y&&`${_}-textarea-affix-wrapper-resize-dirty`),classNames:Object.assign(Object.assign(Object.assign({},u),w),{textarea:A({[`${_}-sm`]:U==="small",[`${_}-lg`]:U==="large"},G,u==null?void 0:u.textarea,w.textarea,le&&`${_}-mouse-active`),variant:A({[`${_}-${te}`]:X},yo(_,j)),affixWrapper:A(`${_}-textarea-affix-wrapper`,{[`${_}-affix-wrapper-rtl`]:$==="rtl",[`${_}-affix-wrapper-sm`]:U==="small",[`${_}-affix-wrapper-lg`]:U==="large",[`${_}-textarea-show-count`]:h||((n=e.count)===null||n===void 0?void 0:n.show)},G)}),prefixCls:_,suffix:N&&i.createElement("span",{className:`${_}-textarea-suffix`},T),showCount:h,ref:z,onResize:Z,onMouseDown:ne}))))}),wi=Ca;wi.Group=P8;wi.Search=K8;wi.TextArea=RC;wi.Password=V8;wi.OTP=_8;function rj(e,t,n){return typeof n=="boolean"?n:e.length?!0:xn(t).some(o=>o.type===py)}var PC=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function js({suffixCls:e,tagName:t,displayName:n}){return r=>i.forwardRef((a,l)=>i.createElement(r,Object.assign({ref:l,suffixCls:e,tagName:t},a)))}const If=i.forwardRef((e,t)=>{const{prefixCls:n,suffixCls:r,className:o,tagName:a}=e,l=PC(e,["prefixCls","suffixCls","className","tagName"]),{getPrefixCls:s}=i.useContext(ot),c=s("layout",n),[u,d,f]=gy(c),m=r?`${c}-${r}`:c;return u(i.createElement(a,Object.assign({className:A(n||m,o,d,f),ref:t},l)))}),oj=i.forwardRef((e,t)=>{const{direction:n}=i.useContext(ot),[r,o]=i.useState([]),{prefixCls:a,className:l,rootClassName:s,children:c,hasSider:u,tagName:d,style:f}=e,m=PC(e,["prefixCls","className","rootClassName","children","hasSider","tagName","style"]),v=Gt(m,["suffixCls"]),{getPrefixCls:g,className:h,style:p}=tn("layout"),b=g("layout",a),y=rj(r,c,u),[C,$,S]=gy(b),x=A(b,{[`${b}-has-sider`]:y,[`${b}-rtl`]:n==="rtl"},h,l,s,$,S),E=i.useMemo(()=>({siderHook:{addSider:O=>{o(w=>[].concat(pe(w),[O]))},removeSider:O=>{o(w=>w.filter(I=>I!==O))}}}),[]);return C(i.createElement(fy.Provider,{value:E},i.createElement(d,Object.assign({ref:t,className:x,style:Object.assign(Object.assign({},p),f)},v),c)))}),aj=js({tagName:"div",displayName:"Layout"})(oj),ij=js({suffixCls:"header",tagName:"header",displayName:"Header"})(If),lj=js({suffixCls:"footer",tagName:"footer",displayName:"Footer"})(If),sj=js({suffixCls:"content",tagName:"main",displayName:"Content"})(If),Ei=aj;Ei.Header=ij;Ei.Footer=lj;Ei.Content=sj;Ei.Sider=py;Ei._InternalSiderContext=Rs;var cj={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M272.9 512l265.4-339.1c4.1-5.2.4-12.9-6.3-12.9h-77.3c-4.9 0-9.6 2.3-12.6 6.1L186.8 492.3a31.99 31.99 0 000 39.5l255.3 326.1c3 3.9 7.7 6.1 12.6 6.1H532c6.7 0 10.4-7.7 6.3-12.9L272.9 512zm304 0l265.4-339.1c4.1-5.2.4-12.9-6.3-12.9h-77.3c-4.9 0-9.6 2.3-12.6 6.1L490.8 492.3a31.99 31.99 0 000 39.5l255.3 326.1c3 3.9 7.7 6.1 12.6 6.1H836c6.7 0 10.4-7.7 6.3-12.9L576.9 512z"}}]},name:"double-left",theme:"outlined"},uj=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:cj}))},Gg=i.forwardRef(uj),dj={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M533.2 492.3L277.9 166.1c-3-3.9-7.7-6.1-12.6-6.1H188c-6.7 0-10.4 7.7-6.3 12.9L447.1 512 181.7 851.1A7.98 7.98 0 00188 864h77.3c4.9 0 9.6-2.3 12.6-6.1l255.3-326.1c9.1-11.7 9.1-27.9 0-39.5zm304 0L581.9 166.1c-3-3.9-7.7-6.1-12.6-6.1H492c-6.7 0-10.4 7.7-6.3 12.9L751.1 512 485.7 851.1A7.98 7.98 0 00492 864h77.3c4.9 0 9.6-2.3 12.6-6.1l255.3-326.1c9.1-11.7 9.1-27.9 0-39.5z"}}]},name:"double-right",theme:"outlined"},fj=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:dj}))},qg=i.forwardRef(fj),mj={items_per_page:"条/页",jump_to:"跳至",jump_to_confirm:"确定",page:"页",prev_page:"上一页",next_page:"下一页",prev_5:"向前 5 页",next_5:"向后 5 页",prev_3:"向前 3 页",next_3:"向后 3 页",page_size:"页码"},vj=[10,20,50,100],gj=function(t){var n=t.pageSizeOptions,r=n===void 0?vj:n,o=t.locale,a=t.changeSize,l=t.pageSize,s=t.goButton,c=t.quickGo,u=t.rootPrefixCls,d=t.disabled,f=t.buildOptionText,m=t.showSizeChanger,v=t.sizeChangerRender,g=F.useState(""),h=J(g,2),p=h[0],b=h[1],y=function(){return!p||Number.isNaN(p)?void 0:Number(p)},C=typeof f=="function"?f:function(M){return"".concat(M," ").concat(o.items_per_page)},$=function(R){b(R.target.value)},S=function(R){s||p===""||(b(""),!(R.relatedTarget&&(R.relatedTarget.className.indexOf("".concat(u,"-item-link"))>=0||R.relatedTarget.className.indexOf("".concat(u,"-item"))>=0))&&(c==null||c(y())))},x=function(R){p!==""&&(R.keyCode===Ne.ENTER||R.type==="click")&&(b(""),c==null||c(y()))},E=function(){return r.some(function(R){return R.toString()===l.toString()})?r:r.concat([l]).sort(function(R,N){var T=Number.isNaN(Number(R))?0:Number(R),j=Number.isNaN(Number(N))?0:Number(N);return T-j})},O="".concat(u,"-options");if(!m&&!c)return null;var w=null,I=null,P=null;return m&&v&&(w=v({disabled:d,size:l,onSizeChange:function(R){a==null||a(Number(R))},"aria-label":o.page_size,className:"".concat(O,"-size-changer"),options:E().map(function(M){return{label:C(M),value:M}})})),c&&(s&&(P=typeof s=="boolean"?F.createElement("button",{type:"button",onClick:x,onKeyUp:x,disabled:d,className:"".concat(O,"-quick-jumper-button")},o.jump_to_confirm):F.createElement("span",{onClick:x,onKeyUp:x},s)),I=F.createElement("div",{className:"".concat(O,"-quick-jumper")},o.jump_to,F.createElement("input",{disabled:d,type:"text",value:p,onChange:$,onKeyUp:x,onBlur:S,"aria-label":o.page}),o.page,P)),F.createElement("li",{className:O},w,I)},Ma=function(t){var n=t.rootPrefixCls,r=t.page,o=t.active,a=t.className,l=t.showTitle,s=t.onClick,c=t.onKeyPress,u=t.itemRender,d="".concat(n,"-item"),f=A(d,"".concat(d,"-").concat(r),D(D({},"".concat(d,"-active"),o),"".concat(d,"-disabled"),!r),a),m=function(){s(r)},v=function(p){c(p,s,r)},g=u(r,"page",F.createElement("a",{rel:"nofollow"},r));return g?F.createElement("li",{title:l?String(r):null,className:f,onClick:m,onKeyDown:v,tabIndex:0},g):null},pj=function(t,n,r){return r};function Ug(){}function Xg(e){var t=Number(e);return typeof t=="number"&&!Number.isNaN(t)&&isFinite(t)&&Math.floor(t)===t}function io(e,t,n){var r=typeof e>"u"?t:e;return Math.floor((n-1)/r)+1}var hj=function(t){var n=t.prefixCls,r=n===void 0?"rc-pagination":n,o=t.selectPrefixCls,a=o===void 0?"rc-select":o,l=t.className,s=t.current,c=t.defaultCurrent,u=c===void 0?1:c,d=t.total,f=d===void 0?0:d,m=t.pageSize,v=t.defaultPageSize,g=v===void 0?10:v,h=t.onChange,p=h===void 0?Ug:h,b=t.hideOnSinglePage,y=t.align,C=t.showPrevNextJumpers,$=C===void 0?!0:C,S=t.showQuickJumper,x=t.showLessItems,E=t.showTitle,O=E===void 0?!0:E,w=t.onShowSizeChange,I=w===void 0?Ug:w,P=t.locale,M=P===void 0?mj:P,R=t.style,N=t.totalBoundaryShowSizeChanger,T=N===void 0?50:N,j=t.disabled,z=t.simple,_=t.showTotal,B=t.showSizeChanger,V=B===void 0?f>T:B,G=t.sizeChangerRender,q=t.pageSizeOptions,H=t.itemRender,W=H===void 0?pj:H,K=t.jumpPrevIcon,U=t.jumpNextIcon,te=t.prevIcon,X=t.nextIcon,ae=F.useRef(null),le=Lt(10,{value:m,defaultValue:g}),ee=J(le,2),Y=ee[0],re=ee[1],ne=Lt(1,{value:s,defaultValue:u,postState:function(nt){return Math.max(1,Math.min(nt,io(void 0,Y,f)))}}),Z=J(ne,2),Q=Z[0],ie=Z[1],de=F.useState(Q),he=J(de,2),ye=he[0],oe=he[1];i.useEffect(function(){oe(Q)},[Q]);var ce=Math.max(1,Q-(x?3:5)),ge=Math.min(io(void 0,Y,f),Q+(x?3:5));function se(Ae,nt){var ht=Ae||F.createElement("button",{type:"button","aria-label":nt,className:"".concat(r,"-item-link")});return typeof Ae=="function"&&(ht=F.createElement(Ae,k({},t))),ht}function be(Ae){var nt=Ae.target.value,ht=io(void 0,Y,f),Ft;return nt===""?Ft=nt:Number.isNaN(Number(nt))?Ft=ye:nt>=ht?Ft=ht:Ft=Number(nt),Ft}function we(Ae){return Xg(Ae)&&Ae!==Q&&Xg(f)&&f>0}var Me=f>Y?S:!1;function Te(Ae){(Ae.keyCode===Ne.UP||Ae.keyCode===Ne.DOWN)&&Ae.preventDefault()}function Se(Ae){var nt=be(Ae);switch(nt!==ye&&oe(nt),Ae.keyCode){case Ne.ENTER:me(nt);break;case Ne.UP:me(nt-1);break;case Ne.DOWN:me(nt+1);break}}function Fe(Ae){me(be(Ae))}function Ce(Ae){var nt=io(Ae,Y,f),ht=Q>nt&&nt!==0?nt:Q;re(Ae),oe(ht),I==null||I(Q,Ae),ie(ht),p==null||p(ht,Ae)}function me(Ae){if(we(Ae)&&!j){var nt=io(void 0,Y,f),ht=Ae;return Ae>nt?ht=nt:Ae<1&&(ht=1),ht!==ye&&oe(ht),ie(ht),p==null||p(ht,Y),ht}return Q}var $e=Q>1,Ee=Q<io(void 0,Y,f);function Ie(){$e&&me(Q-1)}function fe(){Ee&&me(Q+1)}function ve(){me(ce)}function xe(){me(ge)}function Re(Ae,nt){if(Ae.key==="Enter"||Ae.charCode===Ne.ENTER||Ae.keyCode===Ne.ENTER){for(var ht=arguments.length,Ft=new Array(ht>2?ht-2:0),qt=2;qt<ht;qt++)Ft[qt-2]=arguments[qt];nt.apply(void 0,Ft)}}function it(Ae){Re(Ae,Ie)}function dt(Ae){Re(Ae,fe)}function Oe(Ae){Re(Ae,ve)}function Le(Ae){Re(Ae,xe)}function Ue(Ae){var nt=W(Ae,"prev",se(te,"prev page"));return F.isValidElement(nt)?F.cloneElement(nt,{disabled:!$e}):nt}function ke(Ae){var nt=W(Ae,"next",se(X,"next page"));return F.isValidElement(nt)?F.cloneElement(nt,{disabled:!Ee}):nt}function Je(Ae){(Ae.type==="click"||Ae.keyCode===Ne.ENTER)&&me(ye)}var Xe=null,He=rn(t,{aria:!0,data:!0}),je=_&&F.createElement("li",{className:"".concat(r,"-total-text")},_(f,[f===0?0:(Q-1)*Y+1,Q*Y>f?f:Q*Y])),rt=null,et=io(void 0,Y,f);if(b&&f<=Y)return null;var Pe=[],qe={rootPrefixCls:r,onClick:me,onKeyPress:Re,showTitle:O,itemRender:W,page:-1},We=Q-1>0?Q-1:0,tt=Q+1<et?Q+1:et,mt=S&&S.goButton,ct=Qe(z)==="object"?z.readOnly:!z,Ke=mt,Ye=null;z&&(mt&&(typeof mt=="boolean"?Ke=F.createElement("button",{type:"button",onClick:Je,onKeyUp:Je},M.jump_to_confirm):Ke=F.createElement("span",{onClick:Je,onKeyUp:Je},mt),Ke=F.createElement("li",{title:O?"".concat(M.jump_to).concat(Q,"/").concat(et):null,className:"".concat(r,"-simple-pager")},Ke)),Ye=F.createElement("li",{title:O?"".concat(Q,"/").concat(et):null,className:"".concat(r,"-simple-pager")},ct?ye:F.createElement("input",{type:"text","aria-label":M.jump_to,value:ye,disabled:j,onKeyDown:Te,onKeyUp:Se,onChange:Se,onBlur:Fe,size:3}),F.createElement("span",{className:"".concat(r,"-slash")},"/"),et));var at=x?1:2;if(et<=3+at*2){et||Pe.push(F.createElement(Ma,ue({},qe,{key:"noPager",page:1,className:"".concat(r,"-item-disabled")})));for(var gt=1;gt<=et;gt+=1)Pe.push(F.createElement(Ma,ue({},qe,{key:gt,page:gt,active:Q===gt})))}else{var Ot=x?M.prev_3:M.prev_5,Pt=x?M.next_3:M.next_5,Rt=W(ce,"jump-prev",se(K,"prev page")),jt=W(ge,"jump-next",se(U,"next page"));$&&(Xe=Rt?F.createElement("li",{title:O?Ot:null,key:"prev",onClick:ve,tabIndex:0,onKeyDown:Oe,className:A("".concat(r,"-jump-prev"),D({},"".concat(r,"-jump-prev-custom-icon"),!!K))},Rt):null,rt=jt?F.createElement("li",{title:O?Pt:null,key:"next",onClick:xe,tabIndex:0,onKeyDown:Le,className:A("".concat(r,"-jump-next"),D({},"".concat(r,"-jump-next-custom-icon"),!!U))},jt):null);var zt=Math.max(1,Q-at),Dt=Math.min(Q+at,et);Q-1<=at&&(Dt=1+at*2),et-Q<=at&&(zt=et-at*2);for(var De=zt;De<=Dt;De+=1)Pe.push(F.createElement(Ma,ue({},qe,{key:De,page:De,active:Q===De})));if(Q-1>=at*2&&Q!==3&&(Pe[0]=F.cloneElement(Pe[0],{className:A("".concat(r,"-item-after-jump-prev"),Pe[0].props.className)}),Pe.unshift(Xe)),et-Q>=at*2&&Q!==et-2){var Ze=Pe[Pe.length-1];Pe[Pe.length-1]=F.cloneElement(Ze,{className:A("".concat(r,"-item-before-jump-next"),Ze.props.className)}),Pe.push(rt)}zt!==1&&Pe.unshift(F.createElement(Ma,ue({},qe,{key:1,page:1}))),Dt!==et&&Pe.push(F.createElement(Ma,ue({},qe,{key:et,page:et})))}var Ge=Ue(We);if(Ge){var Be=!$e||!et;Ge=F.createElement("li",{title:O?M.prev_page:null,onClick:Ie,tabIndex:Be?null:0,onKeyDown:it,className:A("".concat(r,"-prev"),D({},"".concat(r,"-disabled"),Be)),"aria-disabled":Be},Ge)}var ze=ke(tt);if(ze){var _e,lt;z?(_e=!Ee,lt=$e?0:null):(_e=!Ee||!et,lt=_e?null:0),ze=F.createElement("li",{title:O?M.next_page:null,onClick:fe,tabIndex:lt,onKeyDown:dt,className:A("".concat(r,"-next"),D({},"".concat(r,"-disabled"),_e)),"aria-disabled":_e},ze)}var Ct=A(r,l,D(D(D(D(D({},"".concat(r,"-start"),y==="start"),"".concat(r,"-center"),y==="center"),"".concat(r,"-end"),y==="end"),"".concat(r,"-simple"),z),"".concat(r,"-disabled"),j));return F.createElement("ul",ue({className:Ct,style:R,ref:ae},He),je,Ge,z?Ye:Pe,ze,F.createElement(gj,{locale:M,rootPrefixCls:r,disabled:j,selectPrefixCls:a,changeSize:Ce,pageSize:Y,pageSizeOptions:q,quickGo:Me?me:null,goButton:Ke,showSizeChanger:V,sizeChangerRender:G}))};const bj=e=>{const{componentCls:t}=e;return{[`${t}-disabled`]:{"&, &:hover":{cursor:"not-allowed",[`${t}-item-link`]:{color:e.colorTextDisabled,cursor:"not-allowed"}},"&:focus-visible":{cursor:"not-allowed",[`${t}-item-link`]:{color:e.colorTextDisabled,cursor:"not-allowed"}}},[`&${t}-disabled`]:{cursor:"not-allowed",[`${t}-item`]:{cursor:"not-allowed",backgroundColor:"transparent","&:hover, &:active":{backgroundColor:"transparent"},a:{color:e.colorTextDisabled,backgroundColor:"transparent",border:"none",cursor:"not-allowed"},"&-active":{borderColor:e.colorBorder,backgroundColor:e.itemActiveBgDisabled,"&:hover, &:active":{backgroundColor:e.itemActiveBgDisabled},a:{color:e.itemActiveColorDisabled}}},[`${t}-item-link`]:{color:e.colorTextDisabled,cursor:"not-allowed","&:hover, &:active":{backgroundColor:"transparent"},[`${t}-simple&`]:{backgroundColor:"transparent","&:hover, &:active":{backgroundColor:"transparent"}}},[`${t}-simple-pager`]:{color:e.colorTextDisabled},[`${t}-jump-prev, ${t}-jump-next`]:{[`${t}-item-link-icon`]:{opacity:0},[`${t}-item-ellipsis`]:{opacity:1}}}}},yj=e=>{const{componentCls:t}=e;return{[`&${t}-mini ${t}-total-text, &${t}-mini ${t}-simple-pager`]:{height:e.itemSizeSM,lineHeight:L(e.itemSizeSM)},[`&${t}-mini ${t}-item`]:{minWidth:e.itemSizeSM,height:e.itemSizeSM,margin:0,lineHeight:L(e.calc(e.itemSizeSM).sub(2).equal())},[`&${t}-mini ${t}-prev, &${t}-mini ${t}-next`]:{minWidth:e.itemSizeSM,height:e.itemSizeSM,margin:0,lineHeight:L(e.itemSizeSM)},[`&${t}-mini:not(${t}-disabled)`]:{[`${t}-prev, ${t}-next`]:{[`&:hover ${t}-item-link`]:{backgroundColor:e.colorBgTextHover},[`&:active ${t}-item-link`]:{backgroundColor:e.colorBgTextActive},[`&${t}-disabled:hover ${t}-item-link`]:{backgroundColor:"transparent"}}},[`
    &${t}-mini ${t}-prev ${t}-item-link,
    &${t}-mini ${t}-next ${t}-item-link
    `]:{backgroundColor:"transparent",borderColor:"transparent","&::after":{height:e.itemSizeSM,lineHeight:L(e.itemSizeSM)}},[`&${t}-mini ${t}-jump-prev, &${t}-mini ${t}-jump-next`]:{height:e.itemSizeSM,marginInlineEnd:0,lineHeight:L(e.itemSizeSM)},[`&${t}-mini ${t}-options`]:{marginInlineStart:e.paginationMiniOptionsMarginInlineStart,"&-size-changer":{top:e.miniOptionsSizeChangerTop},"&-quick-jumper":{height:e.itemSizeSM,lineHeight:L(e.itemSizeSM),input:Object.assign(Object.assign({},hf(e)),{width:e.paginationMiniQuickJumperInputWidth,height:e.controlHeightSM})}}}},Cj=e=>{const{componentCls:t}=e;return{[`&${t}-simple`]:{[`${t}-prev, ${t}-next`]:{height:e.itemSize,lineHeight:L(e.itemSize),verticalAlign:"top",[`${t}-item-link`]:{height:e.itemSize,backgroundColor:"transparent",border:0,"&:hover":{backgroundColor:e.colorBgTextHover},"&:active":{backgroundColor:e.colorBgTextActive},"&::after":{height:e.itemSize,lineHeight:L(e.itemSize)}}},[`${t}-simple-pager`]:{display:"inline-flex",alignItems:"center",height:e.itemSize,marginInlineEnd:e.marginXS,input:{boxSizing:"border-box",height:"100%",width:e.quickJumperInputWidth,padding:`0 ${L(e.paginationItemPaddingInline)}`,textAlign:"center",backgroundColor:e.itemInputBg,border:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,borderRadius:e.borderRadius,outline:"none",transition:`border-color ${e.motionDurationMid}`,color:"inherit","&:hover":{borderColor:e.colorPrimary},"&:focus":{borderColor:e.colorPrimaryHover,boxShadow:`${L(e.inputOutlineOffset)} 0 ${L(e.controlOutlineWidth)} ${e.controlOutline}`},"&[disabled]":{color:e.colorTextDisabled,backgroundColor:e.colorBgContainerDisabled,borderColor:e.colorBorder,cursor:"not-allowed"}}},[`&${t}-disabled`]:{[`${t}-prev, ${t}-next`]:{[`${t}-item-link`]:{"&:hover, &:active":{backgroundColor:"transparent"}}}},[`&${t}-mini`]:{[`${t}-prev, ${t}-next`]:{height:e.itemSizeSM,lineHeight:L(e.itemSizeSM),[`${t}-item-link`]:{height:e.itemSizeSM,"&::after":{height:e.itemSizeSM,lineHeight:L(e.itemSizeSM)}}},[`${t}-simple-pager`]:{height:e.itemSizeSM,width:e.paginationMiniQuickJumperInputWidth}}}}},Sj=e=>{const{componentCls:t}=e;return{[`${t}-jump-prev, ${t}-jump-next`]:{outline:0,[`${t}-item-container`]:{position:"relative",[`${t}-item-link-icon`]:{color:e.colorPrimary,fontSize:e.fontSizeSM,opacity:0,transition:`all ${e.motionDurationMid}`,"&-svg":{top:0,insetInlineEnd:0,bottom:0,insetInlineStart:0,margin:"auto"}},[`${t}-item-ellipsis`]:{position:"absolute",top:0,insetInlineEnd:0,bottom:0,insetInlineStart:0,display:"block",margin:"auto",color:e.colorTextDisabled,letterSpacing:e.paginationEllipsisLetterSpacing,textAlign:"center",textIndent:e.paginationEllipsisTextIndent,opacity:1,transition:`all ${e.motionDurationMid}`}},"&:hover":{[`${t}-item-link-icon`]:{opacity:1},[`${t}-item-ellipsis`]:{opacity:0}}},[`
    ${t}-prev,
    ${t}-jump-prev,
    ${t}-jump-next
    `]:{marginInlineEnd:e.marginXS},[`
    ${t}-prev,
    ${t}-next,
    ${t}-jump-prev,
    ${t}-jump-next
    `]:{display:"inline-block",minWidth:e.itemSize,height:e.itemSize,color:e.colorText,fontFamily:e.fontFamily,lineHeight:L(e.itemSize),textAlign:"center",verticalAlign:"middle",listStyle:"none",borderRadius:e.borderRadius,cursor:"pointer",transition:`all ${e.motionDurationMid}`},[`${t}-prev, ${t}-next`]:{outline:0,button:{color:e.colorText,cursor:"pointer",userSelect:"none"},[`${t}-item-link`]:{display:"block",width:"100%",height:"100%",padding:0,fontSize:e.fontSizeSM,textAlign:"center",backgroundColor:"transparent",border:`${L(e.lineWidth)} ${e.lineType} transparent`,borderRadius:e.borderRadius,outline:"none",transition:`all ${e.motionDurationMid}`},[`&:hover ${t}-item-link`]:{backgroundColor:e.colorBgTextHover},[`&:active ${t}-item-link`]:{backgroundColor:e.colorBgTextActive},[`&${t}-disabled:hover`]:{[`${t}-item-link`]:{backgroundColor:"transparent"}}},[`${t}-slash`]:{marginInlineEnd:e.paginationSlashMarginInlineEnd,marginInlineStart:e.paginationSlashMarginInlineStart},[`${t}-options`]:{display:"inline-block",marginInlineStart:e.margin,verticalAlign:"middle","&-size-changer":{display:"inline-block",width:"auto"},"&-quick-jumper":{display:"inline-block",height:e.controlHeight,marginInlineStart:e.marginXS,lineHeight:L(e.controlHeight),verticalAlign:"top",input:Object.assign(Object.assign(Object.assign({},$i(e)),pf(e,{borderColor:e.colorBorder,hoverBorderColor:e.colorPrimaryHover,activeBorderColor:e.colorPrimary,activeShadow:e.activeShadow})),{"&[disabled]":Object.assign({},Ns(e)),width:e.quickJumperInputWidth,height:e.controlHeight,boxSizing:"border-box",margin:0,marginInlineStart:e.marginXS,marginInlineEnd:e.marginXS})}}}},$j=e=>{const{componentCls:t}=e;return{[`${t}-item`]:{display:"inline-block",minWidth:e.itemSize,height:e.itemSize,marginInlineEnd:e.marginXS,fontFamily:e.fontFamily,lineHeight:L(e.calc(e.itemSize).sub(2).equal()),textAlign:"center",verticalAlign:"middle",listStyle:"none",backgroundColor:e.itemBg,border:`${L(e.lineWidth)} ${e.lineType} transparent`,borderRadius:e.borderRadius,outline:0,cursor:"pointer",userSelect:"none",a:{display:"block",padding:`0 ${L(e.paginationItemPaddingInline)}`,color:e.colorText,"&:hover":{textDecoration:"none"}},[`&:not(${t}-item-active)`]:{"&:hover":{transition:`all ${e.motionDurationMid}`,backgroundColor:e.colorBgTextHover},"&:active":{backgroundColor:e.colorBgTextActive}},"&-active":{fontWeight:e.fontWeightStrong,backgroundColor:e.itemActiveBg,borderColor:e.colorPrimary,a:{color:e.colorPrimary},"&:hover":{borderColor:e.colorPrimaryHover},"&:hover a":{color:e.colorPrimaryHover}}}}},xj=e=>{const{componentCls:t}=e;return{[t]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),{display:"flex","&-start":{justifyContent:"start"},"&-center":{justifyContent:"center"},"&-end":{justifyContent:"end"},"ul, ol":{margin:0,padding:0,listStyle:"none"},"&::after":{display:"block",clear:"both",height:0,overflow:"hidden",visibility:"hidden",content:'""'},[`${t}-total-text`]:{display:"inline-block",height:e.itemSize,marginInlineEnd:e.marginXS,lineHeight:L(e.calc(e.itemSize).sub(2).equal()),verticalAlign:"middle"}}),$j(e)),Sj(e)),Cj(e)),yj(e)),bj(e)),{[`@media only screen and (max-width: ${e.screenLG}px)`]:{[`${t}-item`]:{"&-after-jump-prev, &-before-jump-next":{display:"none"}}},[`@media only screen and (max-width: ${e.screenSM}px)`]:{[`${t}-options`]:{display:"none"}}}),[`&${e.componentCls}-rtl`]:{direction:"rtl"}}},wj=e=>{const{componentCls:t}=e;return{[`${t}:not(${t}-disabled)`]:{[`${t}-item`]:Object.assign({},Vn(e)),[`${t}-jump-prev, ${t}-jump-next`]:{"&:focus-visible":Object.assign({[`${t}-item-link-icon`]:{opacity:1},[`${t}-item-ellipsis`]:{opacity:0}},Cr(e))},[`${t}-prev, ${t}-next`]:{[`&:focus-visible ${t}-item-link`]:Cr(e)}}}},NC=e=>Object.assign({itemBg:e.colorBgContainer,itemSize:e.controlHeight,itemSizeSM:e.controlHeightSM,itemActiveBg:e.colorBgContainer,itemLinkBg:e.colorBgContainer,itemActiveColorDisabled:e.colorTextDisabled,itemActiveBgDisabled:e.controlItemBgActiveDisabled,itemInputBg:e.colorBgContainer,miniOptionsSizeChangerTop:0},ya(e)),MC=e=>yt(e,{inputOutlineOffset:0,quickJumperInputWidth:e.calc(e.controlHeightLG).mul(1.25).equal(),paginationMiniOptionsMarginInlineStart:e.calc(e.marginXXS).div(2).equal(),paginationMiniQuickJumperInputWidth:e.calc(e.controlHeightLG).mul(1.1).equal(),paginationItemPaddingInline:e.calc(e.marginXXS).mul(1.5).equal(),paginationEllipsisLetterSpacing:e.calc(e.marginXXS).div(2).equal(),paginationSlashMarginInlineStart:e.marginSM,paginationSlashMarginInlineEnd:e.marginSM,paginationEllipsisTextIndent:"0.13em"},ba(e)),Ej=It("Pagination",e=>{const t=MC(e);return[xj(t),wj(t)]},NC),Oj=e=>{const{componentCls:t}=e;return{[`${t}${t}-bordered${t}-disabled:not(${t}-mini)`]:{"&, &:hover":{[`${t}-item-link`]:{borderColor:e.colorBorder}},"&:focus-visible":{[`${t}-item-link`]:{borderColor:e.colorBorder}},[`${t}-item, ${t}-item-link`]:{backgroundColor:e.colorBgContainerDisabled,borderColor:e.colorBorder,[`&:hover:not(${t}-item-active)`]:{backgroundColor:e.colorBgContainerDisabled,borderColor:e.colorBorder,a:{color:e.colorTextDisabled}},[`&${t}-item-active`]:{backgroundColor:e.itemActiveBgDisabled}},[`${t}-prev, ${t}-next`]:{"&:hover button":{backgroundColor:e.colorBgContainerDisabled,borderColor:e.colorBorder,color:e.colorTextDisabled},[`${t}-item-link`]:{backgroundColor:e.colorBgContainerDisabled,borderColor:e.colorBorder}}},[`${t}${t}-bordered:not(${t}-mini)`]:{[`${t}-prev, ${t}-next`]:{"&:hover button":{borderColor:e.colorPrimaryHover,backgroundColor:e.itemBg},[`${t}-item-link`]:{backgroundColor:e.itemLinkBg,borderColor:e.colorBorder},[`&:hover ${t}-item-link`]:{borderColor:e.colorPrimary,backgroundColor:e.itemBg,color:e.colorPrimary},[`&${t}-disabled`]:{[`${t}-item-link`]:{borderColor:e.colorBorder,color:e.colorTextDisabled}}},[`${t}-item`]:{backgroundColor:e.itemBg,border:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,[`&:hover:not(${t}-item-active)`]:{borderColor:e.colorPrimary,backgroundColor:e.itemBg,a:{color:e.colorPrimary}},"&-active":{borderColor:e.colorPrimary}}}}},Ij=ua(["Pagination","bordered"],e=>{const t=MC(e);return Oj(t)},NC);function Yg(e){return i.useMemo(()=>typeof e=="boolean"?[e,{}]:e&&typeof e=="object"?[!0,e]:[void 0,void 0],[e])}var Rj=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Pj=e=>{const{align:t,prefixCls:n,selectPrefixCls:r,className:o,rootClassName:a,style:l,size:s,locale:c,responsive:u,showSizeChanger:d,selectComponentClass:f,pageSizeOptions:m}=e,v=Rj(e,["align","prefixCls","selectPrefixCls","className","rootClassName","style","size","locale","responsive","showSizeChanger","selectComponentClass","pageSizeOptions"]),{xs:g}=xs(u),[,h]=yn(),{getPrefixCls:p,direction:b,showSizeChanger:y,className:C,style:$}=tn("pagination"),S=p("pagination",n),[x,E,O]=Ej(S),w=Sn(s),I=w==="small"||!!(g&&!w&&u),[P]=Kn("Pagination",Rh),M=Object.assign(Object.assign({},P),c),[R,N]=Yg(d),[T,j]=Yg(y),z=R??T,_=N??j,B=f||Eo,V=i.useMemo(()=>m?m.map(U=>Number(U)):void 0,[m]),G=U=>{var te;const{disabled:X,size:ae,onSizeChange:le,"aria-label":ee,className:Y,options:re}=U,{className:ne,onChange:Z}=_||{},Q=(te=re.find(ie=>String(ie.value)===String(ae)))===null||te===void 0?void 0:te.value;return i.createElement(B,Object.assign({disabled:X,showSearch:!0,popupMatchSelectWidth:!1,getPopupContainer:ie=>ie.parentNode,"aria-label":ee,options:re},_,{value:Q,onChange:(ie,de)=>{le==null||le(ie),Z==null||Z(ie,de)},size:I?"small":"middle",className:A(Y,ne)}))},q=i.useMemo(()=>{const U=i.createElement("span",{className:`${S}-item-ellipsis`},"•••"),te=i.createElement("button",{className:`${S}-item-link`,type:"button",tabIndex:-1},b==="rtl"?i.createElement(na,null):i.createElement(Ja,null)),X=i.createElement("button",{className:`${S}-item-link`,type:"button",tabIndex:-1},b==="rtl"?i.createElement(Ja,null):i.createElement(na,null)),ae=i.createElement("a",{className:`${S}-item-link`},i.createElement("div",{className:`${S}-item-container`},b==="rtl"?i.createElement(qg,{className:`${S}-item-link-icon`}):i.createElement(Gg,{className:`${S}-item-link-icon`}),U)),le=i.createElement("a",{className:`${S}-item-link`},i.createElement("div",{className:`${S}-item-container`},b==="rtl"?i.createElement(Gg,{className:`${S}-item-link-icon`}):i.createElement(qg,{className:`${S}-item-link-icon`}),U));return{prevIcon:te,nextIcon:X,jumpPrevIcon:ae,jumpNextIcon:le}},[b,S]),H=p("select",r),W=A({[`${S}-${t}`]:!!t,[`${S}-mini`]:I,[`${S}-rtl`]:b==="rtl",[`${S}-bordered`]:h.wireframe},C,o,a,E,O),K=Object.assign(Object.assign({},$),l);return x(i.createElement(i.Fragment,null,h.wireframe&&i.createElement(Ij,{prefixCls:S}),i.createElement(hj,Object.assign({},q,v,{style:K,prefixCls:S,selectPrefixCls:H,className:W,locale:M,pageSizeOptions:V,showSizeChanger:z,sizeChangerRender:G}))))},Nl=100,TC=Nl/5,jC=Nl/2-TC/2,Mc=jC*2*Math.PI,Qg=50,Zg=e=>{const{dotClassName:t,style:n,hasCircleCls:r}=e;return i.createElement("circle",{className:A(`${t}-circle`,{[`${t}-circle-bg`]:r}),r:jC,cx:Qg,cy:Qg,strokeWidth:TC,style:n})},Nj=({percent:e,prefixCls:t})=>{const n=`${t}-dot`,r=`${n}-holder`,o=`${r}-hidden`,[a,l]=i.useState(!1);wt(()=>{e!==0&&l(!0)},[e!==0]);const s=Math.max(Math.min(e,100),0);if(!a)return null;const c={strokeDashoffset:`${Mc/4}`,strokeDasharray:`${Mc*s/100} ${Mc*(100-s)/100}`};return i.createElement("span",{className:A(r,`${n}-progress`,s<=0&&o)},i.createElement("svg",{viewBox:`0 0 ${Nl} ${Nl}`,role:"progressbar","aria-valuemin":0,"aria-valuemax":100,"aria-valuenow":s},i.createElement(Zg,{dotClassName:n,hasCircleCls:!0}),i.createElement(Zg,{dotClassName:n,style:c})))};function Mj(e){const{prefixCls:t,percent:n=0}=e,r=`${t}-dot`,o=`${r}-holder`,a=`${o}-hidden`;return i.createElement(i.Fragment,null,i.createElement("span",{className:A(o,n>0&&a)},i.createElement("span",{className:A(r,`${t}-dot-spin`)},[1,2,3,4].map(l=>i.createElement("i",{className:`${t}-dot-item`,key:l})))),i.createElement(Nj,{prefixCls:t,percent:n}))}function Tj(e){var t;const{prefixCls:n,indicator:r,percent:o}=e,a=`${n}-dot`;return r&&i.isValidElement(r)?cn(r,{className:A((t=r.props)===null||t===void 0?void 0:t.className,a),percent:o}):i.createElement(Mj,{prefixCls:n,percent:o})}const jj=new $t("antSpinMove",{to:{opacity:1}}),zj=new $t("antRotate",{to:{transform:"rotate(405deg)"}}),Dj=e=>{const{componentCls:t,calc:n}=e;return{[t]:Object.assign(Object.assign({},Tt(e)),{position:"absolute",display:"none",color:e.colorPrimary,fontSize:0,textAlign:"center",verticalAlign:"middle",opacity:0,transition:`transform ${e.motionDurationSlow} ${e.motionEaseInOutCirc}`,"&-spinning":{position:"relative",display:"inline-block",opacity:1},[`${t}-text`]:{fontSize:e.fontSize,paddingTop:n(n(e.dotSize).sub(e.fontSize)).div(2).add(2).equal()},"&-fullscreen":{position:"fixed",width:"100vw",height:"100vh",backgroundColor:e.colorBgMask,zIndex:e.zIndexPopupBase,inset:0,display:"flex",alignItems:"center",flexDirection:"column",justifyContent:"center",opacity:0,visibility:"hidden",transition:`all ${e.motionDurationMid}`,"&-show":{opacity:1,visibility:"visible"},[t]:{[`${t}-dot-holder`]:{color:e.colorWhite},[`${t}-text`]:{color:e.colorTextLightSolid}}},"&-nested-loading":{position:"relative",[`> div > ${t}`]:{position:"absolute",top:0,insetInlineStart:0,zIndex:4,display:"block",width:"100%",height:"100%",maxHeight:e.contentHeight,[`${t}-dot`]:{position:"absolute",top:"50%",insetInlineStart:"50%",margin:n(e.dotSize).mul(-1).div(2).equal()},[`${t}-text`]:{position:"absolute",top:"50%",width:"100%",textShadow:`0 1px 2px ${e.colorBgContainer}`},[`&${t}-show-text ${t}-dot`]:{marginTop:n(e.dotSize).div(2).mul(-1).sub(10).equal()},"&-sm":{[`${t}-dot`]:{margin:n(e.dotSizeSM).mul(-1).div(2).equal()},[`${t}-text`]:{paddingTop:n(n(e.dotSizeSM).sub(e.fontSize)).div(2).add(2).equal()},[`&${t}-show-text ${t}-dot`]:{marginTop:n(e.dotSizeSM).div(2).mul(-1).sub(10).equal()}},"&-lg":{[`${t}-dot`]:{margin:n(e.dotSizeLG).mul(-1).div(2).equal()},[`${t}-text`]:{paddingTop:n(n(e.dotSizeLG).sub(e.fontSize)).div(2).add(2).equal()},[`&${t}-show-text ${t}-dot`]:{marginTop:n(e.dotSizeLG).div(2).mul(-1).sub(10).equal()}}},[`${t}-container`]:{position:"relative",transition:`opacity ${e.motionDurationSlow}`,"&::after":{position:"absolute",top:0,insetInlineEnd:0,bottom:0,insetInlineStart:0,zIndex:10,width:"100%",height:"100%",background:e.colorBgContainer,opacity:0,transition:`all ${e.motionDurationSlow}`,content:'""',pointerEvents:"none"}},[`${t}-blur`]:{clear:"both",opacity:.5,userSelect:"none",pointerEvents:"none","&::after":{opacity:.4,pointerEvents:"auto"}}},"&-tip":{color:e.spinDotDefault},[`${t}-dot-holder`]:{width:"1em",height:"1em",fontSize:e.dotSize,display:"inline-block",transition:`transform ${e.motionDurationSlow} ease, opacity ${e.motionDurationSlow} ease`,transformOrigin:"50% 50%",lineHeight:1,color:e.colorPrimary,"&-hidden":{transform:"scale(0.3)",opacity:0}},[`${t}-dot-progress`]:{position:"absolute",inset:0},[`${t}-dot`]:{position:"relative",display:"inline-block",fontSize:e.dotSize,width:"1em",height:"1em","&-item":{position:"absolute",display:"block",width:n(e.dotSize).sub(n(e.marginXXS).div(2)).div(2).equal(),height:n(e.dotSize).sub(n(e.marginXXS).div(2)).div(2).equal(),background:"currentColor",borderRadius:"100%",transform:"scale(0.75)",transformOrigin:"50% 50%",opacity:.3,animationName:jj,animationDuration:"1s",animationIterationCount:"infinite",animationTimingFunction:"linear",animationDirection:"alternate","&:nth-child(1)":{top:0,insetInlineStart:0,animationDelay:"0s"},"&:nth-child(2)":{top:0,insetInlineEnd:0,animationDelay:"0.4s"},"&:nth-child(3)":{insetInlineEnd:0,bottom:0,animationDelay:"0.8s"},"&:nth-child(4)":{bottom:0,insetInlineStart:0,animationDelay:"1.2s"}},"&-spin":{transform:"rotate(45deg)",animationName:zj,animationDuration:"1.2s",animationIterationCount:"infinite",animationTimingFunction:"linear"},"&-circle":{strokeLinecap:"round",transition:["stroke-dashoffset","stroke-dasharray","stroke","stroke-width","opacity"].map(r=>`${r} ${e.motionDurationSlow} ease`).join(","),fillOpacity:0,stroke:"currentcolor"},"&-circle-bg":{stroke:e.colorFillSecondary}},[`&-sm ${t}-dot`]:{"&, &-holder":{fontSize:e.dotSizeSM}},[`&-sm ${t}-dot-holder`]:{i:{width:n(n(e.dotSizeSM).sub(n(e.marginXXS).div(2))).div(2).equal(),height:n(n(e.dotSizeSM).sub(n(e.marginXXS).div(2))).div(2).equal()}},[`&-lg ${t}-dot`]:{"&, &-holder":{fontSize:e.dotSizeLG}},[`&-lg ${t}-dot-holder`]:{i:{width:n(n(e.dotSizeLG).sub(e.marginXXS)).div(2).equal(),height:n(n(e.dotSizeLG).sub(e.marginXXS)).div(2).equal()}},[`&${t}-show-text ${t}-text`]:{display:"block"}})}},_j=e=>{const{controlHeightLG:t,controlHeight:n}=e;return{contentHeight:400,dotSize:t/2,dotSizeSM:t*.35,dotSizeLG:n}},Bj=It("Spin",e=>{const t=yt(e,{spinDotDefault:e.colorTextDescription});return Dj(t)},_j),Lj=200,Jg=[[30,.05],[70,.03],[96,.01]];function Hj(e,t){const[n,r]=i.useState(0),o=i.useRef(null),a=t==="auto";return i.useEffect(()=>(a&&e&&(r(0),o.current=setInterval(()=>{r(l=>{const s=100-l;for(let c=0;c<Jg.length;c+=1){const[u,d]=Jg[c];if(l<=u)return l+s*d}return l})},Lj)),()=>{clearInterval(o.current)}),[a,e]),a?n:t}var Aj=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};let zC;function Fj(e,t){return!!e&&!!t&&!Number.isNaN(Number(t))}const DC=e=>{var t;const{prefixCls:n,spinning:r=!0,delay:o=0,className:a,rootClassName:l,size:s="default",tip:c,wrapperClassName:u,style:d,children:f,fullscreen:m=!1,indicator:v,percent:g}=e,h=Aj(e,["prefixCls","spinning","delay","className","rootClassName","size","tip","wrapperClassName","style","children","fullscreen","indicator","percent"]),{getPrefixCls:p,direction:b,className:y,style:C,indicator:$}=tn("spin"),S=p("spin",n),[x,E,O]=Bj(S),[w,I]=i.useState(()=>r&&!Fj(r,o)),P=Hj(w,g);i.useEffect(()=>{if(r){const _=_6(o,()=>{I(!0)});return _(),()=>{var B;(B=_==null?void 0:_.cancel)===null||B===void 0||B.call(_)}}I(!1)},[o,r]);const M=i.useMemo(()=>typeof f<"u"&&!m,[f,m]),R=A(S,y,{[`${S}-sm`]:s==="small",[`${S}-lg`]:s==="large",[`${S}-spinning`]:w,[`${S}-show-text`]:!!c,[`${S}-rtl`]:b==="rtl"},a,!m&&l,E,O),N=A(`${S}-container`,{[`${S}-blur`]:w}),T=(t=v??$)!==null&&t!==void 0?t:zC,j=Object.assign(Object.assign({},C),d),z=i.createElement("div",Object.assign({},h,{style:j,className:R,"aria-live":"polite","aria-busy":w}),i.createElement(Tj,{prefixCls:S,indicator:T,percent:P}),c&&(M||m)?i.createElement("div",{className:`${S}-text`},c):null);return x(M?i.createElement("div",Object.assign({},h,{className:A(`${S}-nested-loading`,u,E,O)}),w&&i.createElement("div",{key:"loading"},z),i.createElement("div",{className:N,key:"container"},f)):m?i.createElement("div",{className:A(`${S}-fullscreen`,{[`${S}-fullscreen-show`]:w},l,E,O)},z):z)};DC.setDefaultIndicator=e=>{zC=e};const kj=(e,t=!1)=>t&&e==null?[]:Array.isArray(e)?e:[e];let ir=null,mo=e=>e(),ti=[],ni={};function ep(){const{getContainer:e,duration:t,rtl:n,maxCount:r,top:o}=ni,a=(e==null?void 0:e())||document.body;return{getContainer:()=>a,duration:t,rtl:n,maxCount:r,top:o}}const Vj=F.forwardRef((e,t)=>{const{messageConfig:n,sync:r}=e,{getPrefixCls:o}=i.useContext(ot),a=ni.prefixCls||o("message"),l=i.useContext(Sb),[s,c]=b0(Object.assign(Object.assign(Object.assign({},n),{prefixCls:a}),l.message));return F.useImperativeHandle(t,()=>{const u=Object.assign({},s);return Object.keys(u).forEach(d=>{u[d]=(...f)=>(r(),s[d].apply(s,f))}),{instance:u,sync:r}}),c}),Wj=F.forwardRef((e,t)=>{const[n,r]=F.useState(ep),o=()=>{r(ep)};F.useEffect(o,[]);const a=Pd(),l=a.getRootPrefixCls(),s=a.getIconPrefixCls(),c=a.getTheme(),u=F.createElement(Vj,{ref:t,sync:o,messageConfig:n});return F.createElement(wr,{prefixCls:l,iconPrefixCls:s,theme:c},a.holderRender?a.holderRender(u):u)}),zs=()=>{if(!ir){const e=document.createDocumentFragment(),t={fragment:e};ir=t,mo(()=>{rs()(F.createElement(Wj,{ref:r=>{const{instance:o,sync:a}=r||{};Promise.resolve().then(()=>{!t.instance&&o&&(t.instance=o,t.sync=a,zs())})}}),e)});return}ir.instance&&(ti.forEach(e=>{const{type:t,skipped:n}=e;if(!n)switch(t){case"open":{mo(()=>{const r=ir.instance.open(Object.assign(Object.assign({},ni),e.config));r==null||r.then(e.resolve),e.setCloseFn(r)});break}case"destroy":mo(()=>{ir==null||ir.instance.destroy(e.key)});break;default:mo(()=>{var r;const o=(r=ir.instance)[t].apply(r,pe(e.args));o==null||o.then(e.resolve),e.setCloseFn(o)})}}),ti=[])};function Kj(e){ni=Object.assign(Object.assign({},ni),e),mo(()=>{var t;(t=ir==null?void 0:ir.sync)===null||t===void 0||t.call(ir)})}function Gj(e){const t=jd(n=>{let r;const o={type:"open",config:e,resolve:n,setCloseFn:a=>{r=a}};return ti.push(o),()=>{r?mo(()=>{r()}):o.skipped=!0}});return zs(),t}function qj(e,t){const n=jd(r=>{let o;const a={type:e,args:t,resolve:r,setCloseFn:l=>{o=l}};return ti.push(a),()=>{o?mo(()=>{o()}):a.skipped=!0}});return zs(),n}const Uj=e=>{ti.push({type:"destroy",key:e}),zs()},Xj=["success","info","warning","error","loading"],Yj={open:Gj,destroy:Uj,config:Kj,useMessage:Qw,_InternalPanelDoNotUseOrYouWillBeFired:Vw},Qj=Yj;Xj.forEach(e=>{Qj[e]=(...t)=>qj(e,t)});var Zj=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Jj=e=>{const{prefixCls:t,className:n,closeIcon:r,closable:o,type:a,title:l,children:s,footer:c}=e,u=Zj(e,["prefixCls","className","closeIcon","closable","type","title","children","footer"]),{getPrefixCls:d}=i.useContext(ot),f=d(),m=t||d("modal"),v=Cn(f),[g,h,p]=ob(m,v),b=`${m}-confirm`;let y={};return a?y={closable:o??!1,title:"",footer:"",children:i.createElement(ib,Object.assign({},e,{prefixCls:m,confirmPrefixCls:b,rootPrefixCls:f,content:s}))}:y={closable:o??!0,title:l,footer:c!==null&&i.createElement(eb,Object.assign({},e)),children:s},g(i.createElement(k0,Object.assign({prefixCls:m,className:A(h,`${m}-pure-panel`,a&&b,a&&`${b}-${a}`,n,p,v)},u,{closeIcon:J0(m,r),closable:o},y)))},ez=$b(Jj);function _C(e){return pi(ub(e))}const Dr=ab;Dr.useModal=bR;Dr.info=function(t){return pi(db(t))};Dr.success=function(t){return pi(fb(t))};Dr.error=function(t){return pi(mb(t))};Dr.warning=_C;Dr.warn=_C;Dr.confirm=function(t){return pi(vb(t))};Dr.destroyAll=function(){for(;uo.length;){const t=uo.pop();t&&t()}};Dr.config=mR;Dr._InternalPanelDoNotUseOrYouWillBeFired=ez;let vr=null,cl=e=>e(),Ml=[],ri={};function tp(){const{getContainer:e,rtl:t,maxCount:n,top:r,bottom:o,showProgress:a,pauseOnHover:l}=ri,s=(e==null?void 0:e())||document.body;return{getContainer:()=>s,rtl:t,maxCount:n,top:r,bottom:o,showProgress:a,pauseOnHover:l}}const tz=F.forwardRef((e,t)=>{const{notificationConfig:n,sync:r}=e,{getPrefixCls:o}=i.useContext(ot),a=ri.prefixCls||o("notification"),l=i.useContext(Sb),[s,c]=Cb(Object.assign(Object.assign(Object.assign({},n),{prefixCls:a}),l.notification));return F.useEffect(r,[]),F.useImperativeHandle(t,()=>{const u=Object.assign({},s);return Object.keys(u).forEach(d=>{u[d]=(...f)=>(r(),s[d].apply(s,f))}),{instance:u,sync:r}}),c}),nz=F.forwardRef((e,t)=>{const[n,r]=F.useState(tp),o=()=>{r(tp)};F.useEffect(o,[]);const a=Pd(),l=a.getRootPrefixCls(),s=a.getIconPrefixCls(),c=a.getTheme(),u=F.createElement(tz,{ref:t,sync:o,notificationConfig:n});return F.createElement(wr,{prefixCls:l,iconPrefixCls:s,theme:c},a.holderRender?a.holderRender(u):u)}),Rf=()=>{if(!vr){const e=document.createDocumentFragment(),t={fragment:e};vr=t,cl(()=>{rs()(F.createElement(nz,{ref:r=>{const{instance:o,sync:a}=r||{};Promise.resolve().then(()=>{!t.instance&&o&&(t.instance=o,t.sync=a,Rf())})}}),e)});return}vr.instance&&(Ml.forEach(e=>{switch(e.type){case"open":{cl(()=>{vr.instance.open(Object.assign(Object.assign({},ri),e.config))});break}case"destroy":cl(()=>{var t;(t=vr==null?void 0:vr.instance)===null||t===void 0||t.destroy(e.key)});break}}),Ml=[])};function rz(e){ri=Object.assign(Object.assign({},ri),e),cl(()=>{var t;(t=vr==null?void 0:vr.sync)===null||t===void 0||t.call(vr)})}function BC(e){Ml.push({type:"open",config:e}),Rf()}const oz=e=>{Ml.push({type:"destroy",key:e}),Rf()},az=["success","info","warning","error"],iz={open:BC,destroy:oz,config:rz,useNotification:AR,_InternalPanelDoNotUseOrYouWillBeFired:NR},lz=iz;az.forEach(e=>{lz[e]=t=>BC(Object.assign(Object.assign({},t),{type:e}))});const sz=e=>{const{componentCls:t,iconCls:n,antCls:r,zIndexPopup:o,colorText:a,colorWarning:l,marginXXS:s,marginXS:c,fontSize:u,fontWeightStrong:d,colorTextHeading:f}=e;return{[t]:{zIndex:o,[`&${r}-popover`]:{fontSize:u},[`${t}-message`]:{marginBottom:c,display:"flex",flexWrap:"nowrap",alignItems:"start",[`> ${t}-message-icon ${n}`]:{color:l,fontSize:u,lineHeight:1,marginInlineEnd:c},[`${t}-title`]:{fontWeight:d,color:f,"&:only-child":{fontWeight:"normal"}},[`${t}-description`]:{marginTop:s,color:a}},[`${t}-buttons`]:{textAlign:"end",whiteSpace:"nowrap",button:{marginInlineStart:c}}}}},cz=e=>{const{zIndexPopupBase:t}=e;return{zIndexPopup:t+60}},LC=It("Popconfirm",e=>sz(e),cz,{resetStyle:!1});var uz=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const HC=e=>{const{prefixCls:t,okButtonProps:n,cancelButtonProps:r,title:o,description:a,cancelText:l,okText:s,okType:c="primary",icon:u=i.createElement(fa,null),showCancel:d=!0,close:f,onConfirm:m,onCancel:v,onPopupClick:g}=e,{getPrefixCls:h}=i.useContext(ot),[p]=Kn("Popconfirm",br.Popconfirm),b=ia(o),y=ia(a);return i.createElement("div",{className:`${t}-inner-content`,onClick:g},i.createElement("div",{className:`${t}-message`},u&&i.createElement("span",{className:`${t}-message-icon`},u),i.createElement("div",{className:`${t}-message-text`},b&&i.createElement("div",{className:`${t}-title`},b),y&&i.createElement("div",{className:`${t}-description`},y))),i.createElement("div",{className:`${t}-buttons`},d&&i.createElement(er,Object.assign({onClick:v,size:"small"},r),l||(p==null?void 0:p.cancelText)),i.createElement(Wd,{buttonProps:Object.assign(Object.assign({size:"small"},Dd(c)),n),actionFn:m,close:f,prefixCls:h("btn"),quitOnNullishReturnValue:!0,emitEvent:!0},s||(p==null?void 0:p.okText))))},dz=e=>{const{prefixCls:t,placement:n,className:r,style:o}=e,a=uz(e,["prefixCls","placement","className","style"]),{getPrefixCls:l}=i.useContext(ot),s=l("popconfirm",t),[c]=LC(s);return c(i.createElement(Qb,{placement:n,className:A(s,r),style:o,content:i.createElement(HC,Object.assign({prefixCls:s},a))}))};var fz=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const mz=i.forwardRef((e,t)=>{var n,r;const{prefixCls:o,placement:a="top",trigger:l="click",okType:s="primary",icon:c=i.createElement(fa,null),children:u,overlayClassName:d,onOpenChange:f,onVisibleChange:m,overlayStyle:v,styles:g,classNames:h}=e,p=fz(e,["prefixCls","placement","trigger","okType","icon","children","overlayClassName","onOpenChange","onVisibleChange","overlayStyle","styles","classNames"]),{getPrefixCls:b,className:y,style:C,classNames:$,styles:S}=tn("popconfirm"),[x,E]=Lt(!1,{value:(n=e.open)!==null&&n!==void 0?n:e.visible,defaultValue:(r=e.defaultOpen)!==null&&r!==void 0?r:e.defaultVisible}),O=(z,_)=>{E(z,!0),m==null||m(z),f==null||f(z,_)},w=z=>{O(!1,z)},I=z=>{var _;return(_=e.onConfirm)===null||_===void 0?void 0:_.call(void 0,z)},P=z=>{var _;O(!1,z),(_=e.onCancel)===null||_===void 0||_.call(void 0,z)},M=(z,_)=>{const{disabled:B=!1}=e;B||O(z,_)},R=b("popconfirm",o),N=A(R,y,d,$.root,h==null?void 0:h.root),T=A($.body,h==null?void 0:h.body),[j]=LC(R);return j(i.createElement(lf,Object.assign({},Gt(p,["title"]),{trigger:l,placement:a,onOpenChange:M,open:x,ref:t,classNames:{root:N,body:T},styles:{root:Object.assign(Object.assign(Object.assign(Object.assign({},S.root),C),v),g==null?void 0:g.root),body:Object.assign(Object.assign({},S.body),g==null?void 0:g.body)},content:i.createElement(HC,Object.assign({okType:s,icon:c},e,{prefixCls:R,close:w,onConfirm:I,onCancel:P})),"data-popover-inject":!0}),u))}),vz=mz;vz._InternalPanelDoNotUseOrYouWillBeFired=dz;var gz={percent:0,prefixCls:"rc-progress",strokeColor:"#2db7f5",strokeLinecap:"round",strokeWidth:1,trailColor:"#D9D9D9",trailWidth:1,gapPosition:"bottom"},pz=function(){var t=i.useRef([]),n=i.useRef(null);return i.useEffect(function(){var r=Date.now(),o=!1;t.current.forEach(function(a){if(a){o=!0;var l=a.style;l.transitionDuration=".3s, .3s, .3s, .06s",n.current&&r-n.current<100&&(l.transitionDuration="0s, 0s")}}),o&&(n.current=Date.now())}),t.current},np=0,hz=wn();function bz(){var e;return hz?(e=np,np+=1):e="TEST_OR_SSR",e}const yz=function(e){var t=i.useState(),n=J(t,2),r=n[0],o=n[1];return i.useEffect(function(){o("rc_progress_".concat(bz()))},[]),e||r};var rp=function(t){var n=t.bg,r=t.children;return i.createElement("div",{style:{width:"100%",height:"100%",background:n}},r)};function op(e,t){return Object.keys(e).map(function(n){var r=parseFloat(n),o="".concat(Math.floor(r*t),"%");return"".concat(e[n]," ").concat(o)})}var Cz=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.color,o=e.gradientId,a=e.radius,l=e.style,s=e.ptg,c=e.strokeLinecap,u=e.strokeWidth,d=e.size,f=e.gapDegree,m=r&&Qe(r)==="object",v=m?"#FFF":void 0,g=d/2,h=i.createElement("circle",{className:"".concat(n,"-circle-path"),r:a,cx:g,cy:g,stroke:v,strokeLinecap:c,strokeWidth:u,opacity:s===0?0:1,style:l,ref:t});if(!m)return h;var p="".concat(o,"-conic"),b=f?"".concat(180+f/2,"deg"):"0deg",y=op(r,(360-f)/360),C=op(r,1),$="conic-gradient(from ".concat(b,", ").concat(y.join(", "),")"),S="linear-gradient(to ".concat(f?"bottom":"top",", ").concat(C.join(", "),")");return i.createElement(i.Fragment,null,i.createElement("mask",{id:p},h),i.createElement("foreignObject",{x:0,y:0,width:d,height:d,mask:"url(#".concat(p,")")},i.createElement(rp,{bg:S},i.createElement(rp,{bg:$}))))}),_a=100,Tc=function(t,n,r,o,a,l,s,c,u,d){var f=arguments.length>10&&arguments[10]!==void 0?arguments[10]:0,m=r/100*360*((360-l)/360),v=l===0?0:{bottom:0,top:180,left:90,right:-90}[s],g=(100-o)/100*n;u==="round"&&o!==100&&(g+=d/2,g>=n&&(g=n-.01));var h=_a/2;return{stroke:typeof c=="string"?c:void 0,strokeDasharray:"".concat(n,"px ").concat(t),strokeDashoffset:g+f,transform:"rotate(".concat(a+m+v,"deg)"),transformOrigin:"".concat(h,"px ").concat(h,"px"),transition:"stroke-dashoffset .3s ease 0s, stroke-dasharray .3s ease 0s, stroke .3s, stroke-width .06s ease .3s, opacity .3s ease 0s",fillOpacity:0}},Sz=["id","prefixCls","steps","strokeWidth","trailWidth","gapDegree","gapPosition","trailColor","strokeLinecap","style","className","strokeColor","percent"];function ap(e){var t=e??[];return Array.isArray(t)?t:[t]}var $z=function(t){var n=k(k({},gz),t),r=n.id,o=n.prefixCls,a=n.steps,l=n.strokeWidth,s=n.trailWidth,c=n.gapDegree,u=c===void 0?0:c,d=n.gapPosition,f=n.trailColor,m=n.strokeLinecap,v=n.style,g=n.className,h=n.strokeColor,p=n.percent,b=ft(n,Sz),y=_a/2,C=yz(r),$="".concat(C,"-gradient"),S=y-l/2,x=Math.PI*2*S,E=u>0?90+u/2:-90,O=x*((360-u)/360),w=Qe(a)==="object"?a:{count:a,gap:2},I=w.count,P=w.gap,M=ap(p),R=ap(h),N=R.find(function(G){return G&&Qe(G)==="object"}),T=N&&Qe(N)==="object",j=T?"butt":m,z=Tc(x,O,0,100,E,u,d,f,j,l),_=pz(),B=function(){var q=0;return M.map(function(H,W){var K=R[W]||R[R.length-1],U=Tc(x,O,q,H,E,u,d,K,j,l);return q+=H,i.createElement(Cz,{key:W,color:K,ptg:H,radius:S,prefixCls:o,gradientId:$,style:U,strokeLinecap:j,strokeWidth:l,gapDegree:u,ref:function(X){_[W]=X},size:_a})}).reverse()},V=function(){var q=Math.round(I*(M[0]/100)),H=100/I,W=0;return new Array(I).fill(null).map(function(K,U){var te=U<=q-1?R[0]:f,X=te&&Qe(te)==="object"?"url(#".concat($,")"):void 0,ae=Tc(x,O,W,H,E,u,d,te,"butt",l,P);return W+=(O-ae.strokeDashoffset+P)*100/O,i.createElement("circle",{key:U,className:"".concat(o,"-circle-path"),r:S,cx:y,cy:y,stroke:X,strokeWidth:l,opacity:1,style:ae,ref:function(ee){_[U]=ee}})})};return i.createElement("svg",ue({className:A("".concat(o,"-circle"),g),viewBox:"0 0 ".concat(_a," ").concat(_a),style:v,id:r,role:"presentation"},b),!I&&i.createElement("circle",{className:"".concat(o,"-circle-trail"),r:S,cx:y,cy:y,stroke:f,strokeLinecap:j,strokeWidth:s||l,style:z}),I?V():B())};function Qr(e){return!e||e<0?0:e>100?100:e}function Tl({success:e,successPercent:t}){let n=t;return e&&"progress"in e&&(n=e.progress),e&&"percent"in e&&(n=e.percent),n}const xz=({percent:e,success:t,successPercent:n})=>{const r=Qr(Tl({success:t,successPercent:n}));return[r,Qr(Qr(e)-r)]},wz=({success:e={},strokeColor:t})=>{const{strokeColor:n}=e;return[n||Vo.green,t||null]},Ds=(e,t,n)=>{var r,o,a,l;let s=-1,c=-1;if(t==="step"){const u=n.steps,d=n.strokeWidth;typeof e=="string"||typeof e>"u"?(s=e==="small"?2:14,c=d??8):typeof e=="number"?[s,c]=[e,e]:[s=14,c=8]=Array.isArray(e)?e:[e.width,e.height],s*=u}else if(t==="line"){const u=n==null?void 0:n.strokeWidth;typeof e=="string"||typeof e>"u"?c=u||(e==="small"?6:8):typeof e=="number"?[s,c]=[e,e]:[s=-1,c=8]=Array.isArray(e)?e:[e.width,e.height]}else(t==="circle"||t==="dashboard")&&(typeof e=="string"||typeof e>"u"?[s,c]=e==="small"?[60,60]:[120,120]:typeof e=="number"?[s,c]=[e,e]:Array.isArray(e)&&(s=(o=(r=e[0])!==null&&r!==void 0?r:e[1])!==null&&o!==void 0?o:120,c=(l=(a=e[0])!==null&&a!==void 0?a:e[1])!==null&&l!==void 0?l:120));return[s,c]},Ez=3,Oz=e=>Ez/e*100,Iz=e=>{const{prefixCls:t,trailColor:n=null,strokeLinecap:r="round",gapPosition:o,gapDegree:a,width:l=120,type:s,children:c,success:u,size:d=l,steps:f}=e,[m,v]=Ds(d,"circle");let{strokeWidth:g}=e;g===void 0&&(g=Math.max(Oz(m),6));const h={width:m,height:v,fontSize:m*.15+6},p=i.useMemo(()=>{if(a||a===0)return a;if(s==="dashboard")return 75},[a,s]),b=xz(e),y=o||s==="dashboard"&&"bottom"||void 0,C=Object.prototype.toString.call(e.strokeColor)==="[object Object]",$=wz({success:u,strokeColor:e.strokeColor}),S=A(`${t}-inner`,{[`${t}-circle-gradient`]:C}),x=i.createElement($z,{steps:f,percent:f?b[1]:b,strokeWidth:g,trailWidth:g,strokeColor:f?$[1]:$,strokeLinecap:r,trailColor:n,prefixCls:t,gapDegree:p,gapPosition:y}),E=m<=20,O=i.createElement("div",{className:S,style:h},x,!E&&c);return E?i.createElement($r,{title:c},O):O},jl="--progress-line-stroke-color",AC="--progress-percent",ip=e=>{const t=e?"100%":"-100%";return new $t(`antProgress${e?"RTL":"LTR"}Active`,{"0%":{transform:`translateX(${t}) scaleX(0)`,opacity:.1},"20%":{transform:`translateX(${t}) scaleX(0)`,opacity:.5},to:{transform:"translateX(0) scaleX(1)",opacity:0}})},Rz=e=>{const{componentCls:t,iconCls:n}=e;return{[t]:Object.assign(Object.assign({},Tt(e)),{display:"inline-block","&-rtl":{direction:"rtl"},"&-line":{position:"relative",width:"100%",fontSize:e.fontSize},[`${t}-outer`]:{display:"inline-flex",alignItems:"center",width:"100%"},[`${t}-inner`]:{position:"relative",display:"inline-block",width:"100%",flex:1,overflow:"hidden",verticalAlign:"middle",backgroundColor:e.remainingColor,borderRadius:e.lineBorderRadius},[`${t}-inner:not(${t}-circle-gradient)`]:{[`${t}-circle-path`]:{stroke:e.defaultColor}},[`${t}-success-bg, ${t}-bg`]:{position:"relative",background:e.defaultColor,borderRadius:e.lineBorderRadius,transition:`all ${e.motionDurationSlow} ${e.motionEaseInOutCirc}`},[`${t}-layout-bottom`]:{display:"flex",flexDirection:"column",alignItems:"center",justifyContent:"center",[`${t}-text`]:{width:"max-content",marginInlineStart:0,marginTop:e.marginXXS}},[`${t}-bg`]:{overflow:"hidden","&::after":{content:'""',background:{_multi_value_:!0,value:["inherit",`var(${jl})`]},height:"100%",width:`calc(1 / var(${AC}) * 100%)`,display:"block"},[`&${t}-bg-inner`]:{minWidth:"max-content","&::after":{content:"none"},[`${t}-text-inner`]:{color:e.colorWhite,[`&${t}-text-bright`]:{color:"rgba(0, 0, 0, 0.45)"}}}},[`${t}-success-bg`]:{position:"absolute",insetBlockStart:0,insetInlineStart:0,backgroundColor:e.colorSuccess},[`${t}-text`]:{display:"inline-block",marginInlineStart:e.marginXS,color:e.colorText,lineHeight:1,width:"2em",whiteSpace:"nowrap",textAlign:"start",verticalAlign:"middle",wordBreak:"normal",[n]:{fontSize:e.fontSize},[`&${t}-text-outer`]:{width:"max-content"},[`&${t}-text-outer${t}-text-start`]:{width:"max-content",marginInlineStart:0,marginInlineEnd:e.marginXS}},[`${t}-text-inner`]:{display:"flex",justifyContent:"center",alignItems:"center",width:"100%",height:"100%",marginInlineStart:0,padding:`0 ${L(e.paddingXXS)}`,[`&${t}-text-start`]:{justifyContent:"start"},[`&${t}-text-end`]:{justifyContent:"end"}},[`&${t}-status-active`]:{[`${t}-bg::before`]:{position:"absolute",inset:0,backgroundColor:e.colorBgContainer,borderRadius:e.lineBorderRadius,opacity:0,animationName:ip(),animationDuration:e.progressActiveMotionDuration,animationTimingFunction:e.motionEaseOutQuint,animationIterationCount:"infinite",content:'""'}},[`&${t}-rtl${t}-status-active`]:{[`${t}-bg::before`]:{animationName:ip(!0)}},[`&${t}-status-exception`]:{[`${t}-bg`]:{backgroundColor:e.colorError},[`${t}-text`]:{color:e.colorError}},[`&${t}-status-exception ${t}-inner:not(${t}-circle-gradient)`]:{[`${t}-circle-path`]:{stroke:e.colorError}},[`&${t}-status-success`]:{[`${t}-bg`]:{backgroundColor:e.colorSuccess},[`${t}-text`]:{color:e.colorSuccess}},[`&${t}-status-success ${t}-inner:not(${t}-circle-gradient)`]:{[`${t}-circle-path`]:{stroke:e.colorSuccess}}})}},Pz=e=>{const{componentCls:t,iconCls:n}=e;return{[t]:{[`${t}-circle-trail`]:{stroke:e.remainingColor},[`&${t}-circle ${t}-inner`]:{position:"relative",lineHeight:1,backgroundColor:"transparent"},[`&${t}-circle ${t}-text`]:{position:"absolute",insetBlockStart:"50%",insetInlineStart:0,width:"100%",margin:0,padding:0,color:e.circleTextColor,fontSize:e.circleTextFontSize,lineHeight:1,whiteSpace:"normal",textAlign:"center",transform:"translateY(-50%)",[n]:{fontSize:e.circleIconFontSize}},[`${t}-circle&-status-exception`]:{[`${t}-text`]:{color:e.colorError}},[`${t}-circle&-status-success`]:{[`${t}-text`]:{color:e.colorSuccess}}},[`${t}-inline-circle`]:{lineHeight:1,[`${t}-inner`]:{verticalAlign:"bottom"}}}},Nz=e=>{const{componentCls:t}=e;return{[t]:{[`${t}-steps`]:{display:"inline-block","&-outer":{display:"flex",flexDirection:"row",alignItems:"center"},"&-item":{flexShrink:0,minWidth:e.progressStepMinWidth,marginInlineEnd:e.progressStepMarginInlineEnd,backgroundColor:e.remainingColor,transition:`all ${e.motionDurationSlow}`,"&-active":{backgroundColor:e.defaultColor}}}}}},Mz=e=>{const{componentCls:t,iconCls:n}=e;return{[t]:{[`${t}-small&-line, ${t}-small&-line ${t}-text ${n}`]:{fontSize:e.fontSizeSM}}}},Tz=e=>({circleTextColor:e.colorText,defaultColor:e.colorInfo,remainingColor:e.colorFillSecondary,lineBorderRadius:100,circleTextFontSize:"1em",circleIconFontSize:`${e.fontSize/e.fontSizeSM}em`}),jz=It("Progress",e=>{const t=e.calc(e.marginXXS).div(2).equal(),n=yt(e,{progressStepMarginInlineEnd:t,progressStepMinWidth:t,progressActiveMotionDuration:"2.4s"});return[Rz(n),Pz(n),Nz(n),Mz(n)]},Tz);var zz=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Dz=e=>{let t=[];return Object.keys(e).forEach(n=>{const r=parseFloat(n.replace(/%/g,""));Number.isNaN(r)||t.push({key:r,value:e[n]})}),t=t.sort((n,r)=>n.key-r.key),t.map(({key:n,value:r})=>`${r} ${n}%`).join(", ")},_z=(e,t)=>{const{from:n=Vo.blue,to:r=Vo.blue,direction:o=t==="rtl"?"to left":"to right"}=e,a=zz(e,["from","to","direction"]);if(Object.keys(a).length!==0){const s=Dz(a),c=`linear-gradient(${o}, ${s})`;return{background:c,[jl]:c}}const l=`linear-gradient(${o}, ${n}, ${r})`;return{background:l,[jl]:l}},Bz=e=>{const{prefixCls:t,direction:n,percent:r,size:o,strokeWidth:a,strokeColor:l,strokeLinecap:s="round",children:c,trailColor:u=null,percentPosition:d,success:f}=e,{align:m,type:v}=d,g=l&&typeof l!="string"?_z(l,n):{[jl]:l,background:l},h=s==="square"||s==="butt"?0:void 0,p=o??[-1,a||(o==="small"?6:8)],[b,y]=Ds(p,"line",{strokeWidth:a}),C={backgroundColor:u||void 0,borderRadius:h},$=Object.assign(Object.assign({width:`${Qr(r)}%`,height:y,borderRadius:h},g),{[AC]:Qr(r)/100}),S=Tl(e),x={width:`${Qr(S)}%`,height:y,borderRadius:h,backgroundColor:f==null?void 0:f.strokeColor},E={width:b<0?"100%":b},O=i.createElement("div",{className:`${t}-inner`,style:C},i.createElement("div",{className:A(`${t}-bg`,`${t}-bg-${v}`),style:$},v==="inner"&&c),S!==void 0&&i.createElement("div",{className:`${t}-success-bg`,style:x})),w=v==="outer"&&m==="start",I=v==="outer"&&m==="end";return v==="outer"&&m==="center"?i.createElement("div",{className:`${t}-layout-bottom`},O,c):i.createElement("div",{className:`${t}-outer`,style:E},w&&c,O,I&&c)},Lz=e=>{const{size:t,steps:n,rounding:r=Math.round,percent:o=0,strokeWidth:a=8,strokeColor:l,trailColor:s=null,prefixCls:c,children:u}=e,d=r(n*(o/100)),m=t??[t==="small"?2:14,a],[v,g]=Ds(m,"step",{steps:n,strokeWidth:a}),h=v/n,p=Array.from({length:n});for(let b=0;b<n;b++){const y=Array.isArray(l)?l[b]:l;p[b]=i.createElement("div",{key:b,className:A(`${c}-steps-item`,{[`${c}-steps-item-active`]:b<=d-1}),style:{backgroundColor:b<=d-1?y:s,width:h,height:g}})}return i.createElement("div",{className:`${c}-steps-outer`},p,u)};var Hz=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Az=["normal","exception","active","success"],Fz=i.forwardRef((e,t)=>{const{prefixCls:n,className:r,rootClassName:o,steps:a,strokeColor:l,percent:s=0,size:c="default",showInfo:u=!0,type:d="line",status:f,format:m,style:v,percentPosition:g={}}=e,h=Hz(e,["prefixCls","className","rootClassName","steps","strokeColor","percent","size","showInfo","type","status","format","style","percentPosition"]),{align:p="end",type:b="outer"}=g,y=Array.isArray(l)?l[0]:l,C=typeof l=="string"||Array.isArray(l)?l:void 0,$=i.useMemo(()=>{if(y){const B=typeof y=="string"?y:Object.values(y)[0];return new Mt(B).isLight()}return!1},[l]),S=i.useMemo(()=>{var B,V;const G=Tl(e);return parseInt(G!==void 0?(B=G??0)===null||B===void 0?void 0:B.toString():(V=s??0)===null||V===void 0?void 0:V.toString(),10)},[s,e.success,e.successPercent]),x=i.useMemo(()=>!Az.includes(f)&&S>=100?"success":f||"normal",[f,S]),{getPrefixCls:E,direction:O,progress:w}=i.useContext(ot),I=E("progress",n),[P,M,R]=jz(I),N=d==="line",T=N&&!a,j=i.useMemo(()=>{if(!u)return null;const B=Tl(e);let V;const G=m||(H=>`${H}%`),q=N&&$&&b==="inner";return b==="inner"||m||x!=="exception"&&x!=="success"?V=G(Qr(s),Qr(B)):x==="exception"?V=N?i.createElement(wo,null):i.createElement(Fr,null):x==="success"&&(V=N?i.createElement(ii,null):i.createElement(Jd,null)),i.createElement("span",{className:A(`${I}-text`,{[`${I}-text-bright`]:q,[`${I}-text-${p}`]:T,[`${I}-text-${b}`]:T}),title:typeof V=="string"?V:void 0},V)},[u,s,S,x,d,I,m]);let z;d==="line"?z=a?i.createElement(Lz,Object.assign({},e,{strokeColor:C,prefixCls:I,steps:typeof a=="object"?a.count:a}),j):i.createElement(Bz,Object.assign({},e,{strokeColor:y,prefixCls:I,direction:O,percentPosition:{align:p,type:b}}),j):(d==="circle"||d==="dashboard")&&(z=i.createElement(Iz,Object.assign({},e,{strokeColor:y,prefixCls:I,progressStatus:x}),j));const _=A(I,`${I}-status-${x}`,{[`${I}-${d==="dashboard"&&"circle"||d}`]:d!=="line",[`${I}-inline-circle`]:d==="circle"&&Ds(c,"circle")[0]<=20,[`${I}-line`]:T,[`${I}-line-align-${p}`]:T,[`${I}-line-position-${b}`]:T,[`${I}-steps`]:a,[`${I}-show-info`]:u,[`${I}-${c}`]:typeof c=="string",[`${I}-rtl`]:O==="rtl"},w==null?void 0:w.className,r,o,M,R);return P(i.createElement("div",Object.assign({ref:t,style:Object.assign(Object.assign({},w==null?void 0:w.style),v),className:_,role:"progressbar","aria-valuenow":S,"aria-valuemin":0,"aria-valuemax":100},Gt(h,["trailColor","strokeWidth","width","gapDegree","gapPosition","strokeLinecap","success","successPercent"])),z))});var kz={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M464 144H160c-8.8 0-16 7.2-16 16v304c0 8.8 7.2 16 16 16h304c8.8 0 16-7.2 16-16V160c0-8.8-7.2-16-16-16zm-52 268H212V212h200v200zm452-268H560c-8.8 0-16 7.2-16 16v304c0 8.8 7.2 16 16 16h304c8.8 0 16-7.2 16-16V160c0-8.8-7.2-16-16-16zm-52 268H612V212h200v200zM464 544H160c-8.8 0-16 7.2-16 16v304c0 8.8 7.2 16 16 16h304c8.8 0 16-7.2 16-16V560c0-8.8-7.2-16-16-16zm-52 268H212V612h200v200zm452-268H560c-8.8 0-16 7.2-16 16v304c0 8.8 7.2 16 16 16h304c8.8 0 16-7.2 16-16V560c0-8.8-7.2-16-16-16zm-52 268H612V612h200v200z"}}]},name:"appstore",theme:"outlined"},Vz=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:kz}))},gA=i.forwardRef(Vz),Wz={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M862 465.3h-81c-4.6 0-9 2-12.1 5.5L550 723.1V160c0-4.4-3.6-8-8-8h-60c-4.4 0-8 3.6-8 8v563.1L255.1 470.8c-3-3.5-7.4-5.5-12.1-5.5h-81c-6.8 0-10.5 8.1-6 13.2L487.9 861a31.96 31.96 0 0048.3 0L868 478.5c4.5-5.2.8-13.2-6-13.2z"}}]},name:"arrow-down",theme:"outlined"},Kz=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:Wz}))},pA=i.forwardRef(Kz),Gz={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M868 545.5L536.1 163a31.96 31.96 0 00-48.3 0L156 545.5a7.97 7.97 0 006 13.2h81c4.6 0 9-2 12.1-5.5L474 300.9V864c0 4.4 3.6 8 8 8h60c4.4 0 8-3.6 8-8V300.9l218.9 252.3c3 3.5 7.4 5.5 12.1 5.5h81c6.8 0 10.5-8 6-13.2z"}}]},name:"arrow-up",theme:"outlined"},qz=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:Gz}))},hA=i.forwardRef(qz),Uz={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M766.4 744.3c43.7 0 79.4-36.2 79.4-80.5 0-53.5-79.4-140.8-79.4-140.8S687 610.3 687 663.8c0 44.3 35.7 80.5 79.4 80.5zm-377.1-44.1c7.1 7.1 18.6 7.1 25.6 0l256.1-256c7.1-7.1 7.1-18.6 0-25.6l-256-256c-.6-.6-1.3-1.2-2-1.7l-78.2-78.2a9.11 9.11 0 00-12.8 0l-48 48a9.11 9.11 0 000 12.8l67.2 67.2-207.8 207.9c-7.1 7.1-7.1 18.6 0 25.6l255.9 256zm12.9-448.6l178.9 178.9H223.4l178.8-178.9zM904 816H120c-4.4 0-8 3.6-8 8v80c0 4.4 3.6 8 8 8h784c4.4 0 8-3.6 8-8v-80c0-4.4-3.6-8-8-8z"}}]},name:"bg-colors",theme:"outlined"},Xz=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:Uz}))},bA=i.forwardRef(Xz),Yz={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M840.4 300H183.6c-19.7 0-30.7 20.8-18.5 35l328.4 380.8c9.4 10.9 27.5 10.9 37 0L858.9 335c12.2-14.2 1.2-35-18.5-35z"}}]},name:"caret-down",theme:"filled"},Qz=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:Yz}))},Zz=i.forwardRef(Qz),Jz={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M840.4 300H183.6c-19.7 0-30.7 20.8-18.5 35l328.4 380.8c9.4 10.9 27.5 10.9 37 0L858.9 335c12.2-14.2 1.2-35-18.5-35z"}}]},name:"caret-down",theme:"outlined"},eD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:Jz}))},tD=i.forwardRef(eD),nD={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M858.9 689L530.5 308.2c-9.4-10.9-27.5-10.9-37 0L165.1 689c-12.2 14.2-1.2 35 18.5 35h656.8c19.7 0 30.7-20.8 18.5-35z"}}]},name:"caret-up",theme:"outlined"},rD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:nD}))},oD=i.forwardRef(rD),aD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M699 353h-46.9c-10.2 0-19.9 4.9-25.9 13.3L469 584.3l-71.2-98.8c-6-8.3-15.6-13.3-25.9-13.3H325c-6.5 0-10.3 7.4-6.5 12.7l124.6 172.8a31.8 31.8 0 0051.7 0l210.6-292c3.9-5.3.1-12.7-6.4-12.7z"}},{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372s166.6-372 372-372 372 166.6 372 372-166.6 372-372 372z"}}]},name:"check-circle",theme:"outlined"},iD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:aD}))},yA=i.forwardRef(iD),lD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"defs",attrs:{},children:[{tag:"style",attrs:{}}]},{tag:"path",attrs:{d:"M899.1 869.6l-53-305.6H864c14.4 0 26-11.6 26-26V346c0-14.4-11.6-26-26-26H618V138c0-14.4-11.6-26-26-26H432c-14.4 0-26 11.6-26 26v182H160c-14.4 0-26 11.6-26 26v192c0 14.4 11.6 26 26 26h17.9l-53 305.6a25.95 25.95 0 0025.6 30.4h723c1.5 0 3-.1 4.4-.4a25.88 25.88 0 0021.2-30zM204 390h272V182h72v208h272v104H204V390zm468 440V674c0-4.4-3.6-8-8-8h-48c-4.4 0-8 3.6-8 8v156H416V674c0-4.4-3.6-8-8-8h-48c-4.4 0-8 3.6-8 8v156H202.8l45.1-260H776l45.1 260H672z"}}]},name:"clear",theme:"outlined"},sD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:lD}))},CA=i.forwardRef(sD),cD={icon:{tag:"svg",attrs:{"fill-rule":"evenodd",viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64c247.4 0 448 200.6 448 448S759.4 960 512 960 64 759.4 64 512 264.6 64 512 64zm0 76c-205.4 0-372 166.6-372 372s166.6 372 372 372 372-166.6 372-372-166.6-372-372-372zm128.01 198.83c.03 0 .05.01.09.06l45.02 45.01a.2.2 0 01.05.09.12.12 0 010 .07c0 .02-.01.04-.05.08L557.25 512l127.87 127.86a.27.27 0 01.05.06v.02a.12.12 0 010 .07c0 .03-.01.05-.05.09l-45.02 45.02a.2.2 0 01-.09.05.12.12 0 01-.07 0c-.02 0-.04-.01-.08-.05L512 557.25 384.14 685.12c-.04.04-.06.05-.08.05a.12.12 0 01-.07 0c-.03 0-.05-.01-.09-.05l-45.02-45.02a.2.2 0 01-.05-.09.12.12 0 010-.07c0-.02.01-.04.06-.08L466.75 512 338.88 384.14a.27.27 0 01-.05-.06l-.01-.02a.12.12 0 010-.07c0-.03.01-.05.05-.09l45.02-45.02a.2.2 0 01.09-.05.12.12 0 01.07 0c.02 0 .04.01.08.06L512 466.75l127.86-127.86c.04-.05.06-.06.08-.06a.12.12 0 01.07 0z"}}]},name:"close-circle",theme:"outlined"},uD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:cD}))},SA=i.forwardRef(uD),dD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M811.4 368.9C765.6 248 648.9 162 512.2 162S258.8 247.9 213 368.8C126.9 391.5 63.5 470.2 64 563.6 64.6 668 145.6 752.9 247.6 762c4.7.4 8.7-3.3 8.7-8v-60.4c0-4-3-7.4-7-7.9-27-3.4-52.5-15.2-72.1-34.5-24-23.5-37.2-55.1-37.2-88.6 0-28 9.1-54.4 26.2-76.4 16.7-21.4 40.2-36.9 66.1-43.7l37.9-10 13.9-36.7c8.6-22.8 20.6-44.2 35.7-63.5 14.9-19.2 32.6-36 52.4-50 41.1-28.9 89.5-44.2 140-44.2s98.9 15.3 140 44.3c19.9 14 37.5 30.8 52.4 50 15.1 19.3 27.1 40.7 35.7 63.5l13.8 36.6 37.8 10c54.2 14.4 92.1 63.7 92.1 120 0 33.6-13.2 65.1-37.2 88.6-19.5 19.2-44.9 31.1-71.9 34.5-4 .5-6.9 3.9-6.9 7.9V754c0 4.7 4.1 8.4 8.8 8 101.7-9.2 182.5-94 183.2-198.2.6-93.4-62.7-172.1-148.6-194.9z"}},{tag:"path",attrs:{d:"M376.9 656.4c1.8-33.5 15.7-64.7 39.5-88.6 25.4-25.5 60-39.8 96-39.8 36.2 0 70.3 14.1 96 39.8 1.4 1.4 2.7 2.8 4.1 4.3l-25 19.6a8 8 0 003 14.1l98.2 24c5 1.2 9.9-2.6 9.9-7.7l.5-101.3c0-6.7-7.6-10.5-12.9-6.3L663 532.7c-36.6-42-90.4-68.6-150.5-68.6-107.4 0-195 85.1-199.4 191.7-.2 4.5 3.4 8.3 8 8.3H369c4.2-.1 7.7-3.4 7.9-7.7zM703 664h-47.9c-4.2 0-7.7 3.3-8 7.6-1.8 33.5-15.7 64.7-39.5 88.6-25.4 25.5-60 39.8-96 39.8-36.2 0-70.3-14.1-96-39.8-1.4-1.4-2.7-2.8-4.1-4.3l25-19.6a8 8 0 00-3-14.1l-98.2-24c-5-1.2-9.9 2.6-9.9 7.7l-.4 101.4c0 6.7 7.6 10.5 12.9 6.3l23.2-18.2c36.6 42 90.4 68.6 150.5 68.6 107.4 0 195-85.1 199.4-191.7.2-4.5-3.4-8.3-8-8.3z"}}]},name:"cloud-sync",theme:"outlined"},fD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:dD}))},$A=i.forwardRef(fD),mD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M832 64H296c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h496v688c0 4.4 3.6 8 8 8h56c4.4 0 8-3.6 8-8V96c0-17.7-14.3-32-32-32zM704 192H192c-17.7 0-32 14.3-32 32v530.7c0 8.5 3.4 16.6 9.4 22.6l173.3 173.3c2.2 2.2 4.7 4 7.4 5.5v1.9h4.2c3.5 1.3 7.2 2 11 2H704c17.7 0 32-14.3 32-32V224c0-17.7-14.3-32-32-32zM350 856.2L263.9 770H350v86.2zM664 888H414V746c0-22.1-17.9-40-40-40H232V264h432v624z"}}]},name:"copy",theme:"outlined"},vD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:mD}))},gD=i.forwardRef(vD),pD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M924.8 385.6a446.7 446.7 0 00-96-142.4 446.7 446.7 0 00-142.4-96C631.1 123.8 572.5 112 512 112s-119.1 11.8-174.4 35.2a446.7 446.7 0 00-142.4 96 446.7 446.7 0 00-96 142.4C75.8 440.9 64 499.5 64 560c0 132.7 58.3 257.7 159.9 343.1l1.7 1.4c5.8 4.8 13.1 7.5 20.6 7.5h531.7c7.5 0 14.8-2.7 20.6-7.5l1.7-1.4C901.7 817.7 960 692.7 960 560c0-60.5-11.9-119.1-35.2-174.4zM761.4 836H262.6A371.12 371.12 0 01140 560c0-99.4 38.7-192.8 109-263 70.3-70.3 163.7-109 263-109 99.4 0 192.8 38.7 263 109 70.3 70.3 109 163.7 109 263 0 105.6-44.5 205.5-122.6 276zM623.5 421.5a8.03 8.03 0 00-11.3 0L527.7 506c-18.7-5-39.4-.2-54.1 14.5a55.95 55.95 0 000 79.2 55.95 55.95 0 0079.2 0 55.87 55.87 0 0014.5-54.1l84.5-84.5c3.1-3.1 3.1-8.2 0-11.3l-28.3-28.3zM490 320h44c4.4 0 8-3.6 8-8v-80c0-4.4-3.6-8-8-8h-44c-4.4 0-8 3.6-8 8v80c0 4.4 3.6 8 8 8zm260 218v44c0 4.4 3.6 8 8 8h80c4.4 0 8-3.6 8-8v-44c0-4.4-3.6-8-8-8h-80c-4.4 0-8 3.6-8 8zm12.7-197.2l-31.1-31.1a8.03 8.03 0 00-11.3 0l-56.6 56.6a8.03 8.03 0 000 11.3l31.1 31.1c3.1 3.1 8.2 3.1 11.3 0l56.6-56.6c3.1-3.1 3.1-8.2 0-11.3zm-458.6-31.1a8.03 8.03 0 00-11.3 0l-31.1 31.1a8.03 8.03 0 000 11.3l56.6 56.6c3.1 3.1 8.2 3.1 11.3 0l31.1-31.1c3.1-3.1 3.1-8.2 0-11.3l-56.6-56.6zM262 530h-80c-4.4 0-8 3.6-8 8v44c0 4.4 3.6 8 8 8h80c4.4 0 8-3.6 8-8v-44c0-4.4-3.6-8-8-8z"}}]},name:"dashboard",theme:"outlined"},hD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:pD}))},xA=i.forwardRef(hD),bD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M832 64H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V96c0-17.7-14.3-32-32-32zm-600 72h560v208H232V136zm560 480H232V408h560v208zm0 272H232V680h560v208zM304 240a40 40 0 1080 0 40 40 0 10-80 0zm0 272a40 40 0 1080 0 40 40 0 10-80 0zm0 272a40 40 0 1080 0 40 40 0 10-80 0z"}}]},name:"database",theme:"outlined"},yD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:bD}))},wA=i.forwardRef(yD),CD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M360 184h-8c4.4 0 8-3.6 8-8v8h304v-8c0 4.4 3.6 8 8 8h-8v72h72v-80c0-35.3-28.7-64-64-64H352c-35.3 0-64 28.7-64 64v80h72v-72zm504 72H160c-17.7 0-32 14.3-32 32v32c0 4.4 3.6 8 8 8h60.4l24.7 523c1.6 34.1 29.8 61 63.9 61h454c34.2 0 62.3-26.8 63.9-61l24.7-523H888c4.4 0 8-3.6 8-8v-32c0-17.7-14.3-32-32-32zM731.3 840H292.7l-24.2-512h487l-24.2 512z"}}]},name:"delete",theme:"outlined"},SD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:CD}))},$D=i.forwardRef(SD),xD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M505.7 661a8 8 0 0012.6 0l112-141.7c4.1-5.2.4-12.9-6.3-12.9h-74.1V168c0-4.4-3.6-8-8-8h-60c-4.4 0-8 3.6-8 8v338.3H400c-6.7 0-10.4 7.7-6.3 12.9l112 141.8zM878 626h-60c-4.4 0-8 3.6-8 8v154H214V634c0-4.4-3.6-8-8-8h-60c-4.4 0-8 3.6-8 8v198c0 17.7 14.3 32 32 32h684c17.7 0 32-14.3 32-32V634c0-4.4-3.6-8-8-8z"}}]},name:"download",theme:"outlined"},wD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:xD}))},ED=i.forwardRef(wD),OD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M257.7 752c2 0 4-.2 6-.5L431.9 722c2-.4 3.9-1.3 5.3-2.8l423.9-423.9a9.96 9.96 0 000-14.1L694.9 114.9c-1.9-1.9-4.4-2.9-7.1-2.9s-5.2 1-7.1 2.9L256.8 538.8c-1.5 1.5-2.4 3.3-2.8 5.3l-29.5 168.2a33.5 33.5 0 009.4 29.8c6.6 6.4 14.9 9.9 23.8 9.9zm67.4-174.4L687.8 215l73.3 73.3-362.7 362.6-88.9 15.7 15.6-89zM880 836H144c-17.7 0-32 14.3-32 32v36c0 4.4 3.6 8 8 8h784c4.4 0 8-3.6 8-8v-36c0-17.7-14.3-32-32-32z"}}]},name:"edit",theme:"outlined"},ID=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:OD}))},RD=i.forwardRef(ID),PD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M864 170h-60c-4.4 0-8 3.6-8 8v518H310v-73c0-6.7-7.8-10.5-13-6.3l-141.9 112a8 8 0 000 12.6l141.9 112c5.3 4.2 13 .4 13-6.3v-75h498c35.3 0 64-28.7 64-64V178c0-4.4-3.6-8-8-8z"}}]},name:"enter",theme:"outlined"},ND=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:PD}))},MD=i.forwardRef(ND),TD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 472a40 40 0 1080 0 40 40 0 10-80 0zm367 352.9L696.3 352V178H768v-68H256v68h71.7v174L145 824.9c-2.8 7.4-4.3 15.2-4.3 23.1 0 35.3 28.7 64 64 64h614.6c7.9 0 15.7-1.5 23.1-4.3 33-12.7 49.4-49.8 36.6-82.8zM395.7 364.7V180h232.6v184.7L719.2 600c-20.7-5.3-42.1-8-63.9-8-61.2 0-119.2 21.5-165.3 60a188.78 188.78 0 01-121.3 43.9c-32.7 0-64.1-8.3-91.8-23.7l118.8-307.5zM210.5 844l41.7-107.8c35.7 18.1 75.4 27.8 116.6 27.8 61.2 0 119.2-21.5 165.3-60 33.9-28.2 76.3-43.9 121.3-43.9 35 0 68.4 9.5 97.6 27.1L813.5 844h-603z"}}]},name:"experiment",theme:"outlined"},jD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:TD}))},EA=i.forwardRef(jD),zD={icon:{tag:"svg",attrs:{"fill-rule":"evenodd",viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M880 912H144c-17.7 0-32-14.3-32-32V144c0-17.7 14.3-32 32-32h360c4.4 0 8 3.6 8 8v56c0 4.4-3.6 8-8 8H184v656h656V520c0-4.4 3.6-8 8-8h56c4.4 0 8 3.6 8 8v360c0 17.7-14.3 32-32 32zM770.87 199.13l-52.2-52.2a8.01 8.01 0 014.7-13.6l179.4-21c5.1-.6 9.5 3.7 8.9 8.9l-21 179.4c-.8 6.6-8.9 9.4-13.6 4.7l-52.4-52.4-256.2 256.2a8.03 8.03 0 01-11.3 0l-42.4-42.4a8.03 8.03 0 010-11.3l256.1-256.3z"}}]},name:"export",theme:"outlined"},DD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:zD}))},OA=i.forwardRef(DD),_D={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M854.6 288.6L639.4 73.4c-6-6-14.1-9.4-22.6-9.4H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V311.3c0-8.5-3.4-16.7-9.4-22.7zM790.2 326H602V137.8L790.2 326zm1.8 562H232V136h302v216a42 42 0 0042 42h216v494zM514.1 580.1l-61.8-102.4c-2.2-3.6-6.1-5.8-10.3-5.8h-38.4c-2.3 0-4.5.6-6.4 1.9-5.6 3.5-7.3 10.9-3.7 16.6l82.3 130.4-83.4 132.8a12.04 12.04 0 0010.2 18.4h34.5c4.2 0 8-2.2 10.2-5.7L510 664.8l62.3 101.4c2.2 3.6 6.1 5.7 10.2 5.7H620c2.3 0 4.5-.7 6.5-1.9 5.6-3.6 7.2-11 3.6-16.6l-84-130.4 85.3-132.5a12.04 12.04 0 00-10.1-18.5h-35.7c-4.2 0-8.1 2.2-10.3 5.8l-61.2 102.3z"}}]},name:"file-excel",theme:"outlined"},BD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:_D}))},IA=i.forwardRef(BD),LD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M854.6 288.6L639.4 73.4c-6-6-14.1-9.4-22.6-9.4H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V311.3c0-8.5-3.4-16.7-9.4-22.7zM790.2 326H602V137.8L790.2 326zm1.8 562H232V136h302v216a42 42 0 0042 42h216v494z"}}]},name:"file",theme:"outlined"},HD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:LD}))},FC=i.forwardRef(HD),AD={icon:function(t,n){return{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M534 352V136H232v752h560V394H576a42 42 0 01-42-42z",fill:n}},{tag:"path",attrs:{d:"M854.6 288.6L639.4 73.4c-6-6-14.1-9.4-22.6-9.4H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V311.3c0-8.5-3.4-16.7-9.4-22.7zM602 137.8L790.2 326H602V137.8zM792 888H232V136h302v216a42 42 0 0042 42h216v494z",fill:t}}]}},name:"file",theme:"twotone"},FD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:AD}))},kD=i.forwardRef(FD),VD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M349 838c0 17.7 14.2 32 31.8 32h262.4c17.6 0 31.8-14.3 31.8-32V642H349v196zm531.1-684H143.9c-24.5 0-39.8 26.7-27.5 48l221.3 376h348.8l221.3-376c12.1-21.3-3.2-48-27.7-48z"}}]},name:"filter",theme:"filled"},WD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:VD}))},KD=i.forwardRef(WD),GD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M834.1 469.2A347.49 347.49 0 00751.2 354l-29.1-26.7a8.09 8.09 0 00-13 3.3l-13 37.3c-8.1 23.4-23 47.3-44.1 70.8-1.4 1.5-3 1.9-4.1 2-1.1.1-2.8-.1-4.3-1.5-1.4-1.2-2.1-3-2-4.8 3.7-60.2-14.3-128.1-53.7-202C555.3 171 510 123.1 453.4 89.7l-41.3-24.3c-5.4-3.2-12.3 1-12 7.3l2.2 48c1.5 32.8-2.3 61.8-11.3 85.9-11 29.5-26.8 56.9-47 81.5a295.64 295.64 0 01-47.5 46.1 352.6 352.6 0 00-100.3 121.5A347.75 347.75 0 00160 610c0 47.2 9.3 92.9 27.7 136a349.4 349.4 0 0075.5 110.9c32.4 32 70 57.2 111.9 74.7C418.5 949.8 464.5 959 512 959s93.5-9.2 136.9-27.3A348.6 348.6 0 00760.8 857c32.4-32 57.8-69.4 75.5-110.9a344.2 344.2 0 0027.7-136c0-48.8-10-96.2-29.9-140.9zM713 808.5c-53.7 53.2-125 82.4-201 82.4s-147.3-29.2-201-82.4c-53.5-53.1-83-123.5-83-198.4 0-43.5 9.8-85.2 29.1-124 18.8-37.9 46.8-71.8 80.8-97.9a349.6 349.6 0 0058.6-56.8c25-30.5 44.6-64.5 58.2-101a240 240 0 0012.1-46.5c24.1 22.2 44.3 49 61.2 80.4 33.4 62.6 48.8 118.3 45.8 165.7a74.01 74.01 0 0024.4 59.8 73.36 73.36 0 0053.4 18.8c19.7-1 37.8-9.7 51-24.4 13.3-14.9 24.8-30.1 34.4-45.6 14 17.9 25.7 37.4 35 58.4 15.9 35.8 24 73.9 24 113.1 0 74.9-29.5 145.4-83 198.4z"}}]},name:"fire",theme:"outlined"},qD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:GD}))},RA=i.forwardRef(qD),UD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M928 444H820V330.4c0-17.7-14.3-32-32-32H473L355.7 186.2a8.15 8.15 0 00-5.5-2.2H96c-17.7 0-32 14.3-32 32v592c0 17.7 14.3 32 32 32h698c13 0 24.8-7.9 29.7-20l134-332c1.5-3.8 2.3-7.9 2.3-12 0-17.7-14.3-32-32-32zM136 256h188.5l119.6 114.4H748V444H238c-13 0-24.8 7.9-29.7 20L136 643.2V256zm635.3 512H159l103.3-256h612.4L771.3 768z"}}]},name:"folder-open",theme:"outlined"},XD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:UD}))},YD=i.forwardRef(XD),QD={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M880 298.4H521L403.7 186.2a8.15 8.15 0 00-5.5-2.2H144c-17.7 0-32 14.3-32 32v592c0 17.7 14.3 32 32 32h736c17.7 0 32-14.3 32-32V330.4c0-17.7-14.3-32-32-32zM840 768H184V256h188.5l119.6 114.4H840V768z"}}]},name:"folder",theme:"outlined"},ZD=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:QD}))},JD=i.forwardRef(ZD),e_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M854.4 800.9c.2-.3.5-.6.7-.9C920.6 722.1 960 621.7 960 512s-39.4-210.1-104.8-288c-.2-.3-.5-.5-.7-.8-1.1-1.3-2.1-2.5-3.2-3.7-.4-.5-.8-.9-1.2-1.4l-4.1-4.7-.1-.1c-1.5-1.7-3.1-3.4-4.6-5.1l-.1-.1c-3.2-3.4-6.4-6.8-9.7-10.1l-.1-.1-4.8-4.8-.3-.3c-1.5-1.5-3-2.9-4.5-4.3-.5-.5-1-1-1.6-1.5-1-1-2-1.9-3-2.8-.3-.3-.7-.6-1-1C736.4 109.2 629.5 64 512 64s-224.4 45.2-304.3 119.2c-.3.3-.7.6-1 1-1 .9-2 1.9-3 2.9-.5.5-1 1-1.6 1.5-1.5 1.4-3 2.9-4.5 4.3l-.3.3-4.8 4.8-.1.1c-3.3 3.3-6.5 6.7-9.7 10.1l-.1.1c-1.6 1.7-3.1 3.4-4.6 5.1l-.1.1c-1.4 1.5-2.8 3.1-4.1 4.7-.4.5-.8.9-1.2 1.4-1.1 1.2-2.1 2.5-3.2 3.7-.2.3-.5.5-.7.8C103.4 301.9 64 402.3 64 512s39.4 210.1 104.8 288c.2.3.5.6.7.9l3.1 3.7c.4.5.8.9 1.2 1.4l4.1 4.7c0 .1.1.1.1.2 1.5 1.7 3 3.4 4.6 5l.1.1c3.2 3.4 6.4 6.8 9.6 10.1l.1.1c1.6 1.6 3.1 3.2 4.7 4.7l.3.3c3.3 3.3 6.7 6.5 10.1 9.6 80.1 74 187 119.2 304.5 119.2s224.4-45.2 304.3-119.2a300 300 0 0010-9.6l.3-.3c1.6-1.6 3.2-3.1 4.7-4.7l.1-.1c3.3-3.3 6.5-6.7 9.6-10.1l.1-.1c1.5-1.7 3.1-3.3 4.6-5 0-.1.1-.1.1-.2 1.4-1.5 2.8-3.1 4.1-4.7.4-.5.8-.9 1.2-1.4a99 99 0 003.3-3.7zm4.1-142.6c-13.8 32.6-32 62.8-54.2 90.2a444.07 444.07 0 00-81.5-55.9c11.6-46.9 18.8-98.4 20.7-152.6H887c-3 40.9-12.6 80.6-28.5 118.3zM887 484H743.5c-1.9-54.2-9.1-105.7-20.7-152.6 29.3-15.6 56.6-34.4 81.5-55.9A373.86 373.86 0 01887 484zM658.3 165.5c39.7 16.8 75.8 40 107.6 69.2a394.72 394.72 0 01-59.4 41.8c-15.7-45-35.8-84.1-59.2-115.4 3.7 1.4 7.4 2.9 11 4.4zm-90.6 700.6c-9.2 7.2-18.4 12.7-27.7 16.4V697a389.1 389.1 0 01115.7 26.2c-8.3 24.6-17.9 47.3-29 67.8-17.4 32.4-37.8 58.3-59 75.1zm59-633.1c11 20.6 20.7 43.3 29 67.8A389.1 389.1 0 01540 327V141.6c9.2 3.7 18.5 9.1 27.7 16.4 21.2 16.7 41.6 42.6 59 75zM540 640.9V540h147.5c-1.6 44.2-7.1 87.1-16.3 127.8l-.3 1.2A445.02 445.02 0 00540 640.9zm0-156.9V383.1c45.8-2.8 89.8-12.5 130.9-28.1l.3 1.2c9.2 40.7 14.7 83.5 16.3 127.8H540zm-56 56v100.9c-45.8 2.8-89.8 12.5-130.9 28.1l-.3-1.2c-9.2-40.7-14.7-83.5-16.3-127.8H484zm-147.5-56c1.6-44.2 7.1-87.1 16.3-127.8l.3-1.2c41.1 15.6 85 25.3 130.9 28.1V484H336.5zM484 697v185.4c-9.2-3.7-18.5-9.1-27.7-16.4-21.2-16.7-41.7-42.7-59.1-75.1-11-20.6-20.7-43.3-29-67.8 37.2-14.6 75.9-23.3 115.8-26.1zm0-370a389.1 389.1 0 01-115.7-26.2c8.3-24.6 17.9-47.3 29-67.8 17.4-32.4 37.8-58.4 59.1-75.1 9.2-7.2 18.4-12.7 27.7-16.4V327zM365.7 165.5c3.7-1.5 7.3-3 11-4.4-23.4 31.3-43.5 70.4-59.2 115.4-21-12-40.9-26-59.4-41.8 31.8-29.2 67.9-52.4 107.6-69.2zM165.5 365.7c13.8-32.6 32-62.8 54.2-90.2 24.9 21.5 52.2 40.3 81.5 55.9-11.6 46.9-18.8 98.4-20.7 152.6H137c3-40.9 12.6-80.6 28.5-118.3zM137 540h143.5c1.9 54.2 9.1 105.7 20.7 152.6a444.07 444.07 0 00-81.5 55.9A373.86 373.86 0 01137 540zm228.7 318.5c-39.7-16.8-75.8-40-107.6-69.2 18.5-15.8 38.4-29.7 59.4-41.8 15.7 45 35.8 84.1 59.2 115.4-3.7-1.4-7.4-2.9-11-4.4zm292.6 0c-3.7 1.5-7.3 3-11 4.4 23.4-31.3 43.5-70.4 59.2-115.4 21 12 40.9 26 59.4 41.8a373.81 373.81 0 01-107.6 69.2z"}}]},name:"global",theme:"outlined"},t_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:e_}))},PA=i.forwardRef(t_),n_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M923 283.6a260.04 260.04 0 00-56.9-82.8 264.4 264.4 0 00-84-55.5A265.34 265.34 0 00679.7 125c-49.3 0-97.4 13.5-139.2 39-10 6.1-19.5 12.8-28.5 20.1-9-7.3-18.5-14-28.5-20.1-41.8-25.5-89.9-39-139.2-39-35.5 0-69.9 6.8-102.4 20.3-31.4 13-59.7 31.7-84 55.5a258.44 258.44 0 00-56.9 82.8c-13.9 32.3-21 66.6-21 101.9 0 33.3 6.8 68 20.3 103.3 11.3 29.5 27.5 60.1 48.2 91 32.8 48.9 77.9 99.9 133.9 151.6 92.8 85.7 184.7 144.9 188.6 147.3l23.7 15.2c10.5 6.7 24 6.7 34.5 0l23.7-15.2c3.9-2.5 95.7-61.6 188.6-147.3 56-51.7 101.1-102.7 133.9-151.6 20.7-30.9 37-61.5 48.2-91 13.5-35.3 20.3-70 20.3-103.3.1-35.3-7-69.6-20.9-101.9zM512 814.8S156 586.7 156 385.5C156 283.6 240.3 201 344.3 201c73.1 0 136.5 40.8 167.7 100.4C543.2 241.8 606.6 201 679.7 201c104 0 188.3 82.6 188.3 184.5 0 201.2-356 429.3-356 429.3z"}}]},name:"heart",theme:"outlined"},r_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:n_}))},NA=i.forwardRef(r_),o_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M300 276.5a56 56 0 1056-97 56 56 0 00-56 97zm0 284a56 56 0 1056-97 56 56 0 00-56 97zM640 228a56 56 0 10112 0 56 56 0 00-112 0zm0 284a56 56 0 10112 0 56 56 0 00-112 0zM300 844.5a56 56 0 1056-97 56 56 0 00-56 97zM640 796a56 56 0 10112 0 56 56 0 00-112 0z"}}]},name:"holder",theme:"outlined"},a_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:o_}))},i_=i.forwardRef(a_),l_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372s166.6-372 372-372 372 166.6 372 372-166.6 372-372 372z"}},{tag:"path",attrs:{d:"M464 336a48 48 0 1096 0 48 48 0 10-96 0zm72 112h-48c-4.4 0-8 3.6-8 8v272c0 4.4 3.6 8 8 8h48c4.4 0 8-3.6 8-8V456c0-4.4-3.6-8-8-8z"}}]},name:"info-circle",theme:"outlined"},s_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:l_}))},MA=i.forwardRef(s_),c_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M888 792H200V168c0-4.4-3.6-8-8-8h-56c-4.4 0-8 3.6-8 8v688c0 4.4 3.6 8 8 8h752c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8zM305.8 637.7c3.1 3.1 8.1 3.1 11.3 0l138.3-137.6L583 628.5c3.1 3.1 8.2 3.1 11.3 0l275.4-275.3c3.1-3.1 3.1-8.2 0-11.3l-39.6-39.6a8.03 8.03 0 00-11.3 0l-230 229.9L461.4 404a8.03 8.03 0 00-11.3 0L266.3 586.7a8.03 8.03 0 000 11.3l39.5 39.7z"}}]},name:"line-chart",theme:"outlined"},u_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:c_}))},TA=i.forwardRef(u_),d_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M872 474H152c-4.4 0-8 3.6-8 8v60c0 4.4 3.6 8 8 8h720c4.4 0 8-3.6 8-8v-60c0-4.4-3.6-8-8-8z"}}]},name:"minus",theme:"outlined"},f_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:d_}))},jA=i.forwardRef(f_),m_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M328 544h368c4.4 0 8-3.6 8-8v-48c0-4.4-3.6-8-8-8H328c-4.4 0-8 3.6-8 8v48c0 4.4 3.6 8 8 8z"}},{tag:"path",attrs:{d:"M880 112H144c-17.7 0-32 14.3-32 32v736c0 17.7 14.3 32 32 32h736c17.7 0 32-14.3 32-32V144c0-17.7-14.3-32-32-32zm-40 728H184V184h656v656z"}}]},name:"minus-square",theme:"outlined"},v_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:m_}))},g_=i.forwardRef(v_),p_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M779.3 196.6c-94.2-94.2-247.6-94.2-341.7 0l-261 260.8c-1.7 1.7-2.6 4-2.6 6.4s.9 4.7 2.6 6.4l36.9 36.9a9 9 0 0012.7 0l261-260.8c32.4-32.4 75.5-50.2 121.3-50.2s88.9 17.8 121.2 50.2c32.4 32.4 50.2 75.5 50.2 121.2 0 45.8-17.8 88.8-50.2 121.2l-266 265.9-43.1 43.1c-40.3 40.3-105.8 40.3-146.1 0-19.5-19.5-30.2-45.4-30.2-73s10.7-53.5 30.2-73l263.9-263.8c6.7-6.6 15.5-10.3 24.9-10.3h.1c9.4 0 18.1 3.7 24.7 10.3 6.7 6.7 10.3 15.5 10.3 24.9 0 9.3-3.7 18.1-10.3 24.7L372.4 653c-1.7 1.7-2.6 4-2.6 6.4s.9 4.7 2.6 6.4l36.9 36.9a9 9 0 0012.7 0l215.6-215.6c19.9-19.9 30.8-46.3 30.8-74.4s-11-54.6-30.8-74.4c-41.1-41.1-107.9-41-149 0L463 364 224.8 602.1A172.22 172.22 0 00174 724.8c0 46.3 18.1 89.8 50.8 122.5 33.9 33.8 78.3 50.7 122.7 50.7 44.4 0 88.8-16.9 122.6-50.7l309.2-309C824.8 492.7 850 432 850 367.5c.1-64.6-25.1-125.3-70.7-170.9z"}}]},name:"paper-clip",theme:"outlined"},h_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:p_}))},b_=i.forwardRef(h_),y_={icon:function(t,n){return{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M928 160H96c-17.7 0-32 14.3-32 32v640c0 17.7 14.3 32 32 32h832c17.7 0 32-14.3 32-32V192c0-17.7-14.3-32-32-32zm-40 632H136v-39.9l138.5-164.3 150.1 178L658.1 489 888 761.6V792zm0-129.8L664.2 396.8c-3.2-3.8-9-3.8-12.2 0L424.6 666.4l-144-170.7c-3.2-3.8-9-3.8-12.2 0L136 652.7V232h752v430.2z",fill:t}},{tag:"path",attrs:{d:"M424.6 765.8l-150.1-178L136 752.1V792h752v-30.4L658.1 489z",fill:n}},{tag:"path",attrs:{d:"M136 652.7l132.4-157c3.2-3.8 9-3.8 12.2 0l144 170.7L652 396.8c3.2-3.8 9-3.8 12.2 0L888 662.2V232H136v420.7zM304 280a88 88 0 110 176 88 88 0 010-176z",fill:n}},{tag:"path",attrs:{d:"M276 368a28 28 0 1056 0 28 28 0 10-56 0z",fill:n}},{tag:"path",attrs:{d:"M304 456a88 88 0 100-176 88 88 0 000 176zm0-116c15.5 0 28 12.5 28 28s-12.5 28-28 28-28-12.5-28-28 12.5-28 28-28z",fill:t}}]}},name:"picture",theme:"twotone"},C_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:y_}))},S_=i.forwardRef(C_),$_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M328 544h152v152c0 4.4 3.6 8 8 8h48c4.4 0 8-3.6 8-8V544h152c4.4 0 8-3.6 8-8v-48c0-4.4-3.6-8-8-8H544V328c0-4.4-3.6-8-8-8h-48c-4.4 0-8 3.6-8 8v152H328c-4.4 0-8 3.6-8 8v48c0 4.4 3.6 8 8 8z"}},{tag:"path",attrs:{d:"M880 112H144c-17.7 0-32 14.3-32 32v736c0 17.7 14.3 32 32 32h736c17.7 0 32-14.3 32-32V144c0-17.7-14.3-32-32-32zm-40 728H184V184h656v656z"}}]},name:"plus-square",theme:"outlined"},x_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:$_}))},w_=i.forwardRef(x_),E_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M909.1 209.3l-56.4 44.1C775.8 155.1 656.2 92 521.9 92 290 92 102.3 279.5 102 511.5 101.7 743.7 289.8 932 521.9 932c181.3 0 335.8-115 394.6-276.1 1.5-4.2-.7-8.9-4.9-10.3l-56.7-19.5a8 8 0 00-10.1 4.8c-1.8 5-3.8 10-5.9 14.9-17.3 41-42.1 77.8-73.7 109.4A344.77 344.77 0 01655.9 829c-42.3 17.9-87.4 27-133.8 27-46.5 0-91.5-9.1-133.8-27A341.5 341.5 0 01279 755.2a342.16 342.16 0 01-73.7-109.4c-17.9-42.4-27-87.4-27-133.9s9.1-91.5 27-133.9c17.3-41 42.1-77.8 73.7-109.4 31.6-31.6 68.4-56.4 109.3-73.8 42.3-17.9 87.4-27 133.8-27 46.5 0 91.5 9.1 133.8 27a341.5 341.5 0 01109.3 73.8c9.9 9.9 19.2 20.4 27.8 31.4l-60.2 47a8 8 0 003 14.1l175.6 43c5 1.2 9.9-2.6 9.9-7.7l.8-180.9c-.1-6.6-7.8-10.3-13-6.2z"}}]},name:"reload",theme:"outlined"},O_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:E_}))},zA=i.forwardRef(O_),I_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M924.8 625.7l-65.5-56c3.1-19 4.7-38.4 4.7-57.8s-1.6-38.8-4.7-57.8l65.5-56a32.03 32.03 0 009.3-35.2l-.9-2.6a443.74 443.74 0 00-79.7-137.9l-1.8-2.1a32.12 32.12 0 00-35.1-9.5l-81.3 28.9c-30-24.6-63.5-44-99.7-57.6l-15.7-85a32.05 32.05 0 00-25.8-25.7l-2.7-.5c-52.1-9.4-106.9-9.4-159 0l-2.7.5a32.05 32.05 0 00-25.8 25.7l-15.8 85.4a351.86 351.86 0 00-99 57.4l-81.9-29.1a32 32 0 00-35.1 9.5l-1.8 2.1a446.02 446.02 0 00-79.7 137.9l-.9 2.6c-4.5 12.5-.8 26.5 9.3 35.2l66.3 56.6c-3.1 18.8-4.6 38-4.6 57.1 0 19.2 1.5 38.4 4.6 57.1L99 625.5a32.03 32.03 0 00-9.3 35.2l.9 2.6c18.1 50.4 44.9 96.9 79.7 137.9l1.8 2.1a32.12 32.12 0 0035.1 9.5l81.9-29.1c29.8 24.5 63.1 43.9 99 57.4l15.8 85.4a32.05 32.05 0 0025.8 25.7l2.7.5a449.4 449.4 0 00159 0l2.7-.5a32.05 32.05 0 0025.8-25.7l15.7-85a350 350 0 0099.7-57.6l81.3 28.9a32 32 0 0035.1-9.5l1.8-2.1c34.8-41.1 61.6-87.5 79.7-137.9l.9-2.6c4.5-12.3.8-26.3-9.3-35zM788.3 465.9c2.5 15.1 3.8 30.6 3.8 46.1s-1.3 31-3.8 46.1l-6.6 40.1 74.7 63.9a370.03 370.03 0 01-42.6 73.6L721 702.8l-31.4 25.8c-23.9 19.6-50.5 35-79.3 45.8l-38.1 14.3-17.9 97a377.5 377.5 0 01-85 0l-17.9-97.2-37.8-14.5c-28.5-10.8-55-26.2-78.7-45.7l-31.4-25.9-93.4 33.2c-17-22.9-31.2-47.6-42.6-73.6l75.5-64.5-6.5-40c-2.4-14.9-3.7-30.3-3.7-45.5 0-15.3 1.2-30.6 3.7-45.5l6.5-40-75.5-64.5c11.3-26.1 25.6-50.7 42.6-73.6l93.4 33.2 31.4-25.9c23.7-19.5 50.2-34.9 78.7-45.7l37.9-14.3 17.9-97.2c28.1-3.2 56.8-3.2 85 0l17.9 97 38.1 14.3c28.7 10.8 55.4 26.2 79.3 45.8l31.4 25.8 92.8-32.9c17 22.9 31.2 47.6 42.6 73.6L781.8 426l6.5 39.9zM512 326c-97.2 0-176 78.8-176 176s78.8 176 176 176 176-78.8 176-176-78.8-176-176-176zm79.2 255.2A111.6 111.6 0 01512 614c-29.9 0-58-11.7-79.2-32.8A111.6 111.6 0 01400 502c0-29.9 11.7-58 32.8-79.2C454 401.6 482.1 390 512 390c29.9 0 58 11.6 79.2 32.8A111.6 111.6 0 01624 502c0 29.9-11.7 58-32.8 79.2z"}}]},name:"setting",theme:"outlined"},R_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:I_}))},DA=i.forwardRef(R_),P_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M168 504.2c1-43.7 10-86.1 26.9-126 17.3-41 42.1-77.7 73.7-109.4S337 212.3 378 195c42.4-17.9 87.4-27 133.9-27s91.5 9.1 133.8 27A341.5 341.5 0 01755 268.8c9.9 9.9 19.2 20.4 27.8 31.4l-60.2 47a8 8 0 003 14.1l175.7 43c5 1.2 9.9-2.6 9.9-7.7l.8-180.9c0-6.7-7.7-10.5-12.9-6.3l-56.4 44.1C765.8 155.1 646.2 92 511.8 92 282.7 92 96.3 275.6 92 503.8a8 8 0 008 8.2h60c4.4 0 7.9-3.5 8-7.8zm756 7.8h-60c-4.4 0-7.9 3.5-8 7.8-1 43.7-10 86.1-26.9 126-17.3 41-42.1 77.8-73.7 109.4A342.45 342.45 0 01512.1 856a342.24 342.24 0 01-243.2-100.8c-9.9-9.9-19.2-20.4-27.8-31.4l60.2-47a8 8 0 00-3-14.1l-175.7-43c-5-1.2-9.9 2.6-9.9 7.7l-.7 181c0 6.7 7.7 10.5 12.9 6.3l56.4-44.1C258.2 868.9 377.8 932 512.2 932c229.2 0 415.5-183.7 419.8-411.8a8 8 0 00-8-8.2z"}}]},name:"sync",theme:"outlined"},N_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:P_}))},_A=i.forwardRef(N_),M_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M848 359.3H627.7L825.8 109c4.1-5.3.4-13-6.3-13H436c-2.8 0-5.5 1.5-6.9 4L170 547.5c-3.1 5.3.7 12 6.9 12h174.4l-89.4 357.6c-1.9 7.8 7.5 13.3 13.3 7.7L853.5 373c5.2-4.9 1.7-13.7-5.5-13.7zM378.2 732.5l60.3-241H281.1l189.6-327.4h224.6L487 427.4h211L378.2 732.5z"}}]},name:"thunderbolt",theme:"outlined"},T_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:M_}))},BA=i.forwardRef(T_),j_={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M511.4 124C290.5 124.3 112 303 112 523.9c0 128 60.2 242 153.8 315.2l-37.5 48c-4.1 5.3-.3 13 6.3 12.9l167-.8c5.2 0 9-4.9 7.7-9.9L369.8 727a8 8 0 00-14.1-3L315 776.1c-10.2-8-20-16.7-29.3-26a318.64 318.64 0 01-68.6-101.7C200.4 609 192 567.1 192 523.9s8.4-85.1 25.1-124.5c16.1-38.1 39.2-72.3 68.6-101.7 29.4-29.4 63.6-52.5 101.7-68.6C426.9 212.4 468.8 204 512 204s85.1 8.4 124.5 25.1c38.1 16.1 72.3 39.2 101.7 68.6 29.4 29.4 52.5 63.6 68.6 101.7 16.7 39.4 25.1 81.3 25.1 124.5s-8.4 85.1-25.1 124.5a318.64 318.64 0 01-68.6 101.7c-7.5 7.5-15.3 14.5-23.4 21.2a7.93 7.93 0 00-1.2 11.1l39.4 50.5c2.8 3.5 7.9 4.1 11.4 1.3C854.5 760.8 912 649.1 912 523.9c0-221.1-179.4-400.2-400.6-399.9z"}}]},name:"undo",theme:"outlined"},z_=function(t,n){return i.createElement(vt,ue({},t,{ref:n,icon:j_}))},LA=i.forwardRef(z_);const D_=e=>{const{value:t,formatter:n,precision:r,decimalSeparator:o,groupSeparator:a="",prefixCls:l}=e;let s;if(typeof n=="function")s=n(t);else{const c=String(t),u=c.match(/^(-?)(\d*)(\.(\d+))?$/);if(!u||c==="-")s=c;else{const d=u[1];let f=u[2]||"0",m=u[4]||"";f=f.replace(/\B(?=(\d{3})+(?!\d))/g,a),typeof r=="number"&&(m=m.padEnd(r,"0").slice(0,r>0?r:0)),m&&(m=`${o}${m}`),s=[i.createElement("span",{key:"int",className:`${l}-content-value-int`},d,f),m&&i.createElement("span",{key:"decimal",className:`${l}-content-value-decimal`},m)]}}return i.createElement("span",{className:`${l}-content-value`},s)},__=e=>{const{componentCls:t,marginXXS:n,padding:r,colorTextDescription:o,titleFontSize:a,colorTextHeading:l,contentFontSize:s,fontFamily:c}=e;return{[t]:Object.assign(Object.assign({},Tt(e)),{[`${t}-title`]:{marginBottom:n,color:o,fontSize:a},[`${t}-skeleton`]:{paddingTop:r},[`${t}-content`]:{color:l,fontSize:s,fontFamily:c,[`${t}-content-value`]:{display:"inline-block",direction:"ltr"},[`${t}-content-prefix, ${t}-content-suffix`]:{display:"inline-block"},[`${t}-content-prefix`]:{marginInlineEnd:n},[`${t}-content-suffix`]:{marginInlineStart:n}}})}},B_=e=>{const{fontSizeHeading3:t,fontSize:n}=e;return{titleFontSize:n,contentFontSize:t}},L_=It("Statistic",e=>{const t=yt(e,{});return __(t)},B_);var H_=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const Pf=i.forwardRef((e,t)=>{const{prefixCls:n,className:r,rootClassName:o,style:a,valueStyle:l,value:s=0,title:c,valueRender:u,prefix:d,suffix:f,loading:m=!1,formatter:v,precision:g,decimalSeparator:h=".",groupSeparator:p=",",onMouseEnter:b,onMouseLeave:y}=e,C=H_(e,["prefixCls","className","rootClassName","style","valueStyle","value","title","valueRender","prefix","suffix","loading","formatter","precision","decimalSeparator","groupSeparator","onMouseEnter","onMouseLeave"]),{getPrefixCls:$,direction:S,className:x,style:E}=tn("statistic"),O=$("statistic",n),[w,I,P]=L_(O),M=i.createElement(D_,{decimalSeparator:h,groupSeparator:p,prefixCls:O,formatter:v,precision:g,value:s}),R=A(O,{[`${O}-rtl`]:S==="rtl"},x,r,o,I,P),N=i.useRef(null);i.useImperativeHandle(t,()=>({nativeElement:N.current}));const T=rn(C,{aria:!0,data:!0});return w(i.createElement("div",Object.assign({},T,{ref:N,className:R,style:Object.assign(Object.assign({},E),a),onMouseEnter:b,onMouseLeave:y}),c&&i.createElement("div",{className:`${O}-title`},c),i.createElement(kr,{paragraph:!1,loading:m,className:`${O}-skeleton`},i.createElement("div",{style:l,className:`${O}-content`},d&&i.createElement("span",{className:`${O}-content-prefix`},d),u?u(M):M,f&&i.createElement("span",{className:`${O}-content-suffix`},f)))))}),A_=[["Y",1e3*60*60*24*365],["M",1e3*60*60*24*30],["D",1e3*60*60*24],["H",1e3*60*60],["m",1e3*60],["s",1e3],["S",1]];function F_(e,t){let n=e;const r=/\[[^\]]*]/g,o=(t.match(r)||[]).map(c=>c.slice(1,-1)),a=t.replace(r,"[]"),l=A_.reduce((c,[u,d])=>{if(c.includes(u)){const f=Math.floor(n/d);return n-=f*d,c.replace(new RegExp(`${u}+`,"g"),m=>{const v=m.length;return f.toString().padStart(v,"0")})}return c},a);let s=0;return l.replace(r,()=>{const c=o[s];return s+=1,c})}function k_(e,t,n){const{format:r=""}=t,o=new Date(e).getTime(),a=Date.now(),l=Math.max(n?o-a:a-o,0);return F_(l,r)}var V_=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function W_(e){return new Date(e).getTime()}const kC=e=>{const{value:t,format:n="HH:mm:ss",onChange:r,onFinish:o,type:a}=e,l=V_(e,["value","format","onChange","onFinish","type"]),s=a==="countdown",[c,u]=i.useState(null),d=Nt(()=>{const v=Date.now(),g=W_(t);u({});const h=s?g-v:v-g;return r==null||r(h),s&&g<v?(o==null||o(),!1):!0});i.useEffect(()=>{let v;const g=()=>Et.cancel(v),h=()=>{v=Et(()=>{d()&&h()})};return h(),g},[t,s]),i.useEffect(()=>{u({})},[]);const f=(v,g)=>c?k_(v,Object.assign(Object.assign({},g),{format:n}),s):"-",m=v=>cn(v,{title:void 0});return i.createElement(Pf,Object.assign({},l,{value:t,valueRender:m,formatter:f}))},K_=e=>i.createElement(kC,Object.assign({},e,{type:"countdown"})),G_=i.memo(K_);Pf.Timer=kC;Pf.Countdown=G_;var q_=["prefixCls","className","checked","defaultChecked","disabled","loadingIcon","checkedChildren","unCheckedChildren","onClick","onChange","onKeyDown"],VC=i.forwardRef(function(e,t){var n,r=e.prefixCls,o=r===void 0?"rc-switch":r,a=e.className,l=e.checked,s=e.defaultChecked,c=e.disabled,u=e.loadingIcon,d=e.checkedChildren,f=e.unCheckedChildren,m=e.onClick,v=e.onChange,g=e.onKeyDown,h=ft(e,q_),p=Lt(!1,{value:l,defaultValue:s}),b=J(p,2),y=b[0],C=b[1];function $(O,w){var I=y;return c||(I=O,C(I),v==null||v(I,w)),I}function S(O){O.which===Ne.LEFT?$(!1,O):O.which===Ne.RIGHT&&$(!0,O),g==null||g(O)}function x(O){var w=$(!y,O);m==null||m(w,O)}var E=A(o,a,(n={},D(n,"".concat(o,"-checked"),y),D(n,"".concat(o,"-disabled"),c),n));return i.createElement("button",ue({},h,{type:"button",role:"switch","aria-checked":y,disabled:c,className:E,ref:t,onKeyDown:S,onClick:x}),u,i.createElement("span",{className:"".concat(o,"-inner")},i.createElement("span",{className:"".concat(o,"-inner-checked")},d),i.createElement("span",{className:"".concat(o,"-inner-unchecked")},f)))});VC.displayName="Switch";const U_=e=>{const{componentCls:t,trackHeightSM:n,trackPadding:r,trackMinWidthSM:o,innerMinMarginSM:a,innerMaxMarginSM:l,handleSizeSM:s,calc:c}=e,u=`${t}-inner`,d=L(c(s).add(c(r).mul(2)).equal()),f=L(c(l).mul(2).equal());return{[t]:{[`&${t}-small`]:{minWidth:o,height:n,lineHeight:L(n),[`${t}-inner`]:{paddingInlineStart:l,paddingInlineEnd:a,[`${u}-checked, ${u}-unchecked`]:{minHeight:n},[`${u}-checked`]:{marginInlineStart:`calc(-100% + ${d} - ${f})`,marginInlineEnd:`calc(100% - ${d} + ${f})`},[`${u}-unchecked`]:{marginTop:c(n).mul(-1).equal(),marginInlineStart:0,marginInlineEnd:0}},[`${t}-handle`]:{width:s,height:s},[`${t}-loading-icon`]:{top:c(c(s).sub(e.switchLoadingIconSize)).div(2).equal(),fontSize:e.switchLoadingIconSize},[`&${t}-checked`]:{[`${t}-inner`]:{paddingInlineStart:a,paddingInlineEnd:l,[`${u}-checked`]:{marginInlineStart:0,marginInlineEnd:0},[`${u}-unchecked`]:{marginInlineStart:`calc(100% - ${d} + ${f})`,marginInlineEnd:`calc(-100% + ${d} - ${f})`}},[`${t}-handle`]:{insetInlineStart:`calc(100% - ${L(c(s).add(r).equal())})`}},[`&:not(${t}-disabled):active`]:{[`&:not(${t}-checked) ${u}`]:{[`${u}-unchecked`]:{marginInlineStart:c(e.marginXXS).div(2).equal(),marginInlineEnd:c(e.marginXXS).mul(-1).div(2).equal()}},[`&${t}-checked ${u}`]:{[`${u}-checked`]:{marginInlineStart:c(e.marginXXS).mul(-1).div(2).equal(),marginInlineEnd:c(e.marginXXS).div(2).equal()}}}}}}},X_=e=>{const{componentCls:t,handleSize:n,calc:r}=e;return{[t]:{[`${t}-loading-icon${e.iconCls}`]:{position:"relative",top:r(r(n).sub(e.fontSize)).div(2).equal(),color:e.switchLoadingIconColor,verticalAlign:"top"},[`&${t}-checked ${t}-loading-icon`]:{color:e.switchColor}}}},Y_=e=>{const{componentCls:t,trackPadding:n,handleBg:r,handleShadow:o,handleSize:a,calc:l}=e,s=`${t}-handle`;return{[t]:{[s]:{position:"absolute",top:n,insetInlineStart:n,width:a,height:a,transition:`all ${e.switchDuration} ease-in-out`,"&::before":{position:"absolute",top:0,insetInlineEnd:0,bottom:0,insetInlineStart:0,backgroundColor:r,borderRadius:l(a).div(2).equal(),boxShadow:o,transition:`all ${e.switchDuration} ease-in-out`,content:'""'}},[`&${t}-checked ${s}`]:{insetInlineStart:`calc(100% - ${L(l(a).add(n).equal())})`},[`&:not(${t}-disabled):active`]:{[`${s}::before`]:{insetInlineEnd:e.switchHandleActiveInset,insetInlineStart:0},[`&${t}-checked ${s}::before`]:{insetInlineEnd:0,insetInlineStart:e.switchHandleActiveInset}}}}},Q_=e=>{const{componentCls:t,trackHeight:n,trackPadding:r,innerMinMargin:o,innerMaxMargin:a,handleSize:l,calc:s}=e,c=`${t}-inner`,u=L(s(l).add(s(r).mul(2)).equal()),d=L(s(a).mul(2).equal());return{[t]:{[c]:{display:"block",overflow:"hidden",borderRadius:100,height:"100%",paddingInlineStart:a,paddingInlineEnd:o,transition:`padding-inline-start ${e.switchDuration} ease-in-out, padding-inline-end ${e.switchDuration} ease-in-out`,[`${c}-checked, ${c}-unchecked`]:{display:"block",color:e.colorTextLightSolid,fontSize:e.fontSizeSM,transition:`margin-inline-start ${e.switchDuration} ease-in-out, margin-inline-end ${e.switchDuration} ease-in-out`,pointerEvents:"none",minHeight:n},[`${c}-checked`]:{marginInlineStart:`calc(-100% + ${u} - ${d})`,marginInlineEnd:`calc(100% - ${u} + ${d})`},[`${c}-unchecked`]:{marginTop:s(n).mul(-1).equal(),marginInlineStart:0,marginInlineEnd:0}},[`&${t}-checked ${c}`]:{paddingInlineStart:o,paddingInlineEnd:a,[`${c}-checked`]:{marginInlineStart:0,marginInlineEnd:0},[`${c}-unchecked`]:{marginInlineStart:`calc(100% - ${u} + ${d})`,marginInlineEnd:`calc(-100% + ${u} - ${d})`}},[`&:not(${t}-disabled):active`]:{[`&:not(${t}-checked) ${c}`]:{[`${c}-unchecked`]:{marginInlineStart:s(r).mul(2).equal(),marginInlineEnd:s(r).mul(-1).mul(2).equal()}},[`&${t}-checked ${c}`]:{[`${c}-checked`]:{marginInlineStart:s(r).mul(-1).mul(2).equal(),marginInlineEnd:s(r).mul(2).equal()}}}}}},Z_=e=>{const{componentCls:t,trackHeight:n,trackMinWidth:r}=e;return{[t]:Object.assign(Object.assign(Object.assign(Object.assign({},Tt(e)),{position:"relative",display:"inline-block",boxSizing:"border-box",minWidth:r,height:n,lineHeight:L(n),verticalAlign:"middle",background:e.colorTextQuaternary,border:"0",borderRadius:100,cursor:"pointer",transition:`all ${e.motionDurationMid}`,userSelect:"none",[`&:hover:not(${t}-disabled)`]:{background:e.colorTextTertiary}}),Vn(e)),{[`&${t}-checked`]:{background:e.switchColor,[`&:hover:not(${t}-disabled)`]:{background:e.colorPrimaryHover}},[`&${t}-loading, &${t}-disabled`]:{cursor:"not-allowed",opacity:e.switchDisabledOpacity,"*":{boxShadow:"none",cursor:"not-allowed"}},[`&${t}-rtl`]:{direction:"rtl"}})}},J_=e=>{const{fontSize:t,lineHeight:n,controlHeight:r,colorWhite:o}=e,a=t*n,l=r/2,s=2,c=a-s*2,u=l-s*2;return{trackHeight:a,trackHeightSM:l,trackMinWidth:c*2+s*4,trackMinWidthSM:u*2+s*2,trackPadding:s,handleBg:o,handleSize:c,handleSizeSM:u,handleShadow:`0 2px 4px 0 ${new Mt("#00230b").setA(.2).toRgbString()}`,innerMinMargin:c/2,innerMaxMargin:c+s+s*2,innerMinMarginSM:u/2,innerMaxMarginSM:u+s+s*2}},eB=It("Switch",e=>{const t=yt(e,{switchDuration:e.motionDurationMid,switchColor:e.colorPrimary,switchDisabledOpacity:e.opacityLoading,switchLoadingIconSize:e.calc(e.fontSizeIcon).mul(.75).equal(),switchLoadingIconColor:`rgba(0, 0, 0, ${e.opacityLoading})`,switchHandleActiveInset:"-30%"});return[Z_(t),Q_(t),Y_(t),X_(t),U_(t)]},J_);var tB=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const nB=i.forwardRef((e,t)=>{const{prefixCls:n,size:r,disabled:o,loading:a,className:l,rootClassName:s,style:c,checked:u,value:d,defaultChecked:f,defaultValue:m,onChange:v}=e,g=tB(e,["prefixCls","size","disabled","loading","className","rootClassName","style","checked","value","defaultChecked","defaultValue","onChange"]),[h,p]=Lt(!1,{value:u??d,defaultValue:f??m}),{getPrefixCls:b,direction:y,switch:C}=i.useContext(ot),$=i.useContext(Ln),S=(o??$)||a,x=b("switch",n),E=i.createElement("div",{className:`${x}-handle`},a&&i.createElement(Jr,{className:`${x}-loading-icon`})),[O,w,I]=eB(x),P=Sn(r),M=A(C==null?void 0:C.className,{[`${x}-small`]:P==="small",[`${x}-loading`]:a,[`${x}-rtl`]:y==="rtl"},l,s,w,I),R=Object.assign(Object.assign({},C==null?void 0:C.style),c),N=(...T)=>{p(T[0]),v==null||v.apply(void 0,T)};return O(i.createElement(ci,{component:"Switch"},i.createElement(VC,Object.assign({},g,{checked:h,onChange:N,prefixCls:x,className:M,style:R,disabled:S,ref:t,loadingIcon:E}))))}),rB=nB;rB.__ANT_SWITCH=!0;var Lr={},Oi="rc-table-internal-hook";function Nf(e){var t=i.createContext(void 0),n=function(o){var a=o.value,l=o.children,s=i.useRef(a);s.current=a;var c=i.useState(function(){return{getValue:function(){return s.current},listeners:new Set}}),u=J(c,1),d=u[0];return wt(function(){Pr.unstable_batchedUpdates(function(){d.listeners.forEach(function(f){f(a)})})},[a]),i.createElement(t.Provider,{value:d},l)};return{Context:t,Provider:n,defaultValue:e}}function Mn(e,t){var n=Nt(typeof t=="function"?t:function(f){if(t===void 0)return f;if(!Array.isArray(t))return f[t];var m={};return t.forEach(function(v){m[v]=f[v]}),m}),r=i.useContext(e==null?void 0:e.Context),o=r||{},a=o.listeners,l=o.getValue,s=i.useRef();s.current=n(r?l():e==null?void 0:e.defaultValue);var c=i.useState({}),u=J(c,2),d=u[1];return wt(function(){if(!r)return;function f(m){var v=n(m);hr(s.current,v,!0)||d({})}return a.add(f),function(){a.delete(f)}},[r]),s.current}function oB(){var e=i.createContext(null);function t(){return i.useContext(e)}function n(o,a){var l=Nr(o),s=function(u,d){var f=l?{ref:d}:{},m=i.useRef(0),v=i.useRef(u),g=t();return g!==null?i.createElement(o,ue({},u,f)):((!a||a(v.current,u))&&(m.current+=1),v.current=u,i.createElement(e.Provider,{value:m.current},i.createElement(o,ue({},u,f))))};return l?i.forwardRef(s):s}function r(o,a){var l=Nr(o),s=function(u,d){var f=l?{ref:d}:{};return t(),i.createElement(o,ue({},u,f))};return l?i.memo(i.forwardRef(s),a):i.memo(s,a)}return{makeImmutable:n,responseImmutable:r,useImmutableMark:t}}var Mf=oB(),WC=Mf.makeImmutable,Sa=Mf.responseImmutable,aB=Mf.useImmutableMark,Hn=Nf(),KC=i.createContext({renderWithProps:!1}),iB="RC_TABLE_KEY";function lB(e){return e==null?[]:Array.isArray(e)?e:[e]}function _s(e){var t=[],n={};return e.forEach(function(r){for(var o=r||{},a=o.key,l=o.dataIndex,s=a||lB(l).join("-")||iB;n[s];)s="".concat(s,"_next");n[s]=!0,t.push(s)}),t}function nd(e){return e!=null}function sB(e){return typeof e=="number"&&!Number.isNaN(e)}function cB(e){return e&&Qe(e)==="object"&&!Array.isArray(e)&&!i.isValidElement(e)}function uB(e,t,n,r,o,a){var l=i.useContext(KC),s=aB(),c=So(function(){if(nd(r))return[r];var u=t==null||t===""?[]:Array.isArray(t)?t:[t],d=Qn(e,u),f=d,m=void 0;if(o){var v=o(d,e,n);cB(v)?(f=v.children,m=v.props,l.renderWithProps=!0):f=v}return[f,m]},[s,e,r,t,o,n],function(u,d){if(a){var f=J(u,2),m=f[1],v=J(d,2),g=v[1];return a(g,m)}return l.renderWithProps?!0:!hr(u,d,!0)});return c}function dB(e,t,n,r){var o=e+t-1;return e<=r&&o>=n}function fB(e,t){return Mn(Hn,function(n){var r=dB(e,t||1,n.hoverStartRow,n.hoverEndRow);return[r,n.onHover]})}var mB=function(t){var n=t.ellipsis,r=t.rowType,o=t.children,a,l=n===!0?{showTitle:!0}:n;return l&&(l.showTitle||r==="header")&&(typeof o=="string"||typeof o=="number"?a=o.toString():i.isValidElement(o)&&typeof o.props.children=="string"&&(a=o.props.children)),a};function vB(e){var t,n,r,o,a,l,s,c,u=e.component,d=e.children,f=e.ellipsis,m=e.scope,v=e.prefixCls,g=e.className,h=e.align,p=e.record,b=e.render,y=e.dataIndex,C=e.renderIndex,$=e.shouldCellUpdate,S=e.index,x=e.rowType,E=e.colSpan,O=e.rowSpan,w=e.fixLeft,I=e.fixRight,P=e.firstFixLeft,M=e.lastFixLeft,R=e.firstFixRight,N=e.lastFixRight,T=e.appendNode,j=e.additionalProps,z=j===void 0?{}:j,_=e.isSticky,B="".concat(v,"-cell"),V=Mn(Hn,["supportSticky","allColumnsFixedLeft","rowHoverable"]),G=V.supportSticky,q=V.allColumnsFixedLeft,H=V.rowHoverable,W=uB(p,y,C,d,b,$),K=J(W,2),U=K[0],te=K[1],X={},ae=typeof w=="number"&&G,le=typeof I=="number"&&G;ae&&(X.position="sticky",X.left=w),le&&(X.position="sticky",X.right=I);var ee=(t=(n=(r=te==null?void 0:te.colSpan)!==null&&r!==void 0?r:z.colSpan)!==null&&n!==void 0?n:E)!==null&&t!==void 0?t:1,Y=(o=(a=(l=te==null?void 0:te.rowSpan)!==null&&l!==void 0?l:z.rowSpan)!==null&&a!==void 0?a:O)!==null&&o!==void 0?o:1,re=fB(S,Y),ne=J(re,2),Z=ne[0],Q=ne[1],ie=Nt(function(se){var be;p&&Q(S,S+Y-1),z==null||(be=z.onMouseEnter)===null||be===void 0||be.call(z,se)}),de=Nt(function(se){var be;p&&Q(-1,-1),z==null||(be=z.onMouseLeave)===null||be===void 0||be.call(z,se)});if(ee===0||Y===0)return null;var he=(s=z.title)!==null&&s!==void 0?s:mB({rowType:x,ellipsis:f,children:U}),ye=A(B,g,(c={},D(D(D(D(D(D(D(D(D(D(c,"".concat(B,"-fix-left"),ae&&G),"".concat(B,"-fix-left-first"),P&&G),"".concat(B,"-fix-left-last"),M&&G),"".concat(B,"-fix-left-all"),M&&q&&G),"".concat(B,"-fix-right"),le&&G),"".concat(B,"-fix-right-first"),R&&G),"".concat(B,"-fix-right-last"),N&&G),"".concat(B,"-ellipsis"),f),"".concat(B,"-with-append"),T),"".concat(B,"-fix-sticky"),(ae||le)&&_&&G),D(c,"".concat(B,"-row-hover"),!te&&Z)),z.className,te==null?void 0:te.className),oe={};h&&(oe.textAlign=h);var ce=k(k(k(k({},te==null?void 0:te.style),X),oe),z.style),ge=U;return Qe(ge)==="object"&&!Array.isArray(ge)&&!i.isValidElement(ge)&&(ge=null),f&&(M||R)&&(ge=i.createElement("span",{className:"".concat(B,"-content")},ge)),i.createElement(u,ue({},te,z,{className:ye,style:ce,title:he,scope:m,onMouseEnter:H?ie:void 0,onMouseLeave:H?de:void 0,colSpan:ee!==1?ee:null,rowSpan:Y!==1?Y:null}),T,ge)}const $a=i.memo(vB);function Tf(e,t,n,r,o){var a=n[e]||{},l=n[t]||{},s,c;a.fixed==="left"?s=r.left[o==="rtl"?t:e]:l.fixed==="right"&&(c=r.right[o==="rtl"?e:t]);var u=!1,d=!1,f=!1,m=!1,v=n[t+1],g=n[e-1],h=v&&!v.fixed||g&&!g.fixed||n.every(function($){return $.fixed==="left"});if(o==="rtl"){if(s!==void 0){var p=g&&g.fixed==="left";m=!p&&h}else if(c!==void 0){var b=v&&v.fixed==="right";f=!b&&h}}else if(s!==void 0){var y=v&&v.fixed==="left";u=!y&&h}else if(c!==void 0){var C=g&&g.fixed==="right";d=!C&&h}return{fixLeft:s,fixRight:c,lastFixLeft:u,firstFixRight:d,lastFixRight:f,firstFixLeft:m,isSticky:r.isSticky}}var GC=i.createContext({});function gB(e){var t=e.className,n=e.index,r=e.children,o=e.colSpan,a=o===void 0?1:o,l=e.rowSpan,s=e.align,c=Mn(Hn,["prefixCls","direction"]),u=c.prefixCls,d=c.direction,f=i.useContext(GC),m=f.scrollColumnIndex,v=f.stickyOffsets,g=f.flattenColumns,h=n+a-1,p=h+1===m?a+1:a,b=Tf(n,n+p-1,g,v,d);return i.createElement($a,ue({className:t,index:n,component:"td",prefixCls:u,record:null,dataIndex:null,align:s,colSpan:p,rowSpan:l,render:function(){return r}},b))}var pB=["children"];function hB(e){var t=e.children,n=ft(e,pB);return i.createElement("tr",n,t)}function Bs(e){var t=e.children;return t}Bs.Row=hB;Bs.Cell=gB;function bB(e){var t=e.children,n=e.stickyOffsets,r=e.flattenColumns,o=Mn(Hn,"prefixCls"),a=r.length-1,l=r[a],s=i.useMemo(function(){return{stickyOffsets:n,flattenColumns:r,scrollColumnIndex:l!=null&&l.scrollbar?a:null}},[l,r,a,n]);return i.createElement(GC.Provider,{value:s},i.createElement("tfoot",{className:"".concat(o,"-summary")},t))}const Fi=Sa(bB);var qC=Bs;function yB(e){return null}function CB(e){return null}function UC(e,t,n,r,o,a,l){var s=a(t,l);e.push({record:t,indent:n,index:l,rowKey:s});var c=o==null?void 0:o.has(s);if(t&&Array.isArray(t[r])&&c)for(var u=0;u<t[r].length;u+=1)UC(e,t[r][u],n+1,r,o,a,u)}function XC(e,t,n,r){var o=i.useMemo(function(){if(n!=null&&n.size){for(var a=[],l=0;l<(e==null?void 0:e.length);l+=1){var s=e[l];UC(a,s,0,t,n,r,l)}return a}return e==null?void 0:e.map(function(c,u){return{record:c,indent:0,index:u,rowKey:r(c,u)}})},[e,t,n,r]);return o}function YC(e,t,n,r){var o=Mn(Hn,["prefixCls","fixedInfoList","flattenColumns","expandableType","expandRowByClick","onTriggerExpand","rowClassName","expandedRowClassName","indentSize","expandIcon","expandedRowRender","expandIconColumnIndex","expandedKeys","childrenColumnName","rowExpandable","onRow"]),a=o.flattenColumns,l=o.expandableType,s=o.expandedKeys,c=o.childrenColumnName,u=o.onTriggerExpand,d=o.rowExpandable,f=o.onRow,m=o.expandRowByClick,v=o.rowClassName,g=l==="nest",h=l==="row"&&(!d||d(e)),p=h||g,b=s&&s.has(t),y=c&&e&&e[c],C=Nt(u),$=f==null?void 0:f(e,n),S=$==null?void 0:$.onClick,x=function(I){m&&p&&u(e,I);for(var P=arguments.length,M=new Array(P>1?P-1:0),R=1;R<P;R++)M[R-1]=arguments[R];S==null||S.apply(void 0,[I].concat(M))},E;typeof v=="string"?E=v:typeof v=="function"&&(E=v(e,n,r));var O=_s(a);return k(k({},o),{},{columnsKey:O,nestExpandable:g,expanded:b,hasNestChildren:y,record:e,onTriggerExpand:C,rowSupportExpand:h,expandable:p,rowProps:k(k({},$),{},{className:A(E,$==null?void 0:$.className),onClick:x})})}function QC(e){var t=e.prefixCls,n=e.children,r=e.component,o=e.cellComponent,a=e.className,l=e.expanded,s=e.colSpan,c=e.isEmpty,u=e.stickyOffset,d=u===void 0?0:u,f=Mn(Hn,["scrollbarSize","fixHeader","fixColumn","componentWidth","horizonScroll"]),m=f.scrollbarSize,v=f.fixHeader,g=f.fixColumn,h=f.componentWidth,p=f.horizonScroll,b=n;return(c?p&&h:g)&&(b=i.createElement("div",{style:{width:h-d-(v&&!c?m:0),position:"sticky",left:d,overflow:"hidden"},className:"".concat(t,"-expanded-row-fixed")},b)),i.createElement(r,{className:a,style:{display:l?null:"none"}},i.createElement($a,{component:o,prefixCls:t,colSpan:s},b))}function SB(e){var t=e.prefixCls,n=e.record,r=e.onExpand,o=e.expanded,a=e.expandable,l="".concat(t,"-row-expand-icon");if(!a)return i.createElement("span",{className:A(l,"".concat(t,"-row-spaced"))});var s=function(u){r(n,u),u.stopPropagation()};return i.createElement("span",{className:A(l,D(D({},"".concat(t,"-row-expanded"),o),"".concat(t,"-row-collapsed"),!o)),onClick:s})}function $B(e,t,n){var r=[];function o(a){(a||[]).forEach(function(l,s){r.push(t(l,s)),o(l[n])})}return o(e),r}function ZC(e,t,n,r){return typeof e=="string"?e:typeof e=="function"?e(t,n,r):""}function JC(e,t,n,r,o){var a,l=arguments.length>5&&arguments[5]!==void 0?arguments[5]:[],s=arguments.length>6&&arguments[6]!==void 0?arguments[6]:0,c=e.record,u=e.prefixCls,d=e.columnsKey,f=e.fixedInfoList,m=e.expandIconColumnIndex,v=e.nestExpandable,g=e.indentSize,h=e.expandIcon,p=e.expanded,b=e.hasNestChildren,y=e.onTriggerExpand,C=e.expandable,$=e.expandedKeys,S=d[n],x=f[n],E;n===(m||0)&&v&&(E=i.createElement(i.Fragment,null,i.createElement("span",{style:{paddingLeft:"".concat(g*r,"px")},className:"".concat(u,"-row-indent indent-level-").concat(r)}),h({prefixCls:u,expanded:p,expandable:b,record:c,onExpand:y})));var O=((a=t.onCell)===null||a===void 0?void 0:a.call(t,c,o))||{};if(s){var w=O.rowSpan,I=w===void 0?1:w;if(C&&I&&n<s){for(var P=I,M=o;M<o+I;M+=1){var R=l[M];$.has(R)&&(P+=1)}O.rowSpan=P}}return{key:S,fixedInfo:x,appendCellNode:E,additionalCellProps:O}}function xB(e){var t=e.className,n=e.style,r=e.record,o=e.index,a=e.renderIndex,l=e.rowKey,s=e.rowKeys,c=e.indent,u=c===void 0?0:c,d=e.rowComponent,f=e.cellComponent,m=e.scopeCellComponent,v=e.expandedRowInfo,g=YC(r,l,o,u),h=g.prefixCls,p=g.flattenColumns,b=g.expandedRowClassName,y=g.expandedRowRender,C=g.rowProps,$=g.expanded,S=g.rowSupportExpand,x=i.useRef(!1);x.current||(x.current=$);var E=ZC(b,r,o,u),O=i.createElement(d,ue({},C,{"data-row-key":l,className:A(t,"".concat(h,"-row"),"".concat(h,"-row-level-").concat(u),C==null?void 0:C.className,D({},E,u>=1)),style:k(k({},n),C==null?void 0:C.style)}),p.map(function(P,M){var R=P.render,N=P.dataIndex,T=P.className,j=JC(g,P,M,u,o,s,v==null?void 0:v.offset),z=j.key,_=j.fixedInfo,B=j.appendCellNode,V=j.additionalCellProps;return i.createElement($a,ue({className:T,ellipsis:P.ellipsis,align:P.align,scope:P.rowScope,component:P.rowScope?m:f,prefixCls:h,key:z,record:r,index:o,renderIndex:a,dataIndex:N,render:R,shouldCellUpdate:P.shouldCellUpdate},_,{appendNode:B,additionalProps:V}))})),w;if(S&&(x.current||$)){var I=y(r,o,u+1,$);w=i.createElement(QC,{expanded:$,className:A("".concat(h,"-expanded-row"),"".concat(h,"-expanded-row-level-").concat(u+1),E),prefixCls:h,component:d,cellComponent:f,colSpan:v?v.colSpan:p.length,stickyOffset:v==null?void 0:v.sticky,isEmpty:!1},I)}return i.createElement(i.Fragment,null,O,w)}const wB=Sa(xB);function EB(e){var t=e.columnKey,n=e.onColumnResize,r=i.useRef();return wt(function(){r.current&&n(t,r.current.offsetWidth)},[]),i.createElement(Bn,{data:t},i.createElement("td",{ref:r,style:{padding:0,border:0,height:0}},i.createElement("div",{style:{height:0,overflow:"hidden"}}," ")))}function OB(e){var t=e.prefixCls,n=e.columnsKey,r=e.onColumnResize,o=i.useRef(null);return i.createElement("tr",{"aria-hidden":"true",className:"".concat(t,"-measure-row"),style:{height:0,fontSize:0},ref:o},i.createElement(Bn.Collection,{onBatchResize:function(l){as(o.current)&&l.forEach(function(s){var c=s.data,u=s.size;r(c,u.offsetWidth)})}},n.map(function(a){return i.createElement(EB,{key:a,columnKey:a,onColumnResize:r})})))}function IB(e){var t=e.data,n=e.measureColumnWidth,r=Mn(Hn,["prefixCls","getComponent","onColumnResize","flattenColumns","getRowKey","expandedKeys","childrenColumnName","emptyNode","expandedRowOffset","fixedInfoList","colWidths"]),o=r.prefixCls,a=r.getComponent,l=r.onColumnResize,s=r.flattenColumns,c=r.getRowKey,u=r.expandedKeys,d=r.childrenColumnName,f=r.emptyNode,m=r.expandedRowOffset,v=m===void 0?0:m,g=r.colWidths,h=XC(t,d,u,c),p=i.useMemo(function(){return h.map(function(w){return w.rowKey})},[h]),b=i.useRef({renderWithProps:!1}),y=i.useMemo(function(){for(var w=s.length-v,I=0,P=0;P<v;P+=1)I+=g[P]||0;return{offset:v,colSpan:w,sticky:I}},[s.length,v,g]),C=a(["body","wrapper"],"tbody"),$=a(["body","row"],"tr"),S=a(["body","cell"],"td"),x=a(["body","cell"],"th"),E;t.length?E=h.map(function(w,I){var P=w.record,M=w.indent,R=w.index,N=w.rowKey;return i.createElement(wB,{key:N,rowKey:N,rowKeys:p,record:P,index:I,renderIndex:R,rowComponent:$,cellComponent:S,scopeCellComponent:x,indent:M,expandedRowInfo:y})}):E=i.createElement(QC,{expanded:!0,className:"".concat(o,"-placeholder"),prefixCls:o,component:$,cellComponent:S,colSpan:s.length,isEmpty:!0},f);var O=_s(s);return i.createElement(KC.Provider,{value:b.current},i.createElement(C,{className:"".concat(o,"-tbody")},n&&i.createElement(OB,{prefixCls:o,columnsKey:O,onColumnResize:l}),E))}const RB=Sa(IB);var PB=["expandable"],Va="RC_TABLE_INTERNAL_COL_DEFINE";function NB(e){var t=e.expandable,n=ft(e,PB),r;return"expandable"in e?r=k(k({},n),t):r=n,r.showExpandColumn===!1&&(r.expandIconColumnIndex=-1),r}var MB=["columnType"];function eS(e){for(var t=e.colWidths,n=e.columns,r=e.columCount,o=Mn(Hn,["tableLayout"]),a=o.tableLayout,l=[],s=r||n.length,c=!1,u=s-1;u>=0;u-=1){var d=t[u],f=n&&n[u],m=void 0,v=void 0;if(f&&(m=f[Va],a==="auto"&&(v=f.minWidth)),d||v||m||c){var g=m||{};g.columnType;var h=ft(g,MB);l.unshift(i.createElement("col",ue({key:u,style:{width:d,minWidth:v}},h))),c=!0}}return i.createElement("colgroup",null,l)}var TB=["className","noData","columns","flattenColumns","colWidths","columCount","stickyOffsets","direction","fixHeader","stickyTopOffset","stickyBottomOffset","stickyClassName","onScroll","maxContentScroll","children"];function jB(e,t){return i.useMemo(function(){for(var n=[],r=0;r<t;r+=1){var o=e[r];if(o!==void 0)n[r]=o;else return null}return n},[e.join("_"),t])}var zB=i.forwardRef(function(e,t){var n=e.className,r=e.noData,o=e.columns,a=e.flattenColumns,l=e.colWidths,s=e.columCount,c=e.stickyOffsets,u=e.direction,d=e.fixHeader,f=e.stickyTopOffset,m=e.stickyBottomOffset,v=e.stickyClassName,g=e.onScroll,h=e.maxContentScroll,p=e.children,b=ft(e,TB),y=Mn(Hn,["prefixCls","scrollbarSize","isSticky","getComponent"]),C=y.prefixCls,$=y.scrollbarSize,S=y.isSticky,x=y.getComponent,E=x(["header","table"],"table"),O=S&&!d?0:$,w=i.useRef(null),I=i.useCallback(function(_){Ka(t,_),Ka(w,_)},[]);i.useEffect(function(){function _(V){var G=V,q=G.currentTarget,H=G.deltaX;H&&(g({currentTarget:q,scrollLeft:q.scrollLeft+H}),V.preventDefault())}var B=w.current;return B==null||B.addEventListener("wheel",_,{passive:!1}),function(){B==null||B.removeEventListener("wheel",_)}},[]);var P=i.useMemo(function(){return a.every(function(_){return _.width})},[a]),M=a[a.length-1],R={fixed:M?M.fixed:null,scrollbar:!0,onHeaderCell:function(){return{className:"".concat(C,"-cell-scrollbar")}}},N=i.useMemo(function(){return O?[].concat(pe(o),[R]):o},[O,o]),T=i.useMemo(function(){return O?[].concat(pe(a),[R]):a},[O,a]),j=i.useMemo(function(){var _=c.right,B=c.left;return k(k({},c),{},{left:u==="rtl"?[].concat(pe(B.map(function(V){return V+O})),[0]):B,right:u==="rtl"?_:[].concat(pe(_.map(function(V){return V+O})),[0]),isSticky:S})},[O,c,S]),z=jB(l,s);return i.createElement("div",{style:k({overflow:"hidden"},S?{top:f,bottom:m}:{}),ref:I,className:A(n,D({},v,!!v))},i.createElement(E,{style:{tableLayout:"fixed",visibility:r||z?null:"hidden"}},(!r||!h||P)&&i.createElement(eS,{colWidths:z?[].concat(pe(z),[O]):[],columCount:s+1,columns:T}),p(k(k({},b),{},{stickyOffsets:j,columns:N,flattenColumns:T}))))});const lp=i.memo(zB);var DB=function(t){var n=t.cells,r=t.stickyOffsets,o=t.flattenColumns,a=t.rowComponent,l=t.cellComponent,s=t.onHeaderRow,c=t.index,u=Mn(Hn,["prefixCls","direction"]),d=u.prefixCls,f=u.direction,m;s&&(m=s(n.map(function(g){return g.column}),c));var v=_s(n.map(function(g){return g.column}));return i.createElement(a,m,n.map(function(g,h){var p=g.column,b=Tf(g.colStart,g.colEnd,o,r,f),y;return p&&p.onHeaderCell&&(y=g.column.onHeaderCell(p)),i.createElement($a,ue({},g,{scope:p.title?g.colSpan>1?"colgroup":"col":null,ellipsis:p.ellipsis,align:p.align,component:l,prefixCls:d,key:v[h]},b,{additionalProps:y,rowType:"header"}))}))};function _B(e){var t=[];function n(l,s){var c=arguments.length>2&&arguments[2]!==void 0?arguments[2]:0;t[c]=t[c]||[];var u=s,d=l.filter(Boolean).map(function(f){var m={key:f.key,className:f.className||"",children:f.title,column:f,colStart:u},v=1,g=f.children;return g&&g.length>0&&(v=n(g,u,c+1).reduce(function(h,p){return h+p},0),m.hasSubColumns=!0),"colSpan"in f&&(v=f.colSpan),"rowSpan"in f&&(m.rowSpan=f.rowSpan),m.colSpan=v,m.colEnd=m.colStart+v-1,t[c].push(m),u+=v,v});return d}n(e,0);for(var r=t.length,o=function(s){t[s].forEach(function(c){!("rowSpan"in c)&&!c.hasSubColumns&&(c.rowSpan=r-s)})},a=0;a<r;a+=1)o(a);return t}var BB=function(t){var n=t.stickyOffsets,r=t.columns,o=t.flattenColumns,a=t.onHeaderRow,l=Mn(Hn,["prefixCls","getComponent"]),s=l.prefixCls,c=l.getComponent,u=i.useMemo(function(){return _B(r)},[r]),d=c(["header","wrapper"],"thead"),f=c(["header","row"],"tr"),m=c(["header","cell"],"th");return i.createElement(d,{className:"".concat(s,"-thead")},u.map(function(v,g){var h=i.createElement(DB,{key:g,flattenColumns:o,cells:v,stickyOffsets:n,rowComponent:f,cellComponent:m,onHeaderRow:a,index:g});return h}))};const sp=Sa(BB);function cp(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"";return typeof t=="number"?t:t.endsWith("%")?e*parseFloat(t)/100:null}function LB(e,t,n){return i.useMemo(function(){if(t&&t>0){var r=0,o=0;e.forEach(function(m){var v=cp(t,m.width);v?r+=v:o+=1});var a=Math.max(t,n),l=Math.max(a-r,o),s=o,c=l/o,u=0,d=e.map(function(m){var v=k({},m),g=cp(t,v.width);if(g)v.width=g;else{var h=Math.floor(c);v.width=s===1?l:h,l-=h,s-=1}return u+=v.width,v});if(u<a){var f=a/u;l=a,d.forEach(function(m,v){var g=Math.floor(m.width*f);m.width=v===d.length-1?l:g,l-=g})}return[d,Math.max(u,a)]}return[e,t]},[e,t,n])}var HB=["children"],AB=["fixed"];function jf(e){return xn(e).filter(function(t){return i.isValidElement(t)}).map(function(t){var n=t.key,r=t.props,o=r.children,a=ft(r,HB),l=k({key:n},a);return o&&(l.children=jf(o)),l})}function tS(e){return e.filter(function(t){return t&&Qe(t)==="object"&&!t.hidden}).map(function(t){var n=t.children;return n&&n.length>0?k(k({},t),{},{children:tS(n)}):t})}function rd(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"key";return e.filter(function(n){return n&&Qe(n)==="object"}).reduce(function(n,r,o){var a=r.fixed,l=a===!0?"left":a,s="".concat(t,"-").concat(o),c=r.children;return c&&c.length>0?[].concat(pe(n),pe(rd(c,s).map(function(u){return k({fixed:l},u)}))):[].concat(pe(n),[k(k({key:s},r),{},{fixed:l})])},[])}function FB(e){return e.map(function(t){var n=t.fixed,r=ft(t,AB),o=n;return n==="left"?o="right":n==="right"&&(o="left"),k({fixed:o},r)})}function kB(e,t){var n=e.prefixCls,r=e.columns,o=e.children,a=e.expandable,l=e.expandedKeys,s=e.columnTitle,c=e.getRowKey,u=e.onTriggerExpand,d=e.expandIcon,f=e.rowExpandable,m=e.expandIconColumnIndex,v=e.expandedRowOffset,g=v===void 0?0:v,h=e.direction,p=e.expandRowByClick,b=e.columnWidth,y=e.fixed,C=e.scrollWidth,$=e.clientWidth,S=i.useMemo(function(){var N=r||jf(o)||[];return tS(N.slice())},[r,o]),x=i.useMemo(function(){if(a){var N=S.slice();if(!N.includes(Lr)){var T=m||0;T>=0&&(T||y==="left"||!y)&&N.splice(T,0,Lr),y==="right"&&N.splice(S.length,0,Lr)}var j=N.indexOf(Lr);N=N.filter(function(V,G){return V!==Lr||G===j});var z=S[j],_;y?_=y:_=z?z.fixed:null;var B=D(D(D(D(D(D({},Va,{className:"".concat(n,"-expand-icon-col"),columnType:"EXPAND_COLUMN"}),"title",s),"fixed",_),"className","".concat(n,"-row-expand-icon-cell")),"width",b),"render",function(G,q,H){var W=c(q,H),K=l.has(W),U=f?f(q):!0,te=d({prefixCls:n,expanded:K,expandable:U,record:q,onExpand:u});return p?i.createElement("span",{onClick:function(ae){return ae.stopPropagation()}},te):te});return N.map(function(V,G){var q=V===Lr?B:V;return G<g?k(k({},q),{},{fixed:q.fixed||"left"}):q})}return S.filter(function(V){return V!==Lr})},[a,S,c,l,d,h,g]),E=i.useMemo(function(){var N=x;return t&&(N=t(N)),N.length||(N=[{render:function(){return null}}]),N},[t,x,h]),O=i.useMemo(function(){return h==="rtl"?FB(rd(E)):rd(E)},[E,h,C]),w=i.useMemo(function(){for(var N=-1,T=O.length-1;T>=0;T-=1){var j=O[T].fixed;if(j==="left"||j===!0){N=T;break}}if(N>=0)for(var z=0;z<=N;z+=1){var _=O[z].fixed;if(_!=="left"&&_!==!0)return!0}var B=O.findIndex(function(q){var H=q.fixed;return H==="right"});if(B>=0)for(var V=B;V<O.length;V+=1){var G=O[V].fixed;if(G!=="right")return!0}return!1},[O]),I=LB(O,C,$),P=J(I,2),M=P[0],R=P[1];return[E,M,R,w]}function VB(e,t,n){var r=NB(e),o=r.expandIcon,a=r.expandedRowKeys,l=r.defaultExpandedRowKeys,s=r.defaultExpandAllRows,c=r.expandedRowRender,u=r.onExpand,d=r.onExpandedRowsChange,f=r.childrenColumnName,m=o||SB,v=f||"children",g=i.useMemo(function(){return c?"row":e.expandable&&e.internalHooks===Oi&&e.expandable.__PARENT_RENDER_ICON__||t.some(function(S){return S&&Qe(S)==="object"&&S[v]})?"nest":!1},[!!c,t]),h=i.useState(function(){return l||(s?$B(t,n,v):[])}),p=J(h,2),b=p[0],y=p[1],C=i.useMemo(function(){return new Set(a||b||[])},[a,b]),$=i.useCallback(function(S){var x=n(S,t.indexOf(S)),E,O=C.has(x);O?(C.delete(x),E=pe(C)):E=[].concat(pe(C),[x]),y(E),u&&u(!O,S),d&&d(E)},[n,C,t,u,d]);return[r,g,C,m,v,$]}function WB(e,t,n){var r=e.map(function(o,a){return Tf(a,a,e,t,n)});return So(function(){return r},[r],function(o,a){return!hr(o,a)})}function KB(e){var t=i.useRef(e),n=i.useState({}),r=J(n,2),o=r[1],a=i.useRef(null),l=i.useRef([]);function s(c){l.current.push(c);var u=Promise.resolve();a.current=u,u.then(function(){if(a.current===u){var d=l.current,f=t.current;l.current=[],d.forEach(function(m){t.current=m(t.current)}),a.current=null,f!==t.current&&o({})}})}return i.useEffect(function(){return function(){a.current=null}},[]),[t.current,s]}function GB(e){var t=i.useRef(null),n=i.useRef();function r(){window.clearTimeout(n.current)}function o(l){t.current=l,r(),n.current=window.setTimeout(function(){t.current=null,n.current=void 0},100)}function a(){return t.current}return i.useEffect(function(){return r},[]),[o,a]}function qB(){var e=i.useState(-1),t=J(e,2),n=t[0],r=t[1],o=i.useState(-1),a=J(o,2),l=a[0],s=a[1],c=i.useCallback(function(u,d){r(u),s(d)},[]);return[n,l,c]}var up=wn()?window:null;function UB(e,t){var n=Qe(e)==="object"?e:{},r=n.offsetHeader,o=r===void 0?0:r,a=n.offsetSummary,l=a===void 0?0:a,s=n.offsetScroll,c=s===void 0?0:s,u=n.getContainer,d=u===void 0?function(){return up}:u,f=d()||up,m=!!e;return i.useMemo(function(){return{isSticky:m,stickyClassName:m?"".concat(t,"-sticky-holder"):"",offsetHeader:o,offsetSummary:l,offsetScroll:c,container:f}},[m,c,o,l,t,f])}function XB(e,t,n){var r=i.useMemo(function(){var o=t.length,a=function(u,d,f){for(var m=[],v=0,g=u;g!==d;g+=f)m.push(v),t[g].fixed&&(v+=e[g]||0);return m},l=a(0,o,1),s=a(o-1,-1,-1).reverse();return n==="rtl"?{left:s,right:l}:{left:l,right:s}},[e,t,n]);return r}function dp(e){var t=e.className,n=e.children;return i.createElement("div",{className:t},n)}function fp(e){var t=_l(e),n=t.getBoundingClientRect(),r=document.documentElement;return{left:n.left+(window.pageXOffset||r.scrollLeft)-(r.clientLeft||document.body.clientLeft||0),top:n.top+(window.pageYOffset||r.scrollTop)-(r.clientTop||document.body.clientTop||0)}}var YB=function(t,n){var r,o,a=t.scrollBodyRef,l=t.onScroll,s=t.offsetScroll,c=t.container,u=t.direction,d=Mn(Hn,"prefixCls"),f=((r=a.current)===null||r===void 0?void 0:r.scrollWidth)||0,m=((o=a.current)===null||o===void 0?void 0:o.clientWidth)||0,v=f&&m*(m/f),g=i.useRef(),h=KB({scrollLeft:0,isHiddenScrollBar:!0}),p=J(h,2),b=p[0],y=p[1],C=i.useRef({delta:0,x:0}),$=i.useState(!1),S=J($,2),x=S[0],E=S[1],O=i.useRef(null);i.useEffect(function(){return function(){Et.cancel(O.current)}},[]);var w=function(){E(!1)},I=function(T){T.persist(),C.current.delta=T.pageX-b.scrollLeft,C.current.x=0,E(!0),T.preventDefault()},P=function(T){var j,z=T||((j=window)===null||j===void 0?void 0:j.event),_=z.buttons;if(!x||_===0){x&&E(!1);return}var B=C.current.x+T.pageX-C.current.x-C.current.delta,V=u==="rtl";B=Math.max(V?v-m:0,Math.min(V?0:m-v,B));var G=!V||Math.abs(B)+Math.abs(v)<m;G&&(l({scrollLeft:B/m*(f+2)}),C.current.x=T.pageX)},M=function(){Et.cancel(O.current),O.current=Et(function(){if(a.current){var T=fp(a.current).top,j=T+a.current.offsetHeight,z=c===window?document.documentElement.scrollTop+window.innerHeight:fp(c).top+c.clientHeight;j-Ym()<=z||T>=z-s?y(function(_){return k(k({},_),{},{isHiddenScrollBar:!0})}):y(function(_){return k(k({},_),{},{isHiddenScrollBar:!1})})}})},R=function(T){y(function(j){return k(k({},j),{},{scrollLeft:T/f*m||0})})};return i.useImperativeHandle(n,function(){return{setScrollLeft:R,checkScrollBarVisible:M}}),i.useEffect(function(){var N=Kg(document.body,"mouseup",w,!1),T=Kg(document.body,"mousemove",P,!1);return M(),function(){N.remove(),T.remove()}},[v,x]),i.useEffect(function(){if(a.current){for(var N=[],T=_l(a.current);T;)N.push(T),T=T.parentElement;return N.forEach(function(j){return j.addEventListener("scroll",M,!1)}),window.addEventListener("resize",M,!1),window.addEventListener("scroll",M,!1),c.addEventListener("scroll",M,!1),function(){N.forEach(function(j){return j.removeEventListener("scroll",M)}),window.removeEventListener("resize",M),window.removeEventListener("scroll",M),c.removeEventListener("scroll",M)}}},[c]),i.useEffect(function(){b.isHiddenScrollBar||y(function(N){var T=a.current;return T?k(k({},N),{},{scrollLeft:T.scrollLeft/T.scrollWidth*T.clientWidth}):N})},[b.isHiddenScrollBar]),f<=m||!v||b.isHiddenScrollBar?null:i.createElement("div",{style:{height:Ym(),width:m,bottom:s},className:"".concat(d,"-sticky-scroll")},i.createElement("div",{onMouseDown:I,ref:g,className:A("".concat(d,"-sticky-scroll-bar"),D({},"".concat(d,"-sticky-scroll-bar-active"),x)),style:{width:"".concat(v,"px"),transform:"translate3d(".concat(b.scrollLeft,"px, 0, 0)")}}))};const QB=i.forwardRef(YB);var nS="rc-table",ZB=[],JB={};function e7(){return"No Data"}function t7(e,t){var n=k({rowKey:"key",prefixCls:nS,emptyText:e7},e),r=n.prefixCls,o=n.className,a=n.rowClassName,l=n.style,s=n.data,c=n.rowKey,u=n.scroll,d=n.tableLayout,f=n.direction,m=n.title,v=n.footer,g=n.summary,h=n.caption,p=n.id,b=n.showHeader,y=n.components,C=n.emptyText,$=n.onRow,S=n.onHeaderRow,x=n.onScroll,E=n.internalHooks,O=n.transformColumns,w=n.internalRefs,I=n.tailor,P=n.getContainerWidth,M=n.sticky,R=n.rowHoverable,N=R===void 0?!0:R,T=s||ZB,j=!!T.length,z=E===Oi,_=i.useCallback(function(St,bt){return Qn(y,St)||bt},[y]),B=i.useMemo(function(){return typeof c=="function"?c:function(St){var bt=St&&St[c];return bt}},[c]),V=_(["body"]),G=qB(),q=J(G,3),H=q[0],W=q[1],K=q[2],U=VB(n,T,B),te=J(U,6),X=te[0],ae=te[1],le=te[2],ee=te[3],Y=te[4],re=te[5],ne=u==null?void 0:u.x,Z=i.useState(0),Q=J(Z,2),ie=Q[0],de=Q[1],he=kB(k(k(k({},n),X),{},{expandable:!!X.expandedRowRender,columnTitle:X.columnTitle,expandedKeys:le,getRowKey:B,onTriggerExpand:re,expandIcon:ee,expandIconColumnIndex:X.expandIconColumnIndex,direction:f,scrollWidth:z&&I&&typeof ne=="number"?ne:null,clientWidth:ie}),z?O:null),ye=J(he,4),oe=ye[0],ce=ye[1],ge=ye[2],se=ye[3],be=ge??ne,we=i.useMemo(function(){return{columns:oe,flattenColumns:ce}},[oe,ce]),Me=i.useRef(),Te=i.useRef(),Se=i.useRef(),Fe=i.useRef();i.useImperativeHandle(t,function(){return{nativeElement:Me.current,scrollTo:function(bt){var nn;if(Se.current instanceof HTMLElement){var jn=bt.index,Wt=bt.top,Gn=bt.key;if(sB(Wt)){var qn;(qn=Se.current)===null||qn===void 0||qn.scrollTo({top:Wt})}else{var Pn,Fn=Gn??B(T[jn]);(Pn=Se.current.querySelector('[data-row-key="'.concat(Fn,'"]')))===null||Pn===void 0||Pn.scrollIntoView()}}else(nn=Se.current)!==null&&nn!==void 0&&nn.scrollTo&&Se.current.scrollTo(bt)}}});var Ce=i.useRef(),me=i.useState(!1),$e=J(me,2),Ee=$e[0],Ie=$e[1],fe=i.useState(!1),ve=J(fe,2),xe=ve[0],Re=ve[1],it=i.useState(new Map),dt=J(it,2),Oe=dt[0],Le=dt[1],Ue=_s(ce),ke=Ue.map(function(St){return Oe.get(St)}),Je=i.useMemo(function(){return ke},[ke.join("_")]),Xe=XB(Je,ce,f),He=u&&nd(u.y),je=u&&nd(be)||!!X.fixed,rt=je&&ce.some(function(St){var bt=St.fixed;return bt}),et=i.useRef(),Pe=UB(M,r),qe=Pe.isSticky,We=Pe.offsetHeader,tt=Pe.offsetSummary,mt=Pe.offsetScroll,ct=Pe.stickyClassName,Ke=Pe.container,Ye=i.useMemo(function(){return g==null?void 0:g(T)},[g,T]),at=(He||qe)&&i.isValidElement(Ye)&&Ye.type===Bs&&Ye.props.fixed,gt,Ot,Pt;He&&(Ot={overflowY:j?"scroll":"auto",maxHeight:u.y}),je&&(gt={overflowX:"auto"},He||(Ot={overflowY:"hidden"}),Pt={width:be===!0?"auto":be,minWidth:"100%"});var Rt=i.useCallback(function(St,bt){Le(function(nn){if(nn.get(St)!==bt){var jn=new Map(nn);return jn.set(St,bt),jn}return nn})},[]),jt=GB(),zt=J(jt,2),Dt=zt[0],De=zt[1];function Ze(St,bt){bt&&(typeof bt=="function"?bt(St):bt.scrollLeft!==St&&(bt.scrollLeft=St,bt.scrollLeft!==St&&setTimeout(function(){bt.scrollLeft=St},0)))}var Ge=Nt(function(St){var bt=St.currentTarget,nn=St.scrollLeft,jn=f==="rtl",Wt=typeof nn=="number"?nn:bt.scrollLeft,Gn=bt||JB;if(!De()||De()===Gn){var qn;Dt(Gn),Ze(Wt,Te.current),Ze(Wt,Se.current),Ze(Wt,Ce.current),Ze(Wt,(qn=et.current)===null||qn===void 0?void 0:qn.setScrollLeft)}var Pn=bt||Te.current;if(Pn){var Fn=z&&I&&typeof be=="number"?be:Pn.scrollWidth,_r=Pn.clientWidth;if(Fn===_r){Ie(!1),Re(!1);return}jn?(Ie(-Wt<Fn-_r),Re(-Wt>0)):(Ie(Wt>0),Re(Wt<Fn-_r))}}),Be=Nt(function(St){Ge(St),x==null||x(St)}),ze=function(){if(je&&Se.current){var bt;Ge({currentTarget:_l(Se.current),scrollLeft:(bt=Se.current)===null||bt===void 0?void 0:bt.scrollLeft})}else Ie(!1),Re(!1)},_e=function(bt){var nn,jn=bt.width;(nn=et.current)===null||nn===void 0||nn.checkScrollBarVisible();var Wt=Me.current?Me.current.offsetWidth:jn;z&&P&&Me.current&&(Wt=P(Me.current,Wt)||Wt),Wt!==ie&&(ze(),de(Wt))},lt=i.useRef(!1);i.useEffect(function(){lt.current&&ze()},[je,s,oe.length]),i.useEffect(function(){lt.current=!0},[]);var Ct=i.useState(0),Ae=J(Ct,2),nt=Ae[0],ht=Ae[1],Ft=i.useState(!0),qt=J(Ft,2),Qt=qt[0],ln=qt[1];wt(function(){(!I||!z)&&(Se.current instanceof Element?ht(Ru(Se.current).width):ht(Ru(Fe.current).width)),ln(Hu("position","sticky"))},[]),i.useEffect(function(){z&&w&&(w.body.current=Se.current)});var on=i.useCallback(function(St){return i.createElement(i.Fragment,null,i.createElement(sp,St),at==="top"&&i.createElement(Fi,St,Ye))},[at,Ye]),Tn=i.useCallback(function(St){return i.createElement(Fi,St,Ye)},[Ye]),On=_(["table"],"table"),In=i.useMemo(function(){return d||(rt?be==="max-content"?"auto":"fixed":He||qe||ce.some(function(St){var bt=St.ellipsis;return bt})?"fixed":"auto")},[He,rt,ce,d,qe]),An,At={colWidths:Je,columCount:ce.length,stickyOffsets:Xe,onHeaderRow:S,fixHeader:He,scroll:u},ut=i.useMemo(function(){return j?null:typeof C=="function"?C():C},[j,C]),st=i.createElement(RB,{data:T,measureColumnWidth:He||je||qe}),_t=i.createElement(eS,{colWidths:ce.map(function(St){var bt=St.width;return bt}),columns:ce}),Ht=h!=null?i.createElement("caption",{className:"".concat(r,"-caption")},h):void 0,Vt=rn(n,{data:!0}),Xt=rn(n,{aria:!0});if(He||qe){var vn;typeof V=="function"?(vn=V(T,{scrollbarSize:nt,ref:Se,onScroll:Ge}),At.colWidths=ce.map(function(St,bt){var nn=St.width,jn=bt===ce.length-1?nn-nt:nn;return typeof jn=="number"&&!Number.isNaN(jn)?jn:0})):vn=i.createElement("div",{style:k(k({},gt),Ot),onScroll:Be,ref:Se,className:A("".concat(r,"-body"))},i.createElement(On,ue({style:k(k({},Pt),{},{tableLayout:In})},Xt),Ht,_t,st,!at&&Ye&&i.createElement(Fi,{stickyOffsets:Xe,flattenColumns:ce},Ye)));var dn=k(k(k({noData:!T.length,maxContentScroll:je&&be==="max-content"},At),we),{},{direction:f,stickyClassName:ct,onScroll:Ge});An=i.createElement(i.Fragment,null,b!==!1&&i.createElement(lp,ue({},dn,{stickyTopOffset:We,className:"".concat(r,"-header"),ref:Te}),on),vn,at&&at!=="top"&&i.createElement(lp,ue({},dn,{stickyBottomOffset:tt,className:"".concat(r,"-summary"),ref:Ce}),Tn),qe&&Se.current&&Se.current instanceof Element&&i.createElement(QB,{ref:et,offsetScroll:mt,scrollBodyRef:Se,onScroll:Ge,container:Ke,direction:f}))}else An=i.createElement("div",{style:k(k({},gt),Ot),className:A("".concat(r,"-content")),onScroll:Ge,ref:Se},i.createElement(On,ue({style:k(k({},Pt),{},{tableLayout:In})},Xt),Ht,_t,b!==!1&&i.createElement(sp,ue({},At,we)),st,Ye&&i.createElement(Fi,{stickyOffsets:Xe,flattenColumns:ce},Ye)));var gn=i.createElement("div",ue({className:A(r,o,D(D(D(D(D(D(D(D(D(D({},"".concat(r,"-rtl"),f==="rtl"),"".concat(r,"-ping-left"),Ee),"".concat(r,"-ping-right"),xe),"".concat(r,"-layout-fixed"),d==="fixed"),"".concat(r,"-fixed-header"),He),"".concat(r,"-fixed-column"),rt),"".concat(r,"-fixed-column-gapped"),rt&&se),"".concat(r,"-scroll-horizontal"),je),"".concat(r,"-has-fix-left"),ce[0]&&ce[0].fixed),"".concat(r,"-has-fix-right"),ce[ce.length-1]&&ce[ce.length-1].fixed==="right")),style:l,id:p,ref:Me},Vt),m&&i.createElement(dp,{className:"".concat(r,"-title")},m(T)),i.createElement("div",{ref:Fe,className:"".concat(r,"-container")},An),v&&i.createElement(dp,{className:"".concat(r,"-footer")},v(T)));je&&(gn=i.createElement(Bn,{onResize:_e},gn));var pn=WB(ce,Xe,f),Rn=i.useMemo(function(){return{scrollX:be,prefixCls:r,getComponent:_,scrollbarSize:nt,direction:f,fixedInfoList:pn,isSticky:qe,supportSticky:Qt,componentWidth:ie,fixHeader:He,fixColumn:rt,horizonScroll:je,tableLayout:In,rowClassName:a,expandedRowClassName:X.expandedRowClassName,expandIcon:ee,expandableType:ae,expandRowByClick:X.expandRowByClick,expandedRowRender:X.expandedRowRender,expandedRowOffset:X.expandedRowOffset,onTriggerExpand:re,expandIconColumnIndex:X.expandIconColumnIndex,indentSize:X.indentSize,allColumnsFixedLeft:ce.every(function(St){return St.fixed==="left"}),emptyNode:ut,columns:oe,flattenColumns:ce,onColumnResize:Rt,colWidths:Je,hoverStartRow:H,hoverEndRow:W,onHover:K,rowExpandable:X.rowExpandable,onRow:$,getRowKey:B,expandedKeys:le,childrenColumnName:Y,rowHoverable:N}},[be,r,_,nt,f,pn,qe,Qt,ie,He,rt,je,In,a,X.expandedRowClassName,ee,ae,X.expandRowByClick,X.expandedRowRender,X.expandedRowOffset,re,X.expandIconColumnIndex,X.indentSize,ut,oe,ce,Rt,Je,H,W,K,X.rowExpandable,$,B,le,Y,N]);return i.createElement(Hn.Provider,{value:Rn},gn)}var n7=i.forwardRef(t7);function rS(e){return WC(n7,e)}var xa=rS();xa.EXPAND_COLUMN=Lr;xa.INTERNAL_HOOKS=Oi;xa.Column=yB;xa.ColumnGroup=CB;xa.Summary=qC;var zf=Nf(null),oS=Nf(null);function r7(e,t,n){var r=t||1;return n[e+r]-(n[e]||0)}function o7(e){var t=e.rowInfo,n=e.column,r=e.colIndex,o=e.indent,a=e.index,l=e.component,s=e.renderIndex,c=e.record,u=e.style,d=e.className,f=e.inverse,m=e.getHeight,v=n.render,g=n.dataIndex,h=n.className,p=n.width,b=Mn(oS,["columnsOffset"]),y=b.columnsOffset,C=JC(t,n,r,o,a),$=C.key,S=C.fixedInfo,x=C.appendCellNode,E=C.additionalCellProps,O=E.style,w=E.colSpan,I=w===void 0?1:w,P=E.rowSpan,M=P===void 0?1:P,R=r-1,N=r7(R,I,y),T=I>1?p-N:0,j=k(k(k({},O),u),{},{flex:"0 0 ".concat(N,"px"),width:"".concat(N,"px"),marginRight:T,pointerEvents:"auto"}),z=i.useMemo(function(){return f?M<=1:I===0||M===0||M>1},[M,I,f]);z?j.visibility="hidden":f&&(j.height=m==null?void 0:m(M));var _=z?function(){return null}:v,B={};return(M===0||I===0)&&(B.rowSpan=1,B.colSpan=1),i.createElement($a,ue({className:A(h,d),ellipsis:n.ellipsis,align:n.align,scope:n.rowScope,component:l,prefixCls:t.prefixCls,key:$,record:c,index:a,renderIndex:s,dataIndex:g,render:_,shouldCellUpdate:n.shouldCellUpdate},S,{appendNode:x,additionalProps:k(k({},E),{},{style:j},B)}))}var a7=["data","index","className","rowKey","style","extra","getHeight"],i7=i.forwardRef(function(e,t){var n=e.data,r=e.index,o=e.className,a=e.rowKey,l=e.style,s=e.extra,c=e.getHeight,u=ft(e,a7),d=n.record,f=n.indent,m=n.index,v=Mn(Hn,["prefixCls","flattenColumns","fixColumn","componentWidth","scrollX"]),g=v.scrollX,h=v.flattenColumns,p=v.prefixCls,b=v.fixColumn,y=v.componentWidth,C=Mn(zf,["getComponent"]),$=C.getComponent,S=YC(d,a,r,f),x=$(["body","row"],"div"),E=$(["body","cell"],"div"),O=S.rowSupportExpand,w=S.expanded,I=S.rowProps,P=S.expandedRowRender,M=S.expandedRowClassName,R;if(O&&w){var N=P(d,r,f+1,w),T=ZC(M,d,r,f),j={};b&&(j={style:D({},"--virtual-width","".concat(y,"px"))});var z="".concat(p,"-expanded-row-cell");R=i.createElement(x,{className:A("".concat(p,"-expanded-row"),"".concat(p,"-expanded-row-level-").concat(f+1),T)},i.createElement($a,{component:E,prefixCls:p,className:A(z,D({},"".concat(z,"-fixed"),b)),additionalProps:j},N))}var _=k(k({},l),{},{width:g});s&&(_.position="absolute",_.pointerEvents="none");var B=i.createElement(x,ue({},I,u,{"data-row-key":a,ref:O?null:t,className:A(o,"".concat(p,"-row"),I==null?void 0:I.className,D({},"".concat(p,"-row-extra"),s)),style:k(k({},_),I==null?void 0:I.style)}),h.map(function(V,G){return i.createElement(o7,{key:G,component:E,rowInfo:S,column:V,colIndex:G,indent:f,index:r,renderIndex:m,record:d,inverse:s,getHeight:c})}));return O?i.createElement("div",{ref:t},B,R):B}),mp=Sa(i7),l7=i.forwardRef(function(e,t){var n=e.data,r=e.onScroll,o=Mn(Hn,["flattenColumns","onColumnResize","getRowKey","prefixCls","expandedKeys","childrenColumnName","scrollX","direction"]),a=o.flattenColumns,l=o.onColumnResize,s=o.getRowKey,c=o.expandedKeys,u=o.prefixCls,d=o.childrenColumnName,f=o.scrollX,m=o.direction,v=Mn(zf),g=v.sticky,h=v.scrollY,p=v.listItemHeight,b=v.getComponent,y=v.onScroll,C=i.useRef(),$=XC(n,d,c,s),S=i.useMemo(function(){var R=0;return a.map(function(N){var T=N.width,j=N.key;return R+=T,[j,T,R]})},[a]),x=i.useMemo(function(){return S.map(function(R){return R[2]})},[S]);i.useEffect(function(){S.forEach(function(R){var N=J(R,2),T=N[0],j=N[1];l(T,j)})},[S]),i.useImperativeHandle(t,function(){var R,N={scrollTo:function(j){var z;(z=C.current)===null||z===void 0||z.scrollTo(j)},nativeElement:(R=C.current)===null||R===void 0?void 0:R.nativeElement};return Object.defineProperty(N,"scrollLeft",{get:function(){var j;return((j=C.current)===null||j===void 0?void 0:j.getScrollInfo().x)||0},set:function(j){var z;(z=C.current)===null||z===void 0||z.scrollTo({left:j})}}),N});var E=function(N,T){var j,z=(j=$[T])===null||j===void 0?void 0:j.record,_=N.onCell;if(_){var B,V=_(z,T);return(B=V==null?void 0:V.rowSpan)!==null&&B!==void 0?B:1}return 1},O=function(N){var T=N.start,j=N.end,z=N.getSize,_=N.offsetY;if(j<0)return null;for(var B=a.filter(function(ee){return E(ee,T)===0}),V=T,G=function(Y){if(B=B.filter(function(re){return E(re,Y)===0}),!B.length)return V=Y,1},q=T;q>=0&&!G(q);q-=1);for(var H=a.filter(function(ee){return E(ee,j)!==1}),W=j,K=function(Y){if(H=H.filter(function(re){return E(re,Y)!==1}),!H.length)return W=Math.max(Y-1,j),1},U=j;U<$.length&&!K(U);U+=1);for(var te=[],X=function(Y){var re=$[Y];if(!re)return 1;a.some(function(ne){return E(ne,Y)>1})&&te.push(Y)},ae=V;ae<=W;ae+=1)X(ae);var le=te.map(function(ee){var Y=$[ee],re=s(Y.record,ee),ne=function(ie){var de=ee+ie-1,he=s($[de].record,de),ye=z(re,he);return ye.bottom-ye.top},Z=z(re);return i.createElement(mp,{key:ee,data:Y,rowKey:re,index:ee,style:{top:-_+Z.top},extra:!0,getHeight:ne})});return le},w=i.useMemo(function(){return{columnsOffset:x}},[x]),I="".concat(u,"-tbody"),P=b(["body","wrapper"]),M={};return g&&(M.position="sticky",M.bottom=0,Qe(g)==="object"&&g.offsetScroll&&(M.bottom=g.offsetScroll)),i.createElement(oS.Provider,{value:w},i.createElement($s,{fullHeight:!1,ref:C,prefixCls:"".concat(I,"-virtual"),styles:{horizontalScrollBar:M},className:I,height:h,itemHeight:p||24,data:$,itemKey:function(N){return s(N.record)},component:P,scrollWidth:f,direction:m,onVirtualScroll:function(N){var T,j=N.x;r({currentTarget:(T=C.current)===null||T===void 0?void 0:T.nativeElement,scrollLeft:j})},onScroll:y,extraRender:O},function(R,N,T){var j=s(R.record,N);return i.createElement(mp,{data:R,rowKey:j,index:N,style:T.style})}))}),s7=Sa(l7),c7=function(t,n){var r=n.ref,o=n.onScroll;return i.createElement(s7,{ref:r,data:t,onScroll:o})};function u7(e,t){var n=e.data,r=e.columns,o=e.scroll,a=e.sticky,l=e.prefixCls,s=l===void 0?nS:l,c=e.className,u=e.listItemHeight,d=e.components,f=e.onScroll,m=o||{},v=m.x,g=m.y;typeof v!="number"&&(v=1),typeof g!="number"&&(g=500);var h=Nt(function(y,C){return Qn(d,y)||C}),p=Nt(f),b=i.useMemo(function(){return{sticky:a,scrollY:g,listItemHeight:u,getComponent:h,onScroll:p}},[a,g,u,h,p]);return i.createElement(zf.Provider,{value:b},i.createElement(xa,ue({},e,{className:A(c,"".concat(s,"-virtual")),scroll:k(k({},o),{},{x:v}),components:k(k({},d),{},{body:n!=null&&n.length?c7:void 0}),columns:r,internalHooks:Oi,tailor:!0,ref:t})))}var d7=i.forwardRef(u7);function aS(e){return WC(d7,e)}aS();const f7=e=>null,m7=e=>null;var Df=i.createContext(null),v7=i.createContext({}),g7=function(t){for(var n=t.prefixCls,r=t.level,o=t.isStart,a=t.isEnd,l="".concat(n,"-indent-unit"),s=[],c=0;c<r;c+=1)s.push(i.createElement("span",{key:c,className:A(l,D(D({},"".concat(l,"-start"),o[c]),"".concat(l,"-end"),a[c]))}));return i.createElement("span",{"aria-hidden":"true",className:"".concat(n,"-indent")},s)};const p7=i.memo(g7);var h7=["eventKey","className","style","dragOver","dragOverGapTop","dragOverGapBottom","isLeaf","isStart","isEnd","expanded","selected","checked","halfChecked","loading","domRef","active","data","onMouseMove","selectable"],vp="open",gp="close",b7="---",oi=function(t){var n,r,o,a=t.eventKey,l=t.className,s=t.style,c=t.dragOver,u=t.dragOverGapTop,d=t.dragOverGapBottom,f=t.isLeaf,m=t.isStart,v=t.isEnd,g=t.expanded,h=t.selected,p=t.checked,b=t.halfChecked,y=t.loading,C=t.domRef,$=t.active,S=t.data,x=t.onMouseMove,E=t.selectable,O=ft(t,h7),w=F.useContext(Df),I=F.useContext(v7),P=F.useRef(null),M=F.useState(!1),R=J(M,2),N=R[0],T=R[1],j=!!(w.disabled||t.disabled||(n=I.nodeDisabled)!==null&&n!==void 0&&n.call(I,S)),z=F.useMemo(function(){return!w.checkable||t.checkable===!1?!1:w.checkable},[w.checkable,t.checkable]),_=function(me){j||w.onNodeSelect(me,fn(t))},B=function(me){j||!z||t.disableCheckbox||w.onNodeCheck(me,fn(t),!p)},V=F.useMemo(function(){return typeof E=="boolean"?E:w.selectable},[E,w.selectable]),G=function(me){w.onNodeClick(me,fn(t)),V?_(me):B(me)},q=function(me){w.onNodeDoubleClick(me,fn(t))},H=function(me){w.onNodeMouseEnter(me,fn(t))},W=function(me){w.onNodeMouseLeave(me,fn(t))},K=function(me){w.onNodeContextMenu(me,fn(t))},U=F.useMemo(function(){return!!(w.draggable&&(!w.draggable.nodeDraggable||w.draggable.nodeDraggable(S)))},[w.draggable,S]),te=function(me){me.stopPropagation(),T(!0),w.onNodeDragStart(me,t);try{me.dataTransfer.setData("text/plain","")}catch{}},X=function(me){me.preventDefault(),me.stopPropagation(),w.onNodeDragEnter(me,t)},ae=function(me){me.preventDefault(),me.stopPropagation(),w.onNodeDragOver(me,t)},le=function(me){me.stopPropagation(),w.onNodeDragLeave(me,t)},ee=function(me){me.stopPropagation(),T(!1),w.onNodeDragEnd(me,t)},Y=function(me){me.preventDefault(),me.stopPropagation(),T(!1),w.onNodeDrop(me,t)},re=function(me){y||w.onNodeExpand(me,fn(t))},ne=F.useMemo(function(){var Ce=kn(w.keyEntities,a)||{},me=Ce.children;return!!(me||[]).length},[w.keyEntities,a]),Z=F.useMemo(function(){return f===!1?!1:f||!w.loadData&&!ne||w.loadData&&t.loaded&&!ne},[f,w.loadData,ne,t.loaded]);F.useEffect(function(){y||typeof w.loadData=="function"&&g&&!Z&&!t.loaded&&w.onNodeLoad(fn(t))},[y,w.loadData,w.onNodeLoad,g,Z,t]);var Q=F.useMemo(function(){var Ce;return(Ce=w.draggable)!==null&&Ce!==void 0&&Ce.icon?F.createElement("span",{className:"".concat(w.prefixCls,"-draggable-icon")},w.draggable.icon):null},[w.draggable]),ie=function(me){var $e=t.switcherIcon||w.switcherIcon;return typeof $e=="function"?$e(k(k({},t),{},{isLeaf:me})):$e},de=function(){if(Z){var me=ie(!0);return me!==!1?F.createElement("span",{className:A("".concat(w.prefixCls,"-switcher"),"".concat(w.prefixCls,"-switcher-noop"))},me):null}var $e=ie(!1);return $e!==!1?F.createElement("span",{onClick:re,className:A("".concat(w.prefixCls,"-switcher"),"".concat(w.prefixCls,"-switcher_").concat(g?vp:gp))},$e):null},he=F.useMemo(function(){if(!z)return null;var Ce=typeof z!="boolean"?z:null;return F.createElement("span",{className:A("".concat(w.prefixCls,"-checkbox"),D(D(D({},"".concat(w.prefixCls,"-checkbox-checked"),p),"".concat(w.prefixCls,"-checkbox-indeterminate"),!p&&b),"".concat(w.prefixCls,"-checkbox-disabled"),j||t.disableCheckbox)),onClick:B,role:"checkbox","aria-checked":b?"mixed":p,"aria-disabled":j||t.disableCheckbox,"aria-label":"Select ".concat(typeof t.title=="string"?t.title:"tree node")},Ce)},[z,p,b,j,t.disableCheckbox,t.title]),ye=F.useMemo(function(){return Z?null:g?vp:gp},[Z,g]),oe=F.useMemo(function(){return F.createElement("span",{className:A("".concat(w.prefixCls,"-iconEle"),"".concat(w.prefixCls,"-icon__").concat(ye||"docu"),D({},"".concat(w.prefixCls,"-icon_loading"),y))})},[w.prefixCls,ye,y]),ce=F.useMemo(function(){var Ce=!!w.draggable,me=!t.disabled&&Ce&&w.dragOverNodeKey===a;return me?w.dropIndicatorRender({dropPosition:w.dropPosition,dropLevelOffset:w.dropLevelOffset,indent:w.indent,prefixCls:w.prefixCls,direction:w.direction}):null},[w.dropPosition,w.dropLevelOffset,w.indent,w.prefixCls,w.direction,w.draggable,w.dragOverNodeKey,w.dropIndicatorRender]),ge=F.useMemo(function(){var Ce=t.title,me=Ce===void 0?b7:Ce,$e="".concat(w.prefixCls,"-node-content-wrapper"),Ee;if(w.showIcon){var Ie=t.icon||w.icon;Ee=Ie?F.createElement("span",{className:A("".concat(w.prefixCls,"-iconEle"),"".concat(w.prefixCls,"-icon__customize"))},typeof Ie=="function"?Ie(t):Ie):oe}else w.loadData&&y&&(Ee=oe);var fe;return typeof me=="function"?fe=me(S):w.titleRender?fe=w.titleRender(S):fe=me,F.createElement("span",{ref:P,title:typeof me=="string"?me:"",className:A($e,"".concat($e,"-").concat(ye||"normal"),D({},"".concat(w.prefixCls,"-node-selected"),!j&&(h||N))),onMouseEnter:H,onMouseLeave:W,onContextMenu:K,onClick:G,onDoubleClick:q},Ee,F.createElement("span",{className:"".concat(w.prefixCls,"-title")},fe),ce)},[w.prefixCls,w.showIcon,t,w.icon,oe,w.titleRender,S,ye,H,W,K,G,q]),se=rn(O,{aria:!0,data:!0}),be=kn(w.keyEntities,a)||{},we=be.level,Me=v[v.length-1],Te=!j&&U,Se=w.draggingNodeKey===a,Fe=E!==void 0?{"aria-selected":!!E}:void 0;return F.createElement("div",ue({ref:C,role:"treeitem","aria-expanded":f?void 0:g,className:A(l,"".concat(w.prefixCls,"-treenode"),(o={},D(D(D(D(D(D(D(D(D(D(o,"".concat(w.prefixCls,"-treenode-disabled"),j),"".concat(w.prefixCls,"-treenode-switcher-").concat(g?"open":"close"),!f),"".concat(w.prefixCls,"-treenode-checkbox-checked"),p),"".concat(w.prefixCls,"-treenode-checkbox-indeterminate"),b),"".concat(w.prefixCls,"-treenode-selected"),h),"".concat(w.prefixCls,"-treenode-loading"),y),"".concat(w.prefixCls,"-treenode-active"),$),"".concat(w.prefixCls,"-treenode-leaf-last"),Me),"".concat(w.prefixCls,"-treenode-draggable"),U),"dragging",Se),D(D(D(D(D(D(D(o,"drop-target",w.dropTargetKey===a),"drop-container",w.dropContainerKey===a),"drag-over",!j&&c),"drag-over-gap-top",!j&&u),"drag-over-gap-bottom",!j&&d),"filter-node",(r=w.filterTreeNode)===null||r===void 0?void 0:r.call(w,fn(t))),"".concat(w.prefixCls,"-treenode-leaf"),Z))),style:s,draggable:Te,onDragStart:Te?te:void 0,onDragEnter:U?X:void 0,onDragOver:U?ae:void 0,onDragLeave:U?le:void 0,onDrop:U?Y:void 0,onDragEnd:U?ee:void 0,onMouseMove:x},Fe,se),F.createElement(p7,{prefixCls:w.prefixCls,level:we,isStart:m,isEnd:v}),Q,de(),he,ge)};oi.isTreeNode=1;function Or(e,t){if(!e)return[];var n=e.slice(),r=n.indexOf(t);return r>=0&&n.splice(r,1),n}function Br(e,t){var n=(e||[]).slice();return n.indexOf(t)===-1&&n.push(t),n}function _f(e){return e.split("-")}function y7(e,t){var n=[],r=kn(t,e);function o(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[];a.forEach(function(l){var s=l.key,c=l.children;n.push(s),o(c)})}return o(r.children),n}function C7(e){if(e.parent){var t=_f(e.pos);return Number(t[t.length-1])===e.parent.children.length-1}return!1}function S7(e){var t=_f(e.pos);return Number(t[t.length-1])===0}function pp(e,t,n,r,o,a,l,s,c,u){var d,f=e.clientX,m=e.clientY,v=e.target.getBoundingClientRect(),g=v.top,h=v.height,p=(u==="rtl"?-1:1)*(((o==null?void 0:o.x)||0)-f),b=(p-12)/r,y=c.filter(function(j){var z;return(z=s[j])===null||z===void 0||(z=z.children)===null||z===void 0?void 0:z.length}),C=kn(s,n.eventKey);if(m<g+h/2){var $=l.findIndex(function(j){return j.key===C.key}),S=$<=0?0:$-1,x=l[S].key;C=kn(s,x)}var E=C.key,O=C,w=C.key,I=0,P=0;if(!y.includes(E))for(var M=0;M<b&&C7(C);M+=1)C=C.parent,P+=1;var R=t.data,N=C.node,T=!0;return S7(C)&&C.level===0&&m<g+h/2&&a({dragNode:R,dropNode:N,dropPosition:-1})&&C.key===n.eventKey?I=-1:(O.children||[]).length&&y.includes(w)?a({dragNode:R,dropNode:N,dropPosition:0})?I=0:T=!1:P===0?b>-1.5?a({dragNode:R,dropNode:N,dropPosition:1})?I=1:T=!1:a({dragNode:R,dropNode:N,dropPosition:0})?I=0:a({dragNode:R,dropNode:N,dropPosition:1})?I=1:T=!1:a({dragNode:R,dropNode:N,dropPosition:1})?I=1:T=!1,{dropPosition:I,dropLevelOffset:P,dropTargetKey:C.key,dropTargetPos:C.pos,dragOverNodeKey:w,dropContainerKey:I===0?null:((d=C.parent)===null||d===void 0?void 0:d.key)||null,dropAllowed:T}}function hp(e,t){if(e){var n=t.multiple;return n?e.slice():e.length?[e[0]]:e}}function jc(e){if(!e)return null;var t;if(Array.isArray(e))t={checkedKeys:e,halfCheckedKeys:void 0};else if(Qe(e)==="object")t={checkedKeys:e.checked||void 0,halfCheckedKeys:e.halfChecked||void 0};else return Kt(!1,"`checkedKeys` is not an array or an object"),null;return t}function od(e,t){var n=new Set;function r(o){if(!n.has(o)){var a=kn(t,o);if(a){n.add(o);var l=a.parent,s=a.node;s.disabled||l&&r(l.key)}}}return(e||[]).forEach(function(o){r(o)}),pe(n)}function $7(e){const[t,n]=i.useState(null);return[i.useCallback((a,l,s)=>{const c=t??a,u=Math.min(c||0,a),d=Math.max(c||0,a),f=l.slice(u,d+1).map(g=>e(g)),m=f.some(g=>!s.has(g)),v=[];return f.forEach(g=>{m?(s.has(g)||v.push(g),s.add(g)):(s.delete(g),v.push(g))}),n(m?d:null),v},[t]),a=>{n(a)}]}const qr={},ad="SELECT_ALL",id="SELECT_INVERT",ld="SELECT_NONE",bp=[],iS=(e,t,n=[])=>((t||[]).forEach(r=>{n.push(r),r&&typeof r=="object"&&e in r&&iS(e,r[e],n)}),n),x7=(e,t)=>{const{preserveSelectedRowKeys:n,selectedRowKeys:r,defaultSelectedRowKeys:o,getCheckboxProps:a,getTitleCheckboxProps:l,onChange:s,onSelect:c,onSelectAll:u,onSelectInvert:d,onSelectNone:f,onSelectMultiple:m,columnWidth:v,type:g,selections:h,fixed:p,renderCell:b,hideSelectAll:y,checkStrictly:C=!0}=t||{},{prefixCls:$,data:S,pageData:x,getRecordByKey:E,getRowKey:O,expandType:w,childrenColumnName:I,locale:P,getPopupContainer:M}=e,R=no(),[N,T]=$7(Y=>Y),[j,z]=Lt(r||o||bp,{value:r}),_=i.useRef(new Map),B=i.useCallback(Y=>{if(n){const re=new Map;Y.forEach(ne=>{let Z=E(ne);!Z&&_.current.has(ne)&&(Z=_.current.get(ne)),re.set(ne,Z)}),_.current=re}},[E,n]);i.useEffect(()=>{B(j)},[j]);const V=i.useMemo(()=>iS(I,x),[I,x]),{keyEntities:G}=i.useMemo(()=>{if(C)return{keyEntities:null};let Y=S;if(n){const re=new Set(V.map((Z,Q)=>O(Z,Q))),ne=Array.from(_.current).reduce((Z,[Q,ie])=>re.has(Q)?Z:Z.concat(ie),[]);Y=[].concat(pe(Y),pe(ne))}return yf(Y,{externalGetKey:O,childrenPropName:I})},[S,O,C,I,n,V]),q=i.useMemo(()=>{const Y=new Map;return V.forEach((re,ne)=>{const Z=O(re,ne),Q=(a?a(re):null)||{};Y.set(Z,Q)}),Y},[V,O,a]),H=i.useCallback(Y=>{const re=O(Y);let ne;return q.has(re)?ne=q.get(O(Y)):ne=a?a(Y):void 0,!!(ne!=null&&ne.disabled)},[q,O]),[W,K]=i.useMemo(()=>{if(C)return[j||[],[]];const{checkedKeys:Y,halfCheckedKeys:re}=qo(j,!0,G,H);return[Y||[],re]},[j,C,G,H]),U=i.useMemo(()=>{const Y=g==="radio"?W.slice(0,1):W;return new Set(Y)},[W,g]),te=i.useMemo(()=>g==="radio"?new Set:new Set(K),[K,g]);i.useEffect(()=>{t||z(bp)},[!!t]);const X=i.useCallback((Y,re)=>{let ne,Z;B(Y),n?(ne=Y,Z=Y.map(Q=>_.current.get(Q))):(ne=[],Z=[],Y.forEach(Q=>{const ie=E(Q);ie!==void 0&&(ne.push(Q),Z.push(ie))})),z(ne),s==null||s(ne,Z,{type:re})},[z,E,s,n]),ae=i.useCallback((Y,re,ne,Z)=>{if(c){const Q=ne.map(ie=>E(ie));c(E(Y),re,Q,Z)}X(ne,"single")},[c,E,X]),le=i.useMemo(()=>!h||y?null:(h===!0?[ad,id,ld]:h).map(re=>re===ad?{key:"all",text:P.selectionAll,onSelect(){X(S.map((ne,Z)=>O(ne,Z)).filter(ne=>{const Z=q.get(ne);return!(Z!=null&&Z.disabled)||U.has(ne)}),"all")}}:re===id?{key:"invert",text:P.selectInvert,onSelect(){const ne=new Set(U);x.forEach((Q,ie)=>{const de=O(Q,ie),he=q.get(de);he!=null&&he.disabled||(ne.has(de)?ne.delete(de):ne.add(de))});const Z=Array.from(ne);d&&(R.deprecated(!1,"onSelectInvert","onChange"),d(Z)),X(Z,"invert")}}:re===ld?{key:"none",text:P.selectNone,onSelect(){f==null||f(),X(Array.from(U).filter(ne=>{const Z=q.get(ne);return Z==null?void 0:Z.disabled}),"none")}}:re).map(re=>Object.assign(Object.assign({},re),{onSelect:(...ne)=>{var Z,Q;(Q=re.onSelect)===null||Q===void 0||(Z=Q).call.apply(Z,[re].concat(ne)),T(null)}})),[h,U,x,O,d,X]);return[i.useCallback(Y=>{var re;if(!t)return Y.filter(Ce=>Ce!==qr);let ne=pe(Y);const Z=new Set(U),Q=V.map(O).filter(Ce=>!q.get(Ce).disabled),ie=Q.every(Ce=>Z.has(Ce)),de=Q.some(Ce=>Z.has(Ce)),he=()=>{const Ce=[];ie?Q.forEach($e=>{Z.delete($e),Ce.push($e)}):Q.forEach($e=>{Z.has($e)||(Z.add($e),Ce.push($e))});const me=Array.from(Z);u==null||u(!ie,me.map($e=>E($e)),Ce.map($e=>E($e))),X(me,"all"),T(null)};let ye,oe;if(g!=="radio"){let Ce;if(le){const Re={getPopupContainer:M,items:le.map((it,dt)=>{const{key:Oe,text:Le,onSelect:Ue}=it;return{key:Oe??dt,onClick:()=>{Ue==null||Ue(Q)},label:Le}})};Ce=i.createElement("div",{className:`${$}-selection-extra`},i.createElement(Of,{menu:Re,getPopupContainer:M},i.createElement("span",null,i.createElement(ef,null))))}const me=V.map((Re,it)=>{const dt=O(Re,it),Oe=q.get(dt)||{};return Object.assign({checked:Z.has(dt)},Oe)}).filter(({disabled:Re})=>Re),$e=!!me.length&&me.length===V.length,Ee=$e&&me.every(({checked:Re})=>Re),Ie=$e&&me.some(({checked:Re})=>Re),fe=(l==null?void 0:l())||{},{onChange:ve,disabled:xe}=fe;oe=i.createElement(sa,Object.assign({"aria-label":Ce?"Custom selection":"Select all"},fe,{checked:$e?Ee:!!V.length&&ie,indeterminate:$e?!Ee&&Ie:!ie&&de,onChange:Re=>{he(),ve==null||ve(Re)},disabled:xe??(V.length===0||$e),skipGroup:!0})),ye=!y&&i.createElement("div",{className:`${$}-selection`},oe,Ce)}let ce;g==="radio"?ce=(Ce,me,$e)=>{const Ee=O(me,$e),Ie=Z.has(Ee),fe=q.get(Ee);return{node:i.createElement(Si,Object.assign({},fe,{checked:Ie,onClick:ve=>{var xe;ve.stopPropagation(),(xe=fe==null?void 0:fe.onClick)===null||xe===void 0||xe.call(fe,ve)},onChange:ve=>{var xe;Z.has(Ee)||ae(Ee,!0,[Ee],ve.nativeEvent),(xe=fe==null?void 0:fe.onChange)===null||xe===void 0||xe.call(fe,ve)}})),checked:Ie}}:ce=(Ce,me,$e)=>{var Ee;const Ie=O(me,$e),fe=Z.has(Ie),ve=te.has(Ie),xe=q.get(Ie);let Re;return w==="nest"?Re=ve:Re=(Ee=xe==null?void 0:xe.indeterminate)!==null&&Ee!==void 0?Ee:ve,{node:i.createElement(sa,Object.assign({},xe,{indeterminate:Re,checked:fe,skipGroup:!0,onClick:it=>{var dt;it.stopPropagation(),(dt=xe==null?void 0:xe.onClick)===null||dt===void 0||dt.call(xe,it)},onChange:it=>{var dt;const{nativeEvent:Oe}=it,{shiftKey:Le}=Oe,Ue=Q.findIndex(Je=>Je===Ie),ke=W.some(Je=>Q.includes(Je));if(Le&&C&&ke){const Je=N(Ue,Q,Z),Xe=Array.from(Z);m==null||m(!fe,Xe.map(He=>E(He)),Je.map(He=>E(He))),X(Xe,"multiple")}else{const Je=W;if(C){const Xe=fe?Or(Je,Ie):Br(Je,Ie);ae(Ie,!fe,Xe,Oe)}else{const Xe=qo([].concat(pe(Je),[Ie]),!0,G,H),{checkedKeys:He,halfCheckedKeys:je}=Xe;let rt=He;if(fe){const et=new Set(He);et.delete(Ie),rt=qo(Array.from(et),{halfCheckedKeys:je},G,H).checkedKeys}ae(Ie,!fe,rt,Oe)}}T(fe?null:Ue),(dt=xe==null?void 0:xe.onChange)===null||dt===void 0||dt.call(xe,it)}})),checked:fe}};const ge=(Ce,me,$e)=>{const{node:Ee,checked:Ie}=ce(Ce,me,$e);return b?b(Ie,me,$e,Ee):Ee};if(!ne.includes(qr))if(ne.findIndex(Ce=>{var me;return((me=Ce[Va])===null||me===void 0?void 0:me.columnType)==="EXPAND_COLUMN"})===0){const[Ce,...me]=ne;ne=[Ce,qr].concat(pe(me))}else ne=[qr].concat(pe(ne));const se=ne.indexOf(qr);ne=ne.filter((Ce,me)=>Ce!==qr||me===se);const be=ne[se-1],we=ne[se+1];let Me=p;Me===void 0&&((we==null?void 0:we.fixed)!==void 0?Me=we.fixed:(be==null?void 0:be.fixed)!==void 0&&(Me=be.fixed)),Me&&be&&((re=be[Va])===null||re===void 0?void 0:re.columnType)==="EXPAND_COLUMN"&&be.fixed===void 0&&(be.fixed=Me);const Te=A(`${$}-selection-col`,{[`${$}-selection-col-with-dropdown`]:h&&g==="checkbox"}),Se=()=>t!=null&&t.columnTitle?typeof t.columnTitle=="function"?t.columnTitle(oe):t.columnTitle:ye,Fe={fixed:Me,width:v,className:`${$}-selection-column`,title:Se(),render:ge,onCell:t.onCell,align:t.align,[Va]:{className:Te}};return ne.map(Ce=>Ce===qr?Fe:Ce)},[O,V,t,W,U,te,v,le,w,q,m,ae,H]),U]};function w7(e,t){return e._antProxy=e._antProxy||{},Object.keys(t).forEach(n=>{if(!(n in e._antProxy)){const r=e[n];e._antProxy[n]=r,e[n]=t[n]}}),e}function E7(e,t){return i.useImperativeHandle(e,()=>{const n=t(),{nativeElement:r}=n;return typeof Proxy<"u"?new Proxy(r,{get(o,a){return n[a]?n[a]:Reflect.get(o,a)}}):w7(r,n)})}function O7(e){return t=>{const{prefixCls:n,onExpand:r,record:o,expanded:a,expandable:l}=t,s=`${n}-row-expand-icon`;return i.createElement("button",{type:"button",onClick:c=>{r(o,c),c.stopPropagation()},className:A(s,{[`${s}-spaced`]:!l,[`${s}-expanded`]:l&&a,[`${s}-collapsed`]:l&&!a}),"aria-label":a?e.collapse:e.expand,"aria-expanded":a})}}function I7(e){return(n,r)=>{const o=n.querySelector(`.${e}-container`);let a=r;if(o){const l=getComputedStyle(o),s=parseInt(l.borderLeftWidth,10),c=parseInt(l.borderRightWidth,10);a=r-s-c}return a}}const to=(e,t)=>"key"in e&&e.key!==void 0&&e.key!==null?e.key:e.dataIndex?Array.isArray(e.dataIndex)?e.dataIndex.join("."):e.dataIndex:t;function wa(e,t){return t?`${t}-${e}`:`${e}`}const Ls=(e,t)=>typeof e=="function"?e(t):e,R7=(e,t)=>{const n=Ls(e,t);return Object.prototype.toString.call(n)==="[object Object]"?"":n};function P7(e){const t=i.useRef(e),n=nf();return[()=>t.current,r=>{t.current=r,n()}]}var N7=function(t){var n=t.dropPosition,r=t.dropLevelOffset,o=t.indent,a={pointerEvents:"none",position:"absolute",right:0,backgroundColor:"red",height:2};switch(n){case-1:a.top=0,a.left=-r*o;break;case 1:a.bottom=0,a.left=-r*o;break;case 0:a.bottom=0,a.left=o;break}return F.createElement("div",{style:a})};function lS(e){if(e==null)throw new TypeError("Cannot destructure "+e)}function M7(e,t){var n=i.useState(!1),r=J(n,2),o=r[0],a=r[1];wt(function(){if(o)return e(),function(){t()}},[o]),wt(function(){return a(!0),function(){a(!1)}},[])}var T7=["className","style","motion","motionNodes","motionType","onMotionStart","onMotionEnd","active","treeNodeRequiredProps"],j7=i.forwardRef(function(e,t){var n=e.className,r=e.style,o=e.motion,a=e.motionNodes,l=e.motionType,s=e.onMotionStart,c=e.onMotionEnd,u=e.active,d=e.treeNodeRequiredProps,f=ft(e,T7),m=i.useState(!0),v=J(m,2),g=v[0],h=v[1],p=i.useContext(Df),b=p.prefixCls,y=a&&l!=="hide";wt(function(){a&&y!==g&&h(y)},[a]);var C=function(){a&&s()},$=i.useRef(!1),S=function(){a&&!$.current&&($.current=!0,c())};M7(C,S);var x=function(O){y===O&&S()};return a?i.createElement(En,ue({ref:t,visible:g},o,{motionAppear:l==="show",onVisibleChanged:x}),function(E,O){var w=E.className,I=E.style;return i.createElement("div",{ref:O,className:A("".concat(b,"-treenode-motion"),w),style:I},a.map(function(P){var M=Object.assign({},(lS(P.data),P.data)),R=P.title,N=P.key,T=P.isStart,j=P.isEnd;delete M.children;var z=ka(N,d);return i.createElement(oi,ue({},M,z,{title:R,active:u,data:P.data,key:N,isStart:T,isEnd:j}))}))}):i.createElement(oi,ue({domRef:t,className:n,style:r},f,{active:u}))});function z7(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],n=e.length,r=t.length;if(Math.abs(n-r)!==1)return{add:!1,key:null};function o(a,l){var s=new Map;a.forEach(function(u){s.set(u,!0)});var c=l.filter(function(u){return!s.has(u)});return c.length===1?c[0]:null}return n<r?{add:!0,key:o(e,t)}:{add:!1,key:o(t,e)}}function yp(e,t,n){var r=e.findIndex(function(s){return s.key===n}),o=e[r+1],a=t.findIndex(function(s){return s.key===n});if(o){var l=t.findIndex(function(s){return s.key===o.key});return t.slice(a+1,l)}return t.slice(a+1)}var D7=["prefixCls","data","selectable","checkable","expandedKeys","selectedKeys","checkedKeys","loadedKeys","loadingKeys","halfCheckedKeys","keyEntities","disabled","dragging","dragOverNodeKey","dropPosition","motion","height","itemHeight","virtual","scrollWidth","focusable","activeItem","focused","tabIndex","onKeyDown","onFocus","onBlur","onActiveChange","onListChangeStart","onListChangeEnd"],Cp={width:0,height:0,display:"flex",overflow:"hidden",opacity:0,border:0,padding:0,margin:0},_7=function(){},Co="RC_TREE_MOTION_".concat(Math.random()),sd={key:Co},sS={key:Co,level:0,index:0,pos:"0",node:sd,nodes:[sd]},Sp={parent:null,children:[],pos:sS.pos,data:sd,title:null,key:Co,isStart:[],isEnd:[]};function $p(e,t,n,r){return t===!1||!n?e:e.slice(0,Math.ceil(n/r)+1)}function xp(e){var t=e.key,n=e.pos;return xi(t,n)}function B7(e){for(var t=String(e.data.key),n=e;n.parent;)n=n.parent,t="".concat(n.data.key," > ").concat(t);return t}var L7=i.forwardRef(function(e,t){var n=e.prefixCls,r=e.data;e.selectable,e.checkable;var o=e.expandedKeys,a=e.selectedKeys,l=e.checkedKeys,s=e.loadedKeys,c=e.loadingKeys,u=e.halfCheckedKeys,d=e.keyEntities,f=e.disabled,m=e.dragging,v=e.dragOverNodeKey,g=e.dropPosition,h=e.motion,p=e.height,b=e.itemHeight,y=e.virtual,C=e.scrollWidth,$=e.focusable,S=e.activeItem,x=e.focused,E=e.tabIndex,O=e.onKeyDown,w=e.onFocus,I=e.onBlur,P=e.onActiveChange,M=e.onListChangeStart,R=e.onListChangeEnd,N=ft(e,D7),T=i.useRef(null),j=i.useRef(null);i.useImperativeHandle(t,function(){return{scrollTo:function(ce){T.current.scrollTo(ce)},getIndentWidth:function(){return j.current.offsetWidth}}});var z=i.useState(o),_=J(z,2),B=_[0],V=_[1],G=i.useState(r),q=J(G,2),H=q[0],W=q[1],K=i.useState(r),U=J(K,2),te=U[0],X=U[1],ae=i.useState([]),le=J(ae,2),ee=le[0],Y=le[1],re=i.useState(null),ne=J(re,2),Z=ne[0],Q=ne[1],ie=i.useRef(r);ie.current=r;function de(){var oe=ie.current;W(oe),X(oe),Y([]),Q(null),R()}wt(function(){V(o);var oe=z7(B,o);if(oe.key!==null)if(oe.add){var ce=H.findIndex(function(Te){var Se=Te.key;return Se===oe.key}),ge=$p(yp(H,r,oe.key),y,p,b),se=H.slice();se.splice(ce+1,0,Sp),X(se),Y(ge),Q("show")}else{var be=r.findIndex(function(Te){var Se=Te.key;return Se===oe.key}),we=$p(yp(r,H,oe.key),y,p,b),Me=r.slice();Me.splice(be+1,0,Sp),X(Me),Y(we),Q("hide")}else H!==r&&(W(r),X(r))},[o,r]),i.useEffect(function(){m||de()},[m]);var he=h?te:r,ye={expandedKeys:o,selectedKeys:a,loadedKeys:s,loadingKeys:c,checkedKeys:l,halfCheckedKeys:u,dragOverNodeKey:v,dropPosition:g,keyEntities:d};return i.createElement(i.Fragment,null,x&&S&&i.createElement("span",{style:Cp,"aria-live":"assertive"},B7(S)),i.createElement("div",null,i.createElement("input",{style:Cp,disabled:$===!1||f,tabIndex:$!==!1?E:null,onKeyDown:O,onFocus:w,onBlur:I,value:"",onChange:_7,"aria-label":"for screen reader"})),i.createElement("div",{className:"".concat(n,"-treenode"),"aria-hidden":!0,style:{position:"absolute",pointerEvents:"none",visibility:"hidden",height:0,overflow:"hidden",border:0,padding:0}},i.createElement("div",{className:"".concat(n,"-indent")},i.createElement("div",{ref:j,className:"".concat(n,"-indent-unit")}))),i.createElement($s,ue({},N,{data:he,itemKey:xp,height:p,fullHeight:!1,virtual:y,itemHeight:b,scrollWidth:C,prefixCls:"".concat(n,"-list"),ref:T,role:"tree",onVisibleChange:function(ce){ce.every(function(ge){return xp(ge)!==Co})&&de()}}),function(oe){var ce=oe.pos,ge=Object.assign({},(lS(oe.data),oe.data)),se=oe.title,be=oe.key,we=oe.isStart,Me=oe.isEnd,Te=xi(be,ce);delete ge.key,delete ge.children;var Se=ka(Te,ye);return i.createElement(j7,ue({},ge,Se,{title:se,active:!!S&&be===S.key,pos:ce,data:oe.data,isStart:we,isEnd:Me,motion:h,motionNodes:be===Co?ee:null,motionType:Z,onMotionStart:M,onMotionEnd:de,treeNodeRequiredProps:ye,onMouseMove:function(){P(null)}}))}))}),H7=10,Bf=function(e){tr(n,e);var t=ur(n);function n(){var r;Zt(this,n);for(var o=arguments.length,a=new Array(o),l=0;l<o;l++)a[l]=arguments[l];return r=t.call.apply(t,[this].concat(a)),D(Ve(r),"destroyed",!1),D(Ve(r),"delayedDragEnterLogic",void 0),D(Ve(r),"loadingRetryTimes",{}),D(Ve(r),"state",{keyEntities:{},indent:null,selectedKeys:[],checkedKeys:[],halfCheckedKeys:[],loadedKeys:[],loadingKeys:[],expandedKeys:[],draggingNodeKey:null,dragChildrenKeys:[],dropTargetKey:null,dropPosition:null,dropContainerKey:null,dropLevelOffset:null,dropTargetPos:null,dropAllowed:!0,dragOverNodeKey:null,treeData:[],flattenNodes:[],focused:!1,activeKey:null,listChanging:!1,prevProps:null,fieldNames:la()}),D(Ve(r),"dragStartMousePosition",null),D(Ve(r),"dragNodeProps",null),D(Ve(r),"currentMouseOverDroppableNodeKey",null),D(Ve(r),"listRef",i.createRef()),D(Ve(r),"onNodeDragStart",function(s,c){var u=r.state,d=u.expandedKeys,f=u.keyEntities,m=r.props.onDragStart,v=c.eventKey;r.dragNodeProps=c,r.dragStartMousePosition={x:s.clientX,y:s.clientY};var g=Or(d,v);r.setState({draggingNodeKey:v,dragChildrenKeys:y7(v,f),indent:r.listRef.current.getIndentWidth()}),r.setExpandedKeys(g),window.addEventListener("dragend",r.onWindowDragEnd),m==null||m({event:s,node:fn(c)})}),D(Ve(r),"onNodeDragEnter",function(s,c){var u=r.state,d=u.expandedKeys,f=u.keyEntities,m=u.dragChildrenKeys,v=u.flattenNodes,g=u.indent,h=r.props,p=h.onDragEnter,b=h.onExpand,y=h.allowDrop,C=h.direction,$=c.pos,S=c.eventKey;if(r.currentMouseOverDroppableNodeKey!==S&&(r.currentMouseOverDroppableNodeKey=S),!r.dragNodeProps){r.resetDragState();return}var x=pp(s,r.dragNodeProps,c,g,r.dragStartMousePosition,y,v,f,d,C),E=x.dropPosition,O=x.dropLevelOffset,w=x.dropTargetKey,I=x.dropContainerKey,P=x.dropTargetPos,M=x.dropAllowed,R=x.dragOverNodeKey;if(m.includes(w)||!M){r.resetDragState();return}if(r.delayedDragEnterLogic||(r.delayedDragEnterLogic={}),Object.keys(r.delayedDragEnterLogic).forEach(function(N){clearTimeout(r.delayedDragEnterLogic[N])}),r.dragNodeProps.eventKey!==c.eventKey&&(s.persist(),r.delayedDragEnterLogic[$]=window.setTimeout(function(){if(r.state.draggingNodeKey!==null){var N=pe(d),T=kn(f,c.eventKey);T&&(T.children||[]).length&&(N=Br(d,c.eventKey)),r.props.hasOwnProperty("expandedKeys")||r.setExpandedKeys(N),b==null||b(N,{node:fn(c),expanded:!0,nativeEvent:s.nativeEvent})}},800)),r.dragNodeProps.eventKey===w&&O===0){r.resetDragState();return}r.setState({dragOverNodeKey:R,dropPosition:E,dropLevelOffset:O,dropTargetKey:w,dropContainerKey:I,dropTargetPos:P,dropAllowed:M}),p==null||p({event:s,node:fn(c),expandedKeys:d})}),D(Ve(r),"onNodeDragOver",function(s,c){var u=r.state,d=u.dragChildrenKeys,f=u.flattenNodes,m=u.keyEntities,v=u.expandedKeys,g=u.indent,h=r.props,p=h.onDragOver,b=h.allowDrop,y=h.direction;if(r.dragNodeProps){var C=pp(s,r.dragNodeProps,c,g,r.dragStartMousePosition,b,f,m,v,y),$=C.dropPosition,S=C.dropLevelOffset,x=C.dropTargetKey,E=C.dropContainerKey,O=C.dropTargetPos,w=C.dropAllowed,I=C.dragOverNodeKey;d.includes(x)||!w||(r.dragNodeProps.eventKey===x&&S===0?r.state.dropPosition===null&&r.state.dropLevelOffset===null&&r.state.dropTargetKey===null&&r.state.dropContainerKey===null&&r.state.dropTargetPos===null&&r.state.dropAllowed===!1&&r.state.dragOverNodeKey===null||r.resetDragState():$===r.state.dropPosition&&S===r.state.dropLevelOffset&&x===r.state.dropTargetKey&&E===r.state.dropContainerKey&&O===r.state.dropTargetPos&&w===r.state.dropAllowed&&I===r.state.dragOverNodeKey||r.setState({dropPosition:$,dropLevelOffset:S,dropTargetKey:x,dropContainerKey:E,dropTargetPos:O,dropAllowed:w,dragOverNodeKey:I}),p==null||p({event:s,node:fn(c)}))}}),D(Ve(r),"onNodeDragLeave",function(s,c){r.currentMouseOverDroppableNodeKey===c.eventKey&&!s.currentTarget.contains(s.relatedTarget)&&(r.resetDragState(),r.currentMouseOverDroppableNodeKey=null);var u=r.props.onDragLeave;u==null||u({event:s,node:fn(c)})}),D(Ve(r),"onWindowDragEnd",function(s){r.onNodeDragEnd(s,null,!0),window.removeEventListener("dragend",r.onWindowDragEnd)}),D(Ve(r),"onNodeDragEnd",function(s,c){var u=r.props.onDragEnd;r.setState({dragOverNodeKey:null}),r.cleanDragState(),u==null||u({event:s,node:fn(c)}),r.dragNodeProps=null,window.removeEventListener("dragend",r.onWindowDragEnd)}),D(Ve(r),"onNodeDrop",function(s,c){var u,d=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1,f=r.state,m=f.dragChildrenKeys,v=f.dropPosition,g=f.dropTargetKey,h=f.dropTargetPos,p=f.dropAllowed;if(p){var b=r.props.onDrop;if(r.setState({dragOverNodeKey:null}),r.cleanDragState(),g!==null){var y=k(k({},ka(g,r.getTreeNodeRequiredProps())),{},{active:((u=r.getActiveItem())===null||u===void 0?void 0:u.key)===g,data:kn(r.state.keyEntities,g).node}),C=m.includes(g);Kt(!C,"Can not drop to dragNode's children node. This is a bug of rc-tree. Please report an issue.");var $=_f(h),S={event:s,node:fn(y),dragNode:r.dragNodeProps?fn(r.dragNodeProps):null,dragNodesKeys:[r.dragNodeProps.eventKey].concat(m),dropToGap:v!==0,dropPosition:v+Number($[$.length-1])};d||b==null||b(S),r.dragNodeProps=null}}}),D(Ve(r),"cleanDragState",function(){var s=r.state.draggingNodeKey;s!==null&&r.setState({draggingNodeKey:null,dropPosition:null,dropContainerKey:null,dropTargetKey:null,dropLevelOffset:null,dropAllowed:!0,dragOverNodeKey:null}),r.dragStartMousePosition=null,r.currentMouseOverDroppableNodeKey=null}),D(Ve(r),"triggerExpandActionExpand",function(s,c){var u=r.state,d=u.expandedKeys,f=u.flattenNodes,m=c.expanded,v=c.key,g=c.isLeaf;if(!(g||s.shiftKey||s.metaKey||s.ctrlKey)){var h=f.filter(function(b){return b.key===v})[0],p=fn(k(k({},ka(v,r.getTreeNodeRequiredProps())),{},{data:h.data}));r.setExpandedKeys(m?Or(d,v):Br(d,v)),r.onNodeExpand(s,p)}}),D(Ve(r),"onNodeClick",function(s,c){var u=r.props,d=u.onClick,f=u.expandAction;f==="click"&&r.triggerExpandActionExpand(s,c),d==null||d(s,c)}),D(Ve(r),"onNodeDoubleClick",function(s,c){var u=r.props,d=u.onDoubleClick,f=u.expandAction;f==="doubleClick"&&r.triggerExpandActionExpand(s,c),d==null||d(s,c)}),D(Ve(r),"onNodeSelect",function(s,c){var u=r.state.selectedKeys,d=r.state,f=d.keyEntities,m=d.fieldNames,v=r.props,g=v.onSelect,h=v.multiple,p=c.selected,b=c[m.key],y=!p;y?h?u=Br(u,b):u=[b]:u=Or(u,b);var C=u.map(function($){var S=kn(f,$);return S?S.node:null}).filter(Boolean);r.setUncontrolledState({selectedKeys:u}),g==null||g(u,{event:"select",selected:y,node:c,selectedNodes:C,nativeEvent:s.nativeEvent})}),D(Ve(r),"onNodeCheck",function(s,c,u){var d=r.state,f=d.keyEntities,m=d.checkedKeys,v=d.halfCheckedKeys,g=r.props,h=g.checkStrictly,p=g.onCheck,b=c.key,y,C={event:"check",node:c,checked:u,nativeEvent:s.nativeEvent};if(h){var $=u?Br(m,b):Or(m,b),S=Or(v,b);y={checked:$,halfChecked:S},C.checkedNodes=$.map(function(P){return kn(f,P)}).filter(Boolean).map(function(P){return P.node}),r.setUncontrolledState({checkedKeys:$})}else{var x=qo([].concat(pe(m),[b]),!0,f),E=x.checkedKeys,O=x.halfCheckedKeys;if(!u){var w=new Set(E);w.delete(b);var I=qo(Array.from(w),{halfCheckedKeys:O},f);E=I.checkedKeys,O=I.halfCheckedKeys}y=E,C.checkedNodes=[],C.checkedNodesPositions=[],C.halfCheckedKeys=O,E.forEach(function(P){var M=kn(f,P);if(M){var R=M.node,N=M.pos;C.checkedNodes.push(R),C.checkedNodesPositions.push({node:R,pos:N})}}),r.setUncontrolledState({checkedKeys:E},!1,{halfCheckedKeys:O})}p==null||p(y,C)}),D(Ve(r),"onNodeLoad",function(s){var c,u=s.key,d=r.state.keyEntities,f=kn(d,u);if(!(f!=null&&(c=f.children)!==null&&c!==void 0&&c.length)){var m=new Promise(function(v,g){r.setState(function(h){var p=h.loadedKeys,b=p===void 0?[]:p,y=h.loadingKeys,C=y===void 0?[]:y,$=r.props,S=$.loadData,x=$.onLoad;if(!S||b.includes(u)||C.includes(u))return null;var E=S(s);return E.then(function(){var O=r.state.loadedKeys,w=Br(O,u);x==null||x(w,{event:"load",node:s}),r.setUncontrolledState({loadedKeys:w}),r.setState(function(I){return{loadingKeys:Or(I.loadingKeys,u)}}),v()}).catch(function(O){if(r.setState(function(I){return{loadingKeys:Or(I.loadingKeys,u)}}),r.loadingRetryTimes[u]=(r.loadingRetryTimes[u]||0)+1,r.loadingRetryTimes[u]>=H7){var w=r.state.loadedKeys;Kt(!1,"Retry for `loadData` many times but still failed. No more retry."),r.setUncontrolledState({loadedKeys:Br(w,u)}),v()}g(O)}),{loadingKeys:Br(C,u)}})});return m.catch(function(){}),m}}),D(Ve(r),"onNodeMouseEnter",function(s,c){var u=r.props.onMouseEnter;u==null||u({event:s,node:c})}),D(Ve(r),"onNodeMouseLeave",function(s,c){var u=r.props.onMouseLeave;u==null||u({event:s,node:c})}),D(Ve(r),"onNodeContextMenu",function(s,c){var u=r.props.onRightClick;u&&(s.preventDefault(),u({event:s,node:c}))}),D(Ve(r),"onFocus",function(){var s=r.props.onFocus;r.setState({focused:!0});for(var c=arguments.length,u=new Array(c),d=0;d<c;d++)u[d]=arguments[d];s==null||s.apply(void 0,u)}),D(Ve(r),"onBlur",function(){var s=r.props.onBlur;r.setState({focused:!1}),r.onActiveChange(null);for(var c=arguments.length,u=new Array(c),d=0;d<c;d++)u[d]=arguments[d];s==null||s.apply(void 0,u)}),D(Ve(r),"getTreeNodeRequiredProps",function(){var s=r.state,c=s.expandedKeys,u=s.selectedKeys,d=s.loadedKeys,f=s.loadingKeys,m=s.checkedKeys,v=s.halfCheckedKeys,g=s.dragOverNodeKey,h=s.dropPosition,p=s.keyEntities;return{expandedKeys:c||[],selectedKeys:u||[],loadedKeys:d||[],loadingKeys:f||[],checkedKeys:m||[],halfCheckedKeys:v||[],dragOverNodeKey:g,dropPosition:h,keyEntities:p}}),D(Ve(r),"setExpandedKeys",function(s){var c=r.state,u=c.treeData,d=c.fieldNames,f=xc(u,s,d);r.setUncontrolledState({expandedKeys:s,flattenNodes:f},!0)}),D(Ve(r),"onNodeExpand",function(s,c){var u=r.state.expandedKeys,d=r.state,f=d.listChanging,m=d.fieldNames,v=r.props,g=v.onExpand,h=v.loadData,p=c.expanded,b=c[m.key];if(!f){var y=u.includes(b),C=!p;if(Kt(p&&y||!p&&!y,"Expand state not sync with index check"),u=C?Br(u,b):Or(u,b),r.setExpandedKeys(u),g==null||g(u,{node:c,expanded:C,nativeEvent:s.nativeEvent}),C&&h){var $=r.onNodeLoad(c);$&&$.then(function(){var S=xc(r.state.treeData,u,m);r.setUncontrolledState({flattenNodes:S})}).catch(function(){var S=r.state.expandedKeys,x=Or(S,b);r.setExpandedKeys(x)})}}}),D(Ve(r),"onListChangeStart",function(){r.setUncontrolledState({listChanging:!0})}),D(Ve(r),"onListChangeEnd",function(){setTimeout(function(){r.setUncontrolledState({listChanging:!1})})}),D(Ve(r),"onActiveChange",function(s){var c=r.state.activeKey,u=r.props,d=u.onActiveChange,f=u.itemScrollOffset,m=f===void 0?0:f;c!==s&&(r.setState({activeKey:s}),s!==null&&r.scrollTo({key:s,offset:m}),d==null||d(s))}),D(Ve(r),"getActiveItem",function(){var s=r.state,c=s.activeKey,u=s.flattenNodes;return c===null?null:u.find(function(d){var f=d.key;return f===c})||null}),D(Ve(r),"offsetActiveKey",function(s){var c=r.state,u=c.flattenNodes,d=c.activeKey,f=u.findIndex(function(g){var h=g.key;return h===d});f===-1&&s<0&&(f=u.length),f=(f+s+u.length)%u.length;var m=u[f];if(m){var v=m.key;r.onActiveChange(v)}else r.onActiveChange(null)}),D(Ve(r),"onKeyDown",function(s){var c=r.state,u=c.activeKey,d=c.expandedKeys,f=c.checkedKeys,m=c.fieldNames,v=r.props,g=v.onKeyDown,h=v.checkable,p=v.selectable;switch(s.which){case Ne.UP:{r.offsetActiveKey(-1),s.preventDefault();break}case Ne.DOWN:{r.offsetActiveKey(1),s.preventDefault();break}}var b=r.getActiveItem();if(b&&b.data){var y=r.getTreeNodeRequiredProps(),C=b.data.isLeaf===!1||!!(b.data[m.children]||[]).length,$=fn(k(k({},ka(u,y)),{},{data:b.data,active:!0}));switch(s.which){case Ne.LEFT:{C&&d.includes(u)?r.onNodeExpand({},$):b.parent&&r.onActiveChange(b.parent.key),s.preventDefault();break}case Ne.RIGHT:{C&&!d.includes(u)?r.onNodeExpand({},$):b.children&&b.children.length&&r.onActiveChange(b.children[0].key),s.preventDefault();break}case Ne.ENTER:case Ne.SPACE:{h&&!$.disabled&&$.checkable!==!1&&!$.disableCheckbox?r.onNodeCheck({},$,!f.includes(u)):!h&&p&&!$.disabled&&$.selectable!==!1&&r.onNodeSelect({},$);break}}}g==null||g(s)}),D(Ve(r),"setUncontrolledState",function(s){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:null;if(!r.destroyed){var d=!1,f=!0,m={};Object.keys(s).forEach(function(v){if(r.props.hasOwnProperty(v)){f=!1;return}d=!0,m[v]=s[v]}),d&&(!c||f)&&r.setState(k(k({},m),u))}}),D(Ve(r),"scrollTo",function(s){r.listRef.current.scrollTo(s)}),r}return Jt(n,[{key:"componentDidMount",value:function(){this.destroyed=!1,this.onUpdated()}},{key:"componentDidUpdate",value:function(){this.onUpdated()}},{key:"onUpdated",value:function(){var o=this.props,a=o.activeKey,l=o.itemScrollOffset,s=l===void 0?0:l;a!==void 0&&a!==this.state.activeKey&&(this.setState({activeKey:a}),a!==null&&this.scrollTo({key:a,offset:s}))}},{key:"componentWillUnmount",value:function(){window.removeEventListener("dragend",this.onWindowDragEnd),this.destroyed=!0}},{key:"resetDragState",value:function(){this.setState({dragOverNodeKey:null,dropPosition:null,dropLevelOffset:null,dropTargetKey:null,dropContainerKey:null,dropTargetPos:null,dropAllowed:!1})}},{key:"render",value:function(){var o=this.state,a=o.focused,l=o.flattenNodes,s=o.keyEntities,c=o.draggingNodeKey,u=o.activeKey,d=o.dropLevelOffset,f=o.dropContainerKey,m=o.dropTargetKey,v=o.dropPosition,g=o.dragOverNodeKey,h=o.indent,p=this.props,b=p.prefixCls,y=p.className,C=p.style,$=p.showLine,S=p.focusable,x=p.tabIndex,E=x===void 0?0:x,O=p.selectable,w=p.showIcon,I=p.icon,P=p.switcherIcon,M=p.draggable,R=p.checkable,N=p.checkStrictly,T=p.disabled,j=p.motion,z=p.loadData,_=p.filterTreeNode,B=p.height,V=p.itemHeight,G=p.scrollWidth,q=p.virtual,H=p.titleRender,W=p.dropIndicatorRender,K=p.onContextMenu,U=p.onScroll,te=p.direction,X=p.rootClassName,ae=p.rootStyle,le=rn(this.props,{aria:!0,data:!0}),ee;M&&(Qe(M)==="object"?ee=M:typeof M=="function"?ee={nodeDraggable:M}:ee={});var Y={prefixCls:b,selectable:O,showIcon:w,icon:I,switcherIcon:P,draggable:ee,draggingNodeKey:c,checkable:R,checkStrictly:N,disabled:T,keyEntities:s,dropLevelOffset:d,dropContainerKey:f,dropTargetKey:m,dropPosition:v,dragOverNodeKey:g,indent:h,direction:te,dropIndicatorRender:W,loadData:z,filterTreeNode:_,titleRender:H,onNodeClick:this.onNodeClick,onNodeDoubleClick:this.onNodeDoubleClick,onNodeExpand:this.onNodeExpand,onNodeSelect:this.onNodeSelect,onNodeCheck:this.onNodeCheck,onNodeLoad:this.onNodeLoad,onNodeMouseEnter:this.onNodeMouseEnter,onNodeMouseLeave:this.onNodeMouseLeave,onNodeContextMenu:this.onNodeContextMenu,onNodeDragStart:this.onNodeDragStart,onNodeDragEnter:this.onNodeDragEnter,onNodeDragOver:this.onNodeDragOver,onNodeDragLeave:this.onNodeDragLeave,onNodeDragEnd:this.onNodeDragEnd,onNodeDrop:this.onNodeDrop};return i.createElement(Df.Provider,{value:Y},i.createElement("div",{className:A(b,y,X,D(D(D({},"".concat(b,"-show-line"),$),"".concat(b,"-focused"),a),"".concat(b,"-active-focused"),u!==null)),style:ae},i.createElement(L7,ue({ref:this.listRef,prefixCls:b,style:C,data:l,disabled:T,selectable:O,checkable:!!R,motion:j,dragging:c!==null,height:B,itemHeight:V,virtual:q,focusable:S,focused:a,tabIndex:E,activeItem:this.getActiveItem(),onFocus:this.onFocus,onBlur:this.onBlur,onKeyDown:this.onKeyDown,onActiveChange:this.onActiveChange,onListChangeStart:this.onListChangeStart,onListChangeEnd:this.onListChangeEnd,onContextMenu:K,onScroll:U,scrollWidth:G},this.getTreeNodeRequiredProps(),le))))}}],[{key:"getDerivedStateFromProps",value:function(o,a){var l=a.prevProps,s={prevProps:o};function c(E){return!l&&o.hasOwnProperty(E)||l&&l[E]!==o[E]}var u,d=a.fieldNames;if(c("fieldNames")&&(d=la(o.fieldNames),s.fieldNames=d),c("treeData")?u=o.treeData:c("children")&&(Kt(!1,"`children` of Tree is deprecated. Please use `treeData` instead."),u=qy(o.children)),u){s.treeData=u;var f=yf(u,{fieldNames:d});s.keyEntities=k(D({},Co,sS),f.keyEntities)}var m=s.keyEntities||a.keyEntities;if(c("expandedKeys")||l&&c("autoExpandParent"))s.expandedKeys=o.autoExpandParent||!l&&o.defaultExpandParent?od(o.expandedKeys,m):o.expandedKeys;else if(!l&&o.defaultExpandAll){var v=k({},m);delete v[Co];var g=[];Object.keys(v).forEach(function(E){var O=v[E];O.children&&O.children.length&&g.push(O.key)}),s.expandedKeys=g}else!l&&o.defaultExpandedKeys&&(s.expandedKeys=o.autoExpandParent||o.defaultExpandParent?od(o.defaultExpandedKeys,m):o.defaultExpandedKeys);if(s.expandedKeys||delete s.expandedKeys,u||s.expandedKeys){var h=xc(u||a.treeData,s.expandedKeys||a.expandedKeys,d);s.flattenNodes=h}if(o.selectable&&(c("selectedKeys")?s.selectedKeys=hp(o.selectedKeys,o):!l&&o.defaultSelectedKeys&&(s.selectedKeys=hp(o.defaultSelectedKeys,o))),o.checkable){var p;if(c("checkedKeys")?p=jc(o.checkedKeys)||{}:!l&&o.defaultCheckedKeys?p=jc(o.defaultCheckedKeys)||{}:u&&(p=jc(o.checkedKeys)||{checkedKeys:a.checkedKeys,halfCheckedKeys:a.halfCheckedKeys}),p){var b=p,y=b.checkedKeys,C=y===void 0?[]:y,$=b.halfCheckedKeys,S=$===void 0?[]:$;if(!o.checkStrictly){var x=qo(C,!0,m);C=x.checkedKeys,S=x.halfCheckedKeys}s.checkedKeys=C,s.halfCheckedKeys=S}}return c("loadedKeys")&&(s.loadedKeys=o.loadedKeys),s}}]),n}(i.Component);D(Bf,"defaultProps",{prefixCls:"rc-tree",showLine:!1,showIcon:!0,selectable:!0,multiple:!1,checkable:!1,disabled:!1,checkStrictly:!1,draggable:!1,defaultExpandParent:!0,autoExpandParent:!1,defaultExpandAll:!1,defaultExpandedKeys:[],defaultCheckedKeys:[],defaultSelectedKeys:[],dropIndicatorRender:N7,allowDrop:function(){return!0},expandAction:!1});D(Bf,"TreeNode",oi);const A7=({treeCls:e,treeNodeCls:t,directoryNodeSelectedBg:n,directoryNodeSelectedColor:r,motionDurationMid:o,borderRadius:a,controlItemBgHover:l})=>({[`${e}${e}-directory ${t}`]:{[`${e}-node-content-wrapper`]:{position:"static",[`&:has(${e}-drop-indicator)`]:{position:"relative"},[`> *:not(${e}-drop-indicator)`]:{position:"relative"},"&:hover":{background:"transparent"},"&:before":{position:"absolute",inset:0,transition:`background-color ${o}`,content:'""',borderRadius:a},"&:hover:before":{background:l}},[`${e}-switcher, ${e}-checkbox, ${e}-draggable-icon`]:{zIndex:1},"&-selected":{background:n,borderRadius:a,[`${e}-switcher, ${e}-draggable-icon`]:{color:r},[`${e}-node-content-wrapper`]:{color:r,background:"transparent","&:before, &:hover:before":{background:n}}}}}),F7=new $t("ant-tree-node-fx-do-not-use",{"0%":{opacity:0},"100%":{opacity:1}}),k7=(e,t)=>({[`.${e}-switcher-icon`]:{display:"inline-block",fontSize:10,verticalAlign:"baseline",svg:{transition:`transform ${t.motionDurationSlow}`}}}),V7=(e,t)=>({[`.${e}-drop-indicator`]:{position:"absolute",zIndex:1,height:2,backgroundColor:t.colorPrimary,borderRadius:1,pointerEvents:"none","&:after":{position:"absolute",top:-3,insetInlineStart:-6,width:8,height:8,backgroundColor:"transparent",border:`${L(t.lineWidthBold)} solid ${t.colorPrimary}`,borderRadius:"50%",content:'""'}}}),W7=(e,t)=>{const{treeCls:n,treeNodeCls:r,treeNodePadding:o,titleHeight:a,indentSize:l,nodeSelectedBg:s,nodeHoverBg:c,colorTextQuaternary:u,controlItemBgActiveDisabled:d}=t;return{[n]:Object.assign(Object.assign({},Tt(t)),{"--rc-virtual-list-scrollbar-bg":t.colorSplit,background:t.colorBgContainer,borderRadius:t.borderRadius,transition:`background-color ${t.motionDurationSlow}`,"&-rtl":{direction:"rtl"},[`&${n}-rtl ${n}-switcher_close ${n}-switcher-icon svg`]:{transform:"rotate(90deg)"},[`&-focused:not(:hover):not(${n}-active-focused)`]:Cr(t),[`${n}-list-holder-inner`]:{alignItems:"flex-start"},[`&${n}-block-node`]:{[`${n}-list-holder-inner`]:{alignItems:"stretch",[`${n}-node-content-wrapper`]:{flex:"auto"},[`${r}.dragging:after`]:{position:"absolute",inset:0,border:`1px solid ${t.colorPrimary}`,opacity:0,animationName:F7,animationDuration:t.motionDurationSlow,animationPlayState:"running",animationFillMode:"forwards",content:'""',pointerEvents:"none",borderRadius:t.borderRadius}}},[r]:{display:"flex",alignItems:"flex-start",marginBottom:o,lineHeight:L(a),position:"relative","&:before":{content:'""',position:"absolute",zIndex:1,insetInlineStart:0,width:"100%",top:"100%",height:o},[`&-disabled ${n}-node-content-wrapper`]:{color:t.colorTextDisabled,cursor:"not-allowed","&:hover":{background:"transparent"}},[`${n}-checkbox-disabled + ${n}-node-selected,&${r}-disabled${r}-selected ${n}-node-content-wrapper`]:{backgroundColor:d},[`${n}-checkbox-disabled`]:{pointerEvents:"unset"},[`&:not(${r}-disabled)`]:{[`${n}-node-content-wrapper`]:{"&:hover":{color:t.nodeHoverColor}}},[`&-active ${n}-node-content-wrapper`]:{background:t.controlItemBgHover},[`&:not(${r}-disabled).filter-node ${n}-title`]:{color:t.colorPrimary,fontWeight:t.fontWeightStrong},"&-draggable":{cursor:"grab",[`${n}-draggable-icon`]:{flexShrink:0,width:a,textAlign:"center",visibility:"visible",color:u},[`&${r}-disabled ${n}-draggable-icon`]:{visibility:"hidden"}}},[`${n}-indent`]:{alignSelf:"stretch",whiteSpace:"nowrap",userSelect:"none","&-unit":{display:"inline-block",width:l}},[`${n}-draggable-icon`]:{visibility:"hidden"},[`${n}-switcher, ${n}-checkbox`]:{marginInlineEnd:t.calc(t.calc(a).sub(t.controlInteractiveSize)).div(2).equal()},[`${n}-switcher`]:Object.assign(Object.assign({},k7(e,t)),{position:"relative",flex:"none",alignSelf:"stretch",width:a,textAlign:"center",cursor:"pointer",userSelect:"none",transition:`all ${t.motionDurationSlow}`,"&-noop":{cursor:"unset"},"&:before":{pointerEvents:"none",content:'""',width:a,height:a,position:"absolute",left:{_skip_check_:!0,value:0},top:0,borderRadius:t.borderRadius,transition:`all ${t.motionDurationSlow}`},[`&:not(${n}-switcher-noop):hover:before`]:{backgroundColor:t.colorBgTextHover},[`&_close ${n}-switcher-icon svg`]:{transform:"rotate(-90deg)"},"&-loading-icon":{color:t.colorPrimary},"&-leaf-line":{position:"relative",zIndex:1,display:"inline-block",width:"100%",height:"100%","&:before":{position:"absolute",top:0,insetInlineEnd:t.calc(a).div(2).equal(),bottom:t.calc(o).mul(-1).equal(),marginInlineStart:-1,borderInlineEnd:`1px solid ${t.colorBorder}`,content:'""'},"&:after":{position:"absolute",width:t.calc(t.calc(a).div(2).equal()).mul(.8).equal(),height:t.calc(a).div(2).equal(),borderBottom:`1px solid ${t.colorBorder}`,content:'""'}}}),[`${n}-node-content-wrapper`]:Object.assign(Object.assign({position:"relative",minHeight:a,paddingBlock:0,paddingInline:t.paddingXS,background:"transparent",borderRadius:t.borderRadius,cursor:"pointer",transition:`all ${t.motionDurationMid}, border 0s, line-height 0s, box-shadow 0s`},V7(e,t)),{"&:hover":{backgroundColor:c},[`&${n}-node-selected`]:{color:t.nodeSelectedColor,backgroundColor:s},[`${n}-iconEle`]:{display:"inline-block",width:a,height:a,textAlign:"center",verticalAlign:"top","&:empty":{display:"none"}}}),[`${n}-unselectable ${n}-node-content-wrapper:hover`]:{backgroundColor:"transparent"},[`${r}.drop-container > [draggable]`]:{boxShadow:`0 0 0 2px ${t.colorPrimary}`},"&-show-line":{[`${n}-indent-unit`]:{position:"relative",height:"100%","&:before":{position:"absolute",top:0,insetInlineEnd:t.calc(a).div(2).equal(),bottom:t.calc(o).mul(-1).equal(),borderInlineEnd:`1px solid ${t.colorBorder}`,content:'""'},"&-end:before":{display:"none"}},[`${n}-switcher`]:{background:"transparent","&-line-icon":{verticalAlign:"-0.15em"}}},[`${r}-leaf-last ${n}-switcher-leaf-line:before`]:{top:"auto !important",bottom:"auto !important",height:`${L(t.calc(a).div(2).equal())} !important`}})}},K7=(e,t,n=!0)=>{const r=`.${e}`,o=`${r}-treenode`,a=t.calc(t.paddingXS).div(2).equal(),l=yt(t,{treeCls:r,treeNodeCls:o,treeNodePadding:a});return[W7(e,l),n&&A7(l)].filter(Boolean)},G7=e=>{const{controlHeightSM:t,controlItemBgHover:n,controlItemBgActive:r}=e,o=t;return{titleHeight:o,indentSize:o,nodeHoverBg:n,nodeHoverColor:e.colorText,nodeSelectedBg:r,nodeSelectedColor:e.colorText}},q7=e=>{const{colorTextLightSolid:t,colorPrimary:n}=e;return Object.assign(Object.assign({},G7(e)),{directoryNodeSelectedColor:t,directoryNodeSelectedBg:n})},U7=It("Tree",(e,{prefixCls:t})=>[{[e.componentCls]:Xy(`${t}-checkbox`,e)},K7(t,e),ss(e)],q7),wp=4;function X7(e){const{dropPosition:t,dropLevelOffset:n,prefixCls:r,indent:o,direction:a="ltr"}=e,l=a==="ltr"?"left":"right",s=a==="ltr"?"right":"left",c={[l]:-n*o+wp,[s]:0};switch(t){case-1:c.top=-3;break;case 1:c.bottom=-3;break;default:c.bottom=-3,c[l]=o+wp;break}return F.createElement("div",{style:c,className:`${r}-drop-indicator`})}const Y7=e=>{var t,n;const{prefixCls:r,switcherIcon:o,treeNodeProps:a,showLine:l,switcherLoadingIcon:s}=e,{isLeaf:c,expanded:u,loading:d}=a;if(d)return i.isValidElement(s)?s:i.createElement(Jr,{className:`${r}-switcher-loading-icon`});let f;if(l&&typeof l=="object"&&(f=l.showLeafIcon),c){if(!l)return null;if(typeof f!="boolean"&&f){const g=typeof f=="function"?f(a):f,h=`${r}-switcher-line-custom-icon`;return i.isValidElement(g)?cn(g,{className:A((t=g.props)===null||t===void 0?void 0:t.className,h)}):g}return f?i.createElement(FC,{className:`${r}-switcher-line-icon`}):i.createElement("span",{className:`${r}-switcher-leaf-line`})}const m=`${r}-switcher-icon`,v=typeof o=="function"?o(a):o;return i.isValidElement(v)?cn(v,{className:A((n=v.props)===null||n===void 0?void 0:n.className,m)}):v!==void 0?v:l?u?i.createElement(g_,{className:`${r}-switcher-line-icon`}):i.createElement(w_,{className:`${r}-switcher-line-icon`}):i.createElement(Zz,{className:m})},cS=F.forwardRef((e,t)=>{var n;const{getPrefixCls:r,direction:o,virtual:a,tree:l}=F.useContext(ot),{prefixCls:s,className:c,showIcon:u=!1,showLine:d,switcherIcon:f,switcherLoadingIcon:m,blockNode:v=!1,children:g,checkable:h=!1,selectable:p=!0,draggable:b,motion:y,style:C}=e,$=r("tree",s),S=r(),x=y??Object.assign(Object.assign({},os(S)),{motionAppear:!1}),E=Object.assign(Object.assign({},e),{checkable:h,selectable:p,showIcon:u,motion:x,blockNode:v,showLine:!!d,dropIndicatorRender:X7}),[O,w,I]=U7($),[,P]=yn(),M=P.paddingXS/2+(((n=P.Tree)===null||n===void 0?void 0:n.titleHeight)||P.controlHeightSM),R=F.useMemo(()=>{if(!b)return!1;let T={};switch(typeof b){case"function":T.nodeDraggable=b;break;case"object":T=Object.assign({},b);break}return T.icon!==!1&&(T.icon=T.icon||F.createElement(i_,null)),T},[b]),N=T=>F.createElement(Y7,{prefixCls:$,switcherIcon:f,switcherLoadingIcon:m,treeNodeProps:T,showLine:d});return O(F.createElement(Bf,Object.assign({itemHeight:M,ref:t,virtual:a},E,{style:Object.assign(Object.assign({},l==null?void 0:l.style),C),prefixCls:$,className:A({[`${$}-icon-hide`]:!u,[`${$}-block-node`]:v,[`${$}-unselectable`]:!p,[`${$}-rtl`]:o==="rtl"},l==null?void 0:l.className,c,w,I),direction:o,checkable:h&&F.createElement("span",{className:`${$}-checkbox-inner`}),selectable:p,switcherIcon:N,draggable:R}),g))}),Ep=0,zc=1,Op=2;function Lf(e,t,n){const{key:r,children:o}=n;function a(l){const s=l[r],c=l[o];t(s,l)!==!1&&Lf(c||[],t,n)}e.forEach(a)}function Q7({treeData:e,expandedKeys:t,startKey:n,endKey:r,fieldNames:o}){const a=[];let l=Ep;if(n&&n===r)return[n];if(!n||!r)return[];function s(c){return c===n||c===r}return Lf(e,c=>{if(l===Op)return!1;if(s(c)){if(a.push(c),l===Ep)l=zc;else if(l===zc)return l=Op,!1}else l===zc&&a.push(c);return t.includes(c)},la(o)),a}function Dc(e,t,n){const r=pe(t),o=[];return Lf(e,(a,l)=>{const s=r.indexOf(a);return s!==-1&&(o.push(l),r.splice(s,1)),!!r.length},la(n)),o}var Ip=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function Z7(e){const{isLeaf:t,expanded:n}=e;return t?i.createElement(FC,null):n?i.createElement(YD,null):i.createElement(JD,null)}function Rp({treeData:e,children:t}){return e||qy(t)}const J7=(e,t)=>{var{defaultExpandAll:n,defaultExpandParent:r,defaultExpandedKeys:o}=e,a=Ip(e,["defaultExpandAll","defaultExpandParent","defaultExpandedKeys"]);const l=i.useRef(null),s=i.useRef(null),c=()=>{const{keyEntities:O}=yf(Rp(a));let w;return n?w=Object.keys(O):r?w=od(a.expandedKeys||o||[],O):w=a.expandedKeys||o||[],w},[u,d]=i.useState(a.selectedKeys||a.defaultSelectedKeys||[]),[f,m]=i.useState(()=>c());i.useEffect(()=>{"selectedKeys"in a&&d(a.selectedKeys)},[a.selectedKeys]),i.useEffect(()=>{"expandedKeys"in a&&m(a.expandedKeys)},[a.expandedKeys]);const v=(O,w)=>{var I;return"expandedKeys"in a||m(O),(I=a.onExpand)===null||I===void 0?void 0:I.call(a,O,w)},g=(O,w)=>{var I;const{multiple:P,fieldNames:M}=a,{node:R,nativeEvent:N}=w,{key:T=""}=R,j=Rp(a),z=Object.assign(Object.assign({},w),{selected:!0}),_=(N==null?void 0:N.ctrlKey)||(N==null?void 0:N.metaKey),B=N==null?void 0:N.shiftKey;let V;P&&_?(V=O,l.current=T,s.current=V,z.selectedNodes=Dc(j,V,M)):P&&B?(V=Array.from(new Set([].concat(pe(s.current||[]),pe(Q7({treeData:j,expandedKeys:f,startKey:T,endKey:l.current,fieldNames:M}))))),z.selectedNodes=Dc(j,V,M)):(V=[T],l.current=T,s.current=V,z.selectedNodes=Dc(j,V,M)),(I=a.onSelect)===null||I===void 0||I.call(a,V,z),"selectedKeys"in a||d(V)},{getPrefixCls:h,direction:p}=i.useContext(ot),{prefixCls:b,className:y,showIcon:C=!0,expandAction:$="click"}=a,S=Ip(a,["prefixCls","className","showIcon","expandAction"]),x=h("tree",b),E=A(`${x}-directory`,{[`${x}-directory-rtl`]:p==="rtl"},y);return i.createElement(cS,Object.assign({icon:Z7,ref:t,blockNode:!0},S,{showIcon:C,expandAction:$,prefixCls:x,className:E,expandedKeys:f,selectedKeys:u,onSelect:g,onExpand:v}))},eL=i.forwardRef(J7),Hf=cS;Hf.DirectoryTree=eL;Hf.TreeNode=oi;const Pp=e=>{const{value:t,filterSearch:n,tablePrefixCls:r,locale:o,onChange:a}=e;return n?i.createElement("div",{className:`${r}-filter-dropdown-search`},i.createElement(Ca,{prefix:i.createElement(tf,null),placeholder:o.filterSearchPlaceholder,onChange:a,value:t,htmlSize:1,className:`${r}-filter-dropdown-search-input`})):null},tL=e=>{const{keyCode:t}=e;t===Ne.ENTER&&e.stopPropagation()},nL=i.forwardRef((e,t)=>i.createElement("div",{className:e.className,onClick:n=>n.stopPropagation(),onKeyDown:tL,ref:t},e.children));function Uo(e){let t=[];return(e||[]).forEach(({value:n,children:r})=>{t.push(n),r&&(t=[].concat(pe(t),pe(Uo(r))))}),t}function rL(e){return e.some(({children:t})=>t)}function uS(e,t){return typeof t=="string"||typeof t=="number"?t==null?void 0:t.toString().toLowerCase().includes(e.trim().toLowerCase()):!1}function dS({filters:e,prefixCls:t,filteredKeys:n,filterMultiple:r,searchValue:o,filterSearch:a}){return e.map((l,s)=>{const c=String(l.value);if(l.children)return{key:c||s,label:l.text,popupClassName:`${t}-dropdown-submenu`,children:dS({filters:l.children,prefixCls:t,filteredKeys:n,filterMultiple:r,searchValue:o,filterSearch:a})};const u=r?sa:Si,d={key:l.value!==void 0?c:s,label:i.createElement(i.Fragment,null,i.createElement(u,{checked:n.includes(c)}),i.createElement("span",null,l.text))};return o.trim()?typeof a=="function"?a(o,l)?d:null:uS(o,l.text)?d:null:d})}function _c(e){return e||[]}const oL=e=>{var t,n,r,o;const{tablePrefixCls:a,prefixCls:l,column:s,dropdownPrefixCls:c,columnKey:u,filterOnClose:d,filterMultiple:f,filterMode:m="menu",filterSearch:v=!1,filterState:g,triggerFilter:h,locale:p,children:b,getPopupContainer:y,rootClassName:C}=e,{filterResetToDefaultFilteredValue:$,defaultFilteredValue:S,filterDropdownProps:x={},filterDropdownOpen:E,filterDropdownVisible:O,onFilterDropdownVisibleChange:w,onFilterDropdownOpenChange:I}=s,[P,M]=i.useState(!1),R=!!(g&&(!((t=g.filteredKeys)===null||t===void 0)&&t.length||g.forceFiltered)),N=oe=>{var ce;M(oe),(ce=x.onOpenChange)===null||ce===void 0||ce.call(x,oe),I==null||I(oe),w==null||w(oe)},T=(o=(r=(n=x.open)!==null&&n!==void 0?n:E)!==null&&r!==void 0?r:O)!==null&&o!==void 0?o:P,j=g==null?void 0:g.filteredKeys,[z,_]=P7(_c(j)),B=({selectedKeys:oe})=>{_(oe)},V=(oe,{node:ce,checked:ge})=>{B(f?{selectedKeys:oe}:{selectedKeys:ge&&ce.key?[ce.key]:[]})};i.useEffect(()=>{P&&B({selectedKeys:_c(j)})},[j]);const[G,q]=i.useState([]),H=oe=>{q(oe)},[W,K]=i.useState(""),U=oe=>{const{value:ce}=oe.target;K(ce)};i.useEffect(()=>{P||K("")},[P]);const te=oe=>{const ce=oe!=null&&oe.length?oe:null;if(ce===null&&(!g||!g.filteredKeys)||hr(ce,g==null?void 0:g.filteredKeys,!0))return null;h({column:s,key:u,filteredKeys:ce})},X=()=>{N(!1),te(z())},ae=({confirm:oe,closeDropdown:ce}={confirm:!1,closeDropdown:!1})=>{oe&&te([]),ce&&N(!1),K(""),_($?(S||[]).map(ge=>String(ge)):[])},le=({closeDropdown:oe}={closeDropdown:!0})=>{oe&&N(!1),te(z())},ee=(oe,ce)=>{ce.source==="trigger"&&(oe&&j!==void 0&&_(_c(j)),N(oe),!oe&&!s.filterDropdown&&d&&X())},Y=A({[`${c}-menu-without-submenu`]:!rL(s.filters||[])}),re=oe=>{if(oe.target.checked){const ce=Uo(s==null?void 0:s.filters).map(ge=>String(ge));_(ce)}else _([])},ne=({filters:oe})=>(oe||[]).map((ce,ge)=>{const se=String(ce.value),be={title:ce.text,key:ce.value!==void 0?se:String(ge)};return ce.children&&(be.children=ne({filters:ce.children})),be}),Z=oe=>{var ce;return Object.assign(Object.assign({},oe),{text:oe.title,value:oe.key,children:((ce=oe.children)===null||ce===void 0?void 0:ce.map(ge=>Z(ge)))||[]})};let Q;const{direction:ie,renderEmpty:de}=i.useContext(ot);if(typeof s.filterDropdown=="function")Q=s.filterDropdown({prefixCls:`${c}-custom`,setSelectedKeys:oe=>B({selectedKeys:oe}),selectedKeys:z(),confirm:le,clearFilters:ae,filters:s.filters,visible:T,close:()=>{N(!1)}});else if(s.filterDropdown)Q=s.filterDropdown;else{const oe=z()||[],ce=()=>{var se,be;const we=(se=de==null?void 0:de("Table.filter"))!==null&&se!==void 0?se:i.createElement(Hr,{image:Hr.PRESENTED_IMAGE_SIMPLE,description:p.filterEmptyText,styles:{image:{height:24}},style:{margin:0,padding:"16px 0"}});if((s.filters||[]).length===0)return we;if(m==="tree")return i.createElement(i.Fragment,null,i.createElement(Pp,{filterSearch:v,value:W,onChange:U,tablePrefixCls:a,locale:p}),i.createElement("div",{className:`${a}-filter-dropdown-tree`},f?i.createElement(sa,{checked:oe.length===Uo(s.filters).length,indeterminate:oe.length>0&&oe.length<Uo(s.filters).length,className:`${a}-filter-dropdown-checkall`,onChange:re},(be=p==null?void 0:p.filterCheckall)!==null&&be!==void 0?be:p==null?void 0:p.filterCheckAll):null,i.createElement(Hf,{checkable:!0,selectable:!1,blockNode:!0,multiple:f,checkStrictly:!f,className:`${c}-menu`,onCheck:V,checkedKeys:oe,selectedKeys:oe,showIcon:!1,treeData:ne({filters:s.filters}),autoExpandParent:!0,defaultExpandAll:!0,filterTreeNode:W.trim()?Se=>typeof v=="function"?v(W,Z(Se)):uS(W,Se.title):void 0})));const Me=dS({filters:s.filters||[],filterSearch:v,prefixCls:l,filteredKeys:z(),filterMultiple:f,searchValue:W}),Te=Me.every(Se=>Se===null);return i.createElement(i.Fragment,null,i.createElement(Pp,{filterSearch:v,value:W,onChange:U,tablePrefixCls:a,locale:p}),Te?we:i.createElement(ha,{selectable:!0,multiple:f,prefixCls:`${c}-menu`,className:Y,onSelect:B,onDeselect:B,selectedKeys:oe,getPopupContainer:y,openKeys:G,onOpenChange:H,items:Me}))},ge=()=>$?hr((S||[]).map(se=>String(se)),oe,!0):oe.length===0;Q=i.createElement(i.Fragment,null,ce(),i.createElement("div",{className:`${l}-dropdown-btns`},i.createElement(er,{type:"link",size:"small",disabled:ge(),onClick:()=>ae()},p.filterReset),i.createElement(er,{type:"primary",size:"small",onClick:X},p.filterConfirm)))}s.filterDropdown&&(Q=i.createElement(yy,{selectable:void 0},Q)),Q=i.createElement(nL,{className:`${l}-dropdown`},Q);const ye=xl({trigger:["click"],placement:ie==="rtl"?"bottomLeft":"bottomRight",children:(()=>{let oe;return typeof s.filterIcon=="function"?oe=s.filterIcon(R):s.filterIcon?oe=s.filterIcon:oe=i.createElement(KD,null),i.createElement("span",{role:"button",tabIndex:-1,className:A(`${l}-trigger`,{active:R}),onClick:ce=>{ce.stopPropagation()}},oe)})(),getPopupContainer:y},Object.assign(Object.assign({},x),{rootClassName:A(C,x.rootClassName),open:T,onOpenChange:ee,popupRender:()=>typeof(x==null?void 0:x.dropdownRender)=="function"?x.dropdownRender(Q):Q}));return i.createElement("div",{className:`${l}-column`},i.createElement("span",{className:`${a}-column-title`},b),i.createElement(Of,Object.assign({},ye)))},cd=(e,t,n)=>{let r=[];return(e||[]).forEach((o,a)=>{var l;const s=wa(a,n),c=o.filterDropdown!==void 0;if(o.filters||c||"onFilter"in o)if("filteredValue"in o){let u=o.filteredValue;c||(u=(l=u==null?void 0:u.map(String))!==null&&l!==void 0?l:u),r.push({column:o,key:to(o,s),filteredKeys:u,forceFiltered:o.filtered})}else r.push({column:o,key:to(o,s),filteredKeys:t&&o.defaultFilteredValue?o.defaultFilteredValue:void 0,forceFiltered:o.filtered});"children"in o&&(r=[].concat(pe(r),pe(cd(o.children,t,s))))}),r};function fS(e,t,n,r,o,a,l,s,c){return n.map((u,d)=>{const f=wa(d,s),{filterOnClose:m=!0,filterMultiple:v=!0,filterMode:g,filterSearch:h}=u;let p=u;if(p.filters||p.filterDropdown){const b=to(p,f),y=r.find(({key:C})=>b===C);p=Object.assign(Object.assign({},p),{title:C=>i.createElement(oL,{tablePrefixCls:e,prefixCls:`${e}-filter`,dropdownPrefixCls:t,column:p,columnKey:b,filterState:y,filterOnClose:m,filterMultiple:v,filterMode:g,filterSearch:h,triggerFilter:a,locale:o,getPopupContainer:l,rootClassName:c},Ls(u.title,C))})}return"children"in p&&(p=Object.assign(Object.assign({},p),{children:fS(e,t,p.children,r,o,a,l,f,c)})),p})}const Np=e=>{const t={};return e.forEach(({key:n,filteredKeys:r,column:o})=>{const a=n,{filters:l,filterDropdown:s}=o;if(s)t[a]=r||null;else if(Array.isArray(r)){const c=Uo(l);t[a]=c.filter(u=>r.includes(String(u)))}else t[a]=null}),t},ud=(e,t,n)=>t.reduce((o,a)=>{const{column:{onFilter:l,filters:s},filteredKeys:c}=a;return l&&c&&c.length?o.map(u=>Object.assign({},u)).filter(u=>c.some(d=>{const f=Uo(s),m=f.findIndex(g=>String(g)===String(d)),v=m!==-1?f[m]:d;return u[n]&&(u[n]=ud(u[n],t,n)),l(v,u)})):o},e),mS=e=>e.flatMap(t=>"children"in t?[t].concat(pe(mS(t.children||[]))):[t]),aL=e=>{const{prefixCls:t,dropdownPrefixCls:n,mergedColumns:r,onFilterChange:o,getPopupContainer:a,locale:l,rootClassName:s}=e;no();const c=i.useMemo(()=>mS(r||[]),[r]),[u,d]=i.useState(()=>cd(c,!0)),f=i.useMemo(()=>{const h=cd(c,!1);if(h.length===0)return h;let p=!0;if(h.forEach(({filteredKeys:b})=>{b!==void 0&&(p=!1)}),p){const b=(c||[]).map((y,C)=>to(y,wa(C)));return u.filter(({key:y})=>b.includes(y)).map(y=>{const C=c[b.findIndex($=>$===y.key)];return Object.assign(Object.assign({},y),{column:Object.assign(Object.assign({},y.column),C),forceFiltered:C.filtered})})}return h},[c,u]),m=i.useMemo(()=>Np(f),[f]),v=h=>{const p=f.filter(({key:b})=>b!==h.key);p.push(h),d(p),o(Np(p),p)};return[h=>fS(t,n,h,f,l,v,a,void 0,s),f,m]},iL=(e,t,n)=>{const r=i.useRef({});function o(a){var l;if(!r.current||r.current.data!==e||r.current.childrenColumnName!==t||r.current.getRowKey!==n){let c=function(u){u.forEach((d,f)=>{const m=n(d,f);s.set(m,d),d&&typeof d=="object"&&t in d&&c(d[t]||[])})};const s=new Map;c(e),r.current={data:e,childrenColumnName:t,kvMap:s,getRowKey:n}}return(l=r.current.kvMap)===null||l===void 0?void 0:l.get(a)}return[o]};var lL=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const vS=10;function sL(e,t){const n={current:e.current,pageSize:e.pageSize};return Object.keys(t&&typeof t=="object"?t:{}).forEach(o=>{const a=e[o];typeof a!="function"&&(n[o]=a)}),n}function cL(e,t,n){const r=n&&typeof n=="object"?n:{},{total:o=0}=r,a=lL(r,["total"]),[l,s]=i.useState(()=>({current:"defaultCurrent"in a?a.defaultCurrent:1,pageSize:"defaultPageSize"in a?a.defaultPageSize:vS})),c=xl(l,a,{total:o>0?o:e}),u=Math.ceil((o||e)/c.pageSize);c.current>u&&(c.current=u||1);const d=(m,v)=>{s({current:m??1,pageSize:v||c.pageSize})},f=(m,v)=>{var g;n&&((g=n.onChange)===null||g===void 0||g.call(n,m,v)),d(m,v),t(m,v||(c==null?void 0:c.pageSize))};return n===!1?[{},()=>{}]:[Object.assign(Object.assign({},c),{onChange:f}),d]}const ul="ascend",Bc="descend",zl=e=>typeof e.sorter=="object"&&typeof e.sorter.multiple=="number"?e.sorter.multiple:!1,Mp=e=>typeof e=="function"?e:e&&typeof e=="object"&&e.compare?e.compare:!1,uL=(e,t)=>t?e[e.indexOf(t)+1]:e[0],dd=(e,t,n)=>{let r=[];const o=(a,l)=>{r.push({column:a,key:to(a,l),multiplePriority:zl(a),sortOrder:a.sortOrder})};return(e||[]).forEach((a,l)=>{const s=wa(l,n);a.children?("sortOrder"in a&&o(a,s),r=[].concat(pe(r),pe(dd(a.children,t,s)))):a.sorter&&("sortOrder"in a?o(a,s):t&&a.defaultSortOrder&&r.push({column:a,key:to(a,s),multiplePriority:zl(a),sortOrder:a.defaultSortOrder}))}),r},gS=(e,t,n,r,o,a,l,s)=>(t||[]).map((u,d)=>{const f=wa(d,s);let m=u;if(m.sorter){const v=m.sortDirections||o,g=m.showSorterTooltip===void 0?l:m.showSorterTooltip,h=to(m,f),p=n.find(({key:w})=>w===h),b=p?p.sortOrder:null,y=uL(v,b);let C;if(u.sortIcon)C=u.sortIcon({sortOrder:b});else{const w=v.includes(ul)&&i.createElement(oD,{className:A(`${e}-column-sorter-up`,{active:b===ul})}),I=v.includes(Bc)&&i.createElement(tD,{className:A(`${e}-column-sorter-down`,{active:b===Bc})});C=i.createElement("span",{className:A(`${e}-column-sorter`,{[`${e}-column-sorter-full`]:!!(w&&I)})},i.createElement("span",{className:`${e}-column-sorter-inner`,"aria-hidden":"true"},w,I))}const{cancelSort:$,triggerAsc:S,triggerDesc:x}=a||{};let E=$;y===Bc?E=x:y===ul&&(E=S);const O=typeof g=="object"?Object.assign({title:E},g):{title:E};m=Object.assign(Object.assign({},m),{className:A(m.className,{[`${e}-column-sort`]:b}),title:w=>{const I=`${e}-column-sorters`,P=i.createElement("span",{className:`${e}-column-title`},Ls(u.title,w)),M=i.createElement("div",{className:I},P,C);return g?typeof g!="boolean"&&(g==null?void 0:g.target)==="sorter-icon"?i.createElement("div",{className:`${I} ${e}-column-sorters-tooltip-target-sorter`},P,i.createElement($r,Object.assign({},O),C)):i.createElement($r,Object.assign({},O),M):M},onHeaderCell:w=>{var I;const P=((I=u.onHeaderCell)===null||I===void 0?void 0:I.call(u,w))||{},M=P.onClick,R=P.onKeyDown;P.onClick=j=>{r({column:u,key:h,sortOrder:y,multiplePriority:zl(u)}),M==null||M(j)},P.onKeyDown=j=>{j.keyCode===Ne.ENTER&&(r({column:u,key:h,sortOrder:y,multiplePriority:zl(u)}),R==null||R(j))};const N=R7(u.title,{}),T=N==null?void 0:N.toString();return b&&(P["aria-sort"]=b==="ascend"?"ascending":"descending"),P["aria-label"]=T||"",P.className=A(P.className,`${e}-column-has-sorters`),P.tabIndex=0,u.ellipsis&&(P.title=(N??"").toString()),P}})}return"children"in m&&(m=Object.assign(Object.assign({},m),{children:gS(e,m.children,n,r,o,a,l,f)})),m}),Tp=e=>{const{column:t,sortOrder:n}=e;return{column:t,order:n,field:t.dataIndex,columnKey:t.key}},jp=e=>{const t=e.filter(({sortOrder:n})=>n).map(Tp);if(t.length===0&&e.length){const n=e.length-1;return Object.assign(Object.assign({},Tp(e[n])),{column:void 0,order:void 0,field:void 0,columnKey:void 0})}return t.length<=1?t[0]||{}:t},fd=(e,t,n)=>{const r=t.slice().sort((l,s)=>s.multiplePriority-l.multiplePriority),o=e.slice(),a=r.filter(({column:{sorter:l},sortOrder:s})=>Mp(l)&&s);return a.length?o.sort((l,s)=>{for(let c=0;c<a.length;c+=1){const u=a[c],{column:{sorter:d},sortOrder:f}=u,m=Mp(d);if(m&&f){const v=m(l,s,f);if(v!==0)return f===ul?v:-v}}return 0}).map(l=>{const s=l[n];return s?Object.assign(Object.assign({},l),{[n]:fd(s,t,n)}):l}):o},dL=e=>{const{prefixCls:t,mergedColumns:n,sortDirections:r,tableLocale:o,showSorterTooltip:a,onSorterChange:l}=e,[s,c]=i.useState(()=>dd(n,!0)),u=(h,p)=>{const b=[];return h.forEach((y,C)=>{const $=wa(C,p);if(b.push(to(y,$)),Array.isArray(y.children)){const S=u(y.children,$);b.push.apply(b,pe(S))}}),b},d=i.useMemo(()=>{let h=!0;const p=dd(n,!1);if(!p.length){const $=u(n);return s.filter(({key:S})=>$.includes(S))}const b=[];function y($){h?b.push($):b.push(Object.assign(Object.assign({},$),{sortOrder:null}))}let C=null;return p.forEach($=>{C===null?(y($),$.sortOrder&&($.multiplePriority===!1?h=!1:C=!0)):(C&&$.multiplePriority!==!1||(h=!1),y($))}),b},[n,s]),f=i.useMemo(()=>{var h,p;const b=d.map(({column:y,sortOrder:C})=>({column:y,order:C}));return{sortColumns:b,sortColumn:(h=b[0])===null||h===void 0?void 0:h.column,sortOrder:(p=b[0])===null||p===void 0?void 0:p.order}},[d]),m=h=>{let p;h.multiplePriority===!1||!d.length||d[0].multiplePriority===!1?p=[h]:p=[].concat(pe(d.filter(({key:b})=>b!==h.key)),[h]),c(p),l(jp(p),p)};return[h=>gS(t,h,d,m,r,o,a),d,f,()=>jp(d)]},pS=(e,t)=>e.map(r=>{const o=Object.assign({},r);return o.title=Ls(r.title,t),"children"in o&&(o.children=pS(o.children,t)),o}),fL=e=>[i.useCallback(n=>pS(n,e),[e])],mL=rS((e,t)=>{const{_renderTimes:n}=e,{_renderTimes:r}=t;return n!==r}),vL=aS((e,t)=>{const{_renderTimes:n}=e,{_renderTimes:r}=t;return n!==r}),gL=e=>{const{componentCls:t,lineWidth:n,lineType:r,tableBorderColor:o,tableHeaderBg:a,tablePaddingVertical:l,tablePaddingHorizontal:s,calc:c}=e,u=`${L(n)} ${r} ${o}`,d=(f,m,v)=>({[`&${t}-${f}`]:{[`> ${t}-container`]:{[`> ${t}-content, > ${t}-body`]:{"\n            > table > tbody > tr > th,\n            > table > tbody > tr > td\n          ":{[`> ${t}-expanded-row-fixed`]:{margin:`${L(c(m).mul(-1).equal())}
              ${L(c(c(v).add(n)).mul(-1).equal())}`}}}}}});return{[`${t}-wrapper`]:{[`${t}${t}-bordered`]:Object.assign(Object.assign(Object.assign({[`> ${t}-title`]:{border:u,borderBottom:0},[`> ${t}-container`]:{borderInlineStart:u,borderTop:u,[`
            > ${t}-content,
            > ${t}-header,
            > ${t}-body,
            > ${t}-summary
          `]:{"> table":{"\n                > thead > tr > th,\n                > thead > tr > td,\n                > tbody > tr > th,\n                > tbody > tr > td,\n                > tfoot > tr > th,\n                > tfoot > tr > td\n              ":{borderInlineEnd:u},"> thead":{"> tr:not(:last-child) > th":{borderBottom:u},"> tr > th::before":{backgroundColor:"transparent !important"}},"\n                > thead > tr,\n                > tbody > tr,\n                > tfoot > tr\n              ":{[`> ${t}-cell-fix-right-first::after`]:{borderInlineEnd:u}},"\n                > tbody > tr > th,\n                > tbody > tr > td\n              ":{[`> ${t}-expanded-row-fixed`]:{margin:`${L(c(l).mul(-1).equal())} ${L(c(c(s).add(n)).mul(-1).equal())}`,"&::after":{position:"absolute",top:0,insetInlineEnd:n,bottom:0,borderInlineEnd:u,content:'""'}}}}}},[`&${t}-scroll-horizontal`]:{[`> ${t}-container > ${t}-body`]:{"> table > tbody":{[`
                > tr${t}-expanded-row,
                > tr${t}-placeholder
              `]:{"> th, > td":{borderInlineEnd:0}}}}}},d("middle",e.tablePaddingVerticalMiddle,e.tablePaddingHorizontalMiddle)),d("small",e.tablePaddingVerticalSmall,e.tablePaddingHorizontalSmall)),{[`> ${t}-footer`]:{border:u,borderTop:0}}),[`${t}-cell`]:{[`${t}-container:first-child`]:{borderTop:0},"&-scrollbar:not([rowspan])":{boxShadow:`0 ${L(n)} 0 ${L(n)} ${a}`}},[`${t}-bordered ${t}-cell-scrollbar`]:{borderInlineEnd:u}}}},pL=e=>{const{componentCls:t}=e;return{[`${t}-wrapper`]:{[`${t}-cell-ellipsis`]:Object.assign(Object.assign({},sr),{wordBreak:"keep-all",[`
          &${t}-cell-fix-left-last,
          &${t}-cell-fix-right-first
        `]:{overflow:"visible",[`${t}-cell-content`]:{display:"block",overflow:"hidden",textOverflow:"ellipsis"}},[`${t}-column-title`]:{overflow:"hidden",textOverflow:"ellipsis",wordBreak:"keep-all"}})}}},hL=e=>{const{componentCls:t}=e;return{[`${t}-wrapper`]:{[`${t}-tbody > tr${t}-placeholder`]:{textAlign:"center",color:e.colorTextDisabled,"\n          &:hover > th,\n          &:hover > td,\n        ":{background:e.colorBgContainer}}}}},bL=e=>{const{componentCls:t,antCls:n,motionDurationSlow:r,lineWidth:o,paddingXS:a,lineType:l,tableBorderColor:s,tableExpandIconBg:c,tableExpandColumnWidth:u,borderRadius:d,tablePaddingVertical:f,tablePaddingHorizontal:m,tableExpandedRowBg:v,paddingXXS:g,expandIconMarginTop:h,expandIconSize:p,expandIconHalfInner:b,expandIconScale:y,calc:C}=e,$=`${L(o)} ${l} ${s}`,S=C(g).sub(o).equal();return{[`${t}-wrapper`]:{[`${t}-expand-icon-col`]:{width:u},[`${t}-row-expand-icon-cell`]:{textAlign:"center",[`${t}-row-expand-icon`]:{display:"inline-flex",float:"none",verticalAlign:"sub"}},[`${t}-row-indent`]:{height:1,float:"left"},[`${t}-row-expand-icon`]:Object.assign(Object.assign({},Id(e)),{position:"relative",float:"left",width:p,height:p,color:"inherit",lineHeight:L(p),background:c,border:$,borderRadius:d,transform:`scale(${y})`,"&:focus, &:hover, &:active":{borderColor:"currentcolor"},"&::before, &::after":{position:"absolute",background:"currentcolor",transition:`transform ${r} ease-out`,content:'""'},"&::before":{top:b,insetInlineEnd:S,insetInlineStart:S,height:o},"&::after":{top:S,bottom:S,insetInlineStart:b,width:o,transform:"rotate(90deg)"},"&-collapsed::before":{transform:"rotate(-180deg)"},"&-collapsed::after":{transform:"rotate(0deg)"},"&-spaced":{"&::before, &::after":{display:"none",content:"none"},background:"transparent",border:0,visibility:"hidden"}}),[`${t}-row-indent + ${t}-row-expand-icon`]:{marginTop:h,marginInlineEnd:a},[`tr${t}-expanded-row`]:{"&, &:hover":{"> th, > td":{background:v}},[`${n}-descriptions-view`]:{display:"flex",table:{flex:"auto",width:"100%"}}},[`${t}-expanded-row-fixed`]:{position:"relative",margin:`${L(C(f).mul(-1).equal())} ${L(C(m).mul(-1).equal())}`,padding:`${L(f)} ${L(m)}`}}}},yL=e=>{const{componentCls:t,antCls:n,iconCls:r,tableFilterDropdownWidth:o,tableFilterDropdownSearchWidth:a,paddingXXS:l,paddingXS:s,colorText:c,lineWidth:u,lineType:d,tableBorderColor:f,headerIconColor:m,fontSizeSM:v,tablePaddingHorizontal:g,borderRadius:h,motionDurationSlow:p,colorIcon:b,colorPrimary:y,tableHeaderFilterActiveBg:C,colorTextDisabled:$,tableFilterDropdownBg:S,tableFilterDropdownHeight:x,controlItemBgHover:E,controlItemBgActive:O,boxShadowSecondary:w,filterDropdownMenuBg:I,calc:P}=e,M=`${n}-dropdown`,R=`${t}-filter-dropdown`,N=`${n}-tree`,T=`${L(u)} ${d} ${f}`;return[{[`${t}-wrapper`]:{[`${t}-filter-column`]:{display:"flex",justifyContent:"space-between"},[`${t}-filter-trigger`]:{position:"relative",display:"flex",alignItems:"center",marginBlock:P(l).mul(-1).equal(),marginInline:`${L(l)} ${L(P(g).div(2).mul(-1).equal())}`,padding:`0 ${L(l)}`,color:m,fontSize:v,borderRadius:h,cursor:"pointer",transition:`all ${p}`,"&:hover":{color:b,background:C},"&.active":{color:y}}}},{[`${n}-dropdown`]:{[R]:Object.assign(Object.assign({},Tt(e)),{minWidth:o,backgroundColor:S,borderRadius:h,boxShadow:w,overflow:"hidden",[`${M}-menu`]:{maxHeight:x,overflowX:"hidden",border:0,boxShadow:"none",borderRadius:"unset",backgroundColor:I,"&:empty::after":{display:"block",padding:`${L(s)} 0`,color:$,fontSize:v,textAlign:"center",content:'"Not Found"'}},[`${R}-tree`]:{paddingBlock:`${L(s)} 0`,paddingInline:s,[N]:{padding:0},[`${N}-treenode ${N}-node-content-wrapper:hover`]:{backgroundColor:E},[`${N}-treenode-checkbox-checked ${N}-node-content-wrapper`]:{"&, &:hover":{backgroundColor:O}}},[`${R}-search`]:{padding:s,borderBottom:T,"&-input":{input:{minWidth:a},[r]:{color:$}}},[`${R}-checkall`]:{width:"100%",marginBottom:l,marginInlineStart:l},[`${R}-btns`]:{display:"flex",justifyContent:"space-between",padding:`${L(P(s).sub(u).equal())} ${L(s)}`,overflow:"hidden",borderTop:T}})}},{[`${n}-dropdown ${R}, ${R}-submenu`]:{[`${n}-checkbox-wrapper + span`]:{paddingInlineStart:s,color:c},"> ul":{maxHeight:"calc(100vh - 130px)",overflowX:"hidden",overflowY:"auto"}}}]},CL=e=>{const{componentCls:t,lineWidth:n,colorSplit:r,motionDurationSlow:o,zIndexTableFixed:a,tableBg:l,zIndexTableSticky:s,calc:c}=e,u=r;return{[`${t}-wrapper`]:{[`
        ${t}-cell-fix-left,
        ${t}-cell-fix-right
      `]:{position:"sticky !important",zIndex:a,background:l},[`
        ${t}-cell-fix-left-first::after,
        ${t}-cell-fix-left-last::after
      `]:{position:"absolute",top:0,right:{_skip_check_:!0,value:0},bottom:c(n).mul(-1).equal(),width:30,transform:"translateX(100%)",transition:`box-shadow ${o}`,content:'""',pointerEvents:"none",willChange:"transform"},[`${t}-cell-fix-left-all::after`]:{display:"none"},[`
        ${t}-cell-fix-right-first::after,
        ${t}-cell-fix-right-last::after
      `]:{position:"absolute",top:0,bottom:c(n).mul(-1).equal(),left:{_skip_check_:!0,value:0},width:30,transform:"translateX(-100%)",transition:`box-shadow ${o}`,content:'""',pointerEvents:"none"},[`${t}-container`]:{position:"relative","&::before, &::after":{position:"absolute",top:0,bottom:0,zIndex:c(s).add(1).equal({unit:!1}),width:30,transition:`box-shadow ${o}`,content:'""',pointerEvents:"none"},"&::before":{insetInlineStart:0},"&::after":{insetInlineEnd:0}},[`${t}-ping-left`]:{[`&:not(${t}-has-fix-left) ${t}-container::before`]:{boxShadow:`inset 10px 0 8px -8px ${u}`},[`
          ${t}-cell-fix-left-first::after,
          ${t}-cell-fix-left-last::after
        `]:{boxShadow:`inset 10px 0 8px -8px ${u}`},[`${t}-cell-fix-left-last::before`]:{backgroundColor:"transparent !important"}},[`${t}-ping-right`]:{[`&:not(${t}-has-fix-right) ${t}-container::after`]:{boxShadow:`inset -10px 0 8px -8px ${u}`},[`
          ${t}-cell-fix-right-first::after,
          ${t}-cell-fix-right-last::after
        `]:{boxShadow:`inset -10px 0 8px -8px ${u}`}},[`${t}-fixed-column-gapped`]:{[`
        ${t}-cell-fix-left-first::after,
        ${t}-cell-fix-left-last::after,
        ${t}-cell-fix-right-first::after,
        ${t}-cell-fix-right-last::after
      `]:{boxShadow:"none"}}}}},SL=e=>{const{componentCls:t,antCls:n,margin:r}=e;return{[`${t}-wrapper`]:{[`${t}-pagination${n}-pagination`]:{margin:`${L(r)} 0`},[`${t}-pagination`]:{display:"flex",flexWrap:"wrap",rowGap:e.paddingXS,"> *":{flex:"none"},"&-left":{justifyContent:"flex-start"},"&-center":{justifyContent:"center"},"&-right":{justifyContent:"flex-end"}}}}},$L=e=>{const{componentCls:t,tableRadius:n}=e;return{[`${t}-wrapper`]:{[t]:{[`${t}-title, ${t}-header`]:{borderRadius:`${L(n)} ${L(n)} 0 0`},[`${t}-title + ${t}-container`]:{borderStartStartRadius:0,borderStartEndRadius:0,[`${t}-header, table`]:{borderRadius:0},"table > thead > tr:first-child":{"th:first-child, th:last-child, td:first-child, td:last-child":{borderRadius:0}}},"&-container":{borderStartStartRadius:n,borderStartEndRadius:n,"table > thead > tr:first-child":{"> *:first-child":{borderStartStartRadius:n},"> *:last-child":{borderStartEndRadius:n}}},"&-footer":{borderRadius:`0 0 ${L(n)} ${L(n)}`}}}}},xL=e=>{const{componentCls:t}=e;return{[`${t}-wrapper-rtl`]:{direction:"rtl",table:{direction:"rtl"},[`${t}-pagination-left`]:{justifyContent:"flex-end"},[`${t}-pagination-right`]:{justifyContent:"flex-start"},[`${t}-row-expand-icon`]:{float:"right","&::after":{transform:"rotate(-90deg)"},"&-collapsed::before":{transform:"rotate(180deg)"},"&-collapsed::after":{transform:"rotate(0deg)"}},[`${t}-container`]:{"&::before":{insetInlineStart:"unset",insetInlineEnd:0},"&::after":{insetInlineStart:0,insetInlineEnd:"unset"},[`${t}-row-indent`]:{float:"right"}}}}},wL=e=>{const{componentCls:t,antCls:n,iconCls:r,fontSizeIcon:o,padding:a,paddingXS:l,headerIconColor:s,headerIconHoverColor:c,tableSelectionColumnWidth:u,tableSelectedRowBg:d,tableSelectedRowHoverBg:f,tableRowHoverBg:m,tablePaddingHorizontal:v,calc:g}=e;return{[`${t}-wrapper`]:{[`${t}-selection-col`]:{width:u,[`&${t}-selection-col-with-dropdown`]:{width:g(u).add(o).add(g(a).div(4)).equal()}},[`${t}-bordered ${t}-selection-col`]:{width:g(u).add(g(l).mul(2)).equal(),[`&${t}-selection-col-with-dropdown`]:{width:g(u).add(o).add(g(a).div(4)).add(g(l).mul(2)).equal()}},[`
        table tr th${t}-selection-column,
        table tr td${t}-selection-column,
        ${t}-selection-column
      `]:{paddingInlineEnd:e.paddingXS,paddingInlineStart:e.paddingXS,textAlign:"center",[`${n}-radio-wrapper`]:{marginInlineEnd:0}},[`table tr th${t}-selection-column${t}-cell-fix-left`]:{zIndex:g(e.zIndexTableFixed).add(1).equal({unit:!1})},[`table tr th${t}-selection-column::after`]:{backgroundColor:"transparent !important"},[`${t}-selection`]:{position:"relative",display:"inline-flex",flexDirection:"column"},[`${t}-selection-extra`]:{position:"absolute",top:0,zIndex:1,cursor:"pointer",transition:`all ${e.motionDurationSlow}`,marginInlineStart:"100%",paddingInlineStart:L(g(v).div(4).equal()),[r]:{color:s,fontSize:o,verticalAlign:"baseline","&:hover":{color:c}}},[`${t}-tbody`]:{[`${t}-row`]:{[`&${t}-row-selected`]:{[`> ${t}-cell`]:{background:d,"&-row-hover":{background:f}}},[`> ${t}-cell-row-hover`]:{background:m}}}}}},EL=e=>{const{componentCls:t,tableExpandColumnWidth:n,calc:r}=e,o=(a,l,s,c)=>({[`${t}${t}-${a}`]:{fontSize:c,[`
        ${t}-title,
        ${t}-footer,
        ${t}-cell,
        ${t}-thead > tr > th,
        ${t}-tbody > tr > th,
        ${t}-tbody > tr > td,
        tfoot > tr > th,
        tfoot > tr > td
      `]:{padding:`${L(l)} ${L(s)}`},[`${t}-filter-trigger`]:{marginInlineEnd:L(r(s).div(2).mul(-1).equal())},[`${t}-expanded-row-fixed`]:{margin:`${L(r(l).mul(-1).equal())} ${L(r(s).mul(-1).equal())}`},[`${t}-tbody`]:{[`${t}-wrapper:only-child ${t}`]:{marginBlock:L(r(l).mul(-1).equal()),marginInline:`${L(r(n).sub(s).equal())} ${L(r(s).mul(-1).equal())}`}},[`${t}-selection-extra`]:{paddingInlineStart:L(r(s).div(4).equal())}}});return{[`${t}-wrapper`]:Object.assign(Object.assign({},o("middle",e.tablePaddingVerticalMiddle,e.tablePaddingHorizontalMiddle,e.tableFontSizeMiddle)),o("small",e.tablePaddingVerticalSmall,e.tablePaddingHorizontalSmall,e.tableFontSizeSmall))}},OL=e=>{const{componentCls:t,marginXXS:n,fontSizeIcon:r,headerIconColor:o,headerIconHoverColor:a}=e;return{[`${t}-wrapper`]:{[`${t}-thead th${t}-column-has-sorters`]:{outline:"none",cursor:"pointer",transition:`all ${e.motionDurationSlow}, left 0s`,"&:hover":{background:e.tableHeaderSortHoverBg,"&::before":{backgroundColor:"transparent !important"}},"&:focus-visible":{color:e.colorPrimary},[`
          &${t}-cell-fix-left:hover,
          &${t}-cell-fix-right:hover
        `]:{background:e.tableFixedHeaderSortActiveBg}},[`${t}-thead th${t}-column-sort`]:{background:e.tableHeaderSortBg,"&::before":{backgroundColor:"transparent !important"}},[`td${t}-column-sort`]:{background:e.tableBodySortBg},[`${t}-column-title`]:{position:"relative",zIndex:1,flex:1,minWidth:0},[`${t}-column-sorters`]:{display:"flex",flex:"auto",alignItems:"center",justifyContent:"space-between","&::after":{position:"absolute",inset:0,width:"100%",height:"100%",content:'""'}},[`${t}-column-sorters-tooltip-target-sorter`]:{"&::after":{content:"none"}},[`${t}-column-sorter`]:{marginInlineStart:n,color:o,fontSize:0,transition:`color ${e.motionDurationSlow}`,"&-inner":{display:"inline-flex",flexDirection:"column",alignItems:"center"},"&-up, &-down":{fontSize:r,"&.active":{color:e.colorPrimary}},[`${t}-column-sorter-up + ${t}-column-sorter-down`]:{marginTop:"-0.3em"}},[`${t}-column-sorters:hover ${t}-column-sorter`]:{color:a}}}},IL=e=>{const{componentCls:t,opacityLoading:n,tableScrollThumbBg:r,tableScrollThumbBgHover:o,tableScrollThumbSize:a,tableScrollBg:l,zIndexTableSticky:s,stickyScrollBarBorderRadius:c,lineWidth:u,lineType:d,tableBorderColor:f}=e,m=`${L(u)} ${d} ${f}`;return{[`${t}-wrapper`]:{[`${t}-sticky`]:{"&-holder":{position:"sticky",zIndex:s,background:e.colorBgContainer},"&-scroll":{position:"sticky",bottom:0,height:`${L(a)} !important`,zIndex:s,display:"flex",alignItems:"center",background:l,borderTop:m,opacity:n,"&:hover":{transformOrigin:"center bottom"},"&-bar":{height:a,backgroundColor:r,borderRadius:c,transition:`all ${e.motionDurationSlow}, transform 0s`,position:"absolute",bottom:0,"&:hover, &-active":{backgroundColor:o}}}}}}},zp=e=>{const{componentCls:t,lineWidth:n,tableBorderColor:r,calc:o}=e,a=`${L(n)} ${e.lineType} ${r}`;return{[`${t}-wrapper`]:{[`${t}-summary`]:{position:"relative",zIndex:e.zIndexTableFixed,background:e.tableBg,"> tr":{"> th, > td":{borderBottom:a}}},[`div${t}-summary`]:{boxShadow:`0 ${L(o(n).mul(-1).equal())} 0 ${r}`}}}},RL=e=>{const{componentCls:t,motionDurationMid:n,lineWidth:r,lineType:o,tableBorderColor:a,calc:l}=e,s=`${L(r)} ${o} ${a}`,c=`${t}-expanded-row-cell`;return{[`${t}-wrapper`]:{[`${t}-tbody-virtual`]:{[`${t}-tbody-virtual-holder-inner`]:{[`
            & > ${t}-row, 
            & > div:not(${t}-row) > ${t}-row
          `]:{display:"flex",boxSizing:"border-box",width:"100%"}},[`${t}-cell`]:{borderBottom:s,transition:`background ${n}`},[`${t}-expanded-row`]:{[`${c}${c}-fixed`]:{position:"sticky",insetInlineStart:0,overflow:"hidden",width:`calc(var(--virtual-width) - ${L(r)})`,borderInlineEnd:"none"}}},[`${t}-bordered`]:{[`${t}-tbody-virtual`]:{"&:after":{content:'""',insetInline:0,bottom:0,borderBottom:s,position:"absolute"},[`${t}-cell`]:{borderInlineEnd:s,[`&${t}-cell-fix-right-first:before`]:{content:'""',position:"absolute",insetBlock:0,insetInlineStart:l(r).mul(-1).equal(),borderInlineStart:s}}},[`&${t}-virtual`]:{[`${t}-placeholder ${t}-cell`]:{borderInlineEnd:s,borderBottom:s}}}}}},PL=e=>{const{componentCls:t,fontWeightStrong:n,tablePaddingVertical:r,tablePaddingHorizontal:o,tableExpandColumnWidth:a,lineWidth:l,lineType:s,tableBorderColor:c,tableFontSize:u,tableBg:d,tableRadius:f,tableHeaderTextColor:m,motionDurationMid:v,tableHeaderBg:g,tableHeaderCellSplitColor:h,tableFooterTextColor:p,tableFooterBg:b,calc:y}=e,C=`${L(l)} ${s} ${c}`;return{[`${t}-wrapper`]:Object.assign(Object.assign({clear:"both",maxWidth:"100%","--rc-virtual-list-scrollbar-bg":e.tableScrollBg},yr()),{[t]:Object.assign(Object.assign({},Tt(e)),{fontSize:u,background:d,borderRadius:`${L(f)} ${L(f)} 0 0`,scrollbarColor:`${e.tableScrollThumbBg} ${e.tableScrollBg}`}),table:{width:"100%",textAlign:"start",borderRadius:`${L(f)} ${L(f)} 0 0`,borderCollapse:"separate",borderSpacing:0},[`
          ${t}-cell,
          ${t}-thead > tr > th,
          ${t}-tbody > tr > th,
          ${t}-tbody > tr > td,
          tfoot > tr > th,
          tfoot > tr > td
        `]:{position:"relative",padding:`${L(r)} ${L(o)}`,overflowWrap:"break-word"},[`${t}-title`]:{padding:`${L(r)} ${L(o)}`},[`${t}-thead`]:{"\n          > tr > th,\n          > tr > td\n        ":{position:"relative",color:m,fontWeight:n,textAlign:"start",background:g,borderBottom:C,transition:`background ${v} ease`,"&[colspan]:not([colspan='1'])":{textAlign:"center"},[`&:not(:last-child):not(${t}-selection-column):not(${t}-row-expand-icon-cell):not([colspan])::before`]:{position:"absolute",top:"50%",insetInlineEnd:0,width:1,height:"1.6em",backgroundColor:h,transform:"translateY(-50%)",transition:`background-color ${v}`,content:'""'}},"> tr:not(:last-child) > th[colspan]":{borderBottom:0}},[`${t}-tbody`]:{"> tr":{"> th, > td":{transition:`background ${v}, border-color ${v}`,borderBottom:C,[`
              > ${t}-wrapper:only-child,
              > ${t}-expanded-row-fixed > ${t}-wrapper:only-child
            `]:{[t]:{marginBlock:L(y(r).mul(-1).equal()),marginInline:`${L(y(a).sub(o).equal())}
                ${L(y(o).mul(-1).equal())}`,[`${t}-tbody > tr:last-child > td`]:{borderBottomWidth:0,"&:first-child, &:last-child":{borderRadius:0}}}}},"> th":{position:"relative",color:m,fontWeight:n,textAlign:"start",background:g,borderBottom:C,transition:`background ${v} ease`}}},[`${t}-footer`]:{padding:`${L(r)} ${L(o)}`,color:p,background:b}})}},NL=e=>{const{colorFillAlter:t,colorBgContainer:n,colorTextHeading:r,colorFillSecondary:o,colorFillContent:a,controlItemBgActive:l,controlItemBgActiveHover:s,padding:c,paddingSM:u,paddingXS:d,colorBorderSecondary:f,borderRadiusLG:m,controlHeight:v,colorTextPlaceholder:g,fontSize:h,fontSizeSM:p,lineHeight:b,lineWidth:y,colorIcon:C,colorIconHover:$,opacityLoading:S,controlInteractiveSize:x}=e,E=new Mt(o).onBackground(n).toHexString(),O=new Mt(a).onBackground(n).toHexString(),w=new Mt(t).onBackground(n).toHexString(),I=new Mt(C),P=new Mt($),M=x/2-y,R=M*2+y*3;return{headerBg:w,headerColor:r,headerSortActiveBg:E,headerSortHoverBg:O,bodySortBg:w,rowHoverBg:w,rowSelectedBg:l,rowSelectedHoverBg:s,rowExpandedBg:t,cellPaddingBlock:c,cellPaddingInline:c,cellPaddingBlockMD:u,cellPaddingInlineMD:d,cellPaddingBlockSM:d,cellPaddingInlineSM:d,borderColor:f,headerBorderRadius:m,footerBg:w,footerColor:r,cellFontSize:h,cellFontSizeMD:h,cellFontSizeSM:h,headerSplitColor:f,fixedHeaderSortActiveBg:E,headerFilterHoverBg:a,filterDropdownMenuBg:n,filterDropdownBg:n,expandIconBg:n,selectionColumnWidth:v,stickyScrollBarBg:g,stickyScrollBarBorderRadius:100,expandIconMarginTop:(h*b-y*3)/2-Math.ceil((p*1.4-y*3)/2),headerIconColor:I.clone().setA(I.a*S).toRgbString(),headerIconHoverColor:P.clone().setA(P.a*S).toRgbString(),expandIconHalfInner:M,expandIconSize:R,expandIconScale:x/R}},Dp=2,ML=It("Table",e=>{const{colorTextHeading:t,colorSplit:n,colorBgContainer:r,controlInteractiveSize:o,headerBg:a,headerColor:l,headerSortActiveBg:s,headerSortHoverBg:c,bodySortBg:u,rowHoverBg:d,rowSelectedBg:f,rowSelectedHoverBg:m,rowExpandedBg:v,cellPaddingBlock:g,cellPaddingInline:h,cellPaddingBlockMD:p,cellPaddingInlineMD:b,cellPaddingBlockSM:y,cellPaddingInlineSM:C,borderColor:$,footerBg:S,footerColor:x,headerBorderRadius:E,cellFontSize:O,cellFontSizeMD:w,cellFontSizeSM:I,headerSplitColor:P,fixedHeaderSortActiveBg:M,headerFilterHoverBg:R,filterDropdownBg:N,expandIconBg:T,selectionColumnWidth:j,stickyScrollBarBg:z,calc:_}=e,B=yt(e,{tableFontSize:O,tableBg:r,tableRadius:E,tablePaddingVertical:g,tablePaddingHorizontal:h,tablePaddingVerticalMiddle:p,tablePaddingHorizontalMiddle:b,tablePaddingVerticalSmall:y,tablePaddingHorizontalSmall:C,tableBorderColor:$,tableHeaderTextColor:l,tableHeaderBg:a,tableFooterTextColor:x,tableFooterBg:S,tableHeaderCellSplitColor:P,tableHeaderSortBg:s,tableHeaderSortHoverBg:c,tableBodySortBg:u,tableFixedHeaderSortActiveBg:M,tableHeaderFilterActiveBg:R,tableFilterDropdownBg:N,tableRowHoverBg:d,tableSelectedRowBg:f,tableSelectedRowHoverBg:m,zIndexTableFixed:Dp,zIndexTableSticky:_(Dp).add(1).equal({unit:!1}),tableFontSizeMiddle:w,tableFontSizeSmall:I,tableSelectionColumnWidth:j,tableExpandIconBg:T,tableExpandColumnWidth:_(o).add(_(e.padding).mul(2)).equal(),tableExpandedRowBg:v,tableFilterDropdownWidth:120,tableFilterDropdownHeight:264,tableFilterDropdownSearchWidth:140,tableScrollThumbSize:8,tableScrollThumbBg:z,tableScrollThumbBgHover:t,tableScrollBg:n});return[PL(B),SL(B),zp(B),OL(B),yL(B),gL(B),$L(B),bL(B),zp(B),hL(B),wL(B),CL(B),IL(B),pL(B),EL(B),xL(B),RL(B)]},NL,{unitless:{expandIconScale:!0}}),TL=[],jL=(e,t)=>{var n,r;const{prefixCls:o,className:a,rootClassName:l,style:s,size:c,bordered:u,dropdownPrefixCls:d,dataSource:f,pagination:m,rowSelection:v,rowKey:g="key",rowClassName:h,columns:p,children:b,childrenColumnName:y,onChange:C,getPopupContainer:$,loading:S,expandIcon:x,expandable:E,expandedRowRender:O,expandIconColumnIndex:w,indentSize:I,scroll:P,sortDirections:M,locale:R,showSorterTooltip:N={target:"full-header"},virtual:T}=e;no();const j=i.useMemo(()=>p||jf(b),[p,b]),z=i.useMemo(()=>j.some(Ke=>Ke.responsive),[j]),_=xs(z),B=i.useMemo(()=>{const Ke=new Set(Object.keys(_).filter(Ye=>_[Ye]));return j.filter(Ye=>!Ye.responsive||Ye.responsive.some(at=>Ke.has(at)))},[j,_]),V=Gt(e,["className","style","columns"]),{locale:G=br,direction:q,table:H,renderEmpty:W,getPrefixCls:K,getPopupContainer:U}=i.useContext(ot),te=Sn(c),X=Object.assign(Object.assign({},G.Table),R),ae=f||TL,le=K("table",o),ee=K("dropdown",d),[,Y]=yn(),re=Cn(le),[ne,Z,Q]=ML(le,re),ie=Object.assign(Object.assign({childrenColumnName:y,expandIconColumnIndex:w},E),{expandIcon:(n=E==null?void 0:E.expandIcon)!==null&&n!==void 0?n:(r=H==null?void 0:H.expandable)===null||r===void 0?void 0:r.expandIcon}),{childrenColumnName:de="children"}=ie,he=i.useMemo(()=>ae.some(Ke=>Ke==null?void 0:Ke[de])?"nest":O||E!=null&&E.expandedRowRender?"row":null,[ae]),ye={body:i.useRef(null)},oe=I7(le),ce=i.useRef(null),ge=i.useRef(null);E7(t,()=>Object.assign(Object.assign({},ge.current),{nativeElement:ce.current}));const se=i.useMemo(()=>typeof g=="function"?g:Ke=>Ke==null?void 0:Ke[g],[g]),[be]=iL(ae,de,se),we={},Me=(Ke,Ye,at=!1)=>{var gt,Ot,Pt,Rt;const jt=Object.assign(Object.assign({},we),Ke);at&&((gt=we.resetPagination)===null||gt===void 0||gt.call(we),!((Ot=jt.pagination)===null||Ot===void 0)&&Ot.current&&(jt.pagination.current=1),m&&((Pt=m.onChange)===null||Pt===void 0||Pt.call(m,1,(Rt=jt.pagination)===null||Rt===void 0?void 0:Rt.pageSize))),P&&P.scrollToFirstRowOnChange!==!1&&ye.body.current&&Ow(0,{getContainer:()=>ye.body.current}),C==null||C(jt.pagination,jt.filters,jt.sorter,{currentDataSource:ud(fd(ae,jt.sorterStates,de),jt.filterStates,de),action:Ye})},Te=(Ke,Ye)=>{Me({sorter:Ke,sorterStates:Ye},"sort",!1)},[Se,Fe,Ce,me]=dL({prefixCls:le,mergedColumns:B,onSorterChange:Te,sortDirections:M||["ascend","descend"],tableLocale:X,showSorterTooltip:N}),$e=i.useMemo(()=>fd(ae,Fe,de),[ae,Fe]);we.sorter=me(),we.sorterStates=Fe;const Ee=(Ke,Ye)=>{Me({filters:Ke,filterStates:Ye},"filter",!0)},[Ie,fe,ve]=aL({prefixCls:le,locale:X,dropdownPrefixCls:ee,mergedColumns:B,onFilterChange:Ee,getPopupContainer:$||U,rootClassName:A(l,re)}),xe=ud($e,fe,de);we.filters=ve,we.filterStates=fe;const Re=i.useMemo(()=>{const Ke={};return Object.keys(ve).forEach(Ye=>{ve[Ye]!==null&&(Ke[Ye]=ve[Ye])}),Object.assign(Object.assign({},Ce),{filters:Ke})},[Ce,ve]),[it]=fL(Re),dt=(Ke,Ye)=>{Me({pagination:Object.assign(Object.assign({},we.pagination),{current:Ke,pageSize:Ye})},"paginate")},[Oe,Le]=cL(xe.length,dt,m);we.pagination=m===!1?{}:sL(Oe,m),we.resetPagination=Le;const Ue=i.useMemo(()=>{if(m===!1||!Oe.pageSize)return xe;const{current:Ke=1,total:Ye,pageSize:at=vS}=Oe;return xe.length<Ye?xe.length>at?xe.slice((Ke-1)*at,Ke*at):xe:xe.slice((Ke-1)*at,Ke*at)},[!!m,xe,Oe==null?void 0:Oe.current,Oe==null?void 0:Oe.pageSize,Oe==null?void 0:Oe.total]),[ke,Je]=x7({prefixCls:le,data:xe,pageData:Ue,getRowKey:se,getRecordByKey:be,expandType:he,childrenColumnName:de,locale:X,getPopupContainer:$||U},v),Xe=(Ke,Ye,at)=>{let gt;return typeof h=="function"?gt=A(h(Ke,Ye,at)):gt=A(h),A({[`${le}-row-selected`]:Je.has(se(Ke,Ye))},gt)};ie.__PARENT_RENDER_ICON__=ie.expandIcon,ie.expandIcon=ie.expandIcon||x||O7(X),he==="nest"&&ie.expandIconColumnIndex===void 0?ie.expandIconColumnIndex=v?1:0:ie.expandIconColumnIndex>0&&v&&(ie.expandIconColumnIndex-=1),typeof ie.indentSize!="number"&&(ie.indentSize=typeof I=="number"?I:15);const He=i.useCallback(Ke=>it(ke(Ie(Se(Ke)))),[Se,Ie,ke]);let je,rt;if(m!==!1&&(Oe!=null&&Oe.total)){let Ke;Oe.size?Ke=Oe.size:Ke=te==="small"||te==="middle"?"small":void 0;const Ye=Ot=>i.createElement(Pj,Object.assign({},Oe,{className:A(`${le}-pagination ${le}-pagination-${Ot}`,Oe.className),size:Ke})),at=q==="rtl"?"left":"right",{position:gt}=Oe;if(gt!==null&&Array.isArray(gt)){const Ot=gt.find(jt=>jt.includes("top")),Pt=gt.find(jt=>jt.includes("bottom")),Rt=gt.every(jt=>`${jt}`=="none");!Ot&&!Pt&&!Rt&&(rt=Ye(at)),Ot&&(je=Ye(Ot.toLowerCase().replace("top",""))),Pt&&(rt=Ye(Pt.toLowerCase().replace("bottom","")))}else rt=Ye(at)}let et;typeof S=="boolean"?et={spinning:S}:typeof S=="object"&&(et=Object.assign({spinning:!0},S));const Pe=A(Q,re,`${le}-wrapper`,H==null?void 0:H.className,{[`${le}-wrapper-rtl`]:q==="rtl"},a,l,Z),qe=Object.assign(Object.assign({},H==null?void 0:H.style),s),We=typeof(R==null?void 0:R.emptyText)<"u"?R.emptyText:(W==null?void 0:W("Table"))||i.createElement(Bb,{componentName:"Table"}),tt=T?vL:mL,mt={},ct=i.useMemo(()=>{const{fontSize:Ke,lineHeight:Ye,lineWidth:at,padding:gt,paddingXS:Ot,paddingSM:Pt}=Y,Rt=Math.floor(Ke*Ye);switch(te){case"middle":return Pt*2+Rt+at;case"small":return Ot*2+Rt+at;default:return gt*2+Rt+at}},[Y,te]);return T&&(mt.listItemHeight=ct),ne(i.createElement("div",{ref:ce,className:Pe,style:qe},i.createElement(DC,Object.assign({spinning:!1},et),je,i.createElement(tt,Object.assign({},mt,V,{ref:ge,columns:B,direction:q,expandable:ie,prefixCls:le,className:A({[`${le}-middle`]:te==="middle",[`${le}-small`]:te==="small",[`${le}-bordered`]:u,[`${le}-empty`]:ae.length===0},Q,re,Z),data:Ue,rowKey:se,rowClassName:Xe,emptyText:We,internalHooks:Oi,internalRefs:ye,transformColumns:He,getContainerWidth:oe})),rt)))},zL=i.forwardRef(jL),DL=(e,t)=>{const n=i.useRef(0);return n.current+=1,i.createElement(zL,Object.assign({},e,{ref:t,_renderTimes:n.current}))},oo=i.forwardRef(DL);oo.SELECTION_COLUMN=qr;oo.EXPAND_COLUMN=Lr;oo.SELECTION_ALL=ad;oo.SELECTION_INVERT=id;oo.SELECTION_NONE=ld;oo.Column=f7;oo.ColumnGroup=m7;oo.Summary=qC;const _L=e=>{const{paddingXXS:t,lineWidth:n,tagPaddingHorizontal:r,componentCls:o,calc:a}=e,l=a(r).sub(n).equal(),s=a(t).sub(n).equal();return{[o]:Object.assign(Object.assign({},Tt(e)),{display:"inline-block",height:"auto",marginInlineEnd:e.marginXS,paddingInline:l,fontSize:e.tagFontSize,lineHeight:e.tagLineHeight,whiteSpace:"nowrap",background:e.defaultBg,border:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,borderRadius:e.borderRadiusSM,opacity:1,transition:`all ${e.motionDurationMid}`,textAlign:"start",position:"relative",[`&${o}-rtl`]:{direction:"rtl"},"&, a, a:hover":{color:e.defaultColor},[`${o}-close-icon`]:{marginInlineStart:s,fontSize:e.tagIconSize,color:e.colorIcon,cursor:"pointer",transition:`all ${e.motionDurationMid}`,"&:hover":{color:e.colorTextHeading}},[`&${o}-has-color`]:{borderColor:"transparent",[`&, a, a:hover, ${e.iconCls}-close, ${e.iconCls}-close:hover`]:{color:e.colorTextLightSolid}},"&-checkable":{backgroundColor:"transparent",borderColor:"transparent",cursor:"pointer",[`&:not(${o}-checkable-checked):hover`]:{color:e.colorPrimary,backgroundColor:e.colorFillSecondary},"&:active, &-checked":{color:e.colorTextLightSolid},"&-checked":{backgroundColor:e.colorPrimary,"&:hover":{backgroundColor:e.colorPrimaryHover}},"&:active":{backgroundColor:e.colorPrimaryActive}},"&-hidden":{display:"none"},[`> ${e.iconCls} + span, > span + ${e.iconCls}`]:{marginInlineStart:l}}),[`${o}-borderless`]:{borderColor:"transparent",background:e.tagBorderlessBg}}},Af=e=>{const{lineWidth:t,fontSizeIcon:n,calc:r}=e,o=e.fontSizeSM;return yt(e,{tagFontSize:o,tagLineHeight:L(r(e.lineHeightSM).mul(o).equal()),tagIconSize:r(n).sub(r(t).mul(2)).equal(),tagPaddingHorizontal:8,tagBorderlessBg:e.defaultBg})},Ff=e=>({defaultBg:new Mt(e.colorFillQuaternary).onBackground(e.colorBgContainer).toHexString(),defaultColor:e.colorText}),hS=It("Tag",e=>{const t=Af(e);return _L(t)},Ff);var BL=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const LL=i.forwardRef((e,t)=>{const{prefixCls:n,style:r,className:o,checked:a,children:l,icon:s,onChange:c,onClick:u}=e,d=BL(e,["prefixCls","style","className","checked","children","icon","onChange","onClick"]),{getPrefixCls:f,tag:m}=i.useContext(ot),v=C=>{c==null||c(!a),u==null||u(C)},g=f("tag",n),[h,p,b]=hS(g),y=A(g,`${g}-checkable`,{[`${g}-checkable-checked`]:a},m==null?void 0:m.className,o,p,b);return h(i.createElement("span",Object.assign({},d,{ref:t,style:Object.assign(Object.assign({},r),m==null?void 0:m.style),className:y,onClick:v}),s,i.createElement("span",null,l)))}),HL=e=>es(e,(t,{textColor:n,lightBorderColor:r,lightColor:o,darkColor:a})=>({[`${e.componentCls}${e.componentCls}-${t}`]:{color:n,background:o,borderColor:r,"&-inverse":{color:e.colorTextLightSolid,background:a,borderColor:a},[`&${e.componentCls}-borderless`]:{borderColor:"transparent"}}})),AL=ua(["Tag","preset"],e=>{const t=Af(e);return HL(t)},Ff);function FL(e){return typeof e!="string"?e:e.charAt(0).toUpperCase()+e.slice(1)}const ki=(e,t,n)=>{const r=FL(n);return{[`${e.componentCls}${e.componentCls}-${t}`]:{color:e[`color${n}`],background:e[`color${r}Bg`],borderColor:e[`color${r}Border`],[`&${e.componentCls}-borderless`]:{borderColor:"transparent"}}}},kL=ua(["Tag","status"],e=>{const t=Af(e);return[ki(t,"success","Success"),ki(t,"processing","Info"),ki(t,"error","Error"),ki(t,"warning","Warning")]},Ff);var VL=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const WL=i.forwardRef((e,t)=>{const{prefixCls:n,className:r,rootClassName:o,style:a,children:l,icon:s,color:c,onClose:u,bordered:d=!0,visible:f}=e,m=VL(e,["prefixCls","className","rootClassName","style","children","icon","color","onClose","bordered","visible"]),{getPrefixCls:v,direction:g,tag:h}=i.useContext(ot),[p,b]=i.useState(!0),y=Gt(m,["closeIcon","closable"]);i.useEffect(()=>{f!==void 0&&b(f)},[f]);const C=Es(c),$=h4(c),S=C||$,x=Object.assign(Object.assign({backgroundColor:c&&!S?c:void 0},h==null?void 0:h.style),a),E=v("tag",n),[O,w,I]=hS(E),P=A(E,h==null?void 0:h.className,{[`${E}-${c}`]:S,[`${E}-has-color`]:c&&!S,[`${E}-hidden`]:!p,[`${E}-rtl`]:g==="rtl",[`${E}-borderless`]:!d},r,o,w,I),M=_=>{_.stopPropagation(),u==null||u(_),!_.defaultPrevented&&b(!1)},[,R]=Gd(oa(e),oa(h),{closable:!1,closeIconRender:_=>{const B=i.createElement("span",{className:`${E}-close-icon`,onClick:M},_);return Nd(_,B,V=>({onClick:G=>{var q;(q=V==null?void 0:V.onClick)===null||q===void 0||q.call(V,G),M(G)},className:A(V==null?void 0:V.className,`${E}-close-icon`)}))}}),N=typeof m.onClick=="function"||l&&l.type==="a",T=s||null,j=T?i.createElement(i.Fragment,null,T,l&&i.createElement("span",null,l)):l,z=i.createElement("span",Object.assign({},y,{ref:t,className:P,style:x}),j,R,C&&i.createElement(AL,{key:"preset",prefixCls:E}),$&&i.createElement(kL,{key:"status",prefixCls:E}));return O(N?i.createElement(ci,{component:"Tag"},z):z)}),KL=WL;KL.CheckableTag=LL;function GL(e){const{sizeUnit:t,sizeStep:n}=e,r=n-2;return{sizeXXL:t*(r+10),sizeXL:t*(r+6),sizeLG:t*(r+2),sizeMD:t*(r+2),sizeMS:t*(r+1),size:t*r,sizeSM:t*r,sizeXS:t*(r-1),sizeXXS:t*(r-1)}}const qL=(e,t)=>{const n=t??Zl(e),r=n.fontSizeSM,o=n.controlHeight-4;return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},n),GL(t??e)),Dh(r)),{controlHeight:o}),zh(Object.assign(Object.assign({},n),{controlHeight:o})))},ar=(e,t)=>new Mt(e).setA(t).toRgbString(),Bo=(e,t)=>new Mt(e).lighten(t).toHexString(),UL=e=>{const t=bo(e,{theme:"dark"});return{1:t[0],2:t[1],3:t[2],4:t[3],5:t[6],6:t[5],7:t[4],8:t[6],9:t[5],10:t[4]}},XL=(e,t)=>{const n=e||"#000",r=t||"#fff";return{colorBgBase:n,colorTextBase:r,colorText:ar(r,.85),colorTextSecondary:ar(r,.65),colorTextTertiary:ar(r,.45),colorTextQuaternary:ar(r,.25),colorFill:ar(r,.18),colorFillSecondary:ar(r,.12),colorFillTertiary:ar(r,.08),colorFillQuaternary:ar(r,.04),colorBgSolid:ar(r,.95),colorBgSolidHover:ar(r,1),colorBgSolidActive:ar(r,.9),colorBgElevated:Bo(n,12),colorBgContainer:Bo(n,8),colorBgLayout:Bo(n,0),colorBgSpotlight:Bo(n,26),colorBgBlur:ar(r,.04),colorBorder:Bo(n,26),colorBorderSecondary:Bo(n,19)}},YL=(e,t)=>{const n=Object.keys(Od).map(a=>{const l=bo(e[a],{theme:"dark"});return Array.from({length:10},()=>1).reduce((s,c,u)=>(s[`${a}-${u+1}`]=l[u],s[`${a}${u+1}`]=l[u],s),{})}).reduce((a,l)=>(a=Object.assign(Object.assign({},a),l),a),{}),r=t??Zl(e),o=jh(e,{generateColorPalettes:UL,generateNeutralColorPalettes:XL});return Object.assign(Object.assign(Object.assign(Object.assign({},r),n),o),{colorPrimaryBg:o.colorPrimaryBorder,colorPrimaryBgHover:o.colorPrimaryBorderHover})},HA={defaultSeed:pl.token,defaultAlgorithm:Zl,darkAlgorithm:YL,compactAlgorithm:qL},QL=(e,t,n,r)=>{const{titleMarginBottom:o,fontWeightStrong:a}=r;return{marginBottom:o,color:n,fontWeight:a,fontSize:e,lineHeight:t}},ZL=e=>{const t=[1,2,3,4,5],n={};return t.forEach(r=>{n[`
      h${r}&,
      div&-h${r},
      div&-h${r} > textarea,
      h${r}
    `]=QL(e[`fontSizeHeading${r}`],e[`lineHeightHeading${r}`],e.colorTextHeading,e)}),n},JL=e=>{const{componentCls:t}=e;return{"a&, a":Object.assign(Object.assign({},Id(e)),{userSelect:"text",[`&[disabled], &${t}-disabled`]:{color:e.colorTextDisabled,cursor:"not-allowed","&:active, &:hover":{color:e.colorTextDisabled},"&:active":{pointerEvents:"none"}}})}},eH=e=>({code:{margin:"0 0.2em",paddingInline:"0.4em",paddingBlock:"0.2em 0.1em",fontSize:"85%",fontFamily:e.fontFamilyCode,background:"rgba(150, 150, 150, 0.1)",border:"1px solid rgba(100, 100, 100, 0.2)",borderRadius:3},kbd:{margin:"0 0.2em",paddingInline:"0.4em",paddingBlock:"0.15em 0.1em",fontSize:"90%",fontFamily:e.fontFamilyCode,background:"rgba(150, 150, 150, 0.06)",border:"1px solid rgba(100, 100, 100, 0.2)",borderBottomWidth:2,borderRadius:3},mark:{padding:0,backgroundColor:gl[2]},"u, ins":{textDecoration:"underline",textDecorationSkipInk:"auto"},"s, del":{textDecoration:"line-through"},strong:{fontWeight:e.fontWeightStrong},"ul, ol":{marginInline:0,marginBlock:"0 1em",padding:0,li:{marginInline:"20px 0",marginBlock:0,paddingInline:"4px 0",paddingBlock:0}},ul:{listStyleType:"circle",ul:{listStyleType:"disc"}},ol:{listStyleType:"decimal"},"pre, blockquote":{margin:"1em 0"},pre:{padding:"0.4em 0.6em",whiteSpace:"pre-wrap",wordWrap:"break-word",background:"rgba(150, 150, 150, 0.1)",border:"1px solid rgba(100, 100, 100, 0.2)",borderRadius:3,fontFamily:e.fontFamilyCode,code:{display:"inline",margin:0,padding:0,fontSize:"inherit",fontFamily:"inherit",background:"transparent",border:0}},blockquote:{paddingInline:"0.6em 0",paddingBlock:0,borderInlineStart:"4px solid rgba(100, 100, 100, 0.2)",opacity:.85}}),tH=e=>{const{componentCls:t,paddingSM:n}=e,r=n;return{"&-edit-content":{position:"relative","div&":{insetInlineStart:e.calc(e.paddingSM).mul(-1).equal(),marginTop:e.calc(r).mul(-1).equal(),marginBottom:`calc(1em - ${L(r)})`},[`${t}-edit-content-confirm`]:{position:"absolute",insetInlineEnd:e.calc(e.marginXS).add(2).equal(),insetBlockEnd:e.marginXS,color:e.colorIcon,fontWeight:"normal",fontSize:e.fontSize,fontStyle:"normal",pointerEvents:"none"},textarea:{margin:"0!important",MozTransition:"none",height:"1em"}}}},nH=e=>({[`${e.componentCls}-copy-success`]:{"\n    &,\n    &:hover,\n    &:focus":{color:e.colorSuccess}},[`${e.componentCls}-copy-icon-only`]:{marginInlineStart:0}}),rH=()=>({"\n  a&-ellipsis,\n  span&-ellipsis\n  ":{display:"inline-block",maxWidth:"100%"},"&-ellipsis-single-line":{whiteSpace:"nowrap",overflow:"hidden",textOverflow:"ellipsis","a&, span&":{verticalAlign:"bottom"},"> code":{paddingBlock:0,maxWidth:"calc(100% - 1.2em)",display:"inline-block",overflow:"hidden",textOverflow:"ellipsis",verticalAlign:"bottom",boxSizing:"content-box"}},"&-ellipsis-multiple-line":{display:"-webkit-box",overflow:"hidden",WebkitLineClamp:3,WebkitBoxOrient:"vertical"}}),oH=e=>{const{componentCls:t,titleMarginTop:n}=e;return{[t]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:e.colorText,wordBreak:"break-word",lineHeight:e.lineHeight,[`&${t}-secondary`]:{color:e.colorTextDescription},[`&${t}-success`]:{color:e.colorSuccessText},[`&${t}-warning`]:{color:e.colorWarningText},[`&${t}-danger`]:{color:e.colorErrorText,"a&:active, a&:focus":{color:e.colorErrorTextActive},"a&:hover":{color:e.colorErrorTextHover}},[`&${t}-disabled`]:{color:e.colorTextDisabled,cursor:"not-allowed",userSelect:"none"},"\n        div&,\n        p\n      ":{marginBottom:"1em"}},ZL(e)),{[`
      & + h1${t},
      & + h2${t},
      & + h3${t},
      & + h4${t},
      & + h5${t}
      `]:{marginTop:n},"\n      div,\n      ul,\n      li,\n      p,\n      h1,\n      h2,\n      h3,\n      h4,\n      h5":{"\n        + h1,\n        + h2,\n        + h3,\n        + h4,\n        + h5\n        ":{marginTop:n}}}),eH(e)),JL(e)),{[`
        ${t}-expand,
        ${t}-collapse,
        ${t}-edit,
        ${t}-copy
      `]:Object.assign(Object.assign({},Id(e)),{marginInlineStart:e.marginXXS})}),tH(e)),nH(e)),rH()),{"&-rtl":{direction:"rtl"}})}},aH=()=>({titleMarginTop:"1.2em",titleMarginBottom:"0.5em"}),bS=It("Typography",oH,aH),iH=e=>{const{prefixCls:t,"aria-label":n,className:r,style:o,direction:a,maxLength:l,autoSize:s=!0,value:c,onSave:u,onCancel:d,onEnd:f,component:m,enterIcon:v=i.createElement(MD,null)}=e,g=i.useRef(null),h=i.useRef(!1),p=i.useRef(null),[b,y]=i.useState(c);i.useEffect(()=>{y(c)},[c]),i.useEffect(()=>{var N;if(!((N=g.current)===null||N===void 0)&&N.resizableTextArea){const{textArea:T}=g.current.resizableTextArea;T.focus();const{length:j}=T.value;T.setSelectionRange(j,j)}},[]);const C=({target:N})=>{y(N.value.replace(/[\n\r]/g,""))},$=()=>{h.current=!0},S=()=>{h.current=!1},x=({keyCode:N})=>{h.current||(p.current=N)},E=()=>{u(b.trim())},O=({keyCode:N,ctrlKey:T,altKey:j,metaKey:z,shiftKey:_})=>{p.current!==N||h.current||T||j||z||_||(N===Ne.ENTER?(E(),f==null||f()):N===Ne.ESC&&d())},w=()=>{E()},[I,P,M]=bS(t),R=A(t,`${t}-edit-content`,{[`${t}-rtl`]:a==="rtl",[`${t}-${m}`]:!!m},r,P,M);return I(i.createElement("div",{className:R,style:o},i.createElement(RC,{ref:g,maxLength:l,value:b,onChange:C,onKeyDown:x,onKeyUp:O,onCompositionStart:$,onCompositionEnd:S,onBlur:w,"aria-label":n,rows:1,autoSize:s}),v!==null?cn(v,{className:`${t}-edit-content-confirm`}):null))};var lH=function(){var e=document.getSelection();if(!e.rangeCount)return function(){};for(var t=document.activeElement,n=[],r=0;r<e.rangeCount;r++)n.push(e.getRangeAt(r));switch(t.tagName.toUpperCase()){case"INPUT":case"TEXTAREA":t.blur();break;default:t=null;break}return e.removeAllRanges(),function(){e.type==="Caret"&&e.removeAllRanges(),e.rangeCount||n.forEach(function(o){e.addRange(o)}),t&&t.focus()}},sH=lH,_p={"text/plain":"Text","text/html":"Url",default:"Text"},cH="Copy to clipboard: #{key}, Enter";function uH(e){var t=(/mac os x/i.test(navigator.userAgent)?"⌘":"Ctrl")+"+C";return e.replace(/#{\s*key\s*}/g,t)}function dH(e,t){var n,r,o,a,l,s,c=!1;t||(t={}),n=t.debug||!1;try{o=sH(),a=document.createRange(),l=document.getSelection(),s=document.createElement("span"),s.textContent=e,s.ariaHidden="true",s.style.all="unset",s.style.position="fixed",s.style.top=0,s.style.clip="rect(0, 0, 0, 0)",s.style.whiteSpace="pre",s.style.webkitUserSelect="text",s.style.MozUserSelect="text",s.style.msUserSelect="text",s.style.userSelect="text",s.addEventListener("copy",function(d){if(d.stopPropagation(),t.format)if(d.preventDefault(),typeof d.clipboardData>"u"){n&&console.warn("unable to use e.clipboardData"),n&&console.warn("trying IE specific stuff"),window.clipboardData.clearData();var f=_p[t.format]||_p.default;window.clipboardData.setData(f,e)}else d.clipboardData.clearData(),d.clipboardData.setData(t.format,e);t.onCopy&&(d.preventDefault(),t.onCopy(d.clipboardData))}),document.body.appendChild(s),a.selectNodeContents(s),l.addRange(a);var u=document.execCommand("copy");if(!u)throw new Error("copy command was unsuccessful");c=!0}catch(d){n&&console.error("unable to copy using execCommand: ",d),n&&console.warn("trying IE specific stuff");try{window.clipboardData.setData(t.format||"text",e),t.onCopy&&t.onCopy(window.clipboardData),c=!0}catch(f){n&&console.error("unable to copy using clipboardData: ",f),n&&console.error("falling back to prompt"),r=uH("message"in t?t.message:cH),window.prompt(r,e)}}finally{l&&(typeof l.removeRange=="function"?l.removeRange(a):l.removeAllRanges()),s&&document.body.removeChild(s),o()}return c}var fH=dH;const mH=kp(fH);var vH=function(e,t,n,r){function o(a){return a instanceof n?a:new n(function(l){l(a)})}return new(n||(n=Promise))(function(a,l){function s(d){try{u(r.next(d))}catch(f){l(f)}}function c(d){try{u(r.throw(d))}catch(f){l(f)}}function u(d){d.done?a(d.value):o(d.value).then(s,c)}u((r=r.apply(e,t||[])).next())})};const gH=({copyConfig:e,children:t})=>{const[n,r]=i.useState(!1),[o,a]=i.useState(!1),l=i.useRef(null),s=()=>{l.current&&clearTimeout(l.current)},c={};e.format&&(c.format=e.format),i.useEffect(()=>s,[]);const u=Nt(d=>vH(void 0,void 0,void 0,function*(){var f;d==null||d.preventDefault(),d==null||d.stopPropagation(),a(!0);try{const m=typeof e.text=="function"?yield e.text():e.text;mH(m||kj(t,!0).join("")||"",c),a(!1),r(!0),s(),l.current=setTimeout(()=>{r(!1)},3e3),(f=e.onCopy)===null||f===void 0||f.call(e,d)}catch(m){throw a(!1),m}}));return{copied:n,copyLoading:o,onClick:u}};function Lc(e,t){return i.useMemo(()=>{const n=!!e;return[n,Object.assign(Object.assign({},t),n&&typeof e=="object"?e:null)]},[e])}const pH=e=>{const t=i.useRef(void 0);return i.useEffect(()=>{t.current=e}),t.current},hH=(e,t,n)=>i.useMemo(()=>e===!0?{title:t??n}:i.isValidElement(e)?{title:e}:typeof e=="object"?Object.assign({title:t??n},e):{title:e},[e,t,n]);var bH=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const yS=i.forwardRef((e,t)=>{const{prefixCls:n,component:r="article",className:o,rootClassName:a,setContentRef:l,children:s,direction:c,style:u}=e,d=bH(e,["prefixCls","component","className","rootClassName","setContentRef","children","direction","style"]),{getPrefixCls:f,direction:m,className:v,style:g}=tn("typography"),h=c??m,p=l?un(t,l):t,b=f("typography",n),[y,C,$]=bS(b),S=A(b,v,{[`${b}-rtl`]:h==="rtl"},o,a,C,$),x=Object.assign(Object.assign({},g),u);return y(i.createElement(r,Object.assign({className:S,style:x,ref:p},d),s))});function Bp(e){return e===!1?[!1,!1]:Array.isArray(e)?e:[e]}function Hc(e,t,n){return e===!0||e===void 0?t:e||n&&t}function yH(e){const t=document.createElement("em");e.appendChild(t);const n=e.getBoundingClientRect(),r=t.getBoundingClientRect();return e.removeChild(t),n.left>r.left||r.right>n.right||n.top>r.top||r.bottom>n.bottom}const kf=e=>["string","number"].includes(typeof e),CH=({prefixCls:e,copied:t,locale:n,iconOnly:r,tooltips:o,icon:a,tabIndex:l,onCopy:s,loading:c})=>{const u=Bp(o),d=Bp(a),{copied:f,copy:m}=n??{},v=t?f:m,g=Hc(u[t?1:0],v),h=typeof g=="string"?g:v;return i.createElement($r,{title:g,getPopupContainer:p=>p.parentNode},i.createElement("button",{type:"button",className:A(`${e}-copy`,{[`${e}-copy-success`]:t,[`${e}-copy-icon-only`]:r}),onClick:s,"aria-label":h,tabIndex:l},t?Hc(d[1],i.createElement(Jd,null),!0):Hc(d[0],c?i.createElement(Jr,null):i.createElement(gD,null),!0)))},Vi=i.forwardRef(({style:e,children:t},n)=>{const r=i.useRef(null);return i.useImperativeHandle(n,()=>({isExceed:()=>{const o=r.current;return o.scrollHeight>o.clientHeight},getHeight:()=>r.current.clientHeight})),i.createElement("span",{"aria-hidden":!0,ref:r,style:Object.assign({position:"fixed",display:"block",left:0,top:0,pointerEvents:"none",backgroundColor:"rgba(255, 0, 0, 0.65)"},e)},t)}),SH=e=>e.reduce((t,n)=>t+(kf(n)?String(n).length:1),0);function Lp(e,t){let n=0;const r=[];for(let o=0;o<e.length;o+=1){if(n===t)return r;const a=e[o],s=kf(a)?String(a).length:1,c=n+s;if(c>t){const u=t-n;return r.push(String(a).slice(0,u)),r}r.push(a),n=c}return e}const Ac=0,Fc=1,kc=2,Vc=3,Hp=4,Wi={display:"-webkit-box",overflow:"hidden",WebkitBoxOrient:"vertical"};function $H(e){const{enableMeasure:t,width:n,text:r,children:o,rows:a,expanded:l,miscDeps:s,onEllipsis:c}=e,u=i.useMemo(()=>xn(r),[r]),d=i.useMemo(()=>SH(u),[r]),f=i.useMemo(()=>o(u,!1),[r]),[m,v]=i.useState(null),g=i.useRef(null),h=i.useRef(null),p=i.useRef(null),b=i.useRef(null),y=i.useRef(null),[C,$]=i.useState(!1),[S,x]=i.useState(Ac),[E,O]=i.useState(0),[w,I]=i.useState(null);wt(()=>{x(t&&n&&d?Fc:Ac)},[n,r,a,t,u]),wt(()=>{var N,T,j,z;if(S===Fc){x(kc);const _=h.current&&getComputedStyle(h.current).whiteSpace;I(_)}else if(S===kc){const _=!!(!((N=p.current)===null||N===void 0)&&N.isExceed());x(_?Vc:Hp),v(_?[0,d]:null),$(_);const B=((T=p.current)===null||T===void 0?void 0:T.getHeight())||0,V=a===1?0:((j=b.current)===null||j===void 0?void 0:j.getHeight())||0,G=((z=y.current)===null||z===void 0?void 0:z.getHeight())||0,q=Math.max(B,V+G);O(q+1),c(_)}},[S]);const P=m?Math.ceil((m[0]+m[1])/2):0;wt(()=>{var N;const[T,j]=m||[0,0];if(T!==j){const _=(((N=g.current)===null||N===void 0?void 0:N.getHeight())||0)>E;let B=P;j-T===1&&(B=_?T:j),v(_?[T,B]:[B,j])}},[m,P]);const M=i.useMemo(()=>{if(!t)return o(u,!1);if(S!==Vc||!m||m[0]!==m[1]){const N=o(u,!1);return[Hp,Ac].includes(S)?N:i.createElement("span",{style:Object.assign(Object.assign({},Wi),{WebkitLineClamp:a})},N)}return o(l?u:Lp(u,m[0]),C)},[l,S,m,u].concat(pe(s))),R={width:n,margin:0,padding:0,whiteSpace:w==="nowrap"?"normal":"inherit"};return i.createElement(i.Fragment,null,M,S===kc&&i.createElement(i.Fragment,null,i.createElement(Vi,{style:Object.assign(Object.assign(Object.assign({},R),Wi),{WebkitLineClamp:a}),ref:p},f),i.createElement(Vi,{style:Object.assign(Object.assign(Object.assign({},R),Wi),{WebkitLineClamp:a-1}),ref:b},f),i.createElement(Vi,{style:Object.assign(Object.assign(Object.assign({},R),Wi),{WebkitLineClamp:1}),ref:y},o([],!0))),S===Vc&&m&&m[0]!==m[1]&&i.createElement(Vi,{style:Object.assign(Object.assign({},R),{top:400}),ref:g},o(Lp(u,P),!0)),S===Fc&&i.createElement("span",{style:{whiteSpace:"inherit"},ref:h}))}const xH=({enableEllipsis:e,isEllipsis:t,children:n,tooltipProps:r})=>!(r!=null&&r.title)||!e?n:i.createElement($r,Object.assign({open:t?void 0:!1},r),n);var wH=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};function EH({mark:e,code:t,underline:n,delete:r,strong:o,keyboard:a,italic:l},s){let c=s;function u(d,f){f&&(c=i.createElement(d,{},c))}return u("strong",o),u("u",n),u("del",r),u("code",t),u("mark",e),u("kbd",a),u("i",l),c}const OH="...",Ap=["delete","mark","code","underline","strong","keyboard","italic"],Hs=i.forwardRef((e,t)=>{var n;const{prefixCls:r,className:o,style:a,type:l,disabled:s,children:c,ellipsis:u,editable:d,copyable:f,component:m,title:v}=e,g=wH(e,["prefixCls","className","style","type","disabled","children","ellipsis","editable","copyable","component","title"]),{getPrefixCls:h,direction:p}=i.useContext(ot),[b]=Kn("Text"),y=i.useRef(null),C=i.useRef(null),$=h("typography",r),S=Gt(g,Ap),[x,E]=Lc(d),[O,w]=Lt(!1,{value:E.editing}),{triggerType:I=["icon"]}=E,P=fe=>{var ve;fe&&((ve=E.onStart)===null||ve===void 0||ve.call(E)),w(fe)},M=pH(O);wt(()=>{var fe;!O&&M&&((fe=C.current)===null||fe===void 0||fe.focus())},[O]);const R=fe=>{fe==null||fe.preventDefault(),P(!0)},N=fe=>{var ve;(ve=E.onChange)===null||ve===void 0||ve.call(E,fe),P(!1)},T=()=>{var fe;(fe=E.onCancel)===null||fe===void 0||fe.call(E),P(!1)},[j,z]=Lc(f),{copied:_,copyLoading:B,onClick:V}=gH({copyConfig:z,children:c}),[G,q]=i.useState(!1),[H,W]=i.useState(!1),[K,U]=i.useState(!1),[te,X]=i.useState(!1),[ae,le]=i.useState(!0),[ee,Y]=Lc(u,{expandable:!1,symbol:fe=>fe?b==null?void 0:b.collapse:b==null?void 0:b.expand}),[re,ne]=Lt(Y.defaultExpanded||!1,{value:Y.expanded}),Z=ee&&(!re||Y.expandable==="collapsible"),{rows:Q=1}=Y,ie=i.useMemo(()=>Z&&(Y.suffix!==void 0||Y.onEllipsis||Y.expandable||x||j),[Z,Y,x,j]);wt(()=>{ee&&!ie&&(q(Hu("webkitLineClamp")),W(Hu("textOverflow")))},[ie,ee]);const[de,he]=i.useState(Z),ye=i.useMemo(()=>ie?!1:Q===1?H:G,[ie,H,G]);wt(()=>{he(ye&&Z)},[ye,Z]);const oe=Z&&(de?te:K),ce=Z&&Q===1&&de,ge=Z&&Q>1&&de,se=(fe,ve)=>{var xe;ne(ve.expanded),(xe=Y.onExpand)===null||xe===void 0||xe.call(Y,fe,ve)},[be,we]=i.useState(0),Me=({offsetWidth:fe})=>{we(fe)},Te=fe=>{var ve;U(fe),K!==fe&&((ve=Y.onEllipsis)===null||ve===void 0||ve.call(Y,fe))};i.useEffect(()=>{const fe=y.current;if(ee&&de&&fe){const ve=yH(fe);te!==ve&&X(ve)}},[ee,de,c,ge,ae,be]),i.useEffect(()=>{const fe=y.current;if(typeof IntersectionObserver>"u"||!fe||!de||!Z)return;const ve=new IntersectionObserver(()=>{le(!!fe.offsetParent)});return ve.observe(fe),()=>{ve.disconnect()}},[de,Z]);const Se=hH(Y.tooltip,E.text,c),Fe=i.useMemo(()=>{if(!(!ee||de))return[E.text,c,v,Se.title].find(kf)},[ee,de,v,Se.title,oe]);if(O)return i.createElement(iH,{value:(n=E.text)!==null&&n!==void 0?n:typeof c=="string"?c:"",onSave:N,onCancel:T,onEnd:E.onEnd,prefixCls:$,className:o,style:a,direction:p,component:m,maxLength:E.maxLength,autoSize:E.autoSize,enterIcon:E.enterIcon});const Ce=()=>{const{expandable:fe,symbol:ve}=Y;return fe?i.createElement("button",{type:"button",key:"expand",className:`${$}-${re?"collapse":"expand"}`,onClick:xe=>se(xe,{expanded:!re}),"aria-label":re?b.collapse:b==null?void 0:b.expand},typeof ve=="function"?ve(re):ve):null},me=()=>{if(!x)return;const{icon:fe,tooltip:ve,tabIndex:xe}=E,Re=xn(ve)[0]||(b==null?void 0:b.edit),it=typeof Re=="string"?Re:"";return I.includes("icon")?i.createElement($r,{key:"edit",title:ve===!1?"":Re},i.createElement("button",{type:"button",ref:C,className:`${$}-edit`,onClick:R,"aria-label":it,tabIndex:xe},fe||i.createElement(RD,{role:"button"}))):null},$e=()=>j?i.createElement(CH,Object.assign({key:"copy"},z,{prefixCls:$,copied:_,locale:b,onCopy:V,loading:B,iconOnly:c==null})):null,Ee=fe=>[fe&&Ce(),me(),$e()],Ie=fe=>[fe&&!re&&i.createElement("span",{"aria-hidden":!0,key:"ellipsis"},OH),Y.suffix,Ee(fe)];return i.createElement(Bn,{onResize:Me,disabled:!Z},fe=>i.createElement(xH,{tooltipProps:Se,enableEllipsis:Z,isEllipsis:oe},i.createElement(yS,Object.assign({className:A({[`${$}-${l}`]:l,[`${$}-disabled`]:s,[`${$}-ellipsis`]:ee,[`${$}-ellipsis-single-line`]:ce,[`${$}-ellipsis-multiple-line`]:ge},o),prefixCls:r,style:Object.assign(Object.assign({},a),{WebkitLineClamp:ge?Q:void 0}),component:m,ref:un(fe,y,t),direction:p,onClick:I.includes("text")?R:void 0,"aria-label":Fe==null?void 0:Fe.toString(),title:v},S),i.createElement($H,{enableMeasure:Z&&!de,text:c,rows:Q,width:be,onEllipsis:Te,expanded:re,miscDeps:[_,re,B,x,j,b].concat(pe(Ap.map(ve=>e[ve])))},(ve,xe)=>EH(e,i.createElement(i.Fragment,null,ve.length>0&&xe&&!re&&Fe?i.createElement("span",{key:"show-content","aria-hidden":!0},ve):ve,Ie(xe)))))))});var IH=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const RH=i.forwardRef((e,t)=>{var{ellipsis:n,rel:r}=e,o=IH(e,["ellipsis","rel"]);const a=Object.assign(Object.assign({},o),{rel:r===void 0&&o.target==="_blank"?"noopener noreferrer":r});return delete a.navigate,i.createElement(Hs,Object.assign({},a,{ref:t,ellipsis:!!n,component:"a"}))}),PH=i.forwardRef((e,t)=>i.createElement(Hs,Object.assign({ref:t},e,{component:"div"})));var NH=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const MH=(e,t)=>{var{ellipsis:n}=e,r=NH(e,["ellipsis"]);const o=i.useMemo(()=>n&&typeof n=="object"?Gt(n,["expandable","rows"]):n,[n]);return i.createElement(Hs,Object.assign({ref:t},r,{ellipsis:o,component:"span"}))},TH=i.forwardRef(MH);var jH=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const zH=[1,2,3,4,5],DH=i.forwardRef((e,t)=>{const{level:n=1}=e,r=jH(e,["level"]),o=zH.includes(n)?`h${n}`:"h1";return i.createElement(Hs,Object.assign({ref:t},r,{component:o}))}),As=yS;As.Text=TH;As.Link=RH;As.Title=DH;As.Paragraph=PH;const Wc=function(e,t){if(e&&t){var n=Array.isArray(t)?t:t.split(","),r=e.name||"",o=e.type||"",a=o.replace(/\/.*$/,"");return n.some(function(l){var s=l.trim();if(/^\*(\/\*)?$/.test(l))return!0;if(s.charAt(0)==="."){var c=r.toLowerCase(),u=s.toLowerCase(),d=[u];return(u===".jpg"||u===".jpeg")&&(d=[".jpg",".jpeg"]),d.some(function(f){return c.endsWith(f)})}return/\/\*$/.test(s)?a===s.replace(/\/.*$/,""):o===s?!0:/^\w+$/.test(s)?(Kt(!1,"Upload takes an invalidate 'accept' type '".concat(s,"'.Skip for check.")),!0):!1})}return!0};function _H(e,t){var n="cannot ".concat(e.method," ").concat(e.action," ").concat(t.status,"'"),r=new Error(n);return r.status=t.status,r.method=e.method,r.url=e.action,r}function Fp(e){var t=e.responseText||e.response;if(!t)return t;try{return JSON.parse(t)}catch{return t}}function BH(e){var t=new XMLHttpRequest;e.onProgress&&t.upload&&(t.upload.onprogress=function(a){a.total>0&&(a.percent=a.loaded/a.total*100),e.onProgress(a)});var n=new FormData;e.data&&Object.keys(e.data).forEach(function(o){var a=e.data[o];if(Array.isArray(a)){a.forEach(function(l){n.append("".concat(o,"[]"),l)});return}n.append(o,a)}),e.file instanceof Blob?n.append(e.filename,e.file,e.file.name):n.append(e.filename,e.file),t.onerror=function(a){e.onError(a)},t.onload=function(){return t.status<200||t.status>=300?e.onError(_H(e,t),Fp(t)):e.onSuccess(Fp(t),t)},t.open(e.method,e.action,!0),e.withCredentials&&"withCredentials"in t&&(t.withCredentials=!0);var r=e.headers||{};return r["X-Requested-With"]!==null&&t.setRequestHeader("X-Requested-With","XMLHttpRequest"),Object.keys(r).forEach(function(o){r[o]!==null&&t.setRequestHeader(o,r[o])}),t.send(n),{abort:function(){t.abort()}}}var LH=function(){var e=_n(kt().mark(function t(n,r){var o,a,l,s,c,u,d,f;return kt().wrap(function(v){for(;;)switch(v.prev=v.next){case 0:u=function(){return u=_n(kt().mark(function h(p){return kt().wrap(function(y){for(;;)switch(y.prev=y.next){case 0:return y.abrupt("return",new Promise(function(C){p.file(function($){r($)?(p.fullPath&&!$.webkitRelativePath&&(Object.defineProperties($,{webkitRelativePath:{writable:!0}}),$.webkitRelativePath=p.fullPath.replace(/^\//,""),Object.defineProperties($,{webkitRelativePath:{writable:!1}})),C($)):C(null)})}));case 1:case"end":return y.stop()}},h)})),u.apply(this,arguments)},c=function(h){return u.apply(this,arguments)},s=function(){return s=_n(kt().mark(function h(p){var b,y,C,$,S;return kt().wrap(function(E){for(;;)switch(E.prev=E.next){case 0:b=p.createReader(),y=[];case 2:return E.next=5,new Promise(function(O){b.readEntries(O,function(){return O([])})});case 5:if(C=E.sent,$=C.length,$){E.next=9;break}return E.abrupt("break",12);case 9:for(S=0;S<$;S++)y.push(C[S]);E.next=2;break;case 12:return E.abrupt("return",y);case 13:case"end":return E.stop()}},h)})),s.apply(this,arguments)},l=function(h){return s.apply(this,arguments)},o=[],a=[],n.forEach(function(g){return a.push(g.webkitGetAsEntry())}),d=function(){var g=_n(kt().mark(function h(p,b){var y,C;return kt().wrap(function(S){for(;;)switch(S.prev=S.next){case 0:if(p){S.next=2;break}return S.abrupt("return");case 2:if(p.path=b||"",!p.isFile){S.next=10;break}return S.next=6,c(p);case 6:y=S.sent,y&&o.push(y),S.next=15;break;case 10:if(!p.isDirectory){S.next=15;break}return S.next=13,l(p);case 13:C=S.sent,a.push.apply(a,pe(C));case 15:case"end":return S.stop()}},h)}));return function(p,b){return g.apply(this,arguments)}}(),f=0;case 9:if(!(f<a.length)){v.next=15;break}return v.next=12,d(a[f]);case 12:f++,v.next=9;break;case 15:return v.abrupt("return",o);case 16:case"end":return v.stop()}},t)}));return function(n,r){return e.apply(this,arguments)}}(),HH=+new Date,AH=0;function Kc(){return"rc-upload-".concat(HH,"-").concat(++AH)}var FH=["component","prefixCls","className","classNames","disabled","id","name","style","styles","multiple","accept","capture","children","directory","openFileDialogOnClick","onMouseEnter","onMouseLeave","hasControlInside"],kH=function(e){tr(n,e);var t=ur(n);function n(){var r;Zt(this,n);for(var o=arguments.length,a=new Array(o),l=0;l<o;l++)a[l]=arguments[l];return r=t.call.apply(t,[this].concat(a)),D(Ve(r),"state",{uid:Kc()}),D(Ve(r),"reqs",{}),D(Ve(r),"fileInput",void 0),D(Ve(r),"_isMounted",void 0),D(Ve(r),"onChange",function(s){var c=r.props,u=c.accept,d=c.directory,f=s.target.files,m=pe(f).filter(function(v){return!d||Wc(v,u)});r.uploadFiles(m),r.reset()}),D(Ve(r),"onClick",function(s){var c=r.fileInput;if(c){var u=s.target,d=r.props.onClick;if(u&&u.tagName==="BUTTON"){var f=c.parentNode;f.focus(),u.blur()}c.click(),d&&d(s)}}),D(Ve(r),"onKeyDown",function(s){s.key==="Enter"&&r.onClick(s)}),D(Ve(r),"onDataTransferFiles",function(){var s=_n(kt().mark(function c(u,d){var f,m,v,g,h,p,b;return kt().wrap(function(C){for(;;)switch(C.prev=C.next){case 0:if(f=r.props,m=f.multiple,v=f.accept,g=f.directory,h=pe(u.items||[]),p=pe(u.files||[]),(p.length>0||h.some(function($){return $.kind==="file"}))&&(d==null||d()),!g){C.next=11;break}return C.next=7,LH(Array.prototype.slice.call(h),function($){return Wc($,r.props.accept)});case 7:p=C.sent,r.uploadFiles(p),C.next=14;break;case 11:b=pe(p).filter(function($){return Wc($,v)}),m===!1&&(b=p.slice(0,1)),r.uploadFiles(b);case 14:case"end":return C.stop()}},c)}));return function(c,u){return s.apply(this,arguments)}}()),D(Ve(r),"onFilePaste",function(){var s=_n(kt().mark(function c(u){var d,f;return kt().wrap(function(v){for(;;)switch(v.prev=v.next){case 0:if(d=r.props.pastable,d){v.next=3;break}return v.abrupt("return");case 3:if(u.type!=="paste"){v.next=6;break}return f=u.clipboardData,v.abrupt("return",r.onDataTransferFiles(f,function(){u.preventDefault()}));case 6:case"end":return v.stop()}},c)}));return function(c){return s.apply(this,arguments)}}()),D(Ve(r),"onFileDragOver",function(s){s.preventDefault()}),D(Ve(r),"onFileDrop",function(){var s=_n(kt().mark(function c(u){var d;return kt().wrap(function(m){for(;;)switch(m.prev=m.next){case 0:if(u.preventDefault(),u.type!=="drop"){m.next=4;break}return d=u.dataTransfer,m.abrupt("return",r.onDataTransferFiles(d));case 4:case"end":return m.stop()}},c)}));return function(c){return s.apply(this,arguments)}}()),D(Ve(r),"uploadFiles",function(s){var c=pe(s),u=c.map(function(d){return d.uid=Kc(),r.processFile(d,c)});Promise.all(u).then(function(d){var f=r.props.onBatchStart;f==null||f(d.map(function(m){var v=m.origin,g=m.parsedFile;return{file:v,parsedFile:g}})),d.filter(function(m){return m.parsedFile!==null}).forEach(function(m){r.post(m)})})}),D(Ve(r),"processFile",function(){var s=_n(kt().mark(function c(u,d){var f,m,v,g,h,p,b,y,C;return kt().wrap(function(S){for(;;)switch(S.prev=S.next){case 0:if(f=r.props.beforeUpload,m=u,!f){S.next=14;break}return S.prev=3,S.next=6,f(u,d);case 6:m=S.sent,S.next=12;break;case 9:S.prev=9,S.t0=S.catch(3),m=!1;case 12:if(m!==!1){S.next=14;break}return S.abrupt("return",{origin:u,parsedFile:null,action:null,data:null});case 14:if(v=r.props.action,typeof v!="function"){S.next=21;break}return S.next=18,v(u);case 18:g=S.sent,S.next=22;break;case 21:g=v;case 22:if(h=r.props.data,typeof h!="function"){S.next=29;break}return S.next=26,h(u);case 26:p=S.sent,S.next=30;break;case 29:p=h;case 30:return b=(Qe(m)==="object"||typeof m=="string")&&m?m:u,b instanceof File?y=b:y=new File([b],u.name,{type:u.type}),C=y,C.uid=u.uid,S.abrupt("return",{origin:u,data:p,parsedFile:C,action:g});case 35:case"end":return S.stop()}},c,null,[[3,9]])}));return function(c,u){return s.apply(this,arguments)}}()),D(Ve(r),"saveFileInput",function(s){r.fileInput=s}),r}return Jt(n,[{key:"componentDidMount",value:function(){this._isMounted=!0;var o=this.props.pastable;o&&document.addEventListener("paste",this.onFilePaste)}},{key:"componentWillUnmount",value:function(){this._isMounted=!1,this.abort(),document.removeEventListener("paste",this.onFilePaste)}},{key:"componentDidUpdate",value:function(o){var a=this.props.pastable;a&&!o.pastable?document.addEventListener("paste",this.onFilePaste):!a&&o.pastable&&document.removeEventListener("paste",this.onFilePaste)}},{key:"post",value:function(o){var a=this,l=o.data,s=o.origin,c=o.action,u=o.parsedFile;if(this._isMounted){var d=this.props,f=d.onStart,m=d.customRequest,v=d.name,g=d.headers,h=d.withCredentials,p=d.method,b=s.uid,y=m||BH,C={action:c,filename:v,data:l,file:u,headers:g,withCredentials:h,method:p||"post",onProgress:function(S){var x=a.props.onProgress;x==null||x(S,u)},onSuccess:function(S,x){var E=a.props.onSuccess;E==null||E(S,u,x),delete a.reqs[b]},onError:function(S,x){var E=a.props.onError;E==null||E(S,x,u),delete a.reqs[b]}};f(s),this.reqs[b]=y(C)}}},{key:"reset",value:function(){this.setState({uid:Kc()})}},{key:"abort",value:function(o){var a=this.reqs;if(o){var l=o.uid?o.uid:o;a[l]&&a[l].abort&&a[l].abort(),delete a[l]}else Object.keys(a).forEach(function(s){a[s]&&a[s].abort&&a[s].abort(),delete a[s]})}},{key:"render",value:function(){var o=this.props,a=o.component,l=o.prefixCls,s=o.className,c=o.classNames,u=c===void 0?{}:c,d=o.disabled,f=o.id,m=o.name,v=o.style,g=o.styles,h=g===void 0?{}:g,p=o.multiple,b=o.accept,y=o.capture,C=o.children,$=o.directory,S=o.openFileDialogOnClick,x=o.onMouseEnter,E=o.onMouseLeave,O=o.hasControlInside,w=ft(o,FH),I=A(D(D(D({},l,!0),"".concat(l,"-disabled"),d),s,s)),P=$?{directory:"directory",webkitdirectory:"webkitdirectory"}:{},M=d?{}:{onClick:S?this.onClick:function(){},onKeyDown:S?this.onKeyDown:function(){},onMouseEnter:x,onMouseLeave:E,onDrop:this.onFileDrop,onDragOver:this.onFileDragOver,tabIndex:O?void 0:"0"};return F.createElement(a,ue({},M,{className:I,role:O?void 0:"button",style:v}),F.createElement("input",ue({},rn(w,{aria:!0,data:!0}),{id:f,name:m,disabled:d,type:"file",ref:this.saveFileInput,onClick:function(N){return N.stopPropagation()},key:this.state.uid,style:k({display:"none"},h.input),className:u.input,accept:b},P,{multiple:p,onChange:this.onChange},y!=null?{capture:y}:{})),C)}}]),n}(i.Component);function Gc(){}var md=function(e){tr(n,e);var t=ur(n);function n(){var r;Zt(this,n);for(var o=arguments.length,a=new Array(o),l=0;l<o;l++)a[l]=arguments[l];return r=t.call.apply(t,[this].concat(a)),D(Ve(r),"uploader",void 0),D(Ve(r),"saveUploader",function(s){r.uploader=s}),r}return Jt(n,[{key:"abort",value:function(o){this.uploader.abort(o)}},{key:"render",value:function(){return F.createElement(kH,ue({},this.props,{ref:this.saveUploader}))}}]),n}(i.Component);D(md,"defaultProps",{component:"span",prefixCls:"rc-upload",data:{},headers:{},name:"file",multipart:!1,onStart:Gc,onError:Gc,onSuccess:Gc,multiple:!1,beforeUpload:null,customRequest:null,withCredentials:!1,openFileDialogOnClick:!0,hasControlInside:!1});const VH=e=>{const{componentCls:t,iconCls:n}=e;return{[`${t}-wrapper`]:{[`${t}-drag`]:{position:"relative",width:"100%",height:"100%",textAlign:"center",background:e.colorFillAlter,border:`${L(e.lineWidth)} dashed ${e.colorBorder}`,borderRadius:e.borderRadiusLG,cursor:"pointer",transition:`border-color ${e.motionDurationSlow}`,[t]:{padding:e.padding},[`${t}-btn`]:{display:"table",width:"100%",height:"100%",outline:"none",borderRadius:e.borderRadiusLG,"&:focus-visible":{outline:`${L(e.lineWidthFocus)} solid ${e.colorPrimaryBorder}`}},[`${t}-drag-container`]:{display:"table-cell",verticalAlign:"middle"},[`
          &:not(${t}-disabled):hover,
          &-hover:not(${t}-disabled)
        `]:{borderColor:e.colorPrimaryHover},[`p${t}-drag-icon`]:{marginBottom:e.margin,[n]:{color:e.colorPrimary,fontSize:e.uploadThumbnailSize}},[`p${t}-text`]:{margin:`0 0 ${L(e.marginXXS)}`,color:e.colorTextHeading,fontSize:e.fontSizeLG},[`p${t}-hint`]:{color:e.colorTextDescription,fontSize:e.fontSize},[`&${t}-disabled`]:{[`p${t}-drag-icon ${n},
            p${t}-text,
            p${t}-hint
          `]:{color:e.colorTextDisabled}}}}}},WH=e=>{const{componentCls:t,iconCls:n,fontSize:r,lineHeight:o,calc:a}=e,l=`${t}-list-item`,s=`${l}-actions`,c=`${l}-action`;return{[`${t}-wrapper`]:{[`${t}-list`]:Object.assign(Object.assign({},yr()),{lineHeight:e.lineHeight,[l]:{position:"relative",height:a(e.lineHeight).mul(r).equal(),marginTop:e.marginXS,fontSize:r,display:"flex",alignItems:"center",transition:`background-color ${e.motionDurationSlow}`,borderRadius:e.borderRadiusSM,"&:hover":{backgroundColor:e.controlItemBgHover},[`${l}-name`]:Object.assign(Object.assign({},sr),{padding:`0 ${L(e.paddingXS)}`,lineHeight:o,flex:"auto",transition:`all ${e.motionDurationSlow}`}),[s]:{whiteSpace:"nowrap",[c]:{opacity:0},[n]:{color:e.actionsColor,transition:`all ${e.motionDurationSlow}`},[`
              ${c}:focus-visible,
              &.picture ${c}
            `]:{opacity:1}},[`${t}-icon ${n}`]:{color:e.colorIcon,fontSize:r},[`${l}-progress`]:{position:"absolute",bottom:e.calc(e.uploadProgressOffset).mul(-1).equal(),width:"100%",paddingInlineStart:a(r).add(e.paddingXS).equal(),fontSize:r,lineHeight:0,pointerEvents:"none","> div":{margin:0}}},[`${l}:hover ${c}`]:{opacity:1},[`${l}-error`]:{color:e.colorError,[`${l}-name, ${t}-icon ${n}`]:{color:e.colorError},[s]:{[`${n}, ${n}:hover`]:{color:e.colorError},[c]:{opacity:1}}},[`${t}-list-item-container`]:{transition:`opacity ${e.motionDurationSlow}, height ${e.motionDurationSlow}`,"&::before":{display:"table",width:0,height:0,content:'""'}}})}}},KH=e=>{const{componentCls:t}=e,n=new $t("uploadAnimateInlineIn",{from:{width:0,height:0,padding:0,opacity:0,margin:e.calc(e.marginXS).div(-2).equal()}}),r=new $t("uploadAnimateInlineOut",{to:{width:0,height:0,padding:0,opacity:0,margin:e.calc(e.marginXS).div(-2).equal()}}),o=`${t}-animate-inline`;return[{[`${t}-wrapper`]:{[`${o}-appear, ${o}-enter, ${o}-leave`]:{animationDuration:e.motionDurationSlow,animationTimingFunction:e.motionEaseInOutCirc,animationFillMode:"forwards"},[`${o}-appear, ${o}-enter`]:{animationName:n},[`${o}-leave`]:{animationName:r}}},{[`${t}-wrapper`]:T0(e)},n,r]},GH=e=>{const{componentCls:t,iconCls:n,uploadThumbnailSize:r,uploadProgressOffset:o,calc:a}=e,l=`${t}-list`,s=`${l}-item`;return{[`${t}-wrapper`]:{[`
        ${l}${l}-picture,
        ${l}${l}-picture-card,
        ${l}${l}-picture-circle
      `]:{[s]:{position:"relative",height:a(r).add(a(e.lineWidth).mul(2)).add(a(e.paddingXS).mul(2)).equal(),padding:e.paddingXS,border:`${L(e.lineWidth)} ${e.lineType} ${e.colorBorder}`,borderRadius:e.borderRadiusLG,"&:hover":{background:"transparent"},[`${s}-thumbnail`]:Object.assign(Object.assign({},sr),{width:r,height:r,lineHeight:L(a(r).add(e.paddingSM).equal()),textAlign:"center",flex:"none",[n]:{fontSize:e.fontSizeHeading2,color:e.colorPrimary},img:{display:"block",width:"100%",height:"100%",overflow:"hidden"}}),[`${s}-progress`]:{bottom:o,width:`calc(100% - ${L(a(e.paddingSM).mul(2).equal())})`,marginTop:0,paddingInlineStart:a(r).add(e.paddingXS).equal()}},[`${s}-error`]:{borderColor:e.colorError,[`${s}-thumbnail ${n}`]:{[`svg path[fill='${Jo[0]}']`]:{fill:e.colorErrorBg},[`svg path[fill='${Jo.primary}']`]:{fill:e.colorError}}},[`${s}-uploading`]:{borderStyle:"dashed",[`${s}-name`]:{marginBottom:o}}},[`${l}${l}-picture-circle ${s}`]:{[`&, &::before, ${s}-thumbnail`]:{borderRadius:"50%"}}}}},qH=e=>{const{componentCls:t,iconCls:n,fontSizeLG:r,colorTextLightSolid:o,calc:a}=e,l=`${t}-list`,s=`${l}-item`,c=e.uploadPicCardSize;return{[`
      ${t}-wrapper${t}-picture-card-wrapper,
      ${t}-wrapper${t}-picture-circle-wrapper
    `]:Object.assign(Object.assign({},yr()),{display:"block",[`${t}${t}-select`]:{width:c,height:c,textAlign:"center",verticalAlign:"top",backgroundColor:e.colorFillAlter,border:`${L(e.lineWidth)} dashed ${e.colorBorder}`,borderRadius:e.borderRadiusLG,cursor:"pointer",transition:`border-color ${e.motionDurationSlow}`,[`> ${t}`]:{display:"flex",alignItems:"center",justifyContent:"center",height:"100%",textAlign:"center"},[`&:not(${t}-disabled):hover`]:{borderColor:e.colorPrimary}},[`${l}${l}-picture-card, ${l}${l}-picture-circle`]:{display:"flex",flexWrap:"wrap","@supports not (gap: 1px)":{"& > *":{marginBlockEnd:e.marginXS,marginInlineEnd:e.marginXS}},"@supports (gap: 1px)":{gap:e.marginXS},[`${l}-item-container`]:{display:"inline-block",width:c,height:c,verticalAlign:"top"},"&::after":{display:"none"},"&::before":{display:"none"},[s]:{height:"100%",margin:0,"&::before":{position:"absolute",zIndex:1,width:`calc(100% - ${L(a(e.paddingXS).mul(2).equal())})`,height:`calc(100% - ${L(a(e.paddingXS).mul(2).equal())})`,backgroundColor:e.colorBgMask,opacity:0,transition:`all ${e.motionDurationSlow}`,content:'" "'}},[`${s}:hover`]:{[`&::before, ${s}-actions`]:{opacity:1}},[`${s}-actions`]:{position:"absolute",insetInlineStart:0,zIndex:10,width:"100%",whiteSpace:"nowrap",textAlign:"center",opacity:0,transition:`all ${e.motionDurationSlow}`,[`
            ${n}-eye,
            ${n}-download,
            ${n}-delete
          `]:{zIndex:10,width:r,margin:`0 ${L(e.marginXXS)}`,fontSize:r,cursor:"pointer",transition:`all ${e.motionDurationSlow}`,color:o,"&:hover":{color:o},svg:{verticalAlign:"baseline"}}},[`${s}-thumbnail, ${s}-thumbnail img`]:{position:"static",display:"block",width:"100%",height:"100%",objectFit:"contain"},[`${s}-name`]:{display:"none",textAlign:"center"},[`${s}-file + ${s}-name`]:{position:"absolute",bottom:e.margin,display:"block",width:`calc(100% - ${L(a(e.paddingXS).mul(2).equal())})`},[`${s}-uploading`]:{[`&${s}`]:{backgroundColor:e.colorFillAlter},[`&::before, ${n}-eye, ${n}-download, ${n}-delete`]:{display:"none"}},[`${s}-progress`]:{bottom:e.marginXL,width:`calc(100% - ${L(a(e.paddingXS).mul(2).equal())})`,paddingInlineStart:0}}}),[`${t}-wrapper${t}-picture-circle-wrapper`]:{[`${t}${t}-select`]:{borderRadius:"50%"}}}},UH=e=>{const{componentCls:t}=e;return{[`${t}-rtl`]:{direction:"rtl"}}},XH=e=>{const{componentCls:t,colorTextDisabled:n}=e;return{[`${t}-wrapper`]:Object.assign(Object.assign({},Tt(e)),{[t]:{outline:0,"input[type='file']":{cursor:"pointer"}},[`${t}-select`]:{display:"inline-block"},[`${t}-hidden`]:{display:"none"},[`${t}-disabled`]:{color:n,cursor:"not-allowed"}})}},YH=e=>({actionsColor:e.colorIcon}),QH=It("Upload",e=>{const{fontSizeHeading3:t,fontHeight:n,lineWidth:r,controlHeightLG:o,calc:a}=e,l=yt(e,{uploadThumbnailSize:a(t).mul(2).equal(),uploadProgressOffset:a(a(n).div(2)).add(r).equal(),uploadPicCardSize:a(o).mul(2.55).equal()});return[XH(l),VH(l),GH(l),qH(l),WH(l),KH(l),UH(l),ss(l)]},YH);function Ki(e){return Object.assign(Object.assign({},e),{lastModified:e.lastModified,lastModifiedDate:e.lastModifiedDate,name:e.name,size:e.size,type:e.type,uid:e.uid,percent:0,originFileObj:e})}function Gi(e,t){const n=pe(t),r=n.findIndex(({uid:o})=>o===e.uid);return r===-1?n.push(e):n[r]=e,n}function qc(e,t){const n=e.uid!==void 0?"uid":"name";return t.filter(r=>r[n]===e[n])[0]}function ZH(e,t){const n=e.uid!==void 0?"uid":"name",r=t.filter(o=>o[n]!==e[n]);return r.length===t.length?null:r}const JH=(e="")=>{const t=e.split("/"),r=t[t.length-1].split(/#|\?/)[0];return(/\.[^./\\]*$/.exec(r)||[""])[0]},CS=e=>e.indexOf("image/")===0,eA=e=>{if(e.type&&!e.thumbUrl)return CS(e.type);const t=e.thumbUrl||e.url||"",n=JH(t);return/^data:image\//.test(t)||/(webp|svg|png|gif|jpg|jpeg|jfif|bmp|dpg|ico|heic|heif)$/i.test(n)?!0:!(/^data:/.test(t)||n)},Wr=200;function tA(e){return new Promise(t=>{if(!e.type||!CS(e.type)){t("");return}const n=document.createElement("canvas");n.width=Wr,n.height=Wr,n.style.cssText=`position: fixed; left: 0; top: 0; width: ${Wr}px; height: ${Wr}px; z-index: 9999; display: none;`,document.body.appendChild(n);const r=n.getContext("2d"),o=new Image;if(o.onload=()=>{const{width:a,height:l}=o;let s=Wr,c=Wr,u=0,d=0;a>l?(c=l*(Wr/a),d=-(c-s)/2):(s=a*(Wr/l),u=-(s-c)/2),r.drawImage(o,u,d,s,c);const f=n.toDataURL();document.body.removeChild(n),window.URL.revokeObjectURL(o.src),t(f)},o.crossOrigin="anonymous",e.type.startsWith("image/svg+xml")){const a=new FileReader;a.onload=()=>{a.result&&typeof a.result=="string"&&(o.src=a.result)},a.readAsDataURL(e)}else if(e.type.startsWith("image/gif")){const a=new FileReader;a.onload=()=>{a.result&&t(a.result)},a.readAsDataURL(e)}else o.src=window.URL.createObjectURL(e)})}const nA=i.forwardRef(({prefixCls:e,className:t,style:n,locale:r,listType:o,file:a,items:l,progress:s,iconRender:c,actionIconRender:u,itemRender:d,isImgUrl:f,showPreviewIcon:m,showRemoveIcon:v,showDownloadIcon:g,previewIcon:h,removeIcon:p,downloadIcon:b,extra:y,onPreview:C,onDownload:$,onClose:S},x)=>{var E,O;const{status:w}=a,[I,P]=i.useState(w);i.useEffect(()=>{w!=="removed"&&P(w)},[w]);const[M,R]=i.useState(!1);i.useEffect(()=>{const Y=setTimeout(()=>{R(!0)},300);return()=>{clearTimeout(Y)}},[]);const N=c(a);let T=i.createElement("div",{className:`${e}-icon`},N);if(o==="picture"||o==="picture-card"||o==="picture-circle")if(I==="uploading"||!a.thumbUrl&&!a.url){const Y=A(`${e}-list-item-thumbnail`,{[`${e}-list-item-file`]:I!=="uploading"});T=i.createElement("div",{className:Y},N)}else{const Y=f!=null&&f(a)?i.createElement("img",{src:a.thumbUrl||a.url,alt:a.name,className:`${e}-list-item-image`,crossOrigin:a.crossOrigin}):N,re=A(`${e}-list-item-thumbnail`,{[`${e}-list-item-file`]:f&&!f(a)});T=i.createElement("a",{className:re,onClick:ne=>C(a,ne),href:a.url||a.thumbUrl,target:"_blank",rel:"noopener noreferrer"},Y)}const j=A(`${e}-list-item`,`${e}-list-item-${I}`),z=typeof a.linkProps=="string"?JSON.parse(a.linkProps):a.linkProps,_=(typeof v=="function"?v(a):v)?u((typeof p=="function"?p(a):p)||i.createElement($D,null),()=>S(a),e,r.removeFile,!0):null,B=(typeof g=="function"?g(a):g)&&I==="done"?u((typeof b=="function"?b(a):b)||i.createElement(ED,null),()=>$(a),e,r.downloadFile):null,V=o!=="picture-card"&&o!=="picture-circle"&&i.createElement("span",{key:"download-delete",className:A(`${e}-list-item-actions`,{picture:o==="picture"})},B,_),G=typeof y=="function"?y(a):y,q=G&&i.createElement("span",{className:`${e}-list-item-extra`},G),H=A(`${e}-list-item-name`),W=a.url?i.createElement("a",Object.assign({key:"view",target:"_blank",rel:"noopener noreferrer",className:H,title:a.name},z,{href:a.url,onClick:Y=>C(a,Y)}),a.name,q):i.createElement("span",{key:"view",className:H,onClick:Y=>C(a,Y),title:a.name},a.name,q),K=(typeof m=="function"?m(a):m)&&(a.url||a.thumbUrl)?i.createElement("a",{href:a.url||a.thumbUrl,target:"_blank",rel:"noopener noreferrer",onClick:Y=>C(a,Y),title:r.previewFile},typeof h=="function"?h(a):h||i.createElement(IC,null)):null,U=(o==="picture-card"||o==="picture-circle")&&I!=="uploading"&&i.createElement("span",{className:`${e}-list-item-actions`},K,I==="done"&&B,_),{getPrefixCls:te}=i.useContext(ot),X=te(),ae=i.createElement("div",{className:j},T,W,V,U,M&&i.createElement(En,{motionName:`${X}-fade`,visible:I==="uploading",motionDeadline:2e3},({className:Y})=>{const re="percent"in a?i.createElement(Fz,Object.assign({type:"line",percent:a.percent,"aria-label":a["aria-label"],"aria-labelledby":a["aria-labelledby"]},s)):null;return i.createElement("div",{className:A(`${e}-list-item-progress`,Y)},re)})),le=a.response&&typeof a.response=="string"?a.response:((E=a.error)===null||E===void 0?void 0:E.statusText)||((O=a.error)===null||O===void 0?void 0:O.message)||r.uploadError,ee=I==="error"?i.createElement($r,{title:le,getPopupContainer:Y=>Y.parentNode},ae):ae;return i.createElement("div",{className:A(`${e}-list-item-container`,t),style:n,ref:x},d?d(ee,a,l,{download:$.bind(null,a),preview:C.bind(null,a),remove:S.bind(null,a)}):ee)}),rA=(e,t)=>{const{listType:n="text",previewFile:r=tA,onPreview:o,onDownload:a,onRemove:l,locale:s,iconRender:c,isImageUrl:u=eA,prefixCls:d,items:f=[],showPreviewIcon:m=!0,showRemoveIcon:v=!0,showDownloadIcon:g=!1,removeIcon:h,previewIcon:p,downloadIcon:b,extra:y,progress:C={size:[-1,2],showInfo:!1},appendAction:$,appendActionVisible:S=!0,itemRender:x,disabled:E}=e,O=nf(),[w,I]=i.useState(!1),P=["picture-card","picture-circle"].includes(n);i.useEffect(()=>{n.startsWith("picture")&&(f||[]).forEach(H=>{!(H.originFileObj instanceof File||H.originFileObj instanceof Blob)||H.thumbUrl!==void 0||(H.thumbUrl="",r==null||r(H.originFileObj).then(W=>{H.thumbUrl=W||"",O()}))})},[n,f,r]),i.useEffect(()=>{I(!0)},[]);const M=(H,W)=>{if(o)return W==null||W.preventDefault(),o(H)},R=H=>{typeof a=="function"?a(H):H.url&&window.open(H.url)},N=H=>{l==null||l(H)},T=H=>{if(c)return c(H,n);const W=H.status==="uploading";if(n.startsWith("picture")){const K=n==="picture"?i.createElement(Jr,null):s.uploading,U=u!=null&&u(H)?i.createElement(S_,null):i.createElement(kD,null);return W?K:U}return W?i.createElement(Jr,null):i.createElement(b_,null)},j=(H,W,K,U,te)=>{const X={type:"text",size:"small",title:U,onClick:ae=>{var le,ee;W(),i.isValidElement(H)&&((ee=(le=H.props).onClick)===null||ee===void 0||ee.call(le,ae))},className:`${K}-list-item-action`,disabled:te?E:!1};return i.isValidElement(H)?i.createElement(er,Object.assign({},X,{icon:cn(H,Object.assign(Object.assign({},H.props),{onClick:()=>{}}))})):i.createElement(er,Object.assign({},X),i.createElement("span",null,H))};i.useImperativeHandle(t,()=>({handlePreview:M,handleDownload:R}));const{getPrefixCls:z}=i.useContext(ot),_=z("upload",d),B=z(),V=A(`${_}-list`,`${_}-list-${n}`),G=i.useMemo(()=>Gt(os(B),["onAppearEnd","onEnterEnd","onLeaveEnd"]),[B]),q=Object.assign(Object.assign({},P?{}:G),{motionDeadline:2e3,motionName:`${_}-${P?"animate-inline":"animate"}`,keys:pe(f.map(H=>({key:H.uid,file:H}))),motionAppear:w});return i.createElement("div",{className:V},i.createElement(n0,Object.assign({},q,{component:!1}),({key:H,file:W,className:K,style:U})=>i.createElement(nA,{key:H,locale:s,prefixCls:_,className:K,style:U,file:W,items:f,progress:C,listType:n,isImgUrl:u,showPreviewIcon:m,showRemoveIcon:v,showDownloadIcon:g,removeIcon:h,previewIcon:p,downloadIcon:b,extra:y,iconRender:T,actionIconRender:j,itemRender:x,onPreview:M,onDownload:R,onClose:N})),$&&i.createElement(En,Object.assign({},q,{visible:S,forceRender:!0}),({className:H,style:W})=>cn($,K=>({className:A(K.className,H),style:Object.assign(Object.assign(Object.assign({},W),{pointerEvents:H?"none":void 0}),K.style)}))))},oA=i.forwardRef(rA);var aA=function(e,t,n,r){function o(a){return a instanceof n?a:new n(function(l){l(a)})}return new(n||(n=Promise))(function(a,l){function s(d){try{u(r.next(d))}catch(f){l(f)}}function c(d){try{u(r.throw(d))}catch(f){l(f)}}function u(d){d.done?a(d.value):o(d.value).then(s,c)}u((r=r.apply(e,[])).next())})};const Ba=`__LIST_IGNORE_${Date.now()}__`,iA=(e,t)=>{const n=tn("upload"),{fileList:r,defaultFileList:o,onRemove:a,showUploadList:l=!0,listType:s="text",onPreview:c,onDownload:u,onChange:d,onDrop:f,previewFile:m,disabled:v,locale:g,iconRender:h,isImageUrl:p,progress:b,prefixCls:y,className:C,type:$="select",children:S,style:x,itemRender:E,maxCount:O,data:w={},multiple:I=!1,hasControlInside:P=!0,action:M="",accept:R="",supportServerRender:N=!0,rootClassName:T}=e,j=i.useContext(Ln),z=v??j,_=e.customRequest||n.customRequest,[B,V]=Lt(o||[],{value:r,postState:fe=>fe??[]}),[G,q]=i.useState("drop"),H=i.useRef(null),W=i.useRef(null);i.useMemo(()=>{const fe=Date.now();(r||[]).forEach((ve,xe)=>{!ve.uid&&!Object.isFrozen(ve)&&(ve.uid=`__AUTO__${fe}_${xe}__`)})},[r]);const K=(fe,ve,xe)=>{let Re=pe(ve),it=!1;O===1?Re=Re.slice(-1):O&&(it=Re.length>O,Re=Re.slice(0,O)),Pr.flushSync(()=>{V(Re)});const dt={file:fe,fileList:Re};xe&&(dt.event=xe),(!it||fe.status==="removed"||Re.some(Oe=>Oe.uid===fe.uid))&&Pr.flushSync(()=>{d==null||d(dt)})},U=(fe,ve)=>aA(void 0,void 0,void 0,function*(){const{beforeUpload:xe,transformFile:Re}=e;let it=fe;if(xe){const dt=yield xe(fe,ve);if(dt===!1)return!1;if(delete fe[Ba],dt===Ba)return Object.defineProperty(fe,Ba,{value:!0,configurable:!0}),!1;typeof dt=="object"&&dt&&(it=dt)}return Re&&(it=yield Re(it)),it}),te=fe=>{const ve=fe.filter(it=>!it.file[Ba]);if(!ve.length)return;const xe=ve.map(it=>Ki(it.file));let Re=pe(B);xe.forEach(it=>{Re=Gi(it,Re)}),xe.forEach((it,dt)=>{let Oe=it;if(ve[dt].parsedFile)it.status="uploading";else{const{originFileObj:Le}=it;let Ue;try{Ue=new File([Le],Le.name,{type:Le.type})}catch{Ue=new Blob([Le],{type:Le.type}),Ue.name=Le.name,Ue.lastModifiedDate=new Date,Ue.lastModified=new Date().getTime()}Ue.uid=it.uid,Oe=Ue}K(Oe,Re)})},X=(fe,ve,xe)=>{try{typeof fe=="string"&&(fe=JSON.parse(fe))}catch{}if(!qc(ve,B))return;const Re=Ki(ve);Re.status="done",Re.percent=100,Re.response=fe,Re.xhr=xe;const it=Gi(Re,B);K(Re,it)},ae=(fe,ve)=>{if(!qc(ve,B))return;const xe=Ki(ve);xe.status="uploading",xe.percent=fe.percent;const Re=Gi(xe,B);K(xe,Re,fe)},le=(fe,ve,xe)=>{if(!qc(xe,B))return;const Re=Ki(xe);Re.error=fe,Re.response=ve,Re.status="error";const it=Gi(Re,B);K(Re,it)},ee=fe=>{let ve;Promise.resolve(typeof a=="function"?a(fe):a).then(xe=>{var Re;if(xe===!1)return;const it=ZH(fe,B);it&&(ve=Object.assign(Object.assign({},fe),{status:"removed"}),B==null||B.forEach(dt=>{const Oe=ve.uid!==void 0?"uid":"name";dt[Oe]===ve[Oe]&&!Object.isFrozen(dt)&&(dt.status="removed")}),(Re=H.current)===null||Re===void 0||Re.abort(ve),K(ve,it))})},Y=fe=>{q(fe.type),fe.type==="drop"&&(f==null||f(fe))};i.useImperativeHandle(t,()=>({onBatchStart:te,onSuccess:X,onProgress:ae,onError:le,fileList:B,upload:H.current,nativeElement:W.current}));const{getPrefixCls:re,direction:ne,upload:Z}=i.useContext(ot),Q=re("upload",y),ie=Object.assign(Object.assign({onBatchStart:te,onError:le,onProgress:ae,onSuccess:X},e),{customRequest:_,data:w,multiple:I,action:M,accept:R,supportServerRender:N,prefixCls:Q,disabled:z,beforeUpload:U,onChange:void 0,hasControlInside:P});delete ie.className,delete ie.style,(!S||z)&&delete ie.id;const de=`${Q}-wrapper`,[he,ye,oe]=QH(Q,de),[ce]=Kn("Upload",br.Upload),{showRemoveIcon:ge,showPreviewIcon:se,showDownloadIcon:be,removeIcon:we,previewIcon:Me,downloadIcon:Te,extra:Se}=typeof l=="boolean"?{}:l,Fe=typeof ge>"u"?!z:ge,Ce=(fe,ve)=>l?i.createElement(oA,{prefixCls:Q,listType:s,items:B,previewFile:m,onPreview:c,onDownload:u,onRemove:ee,showRemoveIcon:Fe,showPreviewIcon:se,showDownloadIcon:be,removeIcon:we,previewIcon:Me,downloadIcon:Te,iconRender:h,extra:Se,locale:Object.assign(Object.assign({},ce),g),isImageUrl:p,progress:b,appendAction:fe,appendActionVisible:ve,itemRender:E,disabled:z}):fe,me=A(de,C,T,ye,oe,Z==null?void 0:Z.className,{[`${Q}-rtl`]:ne==="rtl",[`${Q}-picture-card-wrapper`]:s==="picture-card",[`${Q}-picture-circle-wrapper`]:s==="picture-circle"}),$e=Object.assign(Object.assign({},Z==null?void 0:Z.style),x);if($==="drag"){const fe=A(ye,Q,`${Q}-drag`,{[`${Q}-drag-uploading`]:B.some(ve=>ve.status==="uploading"),[`${Q}-drag-hover`]:G==="dragover",[`${Q}-disabled`]:z,[`${Q}-rtl`]:ne==="rtl"});return he(i.createElement("span",{className:me,ref:W},i.createElement("div",{className:fe,style:$e,onDrop:Y,onDragOver:Y,onDragLeave:Y},i.createElement(md,Object.assign({},ie,{ref:H,className:`${Q}-btn`}),i.createElement("div",{className:`${Q}-drag-container`},S))),Ce()))}const Ee=A(Q,`${Q}-select`,{[`${Q}-disabled`]:z,[`${Q}-hidden`]:!S}),Ie=i.createElement("div",{className:Ee,style:$e},i.createElement(md,Object.assign({},ie,{ref:H})));return he(s==="picture-card"||s==="picture-circle"?i.createElement("span",{className:me,ref:W},Ce(Ie,!!S)):i.createElement("span",{className:me,ref:W},Ie,Ce()))},SS=i.forwardRef(iA);var lA=function(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var o=0,r=Object.getOwnPropertySymbols(e);o<r.length;o++)t.indexOf(r[o])<0&&Object.prototype.propertyIsEnumerable.call(e,r[o])&&(n[r[o]]=e[r[o]]);return n};const sA=i.forwardRef((e,t)=>{var{style:n,height:r,hasControlInside:o=!1}=e,a=lA(e,["style","height","hasControlInside"]);return i.createElement(SS,Object.assign({ref:t,hasControlInside:o},a,{type:"drag",style:Object.assign(Object.assign({},n),{height:r})}))}),$S=SS;$S.Dragger=sA;$S.LIST_IGNORE=Ba;export{Vy as $,xw as A,er as B,L2 as C,i8 as D,fA as E,oo as F,dA as G,Pf as H,wi as I,tf as J,_A as K,NA as L,Dr as M,sa as N,TA as O,lf as P,Of as Q,BA as R,EC as S,KL as T,ef as U,OA as V,Hr as W,mA as X,SA as Y,yA as Z,b8 as _,$r as a,gA as a0,bA as a1,DA as a2,Si as a3,hC as a4,bT as a5,$S as a6,cC as a7,PA as a8,Ei as a9,HA as aa,wr as ab,ha as ac,EA as ad,$A as ae,Jt as af,Zt as ag,rB as b,$5 as c,Eo as d,As as e,xA as f,wA as g,RA as h,Ky as i,DC as j,zA as k,K4 as l,hA as m,pA as n,jA as o,oT as p,LA as q,MA as r,Qj as s,vz as t,CA as u,$D as v,lz as w,vA as x,IA as y,IC as z};
